@@ -3,7 +3,7 @@
 **
 **	(c) COPYRIGHT MIT 1995.
 **	Please first read the full copyright statement in the file COPYRIGH.
-**	@(#) $Id: HTAABrow.c,v 2.56 1999/02/22 22:10:10 frystyk Exp $
+**	@(#) $Id: HTAABrow.c,v 2.60 2001/03/14 16:25:50 kahan Exp $
 **
 **	Contains code for parsing challenges and creating credentials for 
 **	basic authentication schemes. See also the HTAAUtil module
@@ -26,6 +26,15 @@
 **	Feb 96 HFN	Rewritten to make it scheme independent and based on
 **			callback functions and an info structure
 **      Nov 98 JKO      Added support for message digest authentication
+**    Jun 2000 JKO      Changed the buffer size for HTUU_encode in order
+**                      to avoid a potential SIGSEV when calling that 
+**                      function (as advised by Heiner Kallweit).
+**    Mar 2001 JKO      When doing pipelining digest requests, the stale
+**                      nonce reply appears only for one of such requests,
+**                      all the following ones in the pipe will receive a 
+**                      401. I added some code to take into account these cases
+**                      by trying to infer if a nonce is stale. 
+**
 */
 
 /* Portions of this code (as indicated) are derived from the Internet Draft
@@ -224,7 +233,7 @@ PRIVATE BOOL basic_credentials (HTRequest * request, HTBasic * basic)
 	char * cipher = NULL;
 	int cl_len = strlen(basic->uid ? basic->uid : "") +
 	    strlen(basic->pw ? basic->pw : "") + 5;
-	int ci_len = 4 * (((cl_len+2)/3) + 1);
+	int ci_len = 5 + 4 * (cl_len/3);
 	if ((cleartext = (char *) HT_CALLOC(1, cl_len)) == NULL)
 	    HT_OUTOFMEM("basic_credentials");
 	*cleartext = '\0';
@@ -537,6 +546,7 @@ PUBLIC int HTDigest_updateInfo (HTRequest *request, HTResponse *response,
 				   HTRequest_anchor(request));
 	    digest = (HTDigest *) HTAA_updateNode (proxy, DIGEST_AUTH, realm, 
 						   url, NULL);
+	    HT_FREE(url);
 	}
 	if (!digest) {
 	    HTTRACE(AUTH_TRACE, "Digest Update.. Error: received authentication-info without having a local digest\n");	
@@ -739,8 +749,15 @@ PRIVATE BOOL digest_credentials (HTRequest * request, HTDigest * digest)
 
 	if (digest->proxy)
 	    uri = HTRequest_proxy(request);
-	else
-	    uri = HTAnchor_address( (HTAnchor*)HTRequest_anchor(request));
+	else {
+	     char * tmp;
+	     /* we get the absolute URL */
+	     tmp = HTAnchor_address( (HTAnchor*)HTRequest_anchor(request));
+	     /* and then remove what makes it absolute, to be backwards
+		compatible */
+	     uri = HTParse (tmp, "", PARSE_PATH | PARSE_PUNCTUATION);
+	     HT_FREE(tmp);
+	}
 
 	/* increment the nonce counter */
 	digest->nc++;
@@ -783,6 +800,8 @@ PRIVATE BOOL digest_credentials (HTRequest * request, HTDigest * digest)
 
 	    HT_FREE(cookie);
 	}
+	if (!digest->proxy)
+	  HT_FREE(uri);
 	HT_FREE(cleartext);
 	return HT_OK;
     }
@@ -834,7 +853,7 @@ PUBLIC int HTDigest_generate (HTRequest * request, void * context, int mode)
 	     prompt_digest_user(request, realm, digest) == HT_OK) ||
 	    (!digest->retry && digest->uid)) {
 	/* @@@ here we should generate a new cnonce value */
-	    digest->cnonce = "012345678";
+	    HTSACopy (&(digest->cnonce), "012345678");
 	    digest->retry = NO;
 	    return digest_credentials(request, digest);
 	} else {
@@ -850,6 +869,27 @@ PUBLIC int HTDigest_generate (HTRequest * request, void * context, int mode)
     return HT_OK;
 }
 
+/*
+**	Evaluates the existing authentication info (nonce, uid, pwd) and
+**      returns TRUE if we evaluate that the nonce is stale, FALSE
+**      otherwise.
+*/
+PRIVATE BOOL nonce_is_stale (HTRequest *request, HTDigest * digest, char * old_nonce)
+{
+  if (!digest->uid || !digest->pw)
+      return FALSE;
+  if (!digest->nonce || !old_nonce)
+     return FALSE;
+  if (strcmp (digest->nonce, old_nonce))
+     return TRUE;
+  /* because of a pipelining implementation bug, we don't send any good
+     credentials on requests following the first one in the pipeline  */
+  if (!HTRequest_credentials (request) && HTRequest_AAretrys (request) == 1)
+     return TRUE;
+  
+  return FALSE;
+}
+
 /*	HTDigest_parse
 **	-------------
 **	This function parses the contents of a "digest" challenge 
@@ -871,6 +911,9 @@ PUBLIC int HTDigest_parse (HTRequest * request, HTResponse * response,
 	char * value = NULL;
 	char * token = NULL;
 	char * uris = NULL;
+	/* the value of the previous nonce in case the server has changed its
+	   challenge */
+	char * old_nonce = NULL;
 
 	/*
 	** If valid challenge then make a template for the resource and
@@ -918,6 +961,8 @@ PUBLIC int HTDigest_parse (HTRequest * request, HTResponse * response,
 	    /* it's an old digest, so we clean all in it except for the
 	       uid and the password, hoping that the server send back
 	       that data */
+	    old_nonce = digest->nonce;
+	    digest->nonce = NULL;
 	    HTDigest_reset (digest);
 	} else {
 	    /* it's a brand new digest */
@@ -949,7 +994,6 @@ PUBLIC int HTDigest_parse (HTRequest * request, HTResponse * response,
 		    /* only true if we already had a digest with uid and pw info */
 		    if (digest->uid && digest->pw) {
 			digest->stale = YES;		
-			digest->retry = NO;
 		    }
 		}
 	    } else if (!strcasecomp(token, "algorithm")) {
@@ -959,14 +1003,33 @@ PUBLIC int HTDigest_parse (HTRequest * request, HTResponse * response,
 		    */
 		    HTTRACE(AUTH_TRACE, "Digest Parse Unknown algorithm `%s\'\n" _ value);
 		    HTDigest_delete(digest);
+		    if (old_nonce)
+		      HT_FREE (old_nonce);
 		    return HT_ERROR;
 		} else
 		    digest->algorithm = HTDaMD5;
 	    }
 	}
-	
-	if (digest->stale)
+
+	/* Pipelining support. If a nonce becomes stale When sending 
+	** several requests thru the pipeline, we may miss the stale
+	** reply in the server's answer. To avoid this, we keep a copy
+	** of the nonce in each request. If the nonce wasn't explicitly
+	** marked stale and if it's the same that we sent, then we 
+	** consider that the uid/pwd pairs were false. Otherwise, we
+	** assume the stole went stale before 
+	*/
+	if (!digest->stale && nonce_is_stale (request, digest, old_nonce))
+	    digest->stale = YES;
+
+	if (old_nonce)
+	  HT_FREE (old_nonce);
+
+	if (digest->stale) {
+	    digest->stale = NO;
+	    digest->retry = NO;
 	    return HT_OK;
+	}
 	else if (digest->uid || digest->pw) {
 	    /*
 	    ** For some reason there was no stale nonce header and the
@@ -1035,17 +1098,3 @@ PUBLIC int HTDigest_parse (HTRequest * request, HTResponse * response,
     HTTRACE(AUTH_TRACE, "Auth........ No challenges found\n");
     return HT_ERROR;
 }
-
-
-
-
-
-
-
-
-
-
-
-
-
-
