@@ -3,13 +3,14 @@
 **
 **	(c) COPYRIGHT MIT 1995.
 **	Please first read the full copyright statement in the file COPYRIGH.
-**	@(#) $Id: HTAccess.c,v 1.155 1999/05/20 19:17:17 frystyk Exp $
+**	@(#) $Id: HTAccess.c,v 1.158 2000/07/11 15:52:30 kahan Exp $
 **
 ** Authors
 **	TBL	Tim Berners-Lee timbl@w3.org
 **	JFG	Jean-Francois Groff jfg@dxcern.cern.ch
 **	DD	Denis DeLaRoca (310) 825-4580  <CSP1DWD@mvs.oac.ucla.edu>
 **	HFN	Henrik Frystyk, frystyk@w3.org
+**      JK      Jose Kahan, kahan@w3.org
 ** History
 **       8 Jun 92 Telnet hopping prohibited as telnet is not secure TBL
 **	26 Jun 92 When over DECnet, suppressed FTP, Gopher and News. JFG
@@ -22,6 +23,8 @@
 **	09 May 94 logfile renamed to HTlogfile to avoid clash with WAIS
 **	 8 Jul 94 Insulate HT_FREE();
 **	   Sep 95 Rewritten, HFN
+**      21 Jun 00 Added a Cache-Control: no-cache when doing PUT, as some
+**                proxies do cache PUT requests, JK
 */
 
 /* Library include files */
@@ -1226,9 +1229,15 @@ PRIVATE int HTSaveFilter (HTRequest * request, HTResponse * response,
 	return HT_ERROR;
 
     } else {
-	HTAnchor_setDocument(me->source, me->placeholder);
-	HTChunk_delete(me->document);
-	HT_FREE(me);
+#if 0
+        /* @@ JK 28/03/2000: invalidated this code as we're doing this exact
+           treatment later on. In addition, it was a source of
+           dangling pointer error  */
+	/* @@ JK: Added it again, because it's now working! */
+#endif
+        HTAnchor_setDocument(me->source, me->placeholder);
+        HTChunk_delete(me->document);
+        HT_FREE(me);
     }
     return HT_OK;
 }
@@ -1319,6 +1328,15 @@ PUBLIC BOOL HTPutDocumentAnchor (HTParentAnchor *	source,
 	    */
 	    HTRequest_setReloadMode(request, HT_CACHE_FLUSH_MEM);
 
+	    /*
+	    **  Some proxy servers don't clean up their cache
+	    **  when receiving a PUT, specially if this PUT is
+	    **  redirected. We remove this problem by adding 
+	    **  an explicit Cache-Control: no-cache header to
+	    **  all PUT requests.
+	    */
+	    HTRequest_addCacheControl(request, "no-cache", "");
+
 	    /*
 	    ** Now we load the source document into a chunk. We specify that
 	    ** we want the document ASIS from the source location. 
