@@ -3,7 +3,7 @@
 **
 **	(c) COPYRIGHT MIT 1995.
 **	Please first read the full copyright statement in the file COPYRIGH.
-**	@(#) $Id: HTCache.c,v 2.66.2.1.2.2 1999/10/22 16:15:52 kahan Exp $
+**	@(#) $Id: HTCache.c,v 2.72.2.1 2001/02/26 15:53:19 kahan Exp $
 **
 **	This modules manages the cache
 **
@@ -184,8 +184,12 @@ PRIVATE BOOL HTCacheGarbage (void)
 		    time_t resident_time = cur_time - pres->response_time;
 		    time_t current_age = pres->corrected_initial_age +
 			resident_time;
-		    if (pres->freshness_lifetime < current_age) {
-			HTCache_remove(pres);
+		    /* 2000-08-08 Jens Meggers: HTCache_remove doesn't
+		       remove a cache entry if it's locked. To avoid
+		       an endless loop, we check the return value of 
+		       HTCache_remove before skipping the entry. */
+		    if ((pres->freshness_lifetime < current_age)
+			&& HTCache_remove(pres)) {
 			cur = old_cur;
 		    } else {
 			old_cur = cur;
@@ -210,8 +214,14 @@ PRIVATE BOOL HTCacheGarbage (void)
 		    HTList * old_cur = cur;
 		    HTCache * pres;
 		    while ((pres = (HTCache *) HTList_nextObject(cur))) {
-			if (pres->size > HTCacheMaxEntrySize || pres->hits <= hits) {
-			    HTCache_remove(pres);
+			/* 2000-08-08 Jens Meggers: HTCache_remove doesn't
+			   remove a cache entry if it's locked. To avoid
+			   going into an endless loop, we check the return
+			   value of  HTCache_remove before marking the
+			   object as removed. */
+			if ((pres->size > HTCacheMaxEntrySize 
+			     || pres->hits <= hits) 
+			    && HTCache_remove(pres)) {
 			    cur = old_cur;
 			    removed = YES;
 			} else {
@@ -798,8 +808,7 @@ PUBLIC BOOL HTCacheTerminate (void)
 	HTNet_deleteAfter(HTCacheCheckFilter);
 
 	/*
-	**  Set a lock on the cache so that multiple users
-	**  don't step on each other.
+	**  Remove the global cache lock.
 	*/
 	HTCache_deleteSingleUserLock(HTCacheRoot);
 
@@ -930,6 +939,19 @@ PUBLIC int HTCacheMode_maxCacheEntrySize (void)
     return HTCacheMaxEntrySize / MEGA;
 }
 
+/*
+** Set the default expiration time. In seconds.
+*/
+PUBLIC void HTCacheMode_setDefaultExpiration (const int exp_time)
+{
+    DefaultExpiration = exp_time;
+}
+
+PUBLIC int HTCacheMode_DefaultExpiration (void)
+{
+    return DefaultExpiration;
+}
+
 /* ------------------------------------------------------------------------- */
 /*  				 CACHE OBJECT				     */
 /* ------------------------------------------------------------------------- */
@@ -1178,7 +1200,7 @@ PUBLIC HTCache * HTCache_touch (HTRequest * request, HTResponse * response,
 PRIVATE int HTCacheFilter (HTRequest * request, void * param, int mode)
 {
     HTParentAnchor * anchor = HTRequest_anchor(request);
-    char *default_name = HTRequest_defaultPutName (request);
+    char * default_name = HTRequest_defaultPutName (request); 
     HTCache * cache = NULL;
     HTReload reload = HTRequest_reloadMode(request);
     HTMethod method = HTRequest_method(request);
@@ -1369,15 +1391,27 @@ PRIVATE int HTCacheCheckFilter (HTRequest * request, HTResponse * response,
 	    char * default_name = HTRequest_defaultPutName(request);
 	    HTCache * cache = HTCache_find(anchor, default_name);
 	    if (cache) {
-	      HTMethod method = HTRequest_method(request);	      
-	      if (status == 204 && method != METHOD_PUT) {
-		/* to avoid cache corruption, we remove all entries
-		   we PUT */
-		HTCache_updateMeta(cache, request, response);
-	      }
-	      else
-		HTCache_remove(cache);
-	    }
+		/* 
+		** If we receive a 204 and the method is unsafe then we have
+		** to delete the cache body but not the header information
+		*/
+		/*
+		** @@ JK: see how to add all the methods here (201, etc.) when
+		** it's a PUT
+		*/
+		if (status == 204) {
+		    HTCache_updateMeta(cache, request, response);
+		    cache->size = 0;
+		    cache->range = YES;
+		    /* @@ JK: update the cache meta data on disk */
+		    HTCache_writeMeta (cache, request, response);
+		    /* @@ JK: and we remove the file name as it's obsolete 
+		       now */
+		    REMOVE(cache->cachename);
+		} else
+		    HTCache_remove(cache);
+	    } 
+	    /* @@  this operation will clear the cache->size and cache_range */
 	    HTCache_touch(request, response, anchor);
 	}
     }
@@ -1433,10 +1467,11 @@ PUBLIC HTCache * HTCache_find (HTParentAnchor * anchor, char * default_name)
 	char * ptr;
 
 	if (default_name)
-	  StrAllocCopy (url, default_name);
-	else
-	  url =  HTAnchor_address((HTAnchor *) anchor);
+	    StrAllocCopy (url, default_name);
+	  else
+	    url = HTAnchor_address((HTAnchor *) anchor);
 	ptr = url;
+
 	for (; *ptr; ptr++)
 	    hash = (int) ((hash * 3 + (*(unsigned char *) ptr)) % HT_XL_HASH_SIZE);
 	if (!CacheTable[hash]) {
@@ -1651,8 +1686,6 @@ PRIVATE BOOL meta_read (FILE * fp, HTRequest * request, HTStream * target)
 	    /* Send the data down the pipe */
 	    status = (*target->isa->put_block)(target, buffer, status);
 
-	    /* Delete the response headers */ 
-	    HTRequest_setResponse(request, NULL);
 	    if (status == HT_LOADED) {
 		(*target->isa->flush)(target);
 		return YES;
@@ -1696,6 +1729,11 @@ PRIVATE BOOL HTCache_readMeta (HTCache * cache, HTRequest * request)
 	    HTResponse_setCachable(HTRequest_response(request), HT_CACHE_ALL);
 	    status = meta_read(fp, request, target);
 	    (*target->isa->_free)(target);
+	    /* JK: 26/Feb/2001: Moved this delete here, as it was causing a
+	       crash condition before. 
+	       We delete the response headers, as they are already available
+	       in the anchor */ 
+	    HTRequest_setResponse(request, NULL);
 	    fclose(fp);
 	    HT_FREE(name);
 	    return status;
@@ -1810,10 +1848,12 @@ PUBLIC HTReload HTCache_isFresh (HTCache * cache, HTRequest * request)
 	}
 
 	/* the cache size is 0 when we want to force the 
-	   revalidation of the cache, for example, after a PUT */
-	if (cache->size == 0) 
-	  return HT_CACHE_FLUSH;
-	
+    	   revalidation of the cache, for example, after a PUT */
+#if 0
+	/* @@ JK: trying the following instruction */
+    	if (cache->size == 0) 
+    	  return HT_CACHE_FLUSH;
+#endif
 	/*
 	**  If we only have a part of this request then make a range request
 	**  using the If-Range condition GET request
@@ -2184,6 +2224,12 @@ PRIVATE int CacheCleanup (HTRequest * req, int status)
         HT_FREE(cache->local);
         HT_FREE(cache);
     }
+
+    /* if the object was cached, we copy the pertinent HTTP headers
+       from the anchor object (where they are stored) to the
+       response object */
+    if (status == HT_NOT_MODIFIED)
+      HTMIME_anchor2response (req);
     HTNet_delete(net, status);
     return YES;
 }
@@ -2318,7 +2364,7 @@ PRIVATE int CacheEvent (SOCKET soc, void * pVoid, HTEventType type)
 	    break;
 
 	case CL_NEED_OPEN_FILE:
-	    status = HTFileOpen(net, cache->local, HT_FT_RDONLY);
+	    status = HTFileOpen(net, cache->local, HT_FB_RDONLY);
 	    if (status == HT_OK) {
 		/*
 		** Create the stream pipe FROM the channel to the application.
