@@ -246,11 +246,11 @@ there is a channel up and running and whether that channel can be reused,
 it must do an explicit connect the the host.
 */
 
-extern int HTHost_connect (HTHost * host, HTNet * net, char * url,
-                           HTProtocolId port);
+extern int HTHost_connect (HTHost * host, HTNet * net, char * url);
 
-extern int HTHost_accept  (HTHost * host, HTNet * net, HTNet ** accepted,
-	                   char * url, HTProtocolId port);
+extern int HTHost_accept  (HTHost * host, HTNet * net, char * url);
+
+extern int HTHost_listen  (HTHost * host, HTNet * net, char * url);
 
 /*
 (
@@ -637,6 +637,6 @@ extern void HTHost_setActivateRequestCallback
 
   
 
-  @(#) $Id: HTHost.html,v 2.28 1999/03/31 19:48:21 frystyk Exp $
+  @(#) $Id: HTHost.html,v 2.29 1999/07/07 15:43:28 frystyk Exp $
 
 */
