@@ -3,7 +3,7 @@
 **
 **	(c) COPYRIGHT MIT 1995.
 **	Please first read the full copyright statement in the file COPYRIGH.
-**	@(#) $Id: HTMIME.c,v 2.97.2.1 1999/10/21 13:18:47 kahan Exp $
+**	@(#) $Id: HTMIME.c,v 2.100 2000/12/13 17:18:36 kahan Exp $
 **
 **	This is RFC 1341-specific code.
 **	The input stream pushed into this parser is assumed to be
@@ -194,7 +194,11 @@ PRIVATE int pumpData (HTStream * me)
 	    HTStream * append = HTStreamStack(WWW_CACHE_APPEND,
 					      me->target_format,
 					      me->target, request, NO);
-            me->target = append;
+	    if (append) me->target = HTTee(me->target, append, NULL);
+#if 0
+	    /* @@ JK: change */
+	    if (append) me->target = append;
+#endif
 	} else if (HTResponse_isCachable(me->response) == HT_CACHE_ALL) {
 	    HTStream * cache = HTStreamStack(WWW_CACHE, me->target_format,
 					     me->target, request, NO);
@@ -228,14 +232,13 @@ PRIVATE int pumpData (HTStream * me)
     return HT_OK;
 }
 
-/* _dispatchParsers - call request's MIME header parser.
-** Use global parser if no appropriate one is found for request.
+/* _dispatchParsers
+ * call request's MIME header parser. Use global parser if no 
+ * appropriate one is found for request.
 */
-PRIVATE int _dispatchParsers (HTStream * me)
+PRIVATE int _dispatchParsers (HTRequest * req, char * token, char * value)
 {
     int status;
-    char * token = HTChunk_data(me->token);
-    char * value = HTChunk_data(me->value);
     BOOL found = NO;
     BOOL local = NO;
     HTMIMEParseSet * parseSet;
@@ -246,30 +249,49 @@ PRIVATE int _dispatchParsers (HTStream * me)
 			      value ? value : "<null>");
     if (!token) return HT_OK;			    /* Ignore noop token */
 
+    /*
+    ** Search the local set of MIME parsers
+    */
+    if ((parseSet = HTRequest_MIMEParseSet(req, &local)) != NULL) {
+        status = HTMIMEParseSet_dispatch(parseSet, req, 
+					 token, value, &found);
+	if (found) return status;
+    }
+
+    /*
+    ** Search the global set of MIME parsers
+    */
+    if (local==NO && (parseSet = HTHeader_MIMEParseSet()) != NULL) {
+	status = HTMIMEParseSet_dispatch(parseSet, req, 
+					 token, value, &found);
+	if (found) return status;
+    }
+
+    return HT_OK;
+}
+
+/* _stream2dispatchParsers - extracts the arguments from a
+ * MIME stream before calling the generic _dispatchParser
+ * function.
+ */
+PRIVATE int _stream2dispatchParsers (HTStream * me)
+{
+    char * token = HTChunk_data(me->token);
+    char * value = HTChunk_data(me->value);
+
+    /* In case we get an empty header consisting of a CRLF, we fall thru */
+    HTTRACE(STREAM_TRACE, "MIME header. %s: %s\n" _ 
+			      token ? token : "<null>" _ 
+			      value ? value : "<null>");
+    if (!token) return HT_OK;			    /* Ignore noop token */
+
     /*
     ** Remember the original header
     */
     HTResponse_addHeader(me->response, token, value);
 
-    /*
-    ** Search the local set of MIME parsers
-    */
-    if ((parseSet = HTRequest_MIMEParseSet(me->request, &local)) != NULL) {
-        status = HTMIMEParseSet_dispatch(parseSet, me->request, 
-					 token, value, &found);
-	if (found) return status;
-    }
-
-    /*
-    ** Search the global set of MIME parsers
-    */
-    if (local==NO && (parseSet = HTHeader_MIMEParseSet()) != NULL) {
-	status = HTMIMEParseSet_dispatch(parseSet, me->request, 
-					 token, value, &found);
-	if (found) return status;
-    }
-
-    return HT_OK;
+    /* call the parsers to set the headers */
+    return (_dispatchParsers (me->request, token, value));
 }
 
 /*
@@ -336,7 +358,7 @@ PRIVATE int HTMIME_put_block (HTStream * me, const char * b, int l)
 		int ret = HT_ERROR;
 		HTChunk_putb(me->value, value, end-value);
 		HTChunk_putc(me->value, '\0');
-		ret = _dispatchParsers(me);
+		ret =  _stream2dispatchParsers(me);
 		HTNet_addBytesRead(me->net, b-start);
 		start=b, end=b;
 		if (me->EOLstate == EOL_END) {		/* EOL_END */
@@ -352,8 +374,8 @@ PRIVATE int HTMIME_put_block (HTStream * me, const char * b, int l)
                         }
 		    }
 	        } else {				/* EOL_LINE */
-		    HTChunk_clear(me->token);
-		    HTChunk_clear(me->value);
+		    HTChunk_truncate(me->token,0);
+		    HTChunk_truncate(me->value,0);
 		    me->haveToken = NO;
 		    me->hash = 0;
 		    value = NULL;
@@ -470,7 +492,7 @@ PRIVATE int HTMIME_free (HTStream * me)
 {
     int status = HT_OK;
     if (!me->transparent)
-        if (_dispatchParsers(me) == HT_OK)
+        if (_stream2dispatchParsers(me) == HT_OK)
 	    pumpData(me);
     if (me->target) {
 	if ((status = (*me->target->isa->_free)(me->target))==HT_WOULD_BLOCK)
@@ -611,9 +633,12 @@ PUBLIC HTStream * HTMIMEFooter (HTRequest *	request,
 PRIVATE int HTCacheLoadFilter (HTRequest * request, void * param, int mode)
 {
     HTParentAnchor * anchor = HTRequest_anchor(request);
-    char *default_name = HTRequest_defaultPutName (request);
+    char * default_name;
+    HTCache * cache;
+
+    default_name = HTRequest_defaultPutName (request);
+    cache = HTCache_find(anchor, default_name);
 
-    HTCache * cache = HTCache_find(anchor, default_name);
     HTTRACE(STREAM_TRACE, "Cache Load.. loading partial cache entry\n");
     if (cache) {
 	char * name = HTCache_name(cache);
@@ -635,7 +660,11 @@ PRIVATE int HTCacheFlushFilter (HTRequest * request, HTResponse * response,
     if (pipe) {
 	HTTRACE(STREAM_TRACE, "Cache Flush. Flushing and freeing PIPE buffer\n");
 	(*pipe->isa->flush)(pipe);
+#if 0
+	/* @@ JK: flush converts the pipe to an open one, we shouldn't
+	   free it as we'll loose our references */
 	(*pipe->isa->_free)(pipe);
+#endif
     }
 
     /*
@@ -688,6 +717,8 @@ PUBLIC HTStream * HTMIMEPartial (HTRequest *	request,
     me->mode |= HT_MIME_PARTIAL;
     me->target = merge;
 
+#if 0
+    /* JK: this doesn't work because this work is repeated before */
     /*
     **  Create the cache append stream, and a Tee stream
     */
@@ -696,6 +727,7 @@ PUBLIC HTStream * HTMIMEPartial (HTRequest *	request,
 					  output_stream, request, NO);
 	if (append) me->target = HTTee(me->target, append, NULL);
     }
+#endif
 
     /*
     **  Create the pipe buffer stream to buffer the data that we read
@@ -747,3 +779,38 @@ PUBLIC HTConverter * HTMIME_saveStream (void)
 {
     return LocalSaveStream;
 }
+
+/* HTMIME_anchor2response
+ * Copies the anchor HTTP headers into a response object by means
+ * of the generic _dispatchParsers function. Written so that we can
+ * copy the HTTP headers stored in the cache to the response object.
+ */
+PUBLIC void HTMIME_anchor2response (HTRequest * req)
+{
+  char * token;
+  char * value;
+  HTAssocList * header;
+  HTAssoc * pres;
+  HTResponse * res;
+  HTParentAnchor * anchor;
+
+  if (!req)
+    return;
+  
+  anchor = HTRequest_anchor (req);
+  header = HTAnchor_header (anchor);
+  while ((pres = (HTAssoc *) HTAssocList_nextObject (header)))
+    {
+      token = HTAssoc_name (pres);
+      value = HTAssoc_value (pres);
+      _dispatchParsers (req, token, value);
+    }
+  
+  /*
+  **  Notify the response object not to delete the lists that we
+  **  have inherited from the anchor object
+  */
+  res = HTRequest_response (req);
+  HTResponse_isCached (res, YES);  
+}
+
