@@ -302,6 +302,9 @@ Return code for socket functions. We can't use -1 as return value
 #define EHOSTDOWN       WSAEHOSTDOWN
 #define EISCONN         WSAEISCONN
 #define EINVAL          WSAEINVAL
+#define ECONNRESET      WSAECONNRESET
+#define ECONNABORTED    WSAECONNABORTED
+#define ESHUTDOWN       WSAESHUTDOWN
 
 /* Some compilers do only define WIN32 and NOT _WINDOWS */
 #define NO_GROUPS
@@ -1465,7 +1468,7 @@ versions of some system calls.
 #endif
 #endif
 
-#define HOSTENT_MAX	128
+#define HOSTENT_MAX	1024
 #define CTIME_MAX	26
 #endif /* HT_REENTRANT */
 
@@ -1488,6 +1491,6 @@ typedef unsigned long ms_t;
 
   
 
-  @(#) $Id: wwwsys.html,v 2.123 1999/03/14 02:22:04 frystyk Exp $
+  @(#) $Id: wwwsys.html,v 2.125 2000/07/11 09:18:38 kahan Exp $
 
 */
