@@ -1,6 +1,6 @@
 /*
  *
- *  (c) COPYRIGHT MIT and INRIA, 1996.
+ *  (c) COPYRIGHT MIT and INRIA, 1996-2001
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
@@ -12,22 +12,21 @@
  * Author: I. Vatton
  *
  */
-
+ 
 /* Included headerfiles */
 #define THOT_EXPORT extern
 #include "amaya.h"
-
+#include "GraphML.h"
 
 #include "init_f.h"
-#if !defined(AMAYA_JAVA) && !defined(AMAYA_ILU)
 #include "query_f.h"
-#endif
 #include "AHTURLTools_f.h"
 #include "EDITimage_f.h"
 #include "EDITORactions_f.h"
 #include "HTMLactions_f.h"
 #include "HTMLedit_f.h"
-
+#include "html2thot_f.h"
+#include "Xml2thot_f.h"
 
 /*----------------------------------------------------------------------
    AddLoadedImage adds a new image into image descriptor table.	
@@ -38,26 +37,18 @@
    For already loaded remote images the function returns the      
    descriptor entry and the value FALSE.                           
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool            AddLoadedImage (STRING name, STRING pathname, Document doc, LoadedImageDesc ** desc)
-#else  /* __STDC__ */
-ThotBool            AddLoadedImage (name, pathname, doc, desc)
-STRING              name;
-STRING              pathname;
-Document            doc;
-LoadedImageDesc   **desc;
-
-#endif /* __STDC__ */
+ThotBool AddLoadedImage (char *name, char *pathname,
+			 Document doc, LoadedImageDesc ** desc)
 {
    LoadedImageDesc    *pImage, *previous, *sameImage;
-   STRING               localname;
+   char               *localname;
 
    *desc = NULL;
    sameImage = NULL;
    if (pathname == NULL || name == NULL)
       return (FALSE);
    else if (IsHTTPPath (pathname))
-     localname = GetLocalPath (doc, pathname);
+     localname = GetLocalPath (doc, pathname); 
    else
       /* it is a local image */
       return (FALSE);		/* nothing to do */
@@ -66,7 +57,7 @@ LoadedImageDesc   **desc;
    previous = NULL;
    while (pImage != NULL)
      {
-	if (ustrcmp (pathname, pImage->originalName) == 0)
+	if (strcmp (pathname, pImage->originalName) == 0)
 	  {
 	     /* image already loaded */
 	     sameImage = pImage;
@@ -93,10 +84,10 @@ LoadedImageDesc   **desc;
 
    /* It is a new loaded image */
    pImage = (LoadedImageDesc *) TtaGetMemory (sizeof (LoadedImageDesc));
-   pImage->originalName = TtaAllocString (ustrlen (pathname) + 1);
-   ustrcpy (pImage->originalName, pathname);
-   pImage->localName = TtaAllocString (ustrlen (localname) + 1);
-   ustrcpy (pImage->localName, localname);
+   pImage->originalName = TtaGetMemory (strlen (pathname) + 1);
+   strcpy (pImage->originalName, pathname);
+   pImage->localName = TtaGetMemory (strlen (localname) + 1);
+   strcpy (pImage->localName, localname);
    pImage->prevImage = previous;
    if (previous != NULL)
       previous->nextImage = pImage;
@@ -113,28 +104,26 @@ LoadedImageDesc   **desc;
 	/* the image file exist for a different document */
 	pImage->status = IMAGE_LOADED;
 	TtaFileCopy (sameImage->localName, pImage->localName);
+	if (sameImage->content_type)
+	  pImage->content_type = TtaStrdup (sameImage->content_type);
+	else
+	  pImage->content_type = NULL;
 	return (FALSE);
      }
    else
      {
 	pImage->status = IMAGE_NOT_LOADED;
+	pImage->content_type = NULL;
 	return (TRUE);
      }
 }
 
-
 /*----------------------------------------------------------------------
    SearchLoadedImage searches the image descriptor of a loaded image using
    its local name.
    The function returns the descriptor entry or NULL.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-LoadedImageDesc    *SearchLoadedImage (STRING localpath, Document doc)
-#else  /* __STDC__ */
-LoadedImageDesc    *SearchLoadedImage (localpath, doc)
-STRING              localpath;
-Document            doc;
-#endif /* __STDC__ */
+LoadedImageDesc    *SearchLoadedImage (char *localpath, Document doc)
 {
   LoadedImageDesc    *pImage;
   
@@ -145,7 +134,7 @@ Document            doc;
       pImage = ImageURLs;
       while (pImage != NULL)
 	{
-	  if (ustrcmp (localpath, pImage->localName) == 0 && 
+	  if (strcmp (localpath, pImage->localName) == 0 && 
 	      ((doc == 0) || (pImage->document == doc)))
 	    /* image found */
 	    return (pImage);
@@ -157,26 +146,44 @@ Document            doc;
   return (NULL);
 }
 
+/*----------------------------------------------------------------------
+   SearchLoadedDocImage searches the image descriptor of a loaded image 
+   using the docImage document id and the URL (there's only one such image
+   per document).
+   The function returns the descriptor entry or NULL.
+  ----------------------------------------------------------------------*/
+LoadedImageDesc    *SearchLoadedDocImage (Document doc, char *url)
+{
+  LoadedImageDesc    *pImage;
+  char               *ptr;
+
+  pImage = ImageURLs;
+  while (pImage != NULL)
+    {
+      if (pImage->document == doc)
+	{
+	  ptr = pImage->originalName + sizeof ("internal:") - 1;
+	  if (!strcmp (ptr, url))
+	    break;
+	}
+      pImage = pImage->nextImage;
+    }
+  return (pImage);
+}
+
 
 /*----------------------------------------------------------------------
    SetAreaCoords computes the coords attribute value from x, y,       
    width and height of the box.                           
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                SetAreaCoords (Document document, Element element, int attrNum)
-#else  /* __STDC__ */
-void                SetAreaCoords (document, element, attrNum)
-Document            document;
-Element             element;
-int                 attrNum;
-#endif /* __STDC__ */
+void SetAreaCoords (Document document, Element element, int attrNum)
 {
    ElementType         elType;
    Element             child, map;
    AttributeType       attrType;
    Attribute           attrCoords, attrX, attrY;
    Attribute           attrW, attrH, attrShape;
-   STRING              text, buffer;
+   char               *text, *buffer;
    int                 x1, y1, x2, y2;
    int                 w, h;
    int                 length, shape, i;
@@ -203,7 +210,7 @@ int                 attrNum;
    shape = TtaGetAttributeValue (attrShape);
    /* prepare the coords string */
    length = 2000;
-   text = TtaAllocString (length);
+   text = TtaGetMemory (length);
    if (shape == HTML_ATTR_shape_VAL_rectangle || shape == HTML_ATTR_shape_VAL_circle)
      {
 	/* Search the x_coord attribute */
@@ -286,7 +293,7 @@ int                 attrNum;
 	      }    
 	  }
 	if (shape == HTML_ATTR_shape_VAL_rectangle)
-	   usprintf (text, TEXT("%d,%d,%d,%d"), x1, y1, x1 + x2, y1 + y2);
+	   sprintf (text, "%d,%d,%d,%d", x1, y1, x1 + x2, y1 + y2);
 	else
 	  {
 	     /* to make a circle, height and width have to be equal */
@@ -311,24 +318,24 @@ int                 attrNum;
 		 h = y2 / 2;
 	       else
 		 h = x2 / 2;
-	     usprintf (text, TEXT("%d,%d,%d"), x1 + h, y1 + h, h);
+	     sprintf (text, "%d,%d,%d", x1 + h, y1 + h, h);
 	  }
      }
    else if (shape == HTML_ATTR_shape_VAL_polygon)
      {
 	child = TtaGetFirstChild (element);
 	length = TtaGetPolylineLength (child);
-	/* keep points */
+	/* get points */
 	i = 1;
-	buffer = TtaAllocString (100);
+	buffer = TtaGetMemory (100);
 	text[0] = EOS;
 	while (i <= length)
 	  {
 	     TtaGivePolylinePoint (child, i, UnPixel, &x1, &y1);
-	     usprintf (buffer, TEXT("%d,%d"), x1, y1);
-	     ustrcat (text, buffer);
+	     sprintf (buffer, "%d,%d", x1, y1);
+	     strcat (text, buffer);
 	     if (i < length)
-	       ustrcat (text, TEXT(","));
+	       strcat (text, ",");
 	     i++;
 	  }
 	TtaFreeMemory (buffer);
@@ -337,6 +344,7 @@ int                 attrNum;
    TtaFreeMemory (text);
 }
 
+
 /*----------------------------------------------------------------------
   UpdateImageMap sets or updates Ref_IMG MAP attributes for the current
   image.
@@ -344,27 +352,21 @@ int                 attrNum;
   oldWidth is -1 or the old image width.
   oldHeight is -1 or the old image height.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                UpdateImageMap (Element image, Document document, int oldWidth, int oldHeight)
-#else  /* __STDC__ */
-void                UpdateImageMap (image, document, oldWidth, oldHeight)
-Element             image;
-Document            document;
-int                 oldWidth;
-int                 oldHeight;
-#endif /* __STDC__ */
+void UpdateImageMap (Element image, Document doc, int oldWidth, int oldHeight)
 {
    AttributeType       attrType;
    Attribute           attr;
    Element             el, child;
-   STRING              text;
+   Element             prev, next, parent;
+   char               *text;
    int                 shape, w, h, length;
    int                 deltax, deltay, val;
    DisplayMode         dispMode;
+   ThotBool            newMap;
 
-   dispMode = TtaGetDisplayMode (document);
+   dispMode = TtaGetDisplayMode (doc);
    /* Search the USEMAP attribute */
-   attrType.AttrSSchema = TtaGetDocumentSSchema (document);
+   attrType.AttrSSchema = TtaGetDocumentSSchema (doc);
    attrType.AttrTypeNum = HTML_ATTR_USEMAP;
    attr = TtaGetAttribute (image, attrType);
    if (attr != NULL)
@@ -372,10 +374,10 @@ int                 oldHeight;
 	/* Search the MAP element associated with IMAGE element */
 	length = TtaGetTextAttributeLength (attr);
 	length++;
-	text = TtaAllocString (length);
+	text = TtaGetMemory (length);
 	TtaGiveTextAttributeValue (attr, text, &length);
 	if (text[0] == '#')
-	   el = SearchNAMEattribute (document, &text[1], NULL);
+	   el = SearchNAMEattribute (doc, &text[1], NULL);
 	else
 	   el = NULL;
 	TtaFreeMemory (text);
@@ -384,22 +386,44 @@ int                 oldHeight;
 
 	/* ask Thot to stop displaying changes made in the document */
         if (dispMode == DisplayImmediately)
-	  TtaSetDisplayMode (document, DeferredDisplay);
+	  TtaSetDisplayMode (doc, DeferredDisplay);
 
 	/* Update MAP attribute */
 	attrType.AttrTypeNum = HTML_ATTR_Ref_IMG;
 	attr = TtaGetAttribute (el, attrType);
-	if (attr == NULL)
+	parent = NULL;
+	prev = el;
+	newMap = (attr == NULL);
+	if (newMap)
 	  {
-	     /* create it */
-	     attr = TtaNewAttribute (attrType);
-	     TtaAttachAttribute (el, attr, document);
+	    /* change the type of the map */
+	    TtaPreviousSibling (&prev);
+	    if (prev == NULL)
+	      {
+		next = el;
+		TtaNextSibling (&next);
+		if (next == NULL)
+		  parent = TtaGetParent (el);
+	      }
+	    
+	    TtaRemoveTree (el, doc);
+	    ChangeElementType (el, HTML_EL_MAP);
+	    /* create the attribute */
+	    attr = TtaNewAttribute (attrType);
+	    TtaAttachAttribute (el, attr, doc);
+	    /* now reinsert the element new map */
+	    if (prev != NULL)
+	      TtaInsertSibling (el, prev, FALSE, doc);
+	    else if (next != NULL)
+	      TtaInsertSibling (el, next, TRUE, doc);
+	    else
+	      TtaInsertFirstChild (&el, parent, doc);
 	  }
-	TtaSetAttributeReference (attr, el, document, image, document);
+	TtaSetAttributeReference (attr, el, doc, image, doc);
 
 	/* Update AREAs attribute */
 	el = TtaGetFirstChild (el);
-	TtaGiveBoxSize (image, document, 1, UnPixel, &w, &h);
+	TtaGiveBoxSize (image, doc, 1, UnPixel, &w, &h);
 	while (el != NULL)
 	  {
 	     /* Search the shape attribute */
@@ -416,14 +440,14 @@ int                 oldHeight;
 			 {
 			    /* create it */
 			    attr = TtaNewAttribute (attrType);
-			    TtaAttachAttribute (el, attr, document);
+			    TtaAttachAttribute (el, attr, doc);
 			 }
-		       TtaSetAttributeReference (attr, el, document, image, document);
+		       TtaSetAttributeReference (attr, el, doc, image, doc);
 		       /* do we need to initialize the polyline limits */
 		       if (oldWidth == -1 && oldHeight == -1)
 			 {
                             child = TtaGetFirstChild (el);
-                            TtaChangeLimitOfPolyline (child, UnPixel, w, h, document);
+                            TtaChangeLimitOfPolyline (child, UnPixel, w, h, doc);
 			 }
 		    }
 		  else if (oldWidth != -1 || oldHeight != -1)
@@ -440,13 +464,13 @@ int                 oldHeight;
 			      attr = TtaGetAttribute (el, attrType);
 			      val = TtaGetAttributeValue (attr);
 			      val = val + (val * deltax / 100);
-			      TtaSetAttributeValue (attr, val, el, document);    
+			      TtaSetAttributeValue (attr, val, el, doc);    
 			      /* Search the width attribute */
 			      attrType.AttrTypeNum = HTML_ATTR_IntWidthPxl;
 			      attr = TtaGetAttribute (el, attrType);
 			      val = TtaGetAttributeValue (attr);
 			      val = val + (val * deltax / 100);
-			      TtaSetAttributeValue (attr, val, el, document);
+			      TtaSetAttributeValue (attr, val, el, doc);
 			    }
 			}
 		      if (oldHeight != -1 && h != 0)
@@ -459,26 +483,26 @@ int                 oldHeight;
 			      attr = TtaGetAttribute (el, attrType);
 			      val = TtaGetAttributeValue (attr);
 			      val = val + (val * deltay / 100);
-			      TtaSetAttributeValue (attr, val, el, document);
+			      TtaSetAttributeValue (attr, val, el, doc);
 			      /* Search the height attribute */
 			      attrType.AttrTypeNum = HTML_ATTR_height_;
 			      attr = TtaGetAttribute (el, attrType);
 			      val = TtaGetAttributeValue (attr);
 			      val = val + (val * deltay / 100);
-			      TtaSetAttributeValue (attr, val, el, document);
+			      TtaSetAttributeValue (attr, val, el, doc);
 			    }
 			}
 
 		      /* update area coords */
 		      if (deltax && deltay)
 			/* both width and height */
-			SetAreaCoords (document, el, 0);
+			SetAreaCoords (doc, el, 0);
 		      else if (deltax)
 			/* only width */
-			SetAreaCoords (document, el, HTML_ATTR_IntWidthPxl);
+			SetAreaCoords (doc, el, HTML_ATTR_IntWidthPxl);
 		      else
 			/* only height */
-			SetAreaCoords (document, el, HTML_ATTR_height_);
+			SetAreaCoords (doc, el, HTML_ATTR_height_);
 		    }
 	       }
 	     TtaNextSibling (&el);
@@ -486,39 +510,81 @@ int                 oldHeight;
      }
 
    /* ask Thot to display changes made in the document */
-   TtaSetDisplayMode (document, dispMode);
+   TtaSetDisplayMode (doc, dispMode);
 }
 
-
 /*----------------------------------------------------------------------
+  DisplayImage
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                DisplayImage (Document doc, Element el, STRING imageName)
-#else  /* __STDC__ */
-void                DisplayImage (doc, el, imageName)
-Document            doc;
-Element             el;
-STRING              imageName;
-#endif /* __STDC__ */
+void DisplayImage (Document doc, Element el, char *imageName, char *mime_type)
 {
   ElementType         elType;
-  int                 modified;
+  int                 modified, i;
+  ThotBool            is_svg;
+  ThotBool            xmlDec, withDoctype, isXML;
+  DocumentType        thotType;
+  int                 parsingLevel;
+  CHARSET             charset;
+  char                charsetname[MAX_LENGTH];
 
   modified = TtaIsDocumentModified (doc);
   elType = TtaGetElementType (el);
-  if (elType.ElTypeNum == HTML_EL_PICTURE_UNIT)
+  if ((elType.ElTypeNum == HTML_EL_PICTURE_UNIT) ||
+      ((elType.ElTypeNum == HTML_EL_Object) &&
+      (strcmp(TtaGetSSchemaName (elType.ElSSchema), "HTML")  == 0)))
     {
-      /* display the content of a picture element */
-      TtaSetTextContent (el, imageName, SPACE, doc);
-      UpdateImageMap (el, doc, -1, -1);
+      /** for the moment, the above function won't identify SVG images.
+	  So, we do the job here.
+	  This block should at some time be integrated with the above one */
+      if (TtaGetPictureType (el) == unknown_type)
+	{
+	  is_svg = FALSE;
+	  if (mime_type)
+	    {
+	      if (!strcmp (mime_type, "image/svg"))
+		is_svg = TRUE;
+	    }
+	  else
+	    {
+	      /* try the file's extension */
+	      for (i = strlen (imageName); i > 0 && imageName[i] != '.'; i--);
+	      if (imageName[i] == '.' && !strcmp (&imageName[i+1], "svg"))
+		is_svg = TRUE;
+	      else /* try sniffing */
+		{
+		  CheckDocHeader (imageName, &xmlDec, &withDoctype, &isXML,
+				  &parsingLevel, &charset, charsetname, &thotType);
+		  if (isXML && thotType == docSVG)
+		    is_svg = TRUE;
+		}
+	    }
+	}
+      else
+	is_svg = FALSE;
+
+      if (is_svg)
+	{
+	  TtaSetPictureType (el, "image/svg");
+	  /* parse the SVG file and include the parsed tree at the
+	     position of the image element */
+	  ParseXmlSubTree (NULL, imageName, el, FALSE,
+				doc, TtaGetDefaultLanguage(), "SVG");
+	}
+      else
+	{
+	  /* svg images don't use Image Maps */
+	  /* display the content of a picture element */
+	  TtaSetPictureContent (el, imageName, SPACE, doc, mime_type);
+	  UpdateImageMap (el, doc, -1, -1);
+	}
     }
   else
     {
-#      ifndef _WINDOWS
-       fprintf(stderr,"Background image !\n");
-#      endif /* _WINDOWS */
       /* create a background image for the element */
       /* set the value */
+#ifndef _WINDOWS
+      fprintf(stderr,"Background image !\n");
+#endif /* _WINDOWS */
     }
   
   /* if the document was not modified before this update reset it unmodified */
@@ -529,34 +595,23 @@ STRING              imageName;
       DocStatusUpdate (doc, modified);
     }
   /* the image is loaded */
-  TtaSetStatus (doc, 1, TEXT(" "), NULL);
+  TtaSetStatus (doc, 1, " ", NULL);
 }
 
-
 /*----------------------------------------------------------------------
    HandleImageLoaded is the callback procedure when the image is loaded	
    		from the web.						
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                HandleImageLoaded (int doc, int status, STRING urlName,
-                                     STRING outputfile, void * context)
-#else  /* __STDC__ */
-void                HandleImageLoaded (doc, status, urlName, outputfile, context)
-int doc;
-int status;
-STRING urlName;
-STRING outputfile;
-void *context;
-
-#endif /* __STDC__ */
+static void HandleImageLoaded (int doc, int status, char *urlName,
+			       char *outputfile,
+			       AHTHeaders *http_headers,
+			       void * context)
 {
-/***
-   STRING              pathname;	***/
-   STRING              tempfile;
    FetchImage_context *FetchImage_ctx;
    LoadedImageDesc    *desc;
-   STRING              base_url;
-   STRING              ptr;
+   char               *tempfile;
+   char               *base_url;
+   char               *ptr;
    ElemImage          *ctxEl, *ctxPrev;
    ElementType         elType;
 
@@ -570,7 +625,7 @@ void *context;
        TtaFreeMemory (FetchImage_ctx);
        
        /* check if this request wasn't aborted */
-       if (ustrcmp (base_url, DocumentURLs[doc]))
+       if (strcmp (base_url, DocumentURLs[doc]))
 	 {
 	   /* it's not the same url, so let's just return */
 	   TtaFreeMemory (base_url);
@@ -581,29 +636,26 @@ void *context;
 	 TtaFreeMemory (base_url);
      }
 
-#if defined(AMAYA_JAVA) || defined(AMAYA_ILU)
-   FilesLoading[doc]--;
-#endif
    if (DocumentURLs[doc] != NULL)
      {
 	/* the image could not be loaded */
 	if ((status != 200) && (status != 0))
 	   return;
-	tempfile = TtaAllocString (MAX_LENGTH);
+	tempfile = TtaGetMemory (MAX_LENGTH);
 	/* rename the local file of the image */
-	ustrcpy (tempfile, desc->localName);
+	strcpy (tempfile, desc->localName);
 	
 	/* If this is an image document, point to the correct files */
 	if (DocumentTypes[doc] == docImage)
 	  {
-	    ptr = ustrrchr (tempfile, '.');
+	    ptr = strrchr (tempfile, '.');
 	    if (ptr) 
 	      {
 		ptr++;
-		ustrcpy (ptr, html_EXT2);
+		strcpy (ptr, "html");
 	      }
 	    else
-	      ustrcat (tempfile, html_EXT);
+	      strcat (tempfile, ".html");
 	    TtaFreeMemory (desc->localName);
 	    desc->localName = TtaStrdup (tempfile);
 
@@ -611,12 +663,12 @@ void *context;
 	else
 	  {
 	    TtaFileUnlink (tempfile);	
-#   ifndef _WINDOWS
+#ifndef _WINDOWS
 	    rename (outputfile, tempfile);
-#   else /* _WINDOWS */
-	    if (urename (outputfile, tempfile) != 0)
-	      usprintf (tempfile, TEXT("%s"), outputfile); 
-#   endif /* _WINDOWS */
+#else /* _WINDOWS */
+	    if (rename (outputfile, tempfile) != 0)
+	      sprintf (tempfile, "%s", outputfile); 
+#endif /* _WINDOWS */
 	  }
 
 	/* save pathname */
@@ -624,23 +676,30 @@ void *context;
 	   the registered name is not the original name
 	   TtaFreeMemory (desc->originalName);
 	   pathname = urlName;
-	   desc->originalName = TtaAllocString (ustrlen (pathname) + 1);
-	   ustrcpy (desc->originalName, pathname);
+	   desc->originalName = TtaGetMemory (strlen (pathname) + 1);
+	   strcpy (desc->originalName, pathname);
 	*/
 	desc->status = IMAGE_LOADED;
 	/* display for each elements in the list */
-	ctxEl = desc->elImage;
+	/* get the mime type if the image was downloaded from the net */
+	ptr = HTTP_headers (http_headers, AM_HTTP_CONTENT_TYPE); 
+	/* memorize the mime type (in case we want to save the file later on) */
+	if (ptr)
+	  desc->content_type = TtaStrdup (ptr);
+ 	ctxEl = desc->elImage;
 	desc->elImage = NULL;
 	while (ctxEl != NULL)
 	  {
 	    elType = TtaGetElementType (ctxEl->currentElement);
+
 	    if (elType.ElTypeNum == HTML_EL_PICTURE_UNIT)
-	      DisplayImage (doc, ctxEl->currentElement, tempfile);
+	      DisplayImage (doc, ctxEl->currentElement, tempfile, ptr);
 	    else if (ctxEl->callback != NULL)
 	      ctxEl->callback(doc, ctxEl->currentElement, tempfile, ctxEl->extra);
 	    /* get image type */
 	    if (desc->imageType == unknown_type)
 	      desc->imageType = TtaGetPictureType (ctxEl->currentElement);
+
 	    ctxPrev = ctxEl;
 	    ctxEl = ctxEl->nextElement;
 	    TtaFreeMemory ( ctxPrev);
@@ -653,32 +712,17 @@ void *context;
    libWWWImageLoaded is the libWWW callback procedure when the image
                 is loaded from the web.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                libWWWImageLoaded (int doc, int status, STRING urlName,
-                                     STRING outputfile, STRING content_type,
-				       void * context)
-#else  /* __STDC__ */
-void                libWWWImageLoaded (doc, status, urlName, outputfile, 
-				       content_type, context)
-int doc;
-int status;
-STRING urlName;
-STRING outputfile;
-STRING content_type;
-void *context;
-
-#endif /* __STDC__ */
+static void     libWWWImageLoaded (int doc, int status, char *urlName,
+				   char *outputfile, AHTHeaders *http_headers,
+				   void * context)
 {
   FetchImage_context *FetchImage_ctx;
 
   if (DocumentURLs[doc] != NULL)
     {
       /* an image of the document is now loaded */
-
-#if !defined(AMAYA_JAVA) && !defined(AMAYA_ILU)
       /* update the stop button status */
       ResetStop (doc);
-#endif /* AMAYA_JAVA */
 
       /* the image could not be loaded */
       if (status != 0)
@@ -696,7 +740,8 @@ void *context;
 	}
 
       /* rename the local file of the image */
-      HandleImageLoaded (doc, status, urlName, outputfile, context);
+      HandleImageLoaded (doc, status, urlName, outputfile, http_headers,
+			 context);
      }
 }
 
@@ -705,16 +750,9 @@ void *context;
    element is an image map and NULL if it is not.          
    The non-null returned string has the form "?X,Y"        
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-STRING              GetActiveImageInfo (Document document, Element element)
-#else  /* __STDC__ */
-STRING              GetActiveImageInfo (document, element)
-Document            document;
-Element             element;
-
-#endif /* __STDC__ */
+char *GetActiveImageInfo (Document document, Element element)
 {
-   STRING              ptr;
+   char               *ptr;
    int                 X, Y;
 
    ptr = NULL;
@@ -731,41 +769,31 @@ Element             element;
        if (Y < 0)
 	 Y = 0;
        /* create the search string to be appended to the URL */
-       ptr = TtaAllocString (27);
-       usprintf (ptr, TEXT("?%d,%d"), X, Y);
+       ptr = TtaGetMemory (27);
+       sprintf (ptr, "?%d,%d", X, Y);
      }
    return ptr;
 }
 
 /*----------------------------------------------------------------------
-   FetchImage loads an IMG from local file or from the web. The flags
+   FetchImage loads an image from local file or from the web. The flags
    may indicate extra transfer parameters, for example bypassing the cache.		
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                FetchImage (Document doc, Element el, STRING URL, int flags,
-                                LoadedImageCallback callback, void *extra)
-#else  /* __STDC__ */
-void                FetchImage (doc, el, URL, flags, callback, extra)
-Document            doc;
-Element             el;
-STRING              URL;
-int                 flags;
-LoadedImageCallback callback;
-void               *extra;
-
-#endif /* __STDC__ */
+void                FetchImage (Document doc, Element el, char *URL, int flags, LoadedImageCallback callback, void *extra)
 {
   ElemImage          *ctxEl;
+  ElementType         elType;
+  Element             elAttr;
   AttributeType       attrType;
   Attribute           attr;
   LoadedImageDesc    *desc;
-  STRING              imageName;
-  CHAR_T                pathname[MAX_LENGTH];
-  CHAR_T                tempfile[MAX_LENGTH];
-  int                 length, i;
+  char               *imageName;
+  char                pathname[MAX_LENGTH];
+  char                tempfile[MAX_LENGTH];
+  int                 length, i, newflags;
   ThotBool            update;
   ThotBool            newImage;
-  FetchImage_context  *FetchImage_ctx;
+  FetchImage_context *FetchImage_ctx;
 
   pathname[0] = EOS;
   tempfile[0] = EOS;
@@ -778,18 +806,29 @@ void               *extra;
       if (URL == NULL)
 	{
 	  /* prepare the attribute to be searched */
-	  attrType.AttrSSchema = TtaGetDocumentSSchema (doc);
-	  attrType.AttrTypeNum = HTML_ATTR_SRC;
-	  attr = TtaGetAttribute (el, attrType);
+	  elType = TtaGetElementType (el);
+	  attrType.AttrSSchema = elType.ElSSchema;
+	  if (strcmp (TtaGetSSchemaName (elType.ElSSchema), "GraphML"))
+	    /* it's not a SVG element, it's then a HTML img element */
+	    {
+	    attrType.AttrTypeNum = HTML_ATTR_SRC;
+	    elAttr = el;
+	    }
+          else
+	    {
+            attrType.AttrTypeNum = GraphML_ATTR_xlink_href;
+	    elAttr = TtaGetParent (el);
+	    }
+	  attr = TtaGetAttribute (elAttr, attrType);
 	  if (attr != NULL)
-	    /* an element with an attribute SRC has been found */
+	    /* an element with an attribute SRC or xlink:href has been found */
 	    {
 	      /* get the attribute value */
 	      length = TtaGetTextAttributeLength (attr);
 	      if (length > 0)
 		{
 		  /* allocate some memory: length of name + 6 cars for noname */
-		  imageName = TtaAllocString (length + 7);
+		  imageName = TtaGetMemory (length + 7);
 		  TtaGiveTextAttributeValue (attr, imageName, &length);
 		}
 	    }
@@ -797,11 +836,24 @@ void               *extra;
       else
 	imageName = URL;
 
-      if (imageName)
+      /* LC 3/7/01 */
+      /* Don't treat the  xlink:href attributes 
+	 that begins with the string  'data' */
+
+      if (imageName &&
+	  (strncmp (imageName, "data", 4) != 0) &&
+	  (strncmp (imageName, "DATA", 4) != 0))
 	{
 	  update = TRUE;
 	  /* add BASE to image name, if necessary */
 	  NormalizeURL (imageName, doc, pathname, imageName, NULL);
+	  /* if it's not a remote URL, make any necessary file: conversions */
+	  if (!IsW3Path (pathname))
+	  {
+	    NormalizeFile (pathname, tempfile, AM_CONV_ALL);
+	    strcpy (pathname, tempfile);
+	    tempfile[0] = EOS;
+	  }
 	  /* is the image already loaded ? */
 	  newImage = AddLoadedImage (imageName, pathname, doc, &desc);
 	  if (newImage)
@@ -820,19 +872,16 @@ void               *extra;
 	      FetchImage_ctx->desc = desc;
 	      FetchImage_ctx->base_url =  TtaStrdup (DocumentURLs[doc]);
 
-#if defined(AMAYA_JAVA) || defined(AMAYA_ILU)
-	      FilesLoading[doc]++;
-	      i = GetObjectWWW (doc, pathname, NULL, tempfile,
-		                AMAYA_ASYNC | flags, NULL, NULL,
-				(void *) libWWWImageLoaded,
-				(void *) FetchImage_ctx, NO, NULL);
-#else /* !AMAYA_JAVA && !AMAYA_ILU */
 	      UpdateTransfer(doc);
+	      if (flags & AMAYA_MBOOK_IMAGE)
+		newflags = flags | AMAYA_SYNC;
+	      else
+		newflags = flags | AMAYA_ASYNC;
+
 	      i = GetObjectWWW (doc, pathname, NULL, tempfile,
-	                        AMAYA_ASYNC | flags, NULL, NULL,
+	                        newflags, NULL, NULL,
 				(void *) libWWWImageLoaded,
 				(void *) FetchImage_ctx, NO, NULL);
-#endif /* !AMAYA_JAVA && !AMAYA_ILU */
 	      if (i != -1) 
 		desc->status = IMAGE_LOADED;
 	      else
@@ -847,17 +896,17 @@ void               *extra;
 	    {
 	      if (desc == NULL)
 		{
-		  /* it is a local image */
+		/* it is a local image */
 		if (callback)
 		  {
-		    if (!ustrncmp(pathname, TEXT("file:/"), 6))
+		    if (!strncmp(pathname, "file:/", 6))
 		      callback(doc, el, &pathname[6], extra);
 		    else
 		      callback(doc, el, &pathname[0], extra);
 		  }
 		else
-		  DisplayImage (doc, el, pathname);
-	      }
+		  DisplayImage (doc, el, pathname, NULL);
+		}
 	      else
 		if (TtaFileExist (desc->localName))
 		  {
@@ -865,7 +914,7 @@ void               *extra;
 		    if (callback)
 		      callback (doc, el, desc->localName, extra);
 		    else
-		      DisplayImage (doc, el, desc->localName);
+		      DisplayImage (doc, el, desc->localName, NULL);
 		    /* get image type */
 		    desc->imageType = TtaGetPictureType (el);
 		  }
@@ -899,87 +948,156 @@ void               *extra;
    FetchAndDisplayImages   fetch and display all images referred   
    by document doc. The flags may indicate extra transfer parameters,
    for example bypassing the cache.
+   elSubTree indicates we ara paring an external SVG image
    Returns TRUE if the the transfer succeeds without being stopped;
    Otherwise, returns FALSE.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool            FetchAndDisplayImages (Document doc, int flags)
-#else  /* __STDC__ */
-ThotBool            FetchAndDisplayImages (doc, flags)
-Document            doc;
-int                 flags;
-
-#endif /* __STDC__ */
+ThotBool FetchAndDisplayImages (Document doc, int flags, Element elSubTree)
 {
    AttributeType       attrType;
-   Attribute           attr;
-   Element             el, elFound;
+   Attribute           attr, attrFound;
    ElementType         elType;
-   STRING              currentURL;
+   Element             el, elFound, pic, elNext;
+   char               *currentURL, *imageURI;
+   int                 length;
    ThotBool            stopped_flag;
 
-#if defined(AMAYA_JAVA) || defined(AMAYA_ILU)
-   if (FilesLoading[doc] == 0)
-     {
-#else 
    /* JK: verify if StopTransfer was previously called */
    if (W3Loading == doc || DocNetworkStatus[doc] & AMAYA_NET_INACTIVE)
      {
        /* transfer interrupted */
        TtaSetStatus (doc, 1, TtaGetMessage (AMAYA, AM_LOAD_ABORT), NULL);
        DocNetworkStatus[doc] |= AMAYA_NET_ERROR;
-#endif  /* AMAYA_JAVA || AMAYA_ILU */
        return FALSE;
      }
    else if (DocumentTypes[doc] == docText ||
-	    DocumentTypes[doc] == docTextRO ||
-	    DocumentTypes[doc] == docCSS ||
-	    DocumentTypes[doc] == docCSSRO)
+	    DocumentTypes[doc] == docCSS)
      return FALSE;
 
    /* register the current URL */
    currentURL = TtaStrdup (DocumentURLs[doc]);
-   /* get the root element */
-   el = TtaGetMainRoot (doc);
-   /* prepare the type of element to be searched */
-   elType = TtaGetElementType (el);
-   /* prepare the attribute to be searched */
-   attrType.AttrSSchema = elType.ElSSchema;
-   attrType.AttrTypeNum = HTML_ATTR_SRC;
-#if !defined(AMAYA_JAVA) && !defined(AMAYA_ILU)
+
    /* We are currently fetching images for this document */
    /* during this time LoadImage has not to stop transfer */
-#endif
-   /* search all elements having an attribute SRC */
-   do
+   /* prepare the attribute to be searched */
+   attrType.AttrSSchema = TtaGetSSchema ("HTML", doc);
+   if (attrType.AttrSSchema)
+     /* there are some HTML elements in this documents. 
+	Get all 'img' or 'object' elements */
      {
-	TtaHandlePendingEvents ();
-	/* verify if StopTransfer was called */
-	if (DocumentURLs[doc] == NULL || ustrcmp (currentURL, DocumentURLs[doc]))
-	    /* the document has been removed */
-	    break;
+       /* search all elements having an attribute SRC */
+       attrType.AttrTypeNum = HTML_ATTR_SRC;
+       /* Start from the root element */
+       if (elSubTree == NULL)
+	 {
+	   el = TtaGetMainRoot (doc);
+	   TtaSearchAttribute (attrType, SearchForward,
+			       el, &elFound, &attr);
+	 }
+       else
+	 TtaSearchAttribute (attrType, SearchInTree,
+			     elSubTree, &elFound, &attr);
+       el = elFound;
+       do
+	 {
+	   TtaHandlePendingEvents ();
+	   /* verify if StopTransfer was called */
+	   if (DocumentURLs[doc] == NULL ||
+	       strcmp (currentURL, DocumentURLs[doc]))
+	     /* the document has been removed */
+	     break;
+	   
+	   if (W3Loading == doc || DocNetworkStatus[doc] & AMAYA_NET_INACTIVE)
+	     break;
 
-#if !defined(AMAYA_JAVA) && !defined(AMAYA_ILU)
-	if (W3Loading == doc || DocNetworkStatus[doc] & AMAYA_NET_INACTIVE)
-	    break;
-#endif
-	/* search the next element having an attribute SRC */
-	TtaSearchAttribute (attrType, SearchForward, el, &elFound, &attr);
-	el = elFound;
-	/* FetchImage increments FilesLoading[doc] for each new get request */
-	if (el != NULL)
-	    FetchImage (doc, el, NULL, flags, NULL, NULL);
+	   /* FetchImage increments FilesLoading[doc] for
+	      each new get request */
+	   if (el != NULL)
+	     {
+	       /* search the next element having an attribute SRC */
+	       elNext = el;
+	       if (elSubTree == NULL)
+		 TtaSearchAttribute (attrType, SearchForward,
+				     elNext, &elFound, &attr);
+	       if (elSubTree != NULL && elFound != NULL &&
+		   !TtaIsAncestor (elFound, elSubTree))
+		 elFound = NULL;
+	       FetchImage (doc, el, NULL, flags, NULL, NULL);
+	       el = elFound;
+	     }
+	 }
+       while (el);
      }
-   while (el != NULL);
 
-#if !defined(AMAYA_JAVA) && !defined(AMAYA_ILU)
+   /* Now, load all SVG images */
+   /* prepare the attribute to be searched */
+   attrType.AttrSSchema = TtaGetSSchema ("GraphML", doc);
+   if (attrType.AttrSSchema)
+     {
+       attrType.AttrTypeNum = GraphML_ATTR_xlink_href;
+       /* Search the next element having an attribute xlink_href */
+       /* Start from the root element */
+       if (elSubTree == NULL)
+	 {
+	   el = TtaGetMainRoot (doc);
+	   TtaSearchAttribute (attrType, SearchForward,
+			       el, &elFound, &attrFound);
+	 }
+       else
+	 TtaSearchAttribute (attrType, SearchInTree,
+			     elSubTree, &elFound, &attrFound);
+       attr = attrFound;
+       el = elFound;
+       do
+	 {
+	   TtaHandlePendingEvents ();
+	   /* verify if StopTransfer was called */
+	   if (DocumentURLs[doc] == NULL ||
+	       strcmp (currentURL, DocumentURLs[doc]))
+	     /* the document has been removed */
+	     break;
+	   
+	   if (W3Loading == doc || DocNetworkStatus[doc] & AMAYA_NET_INACTIVE)
+	     break;
+	   
+	   /* FetchImage increments FilesLoading[doc] for each new get request */
+	   if (el != NULL)
+	     {
+	       /* search the next element having an attribute xlink_href */
+	       TtaSearchAttribute (attrType, SearchForward,
+				   el, &elFound, &attrFound);
+	       if (elSubTree != NULL && elFound != NULL &&
+		   !TtaIsAncestor (elFound, elSubTree))
+		 elFound = NULL;
+
+	       /* get the PICTURE_UNIT element within the image element */
+	       elType = TtaGetElementType (el);
+	       elType.ElTypeNum = GraphML_EL_PICTURE_UNIT;
+	       pic = TtaSearchTypedElement (elType, SearchInTree, el);
+	       if (pic)
+		 {
+		   /* get the attribute value */
+		   length = TtaGetTextAttributeLength (attr);
+		   if (length > 0)
+		     {
+		       /* allocate some memory */
+		       imageURI = TtaGetMemory (length + 7);
+		       TtaGiveTextAttributeValue (attr, imageURI, &length);
+		       FetchImage (doc, pic, imageURI, flags, NULL, NULL);
+		       TtaFreeMemory (imageURI);
+		     }
+		 }
+	       el = elFound;
+	       attr = attrFound;
+	     }
+	 }
+       while (el);
+     }
+   
    if (W3Loading != doc)
        stopped_flag = FALSE;
    else
      stopped_flag = TRUE;
-#else
-   stopped_flag = FALSE;
-#endif
 
    /* Images fetching is now finished */
    TtaFreeMemory (currentURL);
