@@ -1,6 +1,6 @@
 /*
  *
- *  (c) COPYRIGHT MIT and INRIA, 1996.
+ *  (c) COPYRIGHT MIT and INRIA, 1996-2001
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
@@ -22,9 +22,7 @@
 
 #include "css_f.h"
 #include "init_f.h"
-#if !defined(AMAYA_JAVA) && !defined(AMAYA_ILU)
 #include "query_f.h"
-#endif
 #include "AHTURLTools_f.h"
 #include "UIcss_f.h"
 #include "styleparser_f.h"
@@ -35,14 +33,7 @@
   the document doc and the structure sSchema
   At the same time, this funciton updates the css context.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-PSchema         GetPExtension (Document doc, SSchema sSchema, CSSInfoPtr css)
-#else
-PSchema         GetPExtension (doc, sSchema, css)
-Document        doc;
-SSchema         sSchema;
-CSSInfoPtr      css;
-#endif
+PSchema GetPExtension (Document doc, SSchema sSchema, CSSInfoPtr css)
 {
   CSSInfoPtr          oldcss;
   PInfoPtr            pInfo;
@@ -52,13 +43,14 @@ CSSInfoPtr      css;
   ElementType	      elType;
   AttributeType       attrType;
   Attribute           attr;
-  CHAR_T              buffer[MAX_LENGTH];
+  char              buffer[MAX_LENGTH];
   int                 length;
   ThotBool            found, before;
 
   if (sSchema == NULL)
     sSchema = TtaGetDocumentSSchema (doc);
   pInfo = css->infos;
+  nextLink = NULL;
   found = FALSE;
   pIS = NULL;
   while (pInfo != NULL && !found)
@@ -151,7 +143,7 @@ CSSInfoPtr      css;
 		      /* get a buffer for the attribute value */
 		      length = MAX_LENGTH;
 		      TtaGiveTextAttributeValue (attr, buffer, &length);
-		      found = (!ustrcasecmp (buffer, TEXT("STYLESHEET")) || !ustrcasecmp (buffer, TEXT("STYLE")));
+		      found = (!strcasecmp (buffer, "STYLESHEET") || !strcasecmp (buffer, "STYLE"));
 		    }
 		  if (found)
 		    {
@@ -193,55 +185,57 @@ CSSInfoPtr      css;
 		    }
 		}
 	    }
-
-	  /* look for the next link with rel="STYLESHEET" */
-	  nextLink = pInfo->PiLink;
-	  while (!found && nextLink != NULL)
+	  if (pInfo)
 	    {
-	      nextLink = TtaSearchTypedElementInTree (elType, SearchForward, parent, nextLink);
-	      if (nextLink)
+	      /* look for the next link with rel="STYLESHEET" */
+	      nextLink = pInfo->PiLink;
+	      while (!found && nextLink != NULL)
 		{
-		  attr = TtaGetAttribute (nextLink, attrType);
-		  if (attr != 0)
+		  nextLink = TtaSearchTypedElementInTree (elType, SearchForward, parent, nextLink);
+		  if (nextLink)
 		    {
-		      /* get a buffer for the attribute value */
-		      length = MAX_LENGTH;
-		      TtaGiveTextAttributeValue (attr, buffer, &length);
-		      found = (!ustrcasecmp (buffer, TEXT("STYLESHEET")) || !ustrcasecmp (buffer, TEXT("STYLE")));
-		    }
-		  /* search if the previous CSS has a presentation schema */
-		  if (found)
-		    {
-		      /* there is another linked CSS style sheet after */
-		      oldcss = CSSList;
-		      while (oldcss != NULL)
+		      attr = TtaGetAttribute (nextLink, attrType);
+		      if (attr != 0)
 			{
-			  if (oldcss != css && oldcss->documents[doc] &&
-			      oldcss->category == CSS_EXTERNAL_STYLE)
+			  /* get a buffer for the attribute value */
+			  length = MAX_LENGTH;
+			  TtaGiveTextAttributeValue (attr, buffer, &length);
+			  found = (!strcasecmp (buffer, "STYLESHEET") || !strcasecmp (buffer, "STYLE"));
+			}
+		      /* search if the previous CSS has a presentation schema */
+		      if (found)
+			{
+			  /* there is another linked CSS style sheet after */
+			  oldcss = CSSList;
+			  while (oldcss != NULL)
 			    {
-			      /* check if it includes a presentation schema
-				 for that structure */
-			      pInfo = oldcss->infos;
-			      while (pInfo != NULL && pInfo->PiDoc != doc)
-				pInfo = pInfo->PiNext;
-			      if (pInfo != NULL && pInfo->PiLink == nextLink)
+			      if (oldcss != css && oldcss->documents[doc] &&
+				  oldcss->category == CSS_EXTERNAL_STYLE)
 				{
-				  pIS = pInfo->PiSchemas;
-				  while (pIS && pIS->PiSSchema != sSchema)
-				    pIS = pIS->PiSNext;
-				  if (pIS && pIS->PiPSchema)
+				  /* check if it includes a presentation schema
+				     for that structure */
+				  pInfo = oldcss->infos;
+				  while (pInfo != NULL && pInfo->PiDoc != doc)
+				    pInfo = pInfo->PiNext;
+				  if (pInfo != NULL && pInfo->PiLink == nextLink)
 				    {
-				      /* link before that presentation schema */
-				      before = TRUE;
-				      prevS = pIS->PiPSchema;
+				      pIS = pInfo->PiSchemas;
+				      while (pIS && pIS->PiSSchema != sSchema)
+					pIS = pIS->PiSNext;
+				      if (pIS && pIS->PiPSchema)
+					{
+					  /* link before that presentation schema */
+					  before = TRUE;
+					  prevS = pIS->PiPSchema;
+					}
+				      else
+					found = FALSE;
 				    }
-				  else
-				    found = FALSE;
+				  oldcss = NULL;
 				}
-			      oldcss = NULL;
+			      else
+				oldcss = oldcss->NextCSS;
 			    }
-			  else
-			    oldcss = oldcss->NextCSS;
 			}
 		    }
 		}
@@ -274,7 +268,11 @@ CSSInfoPtr      css;
 				prevS = pIS->PiPSchema;
 				before = FALSE;
 			      }
+			    else
+			      oldcss = oldcss->NextCSS;
 			  }
+			else
+			  oldcss = oldcss->NextCSS;
 		      }
 		    else if (oldcss->category == CSS_DOCUMENT_STYLE)
 		      {
@@ -321,16 +319,8 @@ CSSInfoPtr      css;
 /*----------------------------------------------------------------------
    AddCSS adds a new CSS context in the list.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-CSSInfoPtr      AddCSS (Document doc, Document docRef, CSSCategory category, STRING url, STRING localName)
-#else
-CSSInfoPtr      AddCSS (doc, docRef, category, url, localName)
-Document        doc;
-Document        docRef;
-CSSCategory     category;
-STRING          url;
-STRING          localName;
-#endif
+CSSInfoPtr AddCSS (Document doc, Document docRef, CSSCategory category,
+		   char *url, char *localName)
 {
   CSSInfoPtr          css, prev;
   int                 i;
@@ -374,20 +364,14 @@ STRING          localName;
    SearchCSS searchs the css corresponding to the specific url (doc == 0)
    or the CSS_DOCUMENT_STYLE css of the document.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-CSSInfoPtr          SearchCSS (Document doc, STRING url)
-#else
-CSSInfoPtr          SearchCSS (doc, url)
-Document            doc;
-STRING               url;
-#endif
+CSSInfoPtr SearchCSS (Document doc, char *url)
 {
   CSSInfoPtr          css = CSSList;
  
   while (css != NULL)
     {
-      if (url && ((css->url && !ustrcmp (url, css->url)) ||
-		  (css->localName && !ustrcmp (url, css->localName))))
+      if (url && ((css->url && !strcmp (url, css->url)) ||
+		  (css->localName && !strcmp (url, css->localName))))
 	/* an external CSS */
 	return css;
       else if (doc != 0 && css->doc == doc)
@@ -406,14 +390,8 @@ STRING               url;
    If this CSS is no longer used the context and attached information
    are freed.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void     UnlinkCSS (CSSInfoPtr css, Document doc, ThotBool removed)
-#else
-static void     UnlinkCSS (css, doc, removed)
-CSSInfoPtr      css;
-Document        doc;
-ThotBool        removed;
-#endif
+static void UnlinkCSS (CSSInfoPtr css, Document doc, ThotBool disabled,
+		       ThotBool removed)
 {
   CSSInfoPtr          prev;
   PInfoPtr            pInfo, prevInfo;
@@ -457,8 +435,7 @@ ThotBool        removed;
 		    /* remove presentation schemas */
 		    TtaRemovePSchema (pIS->PiPSchema, pInfo->PiDoc, pIS->PiSSchema);
 		    pInfo->PiSchemas = pIS->PiSNext;
-		    if (removed)
-		      TtaFreeMemory (pIS);
+		    TtaFreeMemory (pIS);
 		  }
 	      }
 	  /* free the document context */
@@ -467,7 +444,8 @@ ThotBool        removed;
 	}
 
       /* the CSS is no longer applied */
-      css->enabled[doc] = FALSE;
+      if (disabled)
+	css->enabled[doc] = FALSE;
       /* look at if this css is alway used */
       used = (css->doc != 0);
       i = 0;
@@ -501,15 +479,10 @@ ThotBool        removed;
 /*----------------------------------------------------------------------
    RemoveDocCSSs removes all CSS information linked with the document.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                RemoveDocCSSs (Document doc)
-#else
-void                RemoveDocCSSs (doc)
-Document            doc;
-#endif
+void RemoveDocCSSs (Document doc)
 {
   CSSInfoPtr          css, next;
-
+ 
   css = CSSList;
   while (css != NULL)
     {
@@ -518,10 +491,10 @@ Document            doc;
 	{
 	  /* the document displays the CSS file itself */
 	  css->doc = 0;
-	  UnlinkCSS (css, doc, TRUE);
+	  UnlinkCSS (css, doc, TRUE, TRUE);
 	}
       else if (css->documents[doc])
-	UnlinkCSS (css, doc, TRUE);
+	UnlinkCSS (css, doc, TRUE, TRUE);
       /* look at the next CSS context */
       css = next;
     }
@@ -532,14 +505,8 @@ Document            doc;
    It could be an external CSS file linked with the document (url not NULL)
    or the document Style element.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void            RemoveStyleSheet (STRING url, Document doc, ThotBool removed)
-#else
-void            RemoveStyleSheet (url, doc, removed)
-STRING          url;
-Document        doc;
-ThotBool        removed;
-#endif
+void  RemoveStyleSheet (char *url, Document doc, ThotBool disabled,
+			ThotBool removed)
 {
   CSSInfoPtr          css;
   ThotBool            found;
@@ -548,18 +515,19 @@ ThotBool        removed;
   found = FALSE;
   while (css != NULL && !found)
     {
-      if (url && ((css->url && !ustrcmp (url, css->url)) ||
-		  (css->localName && !ustrcmp (url, css->localName))))
+      if (url && ((css->url && !strcmp (url, css->url)) ||
+		  (css->localName && !strcmp (url, css->localName))))
 	/* an external CSS */
 	found = TRUE;
-      else if (!url && css->category == CSS_DOCUMENT_STYLE && css->documents[doc])
+      else if (!url && css->category == CSS_DOCUMENT_STYLE &&
+	       css->documents[doc])
 	found = TRUE;
       else
 	css = css->NextCSS;
     }
 
   if (css != NULL)
-    UnlinkCSS (css, doc, removed);
+    UnlinkCSS (css, doc, disabled, removed);
 }
 
 
@@ -568,17 +536,12 @@ ThotBool        removed;
   style element el. It returns NULL if the element is empty.
   The buffer should be freed by the caller.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-STRING              GetStyleContents (Element el)
-#else
-STRING              GetStyleContents (el)
-Element             el;
-#endif
+char *GetStyleContents (Element el)
 {
   ElementType         elType;
   Element             text;
   Language            lang;
-  STRING              buffer;
+  char               *buffer;
   int                 length, i, j;
 
   buffer = NULL;
@@ -586,7 +549,7 @@ Element             el;
   if (length > 1)
     {
       /* get the length of the included text */
-      buffer = TtaAllocString (length);
+      buffer = TtaGetMemory (length);
 
       /* fill the buffer */
       elType = TtaGetElementType (el);
@@ -606,31 +569,26 @@ Element             el;
 }
 
 /*----------------------------------------------------------------------
-   LoadStyleSheet loads the external Style Sheet found at the given
-   url.
-   The parameter el gives the element which links the CSS or NULL.
-   The parameter CSS gives the CSS context which imports this CSS file.
+  LoadStyleSheet loads the external Style Sheet found at the given url.
+  The parameter el gives the element which links the CSS or NULL.
+  The parameter css gives the CSS context which imports this CSS file.
+  The parameter media gives the application limits of the CSS.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                LoadStyleSheet (STRING url, Document doc, Element el, CSSInfoPtr css)
-#else
-void                LoadStyleSheet (url, doc, el, css)
-STRING              url;
-Document            doc;
-Element             el;
-CSSInfoPtr          css;
-#endif
+void LoadStyleSheet (char *url, Document doc, Element el, CSSInfoPtr css,
+		     CSSmedia media)
 {
   CSSInfoPtr          oldcss;
   PInfoPtr            pInfo;
   struct stat         buf;
   FILE               *res;
-  CHAR_T              tempfile[MAX_LENGTH];
-  CHAR_T              tempURL[MAX_LENGTH];
-  STRING              buffer = NULL;
+  char                tempfile[MAX_LENGTH];
+  char                tempURL[MAX_LENGTH];
+  char               *tmpBuff;
   int                 len;
-  ThotBool            import = (css != NULL);
+  ThotBool            import, printing;
 
+  import = (css != NULL);
+  printing = TtaIsPrinting ();
   if (TtaGetViewFrame (doc, 1) != 0 || TtaIsPrinting ())
     {
       LoadRemoteStyleSheet (url, doc, el, css, tempURL, tempfile);
@@ -642,15 +600,33 @@ CSSInfoPtr          css;
 	    /* It's a new CSS file: allocate a new Presentation structure */
 	    css = AddCSS (0, doc, CSS_EXTERNAL_STYLE, tempURL, tempfile);
 	  oldcss = css;
+	  oldcss->media[doc] = media;
 	}
-      else
+      else if (!oldcss->documents[doc])
 	{
+	  /* we have to apply the style sheet to this document */
 	  oldcss->documents[doc] = TRUE;
 	  oldcss->enabled[doc] = TRUE;
+	  /* update the current media value */
+	  if (media == CSS_ALL)
+	    oldcss->media[doc] = media;
+	  else if (oldcss->media[doc] != media ||
+		   oldcss->media[doc] != CSS_ALL)
+	    if ((printing && media == CSS_PRINT) ||
+		(!printing && media == CSS_SCREEN))
+		oldcss->media[doc] = media;
 	}
 
       if (tempfile[0] == EOS)
+	/* cannot do more */
 	return;
+      else if (media == CSS_OTHER ||
+	       (!printing && media == CSS_PRINT) ||
+	       (printing && media == CSS_SCREEN) ||
+	       !oldcss->enabled[doc])
+	/* nothing more to do */
+	return;
+
       /* store the element which links the CSS */
       pInfo = oldcss->infos;
       while (pInfo != NULL && pInfo->PiDoc != doc)
@@ -690,26 +666,26 @@ CSSInfoPtr          css;
 		return;
 	      }
 
-	  buffer = TtaAllocString (buf.st_size + 1000);
-	  if (buffer == NULL)
+	  tmpBuff = TtaGetMemory (buf.st_size + 1000);
+	  if (tmpBuff == NULL)
 	    {
 	      TtaSetStatus (doc, 1, TtaGetMessage (AMAYA, AM_CANNOT_LOAD), tempURL);
 	      fclose (res);
 	      return;
 	    }
-	  len = fread (buffer, buf.st_size, 1, res);
+	  len = fread (tmpBuff, buf.st_size, 1, res);
 	  if (len != 1)
 	    {
 	      TtaSetStatus (doc, 1, TtaGetMessage (AMAYA, AM_CANNOT_LOAD), tempURL);
 	      fclose (res);
-	      TtaFreeMemory (buffer);
+	      TtaFreeMemory (tmpBuff);
 	      return;
 	    }
-	  buffer[buf.st_size] = 0;
+	  tmpBuff[buf.st_size] = 0;
 	  fclose (res);
 
-	  ReadCSSRules (doc, oldcss, buffer, FALSE);
-	  TtaFreeMemory (buffer);
+	  ReadCSSRules (doc, oldcss, tmpBuff, 0, FALSE);
+	  TtaFreeMemory (tmpBuff);
 	}
     }
 }
