@@ -1,24 +1,15 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996.
+ *  (c) COPYRIGHT INRIA, 1996-2001.
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
 
-/*
- * Warning:
- * This module is part of the Thot library, which was originally
- * developed in French. That's why some comments are still in
- * French, but their translation is in progress and the full module
- * will be available in English in the next release.
- * 
- */
- 
 /*
  * platform.c : basic system functions
  *
  * Authors: I. Vatton, D. Veillard (INRIA)
- *          R. Guetari (W3C/INRIA) - Unicode and Windows version
+ *          R. Guetari (W3C/INRIA) Windows version
  *
  */
 
@@ -32,96 +23,76 @@
    Rend 1 si le fichier a e't'e trouve' et 0 sinon.        
    Si filename est un repertoire, on retourne 0.           
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-int                 TtaFileExist (CONST char* filename)
-#else  /* __STDC__ */
-int                 TtaFileExist (filename)
-CONST char*    filename;
-
-#endif /* __STDC__ */
+int TtaFileExist (CONST char *filename)
 {
-   int                 status = 0;
-
-#if defined(_WINDOWS) && !defined(__GNUC__)
-   DWORD               attribs;
-
-   attribs = GetFileAttributes ((LPCTSTR)filename);
-   if (attribs == 0xFFFFFFFF)
-      status = 0;
-   else if (attribs & FILE_ATTRIBUTE_DIRECTORY)
-      status = 0;
-   else
-      status = 1;
-#else /* _WINDOWS && !__GNUC__ */
-   int                 filedes;
-   struct stat         statinfo;
-
+  int         status = 0;
 #ifdef _WINDOWS
-   filedes = open (filename, _O_RDONLY | O_BINARY);
+  DWORD       attribs;
+
+  attribs = GetFileAttributes ((LPCTSTR)filename);
+  if (attribs == 0xFFFFFFFF)
+    status = 0;
+  else if (attribs & FILE_ATTRIBUTE_DIRECTORY)
+    status = 0;
+  else
+    status = 1;
 #else /* _WINDOWS */
-   filedes = open (filename, O_RDONLY);
+
+  int         filedes;
+  struct stat statinfo;
+
+  filedes = open (filename, O_RDONLY);
+  if (filedes < 0)
+    status = 0;
+  else
+    {
+      /* on ne veut pas de directory */
+      if (fstat (filedes, &statinfo) != -1)
+	{
+	  if (statinfo.st_mode & S_IFDIR)
+	    status = 0;
+	  else
+	    status = 1;
+        }
+      close (filedes);
+    }
 #endif /* _WINDOWS */
-   if (filedes < 0)
-      status = 0;
-   else
-     {
-       /* on ne veut pas de directory */
-       if (fstat (filedes, &statinfo) != -1)
-	 {
-	   if (statinfo.st_mode & S_IFDIR)
-	     status = 0;
-	   else
-	     status = 1;
-	 }
-       close (filedes);
-     }
-#endif /* _WINDOWS && !__GNUC__ */
-   return status;
+  return status;
 }
 
 /*----------------------------------------------------------------------
    TtaFileUnlink : remove a file.                                     
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-int                 TtaFileUnlink (CONST STRING filename)
-#else  /* __STDC__ */
-int                 TtaFileUnlink (filename)
-CONST STRING        filename;
-
-#endif /* __STDC__ */
+int TtaFileUnlink (CONST char *filename)
 {
   if (filename)
-    return (uunlink (filename));
-else
-  return 0;
+    return (unlink (filename));
+  else
+    return 0;
 }
 
 /*----------------------------------------------------------------------
    static ThotDirBrowseCopyFile - copy the filename from the          
    platform's directory structure     
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static int          ThotDirBrowse_copyFile (ThotDirBrowse * me)
-#else  /* __STDC__ */
-static int          ThotDirBrowse_copyFile (me)
-ThotDirBrowse      *me;
-
-#endif /* __STDC__ */
+static int ThotDirBrowse_copyFile (ThotDirBrowse * me)
 {
-#if defined(_WINDOWS) && !defined(__GNUC__)
+#ifdef _WINDOWS
    DWORD               attr;
 
-   if (ustrlen (me->data.cFileName) + me->dirLen > (size_t)me->bufLen)
+   if (strlen (me->data.cFileName) + me->dirLen > (size_t)me->bufLen)
       return -2;
-   ustrcpy (me->buf + me->dirLen, me->data.cFileName);
+   strcpy (me->buf + me->dirLen, me->data.cFileName);
    if ((attr = GetFileAttributes (me->buf)) == 0xFFFFFFFF)
       return -1;
-   if (attr & FILE_ATTRIBUTE_DIRECTORY && !(me->PicMask & ThotDirBrowse_DIRECTORIES))
+   if (attr & FILE_ATTRIBUTE_DIRECTORY &&
+       !(me->PicMask & ThotDirBrowse_DIRECTORIES))
       return 0;
-   if (attr & FILE_ATTRIBUTE_NORMAL && !(me->PicMask & ThotDirBrowse_FILES))
+   if (attr & FILE_ATTRIBUTE_NORMAL &&
+       !(me->PicMask & ThotDirBrowse_FILES))
       return 0;
    return 1;
-#else  /* _WINDOWS && !__GNUC__ */
+#else  /* _WINDOWS */
    unsigned int        i;
    int                 ls_car;
    ThotBool            notEof;
@@ -131,19 +102,19 @@ ThotDirBrowse      *me;
      {
 	ls_car = fgetc (me->ls_stream);
 	/* saute les caracteres de separation */
-	while (((CHAR_T) ls_car == SPACE) || ((CHAR_T) ls_car == TAB) ||
-	       ((CHAR_T) ls_car == EOL))
+	while (((char) ls_car == SPACE) || ((char) ls_car == TAB) ||
+	       ((char) ls_car == EOL))
 	   ls_car = fgetc (me->ls_stream);
 	notEof = TRUE;
 	i = 0;
-	while (((CHAR_T) ls_car != SPACE) && ((CHAR_T) ls_car != TAB) &&
-	       ((CHAR_T) ls_car != EOL) && (notEof))
+	while (((char) ls_car != SPACE) && ((char) ls_car != TAB) &&
+	       ((char) ls_car != EOL) && (notEof))
 	  {
 	     if (ls_car == EOF)
 		notEof = FALSE;
 	     else
 	       {
-		  me->buf[i] = (CHAR_T) ls_car;
+		  me->buf[i] = (char) ls_car;
 		  i++;
 		  if (i == me->bufLen)
 		    {
@@ -156,44 +127,37 @@ ThotDirBrowse      *me;
 	me->buf[i] = EOS;
 	if (notEof == FALSE && !i)
 	   return 0;
+
 	if (stat (me->buf, &fileStat) == -1)
 	   return -1;
 	/* next if fileStat is not included in our PicMask */
-	if (S_ISDIR (fileStat.st_mode) && !(me->PicMask & ThotDirBrowse_DIRECTORIES))
+	if (S_ISDIR (fileStat.st_mode) &&
+	    !(me->PicMask & ThotDirBrowse_DIRECTORIES))
 	   continue;
-	if (S_ISREG (fileStat.st_mode) && !(me->PicMask & ThotDirBrowse_FILES))
+	if (S_ISREG (fileStat.st_mode) &&
+	    !(me->PicMask & ThotDirBrowse_FILES))
 	   continue;
 	return 1;
      }
-#endif /* _WINDOWS && !__GNUC__ */
+#endif /* _WINDOWS */
 }
 
 /*----------------------------------------------------------------------
    ThotDirBrowse_first - get first dir/name.ext and setup            
    platform dependent ThotDirBrowse structure                
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-int                 ThotDirBrowse_first (ThotDirBrowse * me, char* dir, char* name, char* ext)
-#else  /* __STDC__ */
-int                 ThotDirBrowse_first (me, dir, name, ext)
-ThotDirBrowse      *me;
-PathBuffer          dir;
-STRING              name;
-STRING              ext;
-
-#endif /* __STDC__ */
+int ThotDirBrowse_first (ThotDirBrowse *me, char *dir, char *name, char *ext)
 {
-   CHAR_T              space[MAX_PATH];
-   int                 ret;
+   char           space[MAX_PATH];
+   int            ret;
 
-   me->dirLen = ustrlen (dir);
-   ustrcpy (me->buf, dir);
-   ustrcpy (me->buf + (me->dirLen++), DIR_STR);
+   me->dirLen = strlen (dir);
+   strcpy (me->buf, dir);
+   strcpy (me->buf + (me->dirLen++), DIR_STR);
 #if defined(_WINDOWS) && !defined(__GNUC__)
-   usprintf (space, TEXT("%s\\%s%s"), dir ? dir : _EMPTYSTR_, name ? name : _EMPTYSTR_, ext ? ext : _EMPTYSTR_);
+   sprintf (space, "%s\\%s%s", dir ? dir : "", name ? name : "", ext ? ext : "");
    me->handle = INVALID_HANDLE_VALUE;
-   if ((me->handle = FindFirstFile (space, &me->data)) ==
-       INVALID_HANDLE_VALUE)
+   if ((me->handle = FindFirstFile (space, &me->data)) == INVALID_HANDLE_VALUE)
       return -1;
    if ((ret = ThotDirBrowse_copyFile (me)) == 1)
       return 1;
@@ -205,8 +169,11 @@ STRING              ext;
    /* sprintf (space, "/bin/ls%s %s/%s%s 2>/dev/null", 
       ext && *ext ? "" : " -d", dir ? dir : "", 
       name ? name : "", ext ? ext : ""); - EGP */
-   sprintf (space, "/bin/ls -d %s/%s%s 2>/dev/null", dir ? dir : "",
-	    name ? name : "", ext ? ext : "");
+   /* JK: the special chars in the dir name should be escaped to
+      avoid having the shell interpret them, for example, when the
+      dir name contains ( chars. As a first attempt, we enclose the
+      arguments between quotes */
+   sprintf (space, "/bin/ls -d \"%s\"/%s%s 2>/dev/null", dir ? dir : "", name ? name : "", ext ? ext : "");
    me->ls_stream = NULL;
    if ((me->ls_stream = popen (space, "r")) == NULL)
       return -1;
@@ -221,13 +188,7 @@ STRING              ext;
 /*----------------------------------------------------------------------
    ThotDirBrowse_next - get next file                                
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-int                 ThotDirBrowse_next (ThotDirBrowse * me)
-#else  /* __STDC__ */
-int                 ThotDirBrowse_next (me)
-ThotDirBrowse      *me;
-
-#endif /* __STDC__ */
+int ThotDirBrowse_next (ThotDirBrowse * me)
 {
 #if defined(_WINDOWS) && !defined(__GNUC__)
    int                 ret;
@@ -247,13 +208,7 @@ ThotDirBrowse      *me;
 /*----------------------------------------------------------------------
    ThotDirBrowse_close - recover system resources                    
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-int                 ThotDirBrowse_close (ThotDirBrowse * me)
-#else  /* __STDC__ */
-int                 ThotDirBrowse_close (me)
-ThotDirBrowse      *me;
-
-#endif /* __STDC__ */
+int ThotDirBrowse_close (ThotDirBrowse * me)
 {
    int                 ret;
 
@@ -278,18 +233,19 @@ ThotDirBrowse      *me;
 #ifdef INCLUDE_TESTING_CODE
 /* ThotFile_test - use to test ThotFile on any platform
  */
-void                ThotFile_test (STRING name)
+void                ThotFile_test (char *name)
 {
    ThotFileHandle      handle = ThotFile_BADHANDLE;
    ThotFileOffset      offset;
    ThotFileInfo        info;
    int                 i;
-   CHAR_T              space[16];
-   CONST STRING        format = "%15d\0";
+   char              space[16];
+   CONST char *       format = "%15d\0";
 
    space[sizeof (space) - 1] = 0;
    printf ("ThotFile_test: opening %s for CREATE/READ/WRITE\n", name);
-   handle = TtaFileOpen (name, ThotFile_CREATE | ThotFile_TRUNCATE | ThotFile_READWRITE);
+   handle = TtaFileOpen (name, ThotFile_CREATE | ThotFile_TRUNCATE |
+			 ThotFile_READWRITE);
    if (handle == ThotFile_BADHANDLE)
      {
 	printf ("ThotFile_test: handle == ThotFile_BADHANDLE\n");
@@ -333,8 +289,10 @@ void                ThotFile_test (STRING name)
 	return;
      }
    printf ("ThotFile_test: end found at %d\n", offset);
-   printf ("ThotFile_test: seeking to offset %d in %s\n", offset - 4 * sizeof (space), name);
-   offset = TtaFileSeek (handle, offset - 4 * sizeof (space), ThotFile_SEEKSET);
+   printf ("ThotFile_test: seeking to offset %d in %s\n",
+	   offset - 4 * sizeof (space), name);
+   offset = TtaFileSeek (handle, offset - 4 * sizeof (space),
+			 ThotFile_SEEKSET);
    if (offset == ThotFile_BADOFFSET)
      {
 	printf ("ThotFile_test: offset == ThotFile_BADOFFSET\n");
@@ -371,14 +329,7 @@ void                ThotFile_test (STRING name)
 /*----------------------------------------------------------------------
    TtaFileOpen returns: ThotFile_BADHANDLE: error handle:		
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotFileHandle      TtaFileOpen (CONST STRING name, ThotFileMode mode)
-#else  /* __STDC__ */
-ThotFileHandle      TtaFileOpen (name, mode)
-CONST STRING        name;
-ThotFileMode        mode;
-
-#endif /* __STDC__ */
+ThotFileHandle TtaFileOpen (CONST char *name, ThotFileMode mode)
 {
    ThotFileHandle      ret;
 
@@ -419,13 +370,7 @@ ThotFileMode        mode;
 /*----------------------------------------------------------------------
    TtaFileClose returns, 0: error, 1: OK.				
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 int                 TtaFileClose (ThotFileHandle handle)
-#else  /* __STDC__ */
-int                 TtaFileClose (handle)
-ThotFileHandle      handle;
-
-#endif /* __STDC__ */
 {
    int                 ret;
 
@@ -440,22 +385,15 @@ ThotFileHandle      handle;
 /*----------------------------------------------------------------------
    TtaFileRead returns +n: number of bytes read, 0: at EOF, -1: error 
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-int                 TtaFileRead (ThotFileHandle handle, void *buffer, unsigned int count)
-#else  /* __STDC__ */
-int                 TtaFileRead (handle, buffer, count)
-ThotFileHandle      handle;
-void               *buffer;
-unsigned int        count;
-
-#endif /* __STDC__ */
+int TtaFileRead (ThotFileHandle handle, void *buffer, unsigned int count)
 {
    int                 ret;
 
 #if defined(_WINDOWS) && !defined(__GNUC__)
    DWORD               red;
 
-   ret = ReadFile (handle, buffer, count, &red, 0);	/* OK as long as we don't open for overlapped IO */
+   /* OK as long as we don't open for overlapped IO */
+   ret = ReadFile (handle, buffer, count, &red, 0);
    if (ret == TRUE)
       ret = (int) red;
    else
@@ -469,15 +407,7 @@ unsigned int        count;
 /*----------------------------------------------------------------------
    TtaFileWrite returns:  n: number of bytes written, -1: error	
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-int                 TtaFileWrite (ThotFileHandle handle, void *buffer, unsigned int count)
-#else  /* __STDC__ */
-int                 TtaFileWrite (handle, buffer, count)
-ThotFileHandle      handle;
-void               *buffer;
-unsigned int        count;
-
-#endif /* __STDC__ */
+int TtaFileWrite (ThotFileHandle handle, void *buffer, unsigned int count)
 {
    int                 ret;
 
@@ -499,15 +429,8 @@ unsigned int        count;
 /*----------------------------------------------------------------------
    TtaFileSeek returns: ThotFile_BADOFFSET: error, ThotFileOffset	
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotFileOffset      TtaFileSeek (ThotFileHandle handle, ThotFileOffset offset, ThotFileOrigin origin)
-#else  /* __STDC__ */
-ThotFileOffset      TtaFileSeek (handle, offset, origin)
-ThotFileHandle      handle;
-ThotFileOffset      offset;
-ThotFileOrigin      origin;
-
-#endif /* __STDC__ */
+ThotFileOffset TtaFileSeek (ThotFileHandle handle, ThotFileOffset offset,
+			    ThotFileOrigin origin)
 {
    ThotFileOffset      ret;
 
@@ -522,14 +445,7 @@ ThotFileOrigin      origin;
 /*----------------------------------------------------------------------
    TtaFileSeek returns: 1: your data is all there, sir, 0: error	
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-int                 TtaFileStat (ThotFileHandle handle, ThotFileInfo * pInfo)
-#else  /* __STDC__ */
-int                 TtaFileStat (handle, pInfo)
-ThotFileHandle      handle;
-ThotFileInfo       *pInfo;
-
-#endif /* __STDC__ */
+int TtaFileStat (ThotFileHandle handle, ThotFileInfo *pInfo)
 {
    ThotFileOffset      ret;
 
@@ -558,40 +474,33 @@ ThotFileInfo       *pInfo;
 /*----------------------------------------------------------------------
    TtaFileCopy copies a source file into a target file.              
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                TtaFileCopy (CONST STRING sourceFileName, CONST STRING targetFileName)
-#else
-void                TtaFileCopy (sourceFileName, targetFileName)
-CONST STRING        sourceFileName;
-CONST STRING        targetFileName;
-
-#endif
+void TtaFileCopy (CONST char *sourceFileName, CONST char *targetFileName)
 {
    FILE               *targetf;
    FILE               *sourcef;
    int                 size;
-   CHAR_T                buffer[8192];
+   char                buffer[8192];
 
-   if (ustrcmp (sourceFileName, targetFileName) != 0)
+   if (strcmp (sourceFileName, targetFileName) != 0)
      {
 #ifdef _WINDOWS
-	if ((targetf = ufopen (targetFileName, _WBinaryMODE_)) == NULL)
+	if ((targetf = fopen (targetFileName, "wb")) == NULL)
 #else
-	if ((targetf = ufopen (targetFileName, "w")) == NULL)
+	if ((targetf = fopen (targetFileName, "w")) == NULL)
 #endif
 	   /* cannot write into the target file */
 	   return;
 	else
 	  {
 #ifdef _WINDOWS
-	     if ((sourcef = ufopen (sourceFileName, _RBinaryMODE_)) == NULL)
+	     if ((sourcef = fopen (sourceFileName, "rb")) == NULL)
 #else
-	     if ((sourcef = ufopen (sourceFileName, "r")) == NULL)
+	     if ((sourcef = fopen (sourceFileName, "r")) == NULL)
 #endif
 	       {
 		  /* cannot read the source file */
 		  fclose (targetf);
-		  uunlink (targetFileName);
+		  unlink (targetFileName);
 		  return;
 	       }
 	     else
@@ -613,63 +522,63 @@ CONST STRING        targetFileName;
   Returns FALSE if one of the files is not available for reading or
   if their content differs, TRUE if they are identical.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool            TtaCompareFiles(CONST STRING file1, CONST STRING file2)
-#else
-ThotBool            TtaCompareFiles(file1, file2)
-CONST STRING        file1;
-CONST STRING        file2;
-
-#endif
+ThotBool TtaCompareFiles(CONST char *file1, CONST char *file2)
 {
-    FILE *f1;
-    FILE *f2;
-    CHAR_T buffer1[512];
-    CHAR_T buffer2[512];
-    size_t res1;
-    size_t res2;
+  FILE   *f1;
+  FILE   *f2;
+  char    buffer1[512];
+  char    buffer2[512];
+  size_t  res1;
+  size_t  res2;
 
-    if (file1 == NULL) return(FALSE);
-    if (file2 == NULL) return(FALSE);
+  if (file1 == NULL)
+    return(FALSE);
+  if (file2 == NULL)
+    return(FALSE);
 #ifdef _WINDOWS
-    f1 = ufopen(file1,_RBinaryMODE_);
+  f1 = fopen(file1,"rb");
 #else
-    f1 = ufopen(file1,"r");
+  f1 = fopen(file1, "r");
 #endif
-    if (f1 == NULL) return(FALSE);
+  if (f1 == NULL) return(FALSE);
 #ifdef _WINDOWS
-    f2 = ufopen(file2, _RBinaryMODE_);
+  f2 = fopen(file2, "rb");
 #else
-    f2 = fopen(file2,"r");
+  f2 = fopen(file2, "r");
 #endif
-    if (f2 == NULL) {
-	fclose(f1);
-        return(FALSE);
+  if (f2 == NULL)
+    {
+      fclose(f1);
+      return(FALSE);
     }
-    while (1) {
-        res1 = fread(&buffer1[0], 1, sizeof(buffer1), f1);
-        res2 = fread(&buffer2[0], 1, sizeof(buffer2), f2);
-	if (res1 != res2) {
-	    fclose(f1);
-	    fclose(f2);
-	    return(FALSE);
+  while (1)
+    {
+      res1 = fread(&buffer1[0], 1, sizeof(buffer1), f1);
+      res2 = fread(&buffer2[0], 1, sizeof(buffer2), f2);
+      if (res1 != res2)
+	{
+	  fclose(f1);
+	  fclose(f2);
+	  return(FALSE);
 	}
-        if (memcmp(&buffer1[0], &buffer2[0], res2)) {
-	    fclose(f1);
-	    fclose(f2);
-	    return(FALSE);
+      if (memcmp(&buffer1[0], &buffer2[0], res2))
+	{
+	  fclose(f1);
+	  fclose(f2);
+	  return(FALSE);
 	}
-	res1 = feof(f1);
-	res2 = feof(f2);
-	if (res1 != res2) {
-	    fclose(f1);
-	    fclose(f2);
-	    return(FALSE);
+      res1 = feof(f1);
+      res2 = feof(f2);
+      if (res1 != res2)
+	{
+	  fclose(f1);
+	  fclose(f2);
+	  return(FALSE);
 	}
-	if (res1) break;
+      if (res1) break;
     }
-    fclose(f1);
-    fclose(f2);
-    return(TRUE);
+  fclose(f1);
+  fclose(f2);
+  return(TRUE);
 }
 
