@@ -1,22 +1,13 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996.
+ *  (c) COPYRIGHT INRIA, 1996-2001
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
 
 /*
- * Warning:
- * This module is part of the Thot library, which was originally
- * developed in French. That's why some comments are still in
- * French, but their translation is in progress and the full module
- * will be available in English in the next release.
- * 
- */
- 
-/*
-   This module loads a presentation schema from a .PRS file
-
+ * This module loads a presentation schema from a .PRS file
+ *
  */
 
 #include "thot_sys.h"
@@ -32,26 +23,18 @@
 
 static ThotBool     error;
 
-
 #include "fileaccess_f.h"
 #include "memory_f.h"
 #include "readstr_f.h"
 #include "readprs_f.h"
 
-
 /*----------------------------------------------------------------------
    	ReadrdTypeRegle  lit un type de regle de presentation et	
    	retourne sa valeur.						
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static PRuleType    ReadrdTypeRegle (BinFile file)
-#else  /* __STDC__ */
-static PRuleType    ReadrdTypeRegle (file)
-BinFile             file;
-
-#endif /* __STDC__ */
 {
-   CHAR_T                c;
+   char c;
 
    if (!TtaReadByte (file, &c))
      {
@@ -84,6 +67,72 @@ BinFile             file;
 	    case C_PR_HPOS:
 	       return PtHorizPos;
 	       break;
+            case C_PR_MARGINTOP:
+	       return PtMarginTop;
+               break;
+            case C_PR_MARGINRIGHT:
+               return PtMarginRight;
+               break;
+            case C_PR_MARGINBOTTOM:
+               return PtMarginBottom;
+               break;
+            case C_PR_MARGINLEFT:
+               return PtMarginLeft;
+               break;
+            case C_PR_PADDINGTOP:
+               return PtPaddingTop;
+               break;
+            case C_PR_PADDINGRIGHT:
+               return PtPaddingRight;
+               break;
+            case C_PR_PADDINGBOTTOM:
+               return PtPaddingBottom;
+               break;
+            case C_PR_PADDINGLEFT:
+               return PtPaddingLeft;
+               break;
+            case C_PR_BORDERTOPWIDTH:
+               return PtBorderTopWidth;
+               break;
+            case C_PR_BORDERRIGHTWIDTH:
+               return PtBorderRightWidth;
+               break;
+            case C_PR_BORDERBOTTOMWIDTH:
+               return PtBorderBottomWidth;
+               break;
+            case C_PR_BORDERLEFTWIDTH:
+               return PtBorderLeftWidth;
+               break;
+            case C_PR_XRADIUS:
+	       return PtXRadius;
+               break;
+            case C_PR_YRADIUS:
+	       return PtYRadius;
+               break;
+            case C_PR_BORDERTOPCOLOR:
+               return PtBorderTopColor;
+               break;
+            case C_PR_BORDERRIGHTCOLOR:
+               return PtBorderRightColor;
+               break;
+            case C_PR_BORDERBOTTOMCOLOR:
+               return PtBorderBottomColor;
+               break;
+            case C_PR_BORDERLEFTCOLOR:
+               return PtBorderLeftColor;
+               break;
+            case C_PR_BORDERTOPSTYLE:
+               return PtBorderTopStyle;
+               break;
+            case C_PR_BORDERRIGHTSTYLE:
+               return PtBorderRightStyle;
+               break;
+            case C_PR_BORDERBOTTOMSTYLE:
+               return PtBorderBottomStyle;
+               break;
+            case C_PR_BORDERLEFTSTYLE:
+               return PtBorderLeftStyle;
+	       break;
 	    case C_PR_SIZE:
 	       return PtSize;
 	       break;
@@ -117,9 +166,6 @@ BinFile             file;
 	    case C_PR_ADJUST:
 	       return PtAdjust;
 	       break;
-	    case C_PR_JUSTIFY:
-	       return PtJustify;
-	       break;
 	    case C_PR_HYPHENATE:
 	       return PtHyphenate;
 	       break;
@@ -147,6 +193,15 @@ BinFile             file;
 	    case C_PR_HORIZOVERFLOW:
 	       return PtHorizOverflow;
 	       break;
+	    case C_PR_GATHER:
+	       return PtGather;
+	       break;
+	    case C_PR_PAGEBREAK:
+	       return PtPageBreak;
+	       break;
+	    case C_PR_LINEBREAK:
+	       return PtLineBreak;
+	       break;
 	    default:
 	       error = True;
 	       return PtVisibility;
@@ -157,15 +212,9 @@ BinFile             file;
 /*----------------------------------------------------------------------
    	ReadPresMode lit un mode de presentation et retourne sa valeur.	
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static PresMode     ReadPresMode (BinFile file)
-#else  /* __STDC__ */
-static PresMode     ReadPresMode (file)
-BinFile             file;
-
-#endif /* __STDC__ */
 {
-   CHAR_T                c;
+   char c;
 
    if (!TtaReadByte (file, &c))
      {
@@ -194,15 +243,9 @@ BinFile             file;
    rdTypeUnite lit un type d'unite dans le fichier                    
    et retourne sa valeur.                                  
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static TypeUnit     rdUnit (BinFile file)
-#else  /* __STDC__ */
-static TypeUnit     rdUnit (file)
-BinFile             file;
-
-#endif /* __STDC__ */
 {
-   CHAR_T                c;
+   char c;
 
    if (!TtaReadByte (file, &c))
      {
@@ -226,6 +269,9 @@ BinFile             file;
 	    case C_UNIT_PERCENT:
 	       return UnPercent;
 	       break;
+	    case C_UNIT_AUTO:
+	       return UnAuto;
+	       break;
 	    default:
 	       error = True;
 	       return UnPoint;
@@ -236,15 +282,9 @@ BinFile             file;
 /*----------------------------------------------------------------------
    ReadInheritMode lit un mode d'heritage et retourne sa valeur.	
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static InheritMode  ReadInheritMode (BinFile file)
-#else  /* __STDC__ */
-static InheritMode  ReadInheritMode (file)
-BinFile             file;
-
-#endif /* __STDC__ */
 {
-   CHAR_T                c;
+   char c;
 
    if (!TtaReadByte (file, &c))
      {
@@ -275,22 +315,14 @@ BinFile             file;
 	 }
 }
 
-
 /*----------------------------------------------------------------------
    	ReadFunctionType  lit un type de fonction de presentation et	
    	retourne sa valeur.						
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static FunctionType ReadFunctionType (BinFile file, ThotBool * repeat)
-#else  /* __STDC__ */
-static FunctionType ReadFunctionType (file, repeat)
-BinFile             file;
-ThotBool           *repeat;
-
-#endif /* __STDC__ */
 {
-   CHAR_T                c;
-   FunctionType        functType;
+   char         c;
+   FunctionType functType;
 
    *repeat = FALSE;
    if (!TtaReadByte (file, &c))
@@ -379,20 +411,13 @@ ThotBool           *repeat;
    return functType;
 }
 
-
 /*----------------------------------------------------------------------
    	ReadAlignment   lit un mode d'alignement des lignes et retourne	
    	sa valeur.							
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static BAlignment   ReadAlignment (BinFile file)
-#else  /* __STDC__ */
-static BAlignment   ReadAlignment (file)
-BinFile             file;
-
-#endif /* __STDC__ */
 {
-   CHAR_T                c;
+   char                c;
    BAlignment          align;
 
    if (!TtaReadByte (file, &c))
@@ -414,6 +439,9 @@ BinFile             file;
 	    case C_PIV_LEFTDOT:
 	       align = AlignLeftDots;
 	       break;
+	    case C_PIV_JUSTIFY:
+	       align = AlignJustify;
+	       break;
 	    default:
 	       error = True;
 	       align = AlignLeft;
@@ -423,20 +451,13 @@ BinFile             file;
    return align;
 }
 
-
 /*----------------------------------------------------------------------
    	ReadPresCondition      lit un type de condition et retourne	
    	sa valeur.							
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static PresCondition ReadPresCondition (BinFile file)
-#else  /* __STDC__ */
-static PresCondition ReadPresCondition (file)
-BinFile             file;
-
-#endif /* __STDC__ */
 {
-   CHAR_T                c;
+   char                c;
    PresCondition       condtype;
 
    if (!TtaReadByte (file, &c))
@@ -491,6 +512,9 @@ BinFile             file;
 	    case C_COND_EMPTY:
 	       condtype = PcEmpty;
 	       break;
+	    case C_COND_ROOT:
+	       condtype = PcRoot;
+	       break;
 	    case C_COND_EVEN:
 	       condtype = PcEven;
 	       break;
@@ -526,19 +550,12 @@ BinFile             file;
    return condtype;
 }
 
-
 /*----------------------------------------------------------------------
    	ReadArithRel     lit la relation d'une condition Within		
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static ArithRel     ReadArithRel (BinFile file)
-#else  /* __STDC__ */
-static ArithRel     ReadArithRel (file)
-BinFile             file;
-
-#endif /* __STDC__ */
 {
-   CHAR_T                c;
+   char                c;
    ArithRel            rel;
 
    if (!TtaReadByte (file, &c))
@@ -560,19 +577,12 @@ BinFile             file;
    return (rel);
 }
 
-
 /*----------------------------------------------------------------------
    	ReadBoxEdge   lit un repere de boite et retourne sa valeur.	
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static BoxEdge      ReadBoxEdge (BinFile file)
-#else  /* __STDC__ */
-static BoxEdge      ReadBoxEdge (file)
-BinFile             file;
-
-#endif /* __STDC__ */
 {
-   CHAR_T                c;
+   char                c;
    BoxEdge             edge;
 
    if (!TtaReadByte (file, &c))
@@ -617,21 +627,13 @@ BinFile             file;
    return edge;
 }
 
-
 /*----------------------------------------------------------------------
    	ReadLevel     lit un niveau relatif de boite et retourn		
    	sa valeur.							
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static Level        ReadLevel (BinFile file)
-
-#else  /* __STDC__ */
-static Level        ReadLevel (file)
-BinFile             file;
-
-#endif /* __STDC__ */
 {
-   CHAR_T                c;
+   char                c;
    Level               level;
 
    if (!TtaReadByte (file, &c))
@@ -683,15 +685,9 @@ BinFile             file;
    	ReadCounterOp  lit un type d'operation sur compteur et retourne	
    	sa valeur.							
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static CounterOp    ReadCounterOp (BinFile file)
-#else  /* __STDC__ */
-static CounterOp    ReadCounterOp (file)
-BinFile             file;
-
-#endif /* __STDC__ */
 {
-   CHAR_T                c;
+   char                c;
    CounterOp           optype;
 
    if (!TtaReadByte (file, &c))
@@ -721,20 +717,13 @@ BinFile             file;
    return optype;
 }
 
-
 /*----------------------------------------------------------------------
    	ReadBasicType lit un type de base dans le fichier et retourne	
    	sa valeur.							
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static BasicType    ReadBasicType (BinFile file)
-#else  /* __STDC__ */
-static BasicType    ReadBasicType (file)
-BinFile             file;
-
-#endif /* __STDC__ */
 {
-   CHAR_T                c;
+   char                c;
    BasicType           basictyp;
 
    if (!TtaReadByte (file, &c))
@@ -770,20 +759,12 @@ BinFile             file;
    return basictyp;
 }
 
-
 /*----------------------------------------------------------------------
    	ReadVariableType  lit un type de variable et retourne sa valeur	
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static VariableType ReadVariableType (BinFile file)
-
-#else  /* __STDC__ */
-static VariableType ReadVariableType (file)
-BinFile             file;
-
-#endif /* __STDC__ */
 {
-   CHAR_T                c;
+   char                c;
    VariableType        vartyp;
 
    if (!TtaReadByte (file, &c))
@@ -832,19 +813,12 @@ BinFile             file;
    return vartyp;
 }
 
-
 /*----------------------------------------------------------------------
    	ReadCounterStyle lit un style de compteur et retourne sa valeur	
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static CounterStyle ReadCounterStyle (BinFile file)
-#else  /* __STDC__ */
-static CounterStyle ReadCounterStyle (file)
-BinFile             file;
-
-#endif /* __STDC__ */
 {
-   CHAR_T                c;
+   char                c;
    CounterStyle        countstyle;
 
    if (!TtaReadByte (file, &c))
@@ -877,20 +851,13 @@ BinFile             file;
    return countstyle;
 }
 
-
 /*----------------------------------------------------------------------
    	ReadCounterValue    lit la nature du compteur inclus dans une	
    	variable et retourne sa valeur.					
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static CounterValue ReadCounterValue (BinFile file)
-#else  /* __STDC__ */
-static CounterValue ReadCounterValue (file)
-BinFile             file;
-
-#endif /* __STDC__ */
 {
-   CHAR_T                c;
+   char                c;
    CounterValue        value;
 
    if (!TtaReadByte (file, &c))
@@ -917,20 +884,12 @@ BinFile             file;
    return value;
 }
 
-
 /*----------------------------------------------------------------------
    	ReadContentType	lit un type de contenu retourne sa valeur.	
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 ContentType         ReadContentType (BinFile file)
-
-#else  /* __STDC__ */
-ContentType         ReadContentType (file)
-BinFile             file;
-
-#endif /* __STDC__ */
 {
-   CHAR_T                c;
+   char                c;
    ContentType         conttype;
 
    if (!TtaReadByte (file, &c))
@@ -949,9 +908,6 @@ BinFile             file;
 	    case C_CONT_CONST:
 	       conttype = ContConst;
 	       break;
-	    case C_CONT_ELEM:
-	       conttype = ContElement;
-	       break;
 	    default:
 	       error = True;
 	       conttype = FreeContent;
@@ -960,22 +916,13 @@ BinFile             file;
    return conttype;
 }
 
-
 /*----------------------------------------------------------------------
    	ReadPRulePtr	retourne un pointeur sur la regle suivante ou	
    	s'il n'y a pas de regle suivante.				
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-PtrPRule            ReadPRulePtr (BinFile file, PtrPRule * pNextPRule)
-
-#else  /* __STDC__ */
-PtrPRule            ReadPRulePtr (file, pNextPRule)
-BinFile             file;
-PtrPRule           *pNextPRule;
-
-#endif /* __STDC__ */
+PtrPRule     ReadPRulePtr (BinFile file, PtrPRule * pNextPRule)
 {
-   CHAR_T                c;
+   char                c;
 
    if (!TtaReadByte (file, &c))
       return NULL;
@@ -985,19 +932,12 @@ PtrPRule           *pNextPRule;
       return *pNextPRule;
 }
 
-
 /*----------------------------------------------------------------------
    	ReadRefKind
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static RefKind      ReadRefKind (BinFile file)
-#else  /* __STDC__ */
-static RefKind      ReadRefKind (file)
-BinFile             file;
-
-#endif /* __STDC__ */
 {
-   CHAR_T                c;
+   char c;
 
    if (!TtaReadByte (file, &c))
       c = SPACE;
@@ -1019,18 +959,10 @@ BinFile             file;
 	 }
 }
 
-
 /*----------------------------------------------------------------------
    	ReadPosRule   lit un positionnement relatif			
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                ReadPosRule (BinFile file, PosRule * pPosRule)
-#else  /* __STDC__ */
-void                ReadPosRule (file, pPosRule)
-BinFile             file;
-PosRule            *pPosRule;
-
-#endif /* __STDC__ */
+void       ReadPosRule (BinFile file, PosRule *pPosRule)
 {
    pPosRule->PoPosDef = ReadBoxEdge (file);
    pPosRule->PoPosRef = ReadBoxEdge (file);
@@ -1044,20 +976,13 @@ PosRule            *pPosRule;
    TtaReadShort (file, &pPosRule->PoRefIdent);
 }
 
-
 /*----------------------------------------------------------------------
    	ReadAttrCompar lit un type de comparaison pour les valeurs	
    	d'attributs retourne sa valeur.					
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 AttrComparType      ReadAttrCompar (BinFile file)
-#else  /* __STDC__ */
-AttrComparType      ReadAttrCompar (file)
-BinFile             file;
-
-#endif /* __STDC__ */
 {
-   CHAR_T                c;
+   char c;
 
    if (!TtaReadByte (file, &c))
       c = SPACE;
@@ -1076,20 +1001,11 @@ BinFile             file;
 	 }
 }
 
-
 /*----------------------------------------------------------------------
    	ReadPRules    lit une suite de regles chainees et fait pointer	
    	le pointeur pPRule sur la premiere regle de la suite de regles lues	
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                ReadPRules (BinFile file, PtrPRule * pPRule, PtrPRule * pNextPRule)
-#else  /* __STDC__ */
-void                ReadPRules (file, pPRule, pNextPRule)
-BinFile             file;
-PtrPRule           *pPRule;
-PtrPRule           *pNextPRule;
-
-#endif /* __STDC__ */
+void      ReadPRules (BinFile file, PtrPRule *pPRule, PtrPRule *pNextPRule)
 {
    PtrPRule            pPR;
    PtrCondition        pCond;
@@ -1155,7 +1071,7 @@ PtrPRule           *pNextPRule;
 			      TtaReadSignedShort (file, &pCond->CoTypeElAttr);
 			      break;
 			   default:
-			      break;
+			      break; 
 			}
 		  typeCond = ReadPresCondition (file);
 	       }
@@ -1185,25 +1101,31 @@ PtrPRule           *pNextPRule;
 				 TtaReadBool (file, &pPR->PrElement);
 				 error = !TtaReadShort (file, &pPR->PrNPresBoxes);
 				 if (!error)
+				   {
 				    if (pPR->PrNPresBoxes == 0)
 				       TtaReadName (file, pPR->PrPresBoxName);
 				    else
 				      {
 					 for (i = 0; i < pPR->PrNPresBoxes; i++)
 					    TtaReadShort (file, &pPR->PrPresBox[i]);
-					 pPR->PrPresBoxName[0] = EOS;
+					 pPR->PrPresBoxName[0] = WC_EOS;
 				      }
+				   }
 			      }
 			    break;
 			 case PresImmediate:
 			    switch (pPR->PrType)
 				  {
+				     case PtFunction:
 				     case PtVisibility:
 				     case PtDepth:
-				     case PtFunction:
 				     case PtFillPattern:
 				     case PtBackground:
 				     case PtForeground:
+                                     case PtBorderTopColor:
+                                     case PtBorderRightColor:
+                                     case PtBorderBottomColor:
+			             case PtBorderLeftColor:
 					TtaReadBool (file, &pPR->PrAttrValue);
 					TtaReadSignedShort (file, &pPR->PrIntValue);
 					break;
@@ -1213,6 +1135,10 @@ PtrPRule           *pNextPRule;
 				     case PtUnderline:
 				     case PtThickness:
 				     case PtLineStyle:
+				     case PtBorderTopStyle:
+			             case PtBorderRightStyle:
+			             case PtBorderBottomStyle:
+			             case PtBorderLeftStyle:
 					if (!TtaReadByte (file, &pPR->PrChrValue))
 					   error = True;
 					break;
@@ -1222,6 +1148,20 @@ PtrPRule           *pNextPRule;
 				     case PtSize:
 				     case PtLineSpacing:
 				     case PtLineWeight:
+				     case PtMarginTop:
+				     case PtMarginRight:
+				     case PtMarginBottom:
+				     case PtMarginLeft:
+				     case PtPaddingTop:
+				     case PtPaddingRight:
+				     case PtPaddingBottom:
+				     case PtPaddingLeft:
+				     case PtBorderTopWidth:
+				     case PtBorderRightWidth:
+				     case PtBorderBottomWidth:
+				     case PtBorderLeftWidth:
+				     case PtXRadius:
+				     case PtYRadius:
 					pPR->PrMinUnit = rdUnit (file);
 					TtaReadBool (file, &pPR->PrMinAttr);
 					TtaReadSignedShort (file, &pPR->PrMinValue);
@@ -1256,11 +1196,13 @@ PtrPRule           *pNextPRule;
 				     case PtAdjust:
 					pPR->PrAdjust = ReadAlignment (file);
 					break;
-				     case PtJustify:
 				     case PtHyphenate:
 				     case PtVertOverflow:
 				     case PtHorizOverflow:
-					TtaReadBool (file, &pPR->PrJustify);
+				     case PtGather:
+				     case PtPageBreak:
+				     case PtLineBreak:
+					TtaReadBool (file, &pPR->PrBoolValue);
 					break;
 				     default:
 					break;
@@ -1275,7 +1217,6 @@ PtrPRule           *pNextPRule;
      }
 }
 
-
 /*----------------------------------------------------------------------
    	ReadPresentationSchema 						
    	lit un fichier contenant un schema de presentation et le charge	
@@ -1287,45 +1228,39 @@ PtrPRule           *pNextPRule;
    	Retourne un pointeur sur le schema de presentation en memoire	
    	chargement reussi, NULL si echec.				
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-PtrPSchema          ReadPresentationSchema (Name fileName, PtrSSchema pSS)
-#else  /* __STDC__ */
-PtrPSchema          ReadPresentationSchema (fileName, pSS)
-Name                fileName;
-PtrSSchema          pSS;
-
-#endif /* __STDC__ */
+PtrPSchema      ReadPresentationSchema (Name fileName, PtrSSchema pSS)
 {
    PtrPRule            pNextPRule;
    PtrPSchema          pPSch;
-   Counter            *pCntr;
-   CntrItem           *pCntrItem;
-   PresConstant       *pConst;
-   PresVariable       *pVar;
-   PresVarItem        *pVarItem;
-   PresentationBox    *pBox;
-   AttributePres      *pAttrP, *pAttrOld;
-   NumAttrCase        *pCase;
+   Counter*            pCntr;
+   CntrItem*           pCntrItem;
+   PresConstant*       pConst;
+   PresVariable*       pVar;
+   PresVarItem*        pVarItem;
+   PresentationBox*    pBox;
+   AttributePres*      pAttrP, *pAttrOld;
+   NumAttrCase*        pCase;
    PathBuffer          dirBuffer;
    BinFile             file;
-   CHAR_T                buf[MAX_TXT_LEN];
-   int                 InitialNElems, i, j, l;
+   char                buf[MAX_TXT_LEN];
+   int                 InitialNElems, i, j, k, l;
+   PtrHostView         pHostView, prevHostView;
    ThotBool            ret;
 
    error = FALSE;
    pPSch = NULL;
    /* compose le nom du fichier a ouvrir */
-   ustrncpy (dirBuffer, SchemaPath, MAX_PATH);
-   MakeCompleteName (fileName, PRS_EXT2, dirBuffer, buf, &i);
+   strncpy (dirBuffer, SchemaPath, MAX_PATH);
+   MakeCompleteName (fileName, "PRS", dirBuffer, buf, &i);
 
    /* teste si le fichier existe */
    file = TtaReadOpen (buf);
    if (file == 0)
      {
 	/* message 'Fichier inaccessible' */
-	ustrncpy (buf, fileName, MAX_NAME_LENGTH);
-	ustrcat (buf, PRS_EXT);
-	TtaDisplayMessage (INFO, TtaGetMessage (LIB, TMSG_LIB_MISSING_FILE), buf);
+	strncpy (buf, fileName, MAX_NAME_LENGTH);
+	strcat (buf, ".PRS");
+	TtaDisplayMessage (INFO, TtaGetMessage (LIB,TMSG_INCORRECT_PRS_FILE ), buf);
      }
    else
      {
@@ -1336,15 +1271,35 @@ PtrSSchema          pSS;
 	GetPresentRule (&pNextPRule);
 	pNextPRule->PrCond = NULL;
 	/* met son nom dans le schema de presentation */
-	ustrncpy (pPSch->PsPresentName, fileName, MAX_NAME_LENGTH - 1);
+	strncpy (pPSch->PsPresentName, fileName, MAX_NAME_LENGTH - 1);
 	/* lit la partie fixe du schema de presentation */
 	/* lit le nom du schema de structure correspondant */
 	TtaReadName (file, pPSch->PsStructName);
 	TtaReadShort (file, &pPSch->PsStructCode);
+	/* read the name of all declared views */
 	error = !TtaReadShort (file, &pPSch->PsNViews);
 	if (!error)
 	   for (i = 0; i < pPSch->PsNViews; i++)
 	      TtaReadName (file, pPSch->PsView[i]);
+        /* read the name of all host view for each declared view */
+	if (!error)
+	   for (i = 0; i < pPSch->PsNViews; i++)
+	      {
+	      TtaReadShort (file, &j);
+	      prevHostView = NULL;
+	      if (!error)
+	         for (k = 0; k < j; k++)
+		    {
+		    pHostView = TtaGetMemory (sizeof(HostView));
+		    TtaReadName (file, pHostView->HostViewName);
+		    pHostView->NextHostView = NULL;
+		    if (prevHostView)
+		      prevHostView->NextHostView = pHostView;
+		    else
+		      pPSch->PsHostViewList[i] = pHostView;
+		    prevHostView = pHostView;
+		    }
+	      }
 	if (!error)
 	   for (i = 0; i < pPSch->PsNViews; i++)
 	      TtaReadBool (file, &pPSch->PsPaginatedView[i]);
@@ -1355,10 +1310,7 @@ PtrSSchema          pSS;
 	error = !TtaReadShort (file, &pPSch->PsNPrintedViews);
 	if (!error)
 	   for (i = 0; i < pPSch->PsNPrintedViews; i++)
-	     {
-		TtaReadBool (file, &pPSch->PsPrintedView[i].VpAssoc);
-		error = !TtaReadShort (file, &pPSch->PsPrintedView[i].VpNumber);
-	     }
+	     error = !TtaReadShort (file, &pPSch->PsPrintedView[i].VpNumber);
 	if (!error)
 	   for (i = 0; i < pPSch->PsNViews; i++)
 	      TtaReadBool (file, &pPSch->PsExportView[i]);
@@ -1368,17 +1320,15 @@ PtrSSchema          pSS;
 	TtaReadShort (file, &pPSch->PsNPresentBoxes);
 	pPSch->PsFirstDefaultPRule = ReadPRulePtr (file, &pNextPRule);
 	ret = !error;
-	if (pSS->SsRootElem == 0)
-	   ret = ReadStructureSchema (pPSch->PsStructName, pSS);
+	if (pSS->SsRootElem == 0) 
+	  ret = FALSE;
+
 	if (!ret || pPSch->PsStructCode != pSS->SsCode)
 	  {
 	     FreeSchPres (pPSch);
 	     FreePresentRule (pNextPRule);
 	     pNextPRule = NULL;
 	     pPSch = NULL;
-	     /* Schemas incompatibles */
-	     TtaDisplayMessage (INFO, TtaGetMessage (LIB, TMSG_OLD_SCH_TO_RECOMP),
-				buf);
 	  }
 	else
 	  {
@@ -1493,9 +1443,6 @@ PtrSSchema          pSS;
 		     pBox = &pPSch->PsPresentBox[i];
 		     TtaReadName (file, pBox->PbName);
 		     pBox->PbFirstPRule = ReadPRulePtr (file, &pNextPRule);
-		     TtaReadBool (file, &pBox->PbAcceptPageBreak);
-		     TtaReadBool (file, &pBox->PbAcceptLineBreak);
-		     TtaReadBool (file, &pBox->PbBuildAll);
 		     TtaReadBool (file, &pBox->PbPageFooter);
 		     TtaReadBool (file, &pBox->PbPageHeader);
 		     TtaReadBool (file, &pBox->PbPageBox);
@@ -1512,10 +1459,6 @@ PtrSSchema          pSS;
 				 case ContConst:
 				    TtaReadShort (file, &pBox->PbContConstant);
 				    break;
-				 case ContElement:
-				    TtaReadShort (file, &pBox->PbContElem);
-				    TtaReadShort (file, &pBox->PbContRefElem);
-				    break;
 				 default:
 				    break;
 			      }
@@ -1665,25 +1608,6 @@ PtrSSchema          pSS;
 		     pPSch->PsComparAttr[i] = NULL;
 		  }
 
-	     if (!error)
-		for (i = 0; i < InitialNElems; i++)
-		   TtaReadBool (file, &pPSch->PsAcceptPageBreak[i]);
-
-	     if (!error)
-		for (i = 0; i < InitialNElems; i++)
-		   TtaReadBool (file, &pPSch->PsAcceptLineBreak[i]);
-
-	     if (!error)
-		for (i = 0; i < InitialNElems; i++)
-		   TtaReadBool (file, &pPSch->PsBuildAll[i]);
-
-	     if (!error)
-		for (i = 0; i < InitialNElems; i++)
-		   TtaReadBool (file, &pPSch->PsInPageHeaderOrFooter[i]);
-
-	     if (!error)
-		for (i = 0; i < InitialNElems; i++)
-		   TtaReadBool (file, &pPSch->PsAssocPaginated[i]);
 	     if (!error)
 		for (i = 0; i < InitialNElems; i++)
 		   TtaReadShort (file, &pPSch->PsElemTransmit[i]);
@@ -1705,6 +1629,7 @@ PtrSSchema          pSS;
 	/* message 'Schema incorrect' */
 	TtaDisplayMessage (INFO, TtaGetMessage (LIB, TMSG_INCORRECT_PRS_FILE),
 			   fileName);
+	FreeSchPres (pPSch);
 	return NULL;
      }
    else
