@@ -1,19 +1,10 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996.
+ *  (c) COPYRIGHT INRIA, 1996-2001
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
 
-/*
- * Warning:
- * This module is part of the Thot library, which was originally
- * developed in French. That's why some comments are still in
- * French, but their translation is in progress and the full module
- * will be available in English in the next release.
- * 
- */
- 
 /*
  * Handle scrolling in document frames
  *
@@ -33,12 +24,14 @@
 
 #include "absboxes_f.h"
 #include "appli_f.h"
+#include "applicationapi_f.h"
 #include "boxselection_f.h"
+#include "buildboxes_f.h"
 #include "frame_f.h"
 #include "structselect_f.h"
 #include "textcommands_f.h"
-#include "windowdisplay_f.h"
-#include "applicationapi_f.h"
+#include "xwindowdisplay_f.h"
+
 
 /*----------------------------------------------------------------------
    VerticalScroll effectue un scroll en avant (delta > 0) ou en arriere   
@@ -50,15 +43,7 @@
    Le parametre selection indique s'il faut ge'rer la      
    selection (valeur 1) ou non (valeur 0).                 
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                VerticalScroll (int frame, int delta, int selection)
-#else  /* __STDC__ */
-void                VerticalScroll (frame, delta, selection)
-int                 frame;
-int                 delta;
-int                 selection;
-#endif /* __STDC__ */
-
+void VerticalScroll (int frame, int delta, int selection)
 {
    int                 y, height;
    int                 max, width;
@@ -80,30 +65,29 @@ int                 selection;
 	     /* Limites du scroll */
 	     if (srcbox != NULL)
 	       {
-		  /* On eteint la selection */
-		  if (selection != 0 && ThotLocalActions[T_switchsel])
-		    (*ThotLocalActions[T_switchsel]) (frame, FALSE);
-
 		  /* A priori pas de paves ajoutes */
 		  add = FALSE;
-		  /* Au plus, la limite du document + le debordement vertical */
+		  /* Au plus, la limite du document + le debordement vertical*/
 		  GetSizesFrame (frame, &lframe, &hframe);
 		  if (pAbb->AbTruncatedTail)
 		     max = delta;
 		  else
-		     max = srcbox->BxYOrg + srcbox->BxHeight - pFrame->FrYOrg - hframe;
+		     max = srcbox->BxYOrg + srcbox->BxHeight -
+		                            pFrame->FrYOrg - hframe;
 		  if (pAbb->AbTruncatedHead)
 		     y = delta;
 		  else
 		    {
 		       y = -pFrame->FrYOrg;
-		       /* Il faut respecter la marge initiale si elle est positive */
+		       /* Il faut respecter la marge initiale si elle est
+			  positive */
 		       if (srcbox->BxYOrg < 0)
 			  y += srcbox->BxYOrg;
 		    }
 
-		  /* Le Scroll est possible --> Calcule l'amplitude du Scroll */
+		  /* Le Scroll est possible --> Calcule l'amplitude du Scroll*/
 		  if ((delta > 0 && max > 0) || (delta < 0 && y < 0))
+		    {
 		     if (delta > 0)
 		       {
 			  /* SCROLL AVANT */
@@ -116,7 +100,7 @@ int                 selection;
 			  height = pFrame->FrYOrg + hframe;
 			  DefClip (frame, pFrame->FrXOrg, height,
 				   pFrame->FrXOrg + lframe, height + delta);
-			  add = RedrawFrameBottom (frame, delta);
+			  add = RedrawFrameBottom (frame, delta, NULL);
 		       }
 		     else
 		       {
@@ -131,8 +115,8 @@ int                 selection;
 			  DefClip (frame, pFrame->FrXOrg, height + delta,
 				   pFrame->FrXOrg + lframe, height);
 			  add = RedrawFrameTop (frame, -delta);
-			  /* On reallume eventuellement une selection cachee */
 		       }
+		    }
 
 		  /* recompute scrolls */
 		  CheckScrollingWidth (frame);
@@ -147,8 +131,6 @@ int                 selection;
 			  /* On reprend la nouvelle */
 			  /* On reallume la selection deja visualisee */
 		       }
-		     else if (ThotLocalActions[T_switchsel])
-		       (*ThotLocalActions[T_switchsel]) (frame, TRUE);
 	       }
 	  }
      }
@@ -163,17 +145,7 @@ int                 selection;
    Le parametre selection indique s'il faut gerer la       
    selection (valeur 1) ou non (valeur 0).                 
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                HorizontalScroll (int frame, int delta, int selection)
-
-#else  /* __STDC__ */
-void                HorizontalScroll (frame, delta, selection)
-int                 frame;
-int                 delta;
-int                 selection;
-
-#endif /* __STDC__ */
-
+void HorizontalScroll (int frame, int delta, int selection)
 {
   int                 x, height;
   int                 min, max, width;
@@ -189,16 +161,13 @@ int                 selection;
 	  CloseInsertion ();
 	  /* finish the current insertion */
 	  srcbox = pFrame->FrAbstractBox->AbBox;
-	  /* switch off the selection */
-	  if (selection != 0 && ThotLocalActions[T_switchsel])
-	    (*ThotLocalActions[T_switchsel]) (frame, FALSE);
 	  GetSizesFrame (frame, &lframe, &hframe);
 	  /* FrameTable[frame].FrScrollOrg is negative or null */
 	  min = FrameTable[frame].FrScrollOrg - pFrame->FrXOrg;
 	  /* Right limit is the current scroll width + extra */
 	  max = min + FrameTable[frame].FrScrollWidth - lframe;
 	  /* Left limit is the current scroll width - extra */
-	  /* keep the right margin if the document is smaller than the window */
+	  /* keep the right margin if the document is smaller than the window*/
 	  if (srcbox->BxXOrg  < 0)
 	    min += srcbox->BxXOrg;
 
@@ -215,7 +184,8 @@ int                 selection;
 		  width = lframe - x + 1;
 		  Scroll (frame, width, height, x, 0, 0, 0);
 		  width = pFrame->FrXOrg + lframe;
-		  DefClip (frame, width, pFrame->FrYOrg, width + x, pFrame->FrYOrg + hframe);
+		  DefClip (frame, width, pFrame->FrYOrg, width + x,
+			   pFrame->FrYOrg + hframe);
 		}
 	      else
 		{
@@ -226,19 +196,16 @@ int                 selection;
 		  width = lframe - x + 1;
 		  Scroll (frame, width, height, 0, 0, x, 0);
 		  width = pFrame->FrXOrg;
-		  DefClip (frame, width - x, pFrame->FrYOrg, width, pFrame->FrYOrg + hframe);
+		  DefClip (frame, width - x, pFrame->FrYOrg, width,
+			   pFrame->FrYOrg + hframe);
 		}
 
 	      /* display the rest of the window */
 	      pFrame->FrXOrg += delta;
-	      RedrawFrameBottom (frame, 0);
+	      RedrawFrameBottom (frame, 0, NULL);
 	      /* recompute the scroll bars */
 	      UpdateScrollbars (frame);
 	    }
-	  
-	  /* switch on the selection */
-	  if (selection != 0 && ThotLocalActions[T_switchsel])
-	    (*ThotLocalActions[T_switchsel]) (frame, TRUE);
 	}
     }
 }
@@ -251,15 +218,7 @@ int                 selection;
    Le parame`tre y donne la position demande'e et le       
    parame`tre haut la hauteur de la fenetree^tre.          
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                ShowYPosition (int frame, int y, int height)
-#else  /* __STDC__ */
-void                ShowYPosition (frame, y, height)
-int                 frame;
-int                 y;
-int                 height;
-
-#endif /* __STDC__ */
+void ShowYPosition (int frame, int y, int height)
 {
    ViewFrame          *pFrame;
    PtrBox              pBox;
@@ -282,19 +241,23 @@ int                 height;
 		     JumpIntoView (frame, 0);
 		  else
 		    {
-		       /* Regarde si le cadrage en haut n'est pas deja effectue */
+		       /* Regarde si le cadrage en haut n'est pas deja
+			  effectue */
 		       delta = pBox->BxYOrg - shift;
 		       if (delta < 0)
-			  /* Cadre la boite racine sur le bord gauche de la fenetre */
+			  /* Cadre la boite racine sur le bord gauche de la
+			     fenetre */
 			  VerticalScroll (frame, delta, 1);
 		    }
 	       }
-	     else if (y == height && !pFrame->FrAbstractBox->AbTruncatedTail)	/* cadrage en bas */
+	     else if (y == height && !pFrame->FrAbstractBox->AbTruncatedTail)
+	       /* cadrage en bas */
 	       {
 		  /* Recupere la hauteur de la fenetre */
 		  GetSizesFrame (frame, &delta, &height);
 		  /* Regarde si le cadrage en bas n'est pas deja effectue */
-		  delta = pBox->BxYOrg + pBox->BxHeight - pFrame->FrYOrg - height;
+		  delta = pBox->BxYOrg + pBox->BxHeight - pFrame->FrYOrg -
+		                                                      height;
 		  if (delta > 0)
 		     /* Cadre la boite racine en bas de la fenetreentre */
 		     VerticalScroll (frame, delta, 1);
@@ -332,16 +295,7 @@ int                 height;
    nbCharEnd indique le nombre de carate`res apres l'image abstraite.    
    total indique le nombre total de carate`res du document.        
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-int                 PositionAbsBox (int frame, int *nbCharBegin, int *nbCharEnd, int *total)
-#else  /* __STDC__ */
-int                 PositionAbsBox (frame, nbCharBegin, nbCharEnd, total)
-int                 frame;
-int                *nbCharBegin;
-int                *nbCharEnd;
-int                *total;
-#endif /* __STDC__ */
-
+int PositionAbsBox (int frame, int *nbCharBegin, int *nbCharEnd, int *total)
 {
    ViewFrame          *pFrame;
    PtrBox              premiere;
@@ -363,7 +317,8 @@ int                *total;
    if (pFrame->FrAbstractBox == NULL)
       return -1;
    /* Regarde si l'image est complete */
-   else if (!pFrame->FrAbstractBox->AbTruncatedHead && !pFrame->FrAbstractBox->AbTruncatedTail)
+   else if (!pFrame->FrAbstractBox->AbTruncatedHead &&
+	    !pFrame->FrAbstractBox->AbTruncatedTail)
      {
 	premiere = pFrame->FrAbstractBox->AbBox;
 	*total = premiere->BxHeight;
@@ -374,8 +329,8 @@ int                *total;
 	/* Repere la position de l'image abstraite dans le document */
 	premiere = pFrame->FrAbstractBox->AbBox->BxNext;
 	derniere = pFrame->FrAbstractBox->AbBox->BxPrevious;
-	VolumeTree (pFrame->FrAbstractBox, premiere->BxAbstractBox, derniere->BxAbstractBox,
-		    nbCharBegin, nbCharEnd, total);
+	VolumeTree (pFrame->FrAbstractBox, premiere->BxAbstractBox,
+		    derniere->BxAbstractBox, nbCharBegin, nbCharEnd, total);
 
 	/* L'image se trouve au debut du document ? */
 	if (!pFrame->FrAbstractBox->AbTruncatedHead)
@@ -398,19 +353,7 @@ int                *total;
    - width : la largeur de la portion de l'arbre visualise'e.    
    - height : la hauteur de la portion de l'arbre visualise'e.    
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                ComputeDisplayedChars (int frame, int *Xpos, int *Ypos, int *width, int *height)
-
-#else  /* __STDC__ */
-void                ComputeDisplayedChars (frame, Xpos, Ypos, width, height)
-int                 frame;
-int                *Xpos;
-int                *Ypos;
-int                *width;
-raint              *height;
-
-#endif /* __STDC__ */
-
+void ComputeDisplayedChars (int frame, int *Xpos, int *Ypos, int *width, int *height)
 {
    PtrBox              pBoxFirst;
    PtrBox              pBoxLast;
@@ -518,7 +461,8 @@ raint              *height;
    /*      +-------------+                   */
 
    /** Compute the part of the document which is not formatted **/
-   if ((!pFrame->FrAbstractBox->AbTruncatedHead) && (!pFrame->FrAbstractBox->AbTruncatedTail))
+   if ((!pFrame->FrAbstractBox->AbTruncatedHead) &&
+       (!pFrame->FrAbstractBox->AbTruncatedTail))
      {
 	/* The whole document is formatted */
 	if (pFrame->FrYOrg - pBox->BxYOrg <= 0)
@@ -531,7 +475,8 @@ raint              *height;
 	   min = - pFrame->FrYOrg + pBox->BxYOrg;	/* marge haut */
 
 	if (pBox->BxYOrg + pBox->BxHeight <= pFrame->FrYOrg + h)
-	   /* Le bas de l'Picture Concrete + le debordement du bas sont visibles */
+	   /* Le bas de l'Picture Concrete + le debordement du bas sont
+	      visibles */
 	   max = 0;
 	else if (pBox->BxYOrg + pBox->BxHeight >= pFrame->FrYOrg + h)
 	   /* le debordement du bas n'est pas visualible */
@@ -553,13 +498,17 @@ raint              *height;
 	     pBoxFirst = pBox->BxNext;	/* pBoxFirst boite terminale */
 	     pBoxLast = pBox->BxPrevious;	/* pBoxLast boite terminale */
 	     /* Elimine les boites de presentations */
-	     while (pBoxFirst->BxAbstractBox->AbPresentationBox && pBoxFirst != pBoxLast)
+	     while (pBoxFirst->BxAbstractBox->AbPresentationBox &&
+		    pBoxFirst != pBoxLast)
 		pBoxFirst = pBoxFirst->BxNext;
-	     while (pBoxLast->BxAbstractBox->AbPresentationBox && pBoxFirst != pBoxLast)
+	     while (pBoxLast->BxAbstractBox->AbPresentationBox &&
+		    pBoxFirst != pBoxLast)
 		pBoxLast = pBoxLast->BxPrevious;
 
-	     /* Evalue la hauteur et la position Y par rapport a l'image abstraite */
-	     VolumeTree (pFrame->FrAbstractBox, pBoxFirst->BxAbstractBox, pBoxLast->BxAbstractBox, &min, &max, &vtotal);
+	     /* Evalue la hauteur et la position Y par rapport a l'image
+		abstraite */
+	     VolumeTree (pFrame->FrAbstractBox, pBoxFirst->BxAbstractBox,
+			 pBoxLast->BxAbstractBox, &min, &max, &vtotal);
 	     /* min donne le volume qui precede l'Picture Concrete */
 	     /* max donne le volume qui suit l'Picture Concrete */
 
@@ -617,16 +566,7 @@ raint              *height;
    haut de la fenetre et le haut de la boite, exprimee en  
    pourcentage de la hauteur de la fenetre.                
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                ShowBox (int frame, PtrBox pBox, int position, int percent)
-#else  /* __STDC__ */
-void                ShowBox (frame, pBox, position, percent)
-int                 frame;
-PtrBox              pBox;
-int                 position;
-int                 percent;
-
-#endif /* __STDC__ */
+void ShowBox (int frame, PtrBox pBox, int position, int percent)
 {
    int                 ymin, ymax;
    int                 width, height;
@@ -667,7 +607,7 @@ int                 percent;
       VerticalScroll (frame, dy, 1);
    else
       {
-      RedrawFrameBottom (frame, dy);
+      RedrawFrameBottom (frame, dy, NULL);
       /* Mise a jour des ascenseurs */
       UpdateScrollbars (frame);
       }
@@ -675,7 +615,7 @@ int                 percent;
 
 /*----------------------------------------------------------------------
    IsScrolled regarde si la marque d'insertion (de'but de se'lection) 
-   est visible dans la fenetree^tre affiche'e sur l'e'cran.        
+   est visible dans la fenetre^tre affiche'e sur l'e'cran.        
    Si c'est le cas, la fonction rend la valeur vrai.       
    Si cela n'est pas le cas, la fonction demande le        
    de'placement horizontal ou vertical de la portion       
@@ -683,14 +623,7 @@ int                 percent;
    Le parame`tre selection indique s'il faut ge'rer la     
    se'lection (valeur 1) ou non (valeur 0).                
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool            IsScrolled (int frame, int selection)
-#else  /* __STDC__ */
-ThotBool            IsScrolled (frame, selection)
-int                 frame;
-int                 selection;
-
-#endif /* __STDC__ */
+ThotBool IsScrolled (int frame, int selection)
 {
    int                 xmin, xmax;
    int                 ymin, ymax;
@@ -701,6 +634,8 @@ int                 selection;
 
    pFrame = &ViewFrameTable[frame - 1];
    pBo1 = pFrame->FrSelectionBegin.VsBox;
+   if (pBo1 == NULL)
+     return TRUE;
    x = pBo1->BxXOrg + pFrame->FrSelectionBegin.VsXPos;
    y = pBo1->BxYOrg;
    h = pBo1->BxHeight;
@@ -748,14 +683,7 @@ int                 selection;
    frame et rend cette frame active si l'indicateur actif     
    est Vrai.                                               
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                ShowSelectedBox (int frame, ThotBool actif)
-#else  /* __STDC__ */
-void                ShowSelectedBox (frame, actif)
-int                 frame;
-ThotBool            actif;
-
-#endif /* __STDC__ */
+void ShowSelectedBox (int frame, ThotBool actif)
 {
    ViewFrame          *pFrame;
    PtrBox              pBo1;
@@ -776,7 +704,8 @@ ThotBool            actif;
 	while (pBo1 != NULL && pBo1->BxAbstractBox != NULL &&
 	       pBo1->BxAbstractBox->AbVisibility < pFrame->FrVisibility)
 	  {
-	     if (pBo1->BxAbstractBox->AbSelected || pBo1 == pFrame->FrSelectionBegin.VsBox)
+	     if (pBo1->BxAbstractBox->AbSelected ||
+		 pBo1 == pFrame->FrSelectionBegin.VsBox)
 		pBo1 = pBo1->BxNext;
 	     else
 		return;		/* aucune boite n'est visible */
@@ -798,21 +727,25 @@ ThotBool            actif;
 	       {
 		 if (!pBo1->BxAbstractBox->AbHorizPos.PosUserSpecified)
 		   /* the box position is not given by the user */
+		   {
 		   if (x + dx < xmin + 10)
 		     /* scroll the window */
 		     HorizontalScroll (frame, x + dx - xmin - 10, 0);
 		   else if (x + dx > xmax - 10)
 		     /* scroll the window */
 		     HorizontalScroll (frame, x + dx - xmax + 10, 0);
+		   }
 
 		 if (!pBo1->BxAbstractBox->AbVertPos.PosUserSpecified)
 		   /* the box position is not given by the user */
+		   {
 		   if (y + pBo1->BxHeight < ymin + dy)
 		     /* scroll the window */
 		     VerticalScroll (frame, y + pBo1->BxHeight - ymin - dy, 0);
 		   else if (y > ymax - dy)
 		     /* scroll the window */
 		     VerticalScroll (frame, y - ymax + dy, 0);
+		   }
 	       }
 	  }
      }
@@ -823,14 +756,7 @@ ThotBool            actif;
    IsAbsBoxVisible retourne Vrai si le pAb deborde de la          
    frame du document.                                       
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool            IsAbsBoxVisible (int frame, PtrAbstractBox pAb)
-#else  /* __STDC__ */
-ThotBool            IsAbsBoxVisible (frame, pAb)
-int                 frame;
-PtrAbstractBox      pAb;
-
-#endif /* __STDC__ */
+ThotBool IsAbsBoxVisible (int frame, PtrAbstractBox pAb)
 {
    ViewFrame          *pFrame;
    int                 y, ymax;
@@ -841,7 +767,8 @@ PtrAbstractBox      pAb;
       return (FALSE);		/* pas de pave a tester */
    else if (pAb->AbBox == NULL)
       return (FALSE);		/* pas de boite a tester */
-   else if (pAb->AbVisibility < pFrame->FrVisibility || pAb->AbBox->BxType == BoGhost)
+   else if (pAb->AbVisibility < pFrame->FrVisibility ||
+	    pAb->AbBox->BxType == BoGhost)
       return (FALSE);		/* la boite n'est pas visible par definition */
    else
      {
