@@ -1,23 +1,14 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996.
+ *  (c) COPYRIGHT INRIA, 1996-2001.
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
 
-/*
- * Warning:
- * This module is part of the Thot library, which was originally
- * developed in French. That's why some comments are still in
- * French, but their translation is in progress and the full module
- * will be available in English in the next release.
- * 
- */
- 
 /*
  * Spell checking
  *
- * Author: H. Richy (INRISA)
+ * Authors: I. Vatton (INRIA), H. Richy (INRIA)
  *
  */
 
@@ -40,8 +31,15 @@
 #undef THOT_EXPORT
 #define THOT_EXPORT
 #include "word_tv.h"
+/* description des chiffres romains (majuscule) */
+static char         NRomain[] = {
+  'M', 'C', 'D', 'L', 'X', 'V', 'I', EOS
+};
+static char         NRomainIsole[] = {
+  'C', 'L', 'V', EOS
+};
 
-extern UCHAR_T Code[256];
+extern unsigned char Code[256];
 extern unsigned      ReverseCode[NbLtr];
 static ThotBool      Clavier_charge;
 static int           Tsub[NbLtr][NbLtr];
@@ -76,17 +74,11 @@ static int           type_err;	/* Type du mot errone (majuscule, SmallLettering)
    Returns -1 if the dictionary can't be loaded.                     
    Returns 1 if the dictionary is loaded.                            
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool            TtaLoadDocumentDictionary (PtrDocument document, int *pDictionary, ThotBool ToCreate)
-#else  /* __STDC__ */
-ThotBool            TtaLoadDocumentDictionary (document, pDictionary, ToCreate)
-PtrDocument         document;
-int                *pDictionary;
-ThotBool            ToCreate;
-#endif /* __STDC__ */
+ThotBool TtaLoadDocumentDictionary (PtrDocument document, int *pDictionary,
+				    ThotBool ToCreate)
 {
-  STRING            extenddic;
-  CHAR_T               path[MAX_PATH], dictname[MAX_PATH];
+  char              *extenddic;
+  char               path[MAX_PATH], dictname[MAX_PATH];
 
   /* dictionary name = document name */
   *pDictionary = (int) NULL;
@@ -96,16 +88,16 @@ ThotBool            ToCreate;
     {
       TtaExtractName (extenddic, path, dictname);
       if (dictname[0] == EOS)
-	ustrcpy (dictname, TEXT("dictionary.DCT"));
+	strcpy (dictname, "dictionary.DCT");
     }
   else
     {
       path[0] = EOS;
-      ustrcpy (dictname, TEXT("dictionary.DCT"));
+      strcpy (dictname, "dictionary.DCT");
     }
 
   if (path[0] == EOS ||  !TtaCheckDirectory (path))
-    ustrcpy (path, TtaGetEnvString ("APP_HOME"));
+    strcpy (path, TtaGetEnvString ("APP_HOME"));
   LoadTreatedDict ((PtrDict *) pDictionary, 0, document, dictname,
 		   path, FALSE, ToCreate);
   return (*pDictionary != EOS);
@@ -114,19 +106,14 @@ ThotBool            ToCreate;
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         Asci2Code (STRING string)
-#else  /* __STDC__ */
-static void         Asci2Code (string)
-STRING              string;
-#endif /* __STDC__ */
+static void         Asci2Code (char *string)
 {
    int                 i;
 
    i = 0;
    while (string[i] != EOS)
      {
-	string[i] = Code[(UCHAR_T) string[i]];
+	string[i] = Code[(unsigned char) string[i]];
 	i++;
      }
 }
@@ -134,18 +121,13 @@ STRING              string;
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         Code2Asci (STRING string)
-#else  /* __STDC__ */
-static void         Code2Asci (string)
-STRING              string;
-#endif /* __STDC__ */
+static void         Code2Asci (char *string)
 {
    int                 i = 0;
 
    while (string[i] != EOS)
      {
-	string[i] = ReverseCode[(UCHAR_T) string[i]];
+	string[i] = ReverseCode[(unsigned char) string[i]];
 	i++;
      }
 }
@@ -154,16 +136,11 @@ STRING              string;
 /*----------------------------------------------------------------------
   minMAJ returns TRUE if the string doesn't contains only lowercases 
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool            minMAJ (STRING string)
-#else  /* __STDC__ */
-ThotBool            minMAJ (string)
-STRING              string;
-#endif /* __STDC__ */
+ThotBool            minMAJ (char *string)
 {
    int                 maj = 0;
    int                 i = 0;
-   CHAR_T                c;
+   char                c;
 
    while ((c = string[i]) != EOS && (maj == 0))
      {
@@ -176,14 +153,9 @@ STRING              string;
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-CHAR_T                tomin (CHAR_T caract)
-#else  /* __STDC__ */
-CHAR_T                tomin (caract)
-CHAR_T                caract;
-#endif /* __STDC__ */
+char                tomin (char caract)
 {
-   CHAR_T                c;
+   char                c;
 
    c = caract;
    if (isimaj (caract) != 0)
@@ -195,12 +167,7 @@ CHAR_T                caract;
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void         SetUpperCase (STRING string)
-#else  /* __STDC__ */
-void         SetUpperCase (string)
-STRING              string;
-#endif /* __STDC__ */
+void         SetUpperCase (char *string)
 {
    int                 i = 0;
 
@@ -215,12 +182,7 @@ STRING              string;
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void         SetCapital (STRING string)
-#else  /* __STDC__ */
-void         SetCapital (string)
-STRING              string;
-#endif /* __STDC__ */
+void         SetCapital (char *string)
 {
    if (isimin (string[0]) != 0)
       string[0] = toupper (string[0]);
@@ -230,16 +192,11 @@ STRING              string;
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool     IsUpperCase (STRING string)
-#else  /* __STDC__ */
-ThotBool     IsUpperCase (string)
-STRING              string;
-#endif /* __STDC__ */
+ThotBool     IsUpperCase (char *string)
 {
    int                 maj = 1;
    int                 i = 0;
-   CHAR_T                c;
+   char                c;
 
    while ((c = string[i]) != EOS && (maj != 0))
      {
@@ -252,16 +209,11 @@ STRING              string;
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool     IsCapital (STRING string)
-#else  /* __STDC__ */
-ThotBool     IsCapital (string)
-STRING              string;
-#endif /* __STDC__ */
+ThotBool     IsCapital (char *string)
 {
    int                 cap = 0;
    int                 i = 0;
-   CHAR_T                c;
+   char                c;
 
    if (string[0] != EOS && isimaj (string[0]) != 0)
      {
@@ -278,19 +230,14 @@ STRING              string;
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool            IsIso (STRING string)
-#else  /* __STDC__ */
-ThotBool            IsIso (string)
-STRING              string;
-#endif /* __STDC__ */
+ThotBool            IsIso (char *string)
 {
    int                 iso = 1;
    int                 i = 0;
 
    while (string[i] != EOS && (iso != 0))
      {
-	iso = isalphiso (string[i]) || string[i] == TEXT('-') || string[i] == TEXT('\'');
+	iso = isalphiso (string[i]) || string[i] == '-' || string[i] == '\'';
 	i++;
      }
    return (iso == 0) ? FALSE : TRUE;
@@ -304,13 +251,7 @@ STRING              string;
    retourne -3  si le mot est present dans le dict                          
    retourne >=0 si le mot n'est pas dans le dict (indice de sa place future) 
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-int                 WordInDictionary (CHAR_T word[MAX_WORD_LEN], PtrDict dict)
-#else  /* __STDC__ */
-int                 WordInDictionary (word, dict)
-CHAR_T                word[MAX_WORD_LEN];
-PtrDict             dict;
-#endif /* __STDC__ */
+int WordInDictionary (char word[MAX_WORD_LEN], PtrDict dict)
 {
    int                 inf, sup, med, rescomp, size;
 
@@ -321,7 +262,7 @@ PtrDict             dict;
      /* dictionnaire vide */
      return (-1);
 
-   size = ustrlen (word);
+   size = strlen (word);
    /* premier mot */
    inf = dict->DictLengths[size];
    if (size >= MAX_WORD_LEN || (dict->DictLengths[size + 1] - 1 > dict->DictNbWords))
@@ -334,7 +275,7 @@ PtrDict             dict;
      /* Recherche dichotomique */
      {
 	med = (sup + inf) / 2;
-	rescomp = ustrcmp (&dict->DictString[dict->DictWords[med]], word);
+	rescomp = strcmp (&dict->DictString[dict->DictWords[med]], word);
 	if (rescomp == 0)
 	  /* Mot present dans le dict */
 	  return (-3);
@@ -356,19 +297,12 @@ PtrDict             dict;
    0 si le mot est inconnu ou vide                         
    -1 s'il n'y a pas de dictionnaire pour verifier ce mot   
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-int                 CheckWord (CHAR_T word[MAX_WORD_LEN], Language language, PtrDict dict)
-#else  /* __STDC__ */
-int                 CheckWord (word, language, dict)
-CHAR_T                word[MAX_WORD_LEN];
-Language            language;
-PtrDict             dict;
-#endif /* __STDC__ */
+int CheckWord (char word[MAX_WORD_LEN], Language language, PtrDict dict)
 {
    ThotBool            present = TRUE;
    int                 res;
-   CHAR_T                word1[MAX_WORD_LEN];
-   CHAR_T                wordmin[MAX_WORD_LEN];
+   char                word1[MAX_WORD_LEN];
+   char                wordmin[MAX_WORD_LEN];
    PtrDict             globalDict;
    PtrDict             personalDict;
    PtrDict             dictsigle;
@@ -381,11 +315,11 @@ PtrDict             dict;
    if (word[0] == EOS)
       return (0);		/* mot vide */
 
-   if (ustrlen (word) >= 2)
+   if (strlen (word) >= 2)
      {
-	ustrcpy (word1, word);
+	strcpy (word1, word);
 	SmallLettering (word1);
-	ustrcpy (wordmin, word1);
+	strcpy (wordmin, word1);
 	Asci2Code (word1);
 
 	globalDict = (PtrDict) TtaGetPrincipalDictionary (language);
@@ -426,7 +360,7 @@ PtrDict             dict;
 		     type_err = 1;	/* SmallLettering ou melange */
 	       }
 	     /* recopier ce mot errone' dans ChkrErrWord */
-	     ustrcpy (ChkrErrWord, word);
+	     strcpy (ChkrErrWord, word);
 	  }
      }
    res = (present == TRUE) ? 1 : 0;
@@ -435,14 +369,7 @@ PtrDict             dict;
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static int          Insert (int x, int pWord, PtrDict dict)
-#else  /* __STDC__ */
-static int          Insert (x, pWord, dict)
-int                 x;
-int                 pWord;
-PtrDict             dict;
-#endif /* __STDC__ */
 {
    int                 i, k;
 
@@ -473,13 +400,7 @@ PtrDict             dict;
    1 si le mot a pu etre ajoute dans le dictionnaire 
    par defaut : tous les mots nouveaux sont insecables        
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static int          InsertWord (PtrDict dict, CHAR_T word[MAX_WORD_LEN])
-#else  /* __STDC__ */
-static int          InsertWord (dict, word)
-PtrDict             dict;
-CHAR_T                word[MAX_WORD_LEN];
-#endif /* __STDC__ */
+static int          InsertWord (PtrDict dict, char word[MAX_WORD_LEN])
 {
    int                 size, place, i, k;
 
@@ -490,8 +411,10 @@ CHAR_T                word[MAX_WORD_LEN];
       return (0);		/* mot deja present dans le dictionnaire */
    if (place == -1)		/* dictionnaire vide */
       place = 0;		/* indice pour inserer dans ce dictionaire */
-   size = ustrlen (word) + 1;
-   if ((dict->DictNbWords >= dict->DictMaxWords - 1) || (dict->DictNbChars >= dict->DictMaxChars + size))
+   size = strlen (word) + 1;
+   /* JK: Changed the limit to - 2 instead of -1 because we had a
+      memory overwrite problem otherwise */
+   if ((dict->DictNbWords >= dict->DictMaxWords - 2) || (dict->DictNbChars >= dict->DictMaxChars + size))
       return (-1);
    else
      {
@@ -507,7 +430,7 @@ CHAR_T                word[MAX_WORD_LEN];
 		dict->DictString[index--] = dict->DictString[k];
 	  }
 	/* insertion nouveau mot */
-	ustrcpy (&dict->DictString[dict->DictWords[place]], word);
+	strcpy (&dict->DictString[dict->DictWords[place]], word);
 	/* mise a jour des pointeurs sur les mots */
 	for (i = dict->DictNbWords + 1; i >= place; i--)
 	   dict->DictWords[i + 1] = dict->DictWords[i] + size;
@@ -525,20 +448,14 @@ CHAR_T                word[MAX_WORD_LEN];
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         Cmp (CHAR_T wordtest[], PtrDict dict)
-#else  /* __STDC__ */
-static void         Cmp (wordtest, dict)
-CHAR_T                wordtest[];
-PtrDict             dict;
-#endif /* __STDC__ */
+static void         Cmp (char wordtest[], PtrDict dict)
 {
   int                 dist[MAX_WORD_LEN][MAX_WORD_LEN];
-  UCHAR_T       wordcmp[MAX_WORD_LEN];
+  unsigned char       wordcmp[MAX_WORD_LEN];
   int                 Lg, idx, sup, pWord, seuilCourant;
   int                 i, j, k, x, y, z;
   int                 difference, iteration, size, largeur, word;
-  UCHAR_T       currentWord[MAX_WORD_LEN];
+  unsigned char       currentWord[MAX_WORD_LEN];
   int                 minimum;
   int                 deb, fin;
   int                 derniere_ligne = MAX_WORD_LEN; /* last computed line */
@@ -559,10 +476,10 @@ PtrDict             dict;
   for (i = 1; i < MAX_WORD_LEN; i++)
     dist[0][i] = dist[0][i - 1] + KI;
   
-  ustrcpy (wordcmp, wordtest);
+  strcpy (wordcmp, wordtest);
   SmallLettering (wordcmp);
   Asci2Code (wordcmp);
-  Lg = ustrlen (wordcmp);
+  Lg = strlen (wordcmp);
   seuilCourant = Seuil[Lg];
   largeur = Delta[Lg];
   
@@ -622,7 +539,7 @@ PtrDict             dict;
 		 a cette valeur, il est inutile de faire le calcul */
 	      if (k <= derniere_ligne)
 		{
-		  ustrcpy (currentWord, &dict->DictString[pWord]);
+		  strcpy (currentWord, &dict->DictString[pWord]);
 		  
 		  /* calcul */
 		  for (j = k; j <= size; j++)
@@ -681,13 +598,13 @@ static void         LoadSpellChecker ()
    int                 i;
    int                 pWord;
 
-   ustrcpy (ChkrCorrection[0], ChkrErrWord);
+   strcpy (ChkrCorrection[0], ChkrErrWord);
    for (i = 0; i < NC; i++)
      {
 	pWord = WordsList[i];
 	if (pWord >= 0)
 	  {
-	     ustrcpy (ChkrCorrection[i + 1], &DictsList[i]->DictString[pWord]);
+	     strcpy (ChkrCorrection[i + 1], &DictsList[i]->DictString[pWord]);
 	     Code2Asci (ChkrCorrection[i + 1]);
 	     switch (type_err)
 		   {
@@ -707,22 +624,17 @@ static void         LoadSpellChecker ()
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static void         SaveDictFile (PtrDict docDict)
-#else  /* __STDC__ */
-static void         SaveDictFile (docDict)
-PtrDict             docDict;
-#endif /* __STDC__ */
 {
    FILE               *f;
    int                 i, j;
-   CHAR_T                tempbuffer[THOT_MAX_CHAR];
-   CHAR_T                word[MAX_WORD_LEN];
+   char                tempbuffer[THOT_MAX_CHAR];
+   char                word[MAX_WORD_LEN];
 
-   FindCompleteName (docDict->DictName, _EMPTYSTR_, docDict->DictDirectory, tempbuffer, &i);
+   FindCompleteName (docDict->DictName, "", docDict->DictDirectory, tempbuffer, &i);
    if (docDict->DictNbWords >= 0)
      {
-	f = ufopen (tempbuffer, _WriteMODE_);
+	f = fopen (tempbuffer, "w");
 	if (f != NULL)
 	  {
 	    /* enregistrer d'abord nb words and nb chars effectifs */
@@ -732,7 +644,7 @@ PtrDict             docDict;
 
 	     for (i = 0; i <= docDict->DictNbWords; i++)
 	       {
-		  ustrcpy (word, &docDict->DictString[docDict->DictWords[i]]);
+		  strcpy (word, &docDict->DictString[docDict->DictWords[i]]);
 		  Code2Asci (word);
 		  fprintf (f, "%s\n", word);
 		  /* ajouter le CR de fin de ligne */
@@ -757,22 +669,16 @@ PtrDict             docDict;
    (s'il n'y a plus de place : ferme et ouvre avec plus d'espace) 
    creation eventuelle et initialisation de ChkrFileDict             
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                AddWord (CHAR_T word[MAX_WORD_LEN], PtrDict * pDict)
-#else  /* __STDC__ */
-void                AddWord (word, pDict)
-CHAR_T                word[MAX_WORD_LEN];
-PtrDict            *pDict;
-#endif /* __STDC__ */
+void                AddWord (char word[MAX_WORD_LEN], PtrDict * pDict)
 {
-   CHAR_T                word1[MAX_WORD_LEN];
+   char                word1[MAX_WORD_LEN];
    int                 ret;
    Name                DiNom;
    ThotBool            OKinsere = TRUE;
    PtrDict             docDict;
 
    docDict = *pDict;
-   ustrcpy (word1, word);
+   strcpy (word1, word);
    /* verifier que ce mot est bien en caracteres iso */
    if (IsIso (word1))
      {
@@ -802,7 +708,7 @@ PtrDict            *pDict;
 		    /* dictionnaire plein */
 		    SaveDictFile (docDict);
 		    /* rechargement du dictionnaire avec plus de memoire */
-		    ustrcpy (DiNom, docDict->DictName);
+		    strcpy (DiNom, docDict->DictName); 
 		    if (ReloadDictionary (pDict) == TRUE)
 		      {
 			 docDict = *pDict;
@@ -852,7 +758,7 @@ static void            InitChecker ()
 
    /* Initialisation de la correction */
    for (j = 0; j <= NC; j++)
-      ustrcpy (ChkrCorrection[j],TEXT("$"));
+      strcpy (ChkrCorrection[j],"$");
 }
 
 
@@ -862,13 +768,7 @@ static void            InitChecker ()
    met dans ChkrCorrection les propositions de correction du mot       
    qui se trouve dans ChkrErrWord                                   
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                GiveProposal (Language language, PtrDict docDict)
-#else  /* __STDC__ */
-void                GiveProposal (language, docDict)
-Language            language;
-PtrDict             docDict;
-#endif /* __STDC__ */
 {
    PtrDict             globalDict;
    PtrDict             personalDict;
@@ -909,15 +809,12 @@ PtrDict             docDict;
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         init_Tsub (FILE * ftsub)
-#else  /* __STDC__ */
-static void         init_Tsub (ftsub)
-FILE               *ftsub;
-#endif /* __STDC__ */
+static void init_Tsub (FILE *ftsub)
 {
+   unsigned char       ch1[80], ch2[80], ch3[80];
+   unsigned char       x, y, valeur;
    int                 i, j;
-   UCHAR_T       ch1[80], ch2[80], ch3[80];
+   int                 coeff;
 
    /* initialisation de Tsub */
    for (i = 0; i < NbLtr; i++)
@@ -925,24 +822,21 @@ FILE               *ftsub;
 	 Tsub[i][j] = KD;
    while (fscanf (ftsub, "%s%s%s", ch1, ch2, ch3) != EOF)
      {
-	int                 coeff;
-	UCHAR_T       x, y, valeur;
-
-	usscanf (ch1, TEXT("%c"), &x);
-	usscanf (ch2, TEXT("%c"), &y);
-	usscanf (ch3, TEXT("%c"), &valeur);
+	sscanf (ch1, "%c", &x);
+	sscanf (ch2, "%c", &y);
+	sscanf (ch3, "%c", &valeur);
 	switch (valeur)
-	      {
-		 case TEXT('b'):
-		    coeff = KB;
-		    break;
-		 case TEXT('m'):
-		    coeff = KM;
-		    break;
-		 default:
-		    coeff = KD;
-		    break;
-	      }
+	  {
+	  case 'b':
+	    coeff = KB;
+	    break;
+	  case 'm':
+	    coeff = KM;
+	    break;
+	  default:
+	    coeff = KD;
+	    break;
+	  }
 	Tsub[Code[x]][Code[y]] = coeff;
      }
    fclose (ftsub);
@@ -951,12 +845,7 @@ FILE               *ftsub;
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static void         init_param (FILE * fd)
-#else  /* __STDC__ */
-static void         init_param (fd)
-FILE               *fd;
-#endif /* __STDC__ */
 {
    int                 i, cc, ii, oo, pp, bb, mm, dd, ss, rr;
 
@@ -1000,12 +889,7 @@ FILE               *fd;
 
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static void         DefaultParams (int lettres)
-#else  /* __STDC__ */
-static void         DefaultParams (lettres)
-int                 lettres;
-#endif /* __STDC__ */
 {
    int                 i;
 
@@ -1025,12 +909,12 @@ int                 lettres;
   ----------------------------------------------------------------------*/
 int                 ParametrizeChecker ()
 {
-   int                 ret;
    FILE               *fparam;
-   Buffer              paramnom;
    FILE               *ftsub;
-   Buffer              clavnom;
-   STRING              corrpath;
+   char                paramnom[MAX_LENGTH];
+   char                clavnom[MAX_LENGTH];
+   char               *corrpath;
+   int                 ret;
 
    ret = 1;
    /* initialisations des parametres du correcteur */
@@ -1039,16 +923,13 @@ int                 ParametrizeChecker ()
 	/* remplir corrpath pour acces aux fichiers param et clavier */
 	corrpath = TtaGetEnvString ("DICOPAR");
 	if (corrpath == NULL)
-	  {
-	     /* pas de variable d'environnement DICOPAR */
-	     TtaDisplayMessage (INFO, TtaGetMessage (LIB, TMSG_MISSING_DICOPAR), "DICOPAR");
-	     ret = 0;
-	  }
+	  ret = 0;
 	else
 	  {
 	     /* Lecture du fichier parametres */
-	     ustrcpy (paramnom, corrpath);
-	     ustrcat (paramnom, TEXT("/param"));
+	     strcpy (paramnom, corrpath);
+         strcat (paramnom, DIR_STR);
+	     strcat (paramnom, "param");
 	     if ((fparam = fopen (paramnom, "r")) != NULL)
 	       /* Existence du fichier */
 		init_param (fparam);
@@ -1059,8 +940,9 @@ int                 ParametrizeChecker ()
 	       }
 
 	     /* Lecture du  fichier clavier */
-	     ustrcpy (clavnom, corrpath);
-	     ustrcat (clavnom, TEXT("/clavier"));
+	     strcpy (clavnom, corrpath);
+         strcat (clavnom, DIR_STR);
+	     strcat (clavnom, "clavier");
 	     if ((ftsub = fopen (clavnom, "r")) != NULL)
 	       /* Existence du fichier */
 	       {
@@ -1081,24 +963,18 @@ int                 ParametrizeChecker ()
 /*----------------------------------------------------------------------
    WordReplace                                               
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                WordReplace (CHAR_T orgWord[MAX_WORD_LEN], CHAR_T newWord[MAX_WORD_LEN])
-#else  /* __STDC__ */
-void                WordReplace (orgWord, newWord)
-CHAR_T                orgWord[MAX_WORD_LEN];
-CHAR_T                newWord[MAX_WORD_LEN];
-#endif /* __STDC__ */
+void WordReplace (char orgWord[MAX_WORD_LEN], char newWord[MAX_WORD_LEN])
 {
    int                 idx;
    int                 stringLength;	/* longueur de cette chaine */
-   CHAR_T                pChaineRemplace[MAX_WORD_LEN]; /* la chaine de remplacement */
+   char                pChaineRemplace[MAX_WORD_LEN]; /* la chaine de remplacement */
    int                 LgChaineRempl;	/* longueur de cette chaine */
 
    /* remplacer le mot errone par le mot corrige */
-   stringLength = ustrlen (orgWord);
+   stringLength = strlen (orgWord);
    /* initialiser LgChaineRempl et pChaineRemplace */
-   LgChaineRempl = ustrlen (newWord);
-   ustrcpy (pChaineRemplace, newWord);
+   LgChaineRempl = strlen (newWord);
+   strcpy (pChaineRemplace, newWord);
 
    /* substitue la nouvelle chaine et la selectionne */
    if (ChkrRange->SStartToEnd)
@@ -1195,17 +1071,11 @@ ThotBool            CheckChangeSelection ()
    retourne TRUE si oui                               
    FALSE sinon                               
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static ThotBool     CheckCharList (CHAR_T car, STRING listcar)
-#else  /* __STDC__ */
-static ThotBool     CheckCharList (car, listcar)
-CHAR_T                car;
-STRING              listcar;
-#endif /* __STDC__ */
+static ThotBool     CheckCharList (char car, char *listcar)
 {
    int                 i;
 
-   for (i = 0; (size_t) i < ustrlen (listcar); i++)
+   for (i = 0; (size_t) i < strlen (listcar); i++)
      {
 	if (car == listcar[i])
 	   return (TRUE);
@@ -1217,12 +1087,7 @@ STRING              listcar;
    ACeCar retourne TRUE si le mot contient un des caracteres       
    contenu dans ListCar.                                    
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static ThotBool     ACeCar (CHAR_T word[MAX_WORD_LEN])
-#else  /* __STDC__ */
-static ThotBool     ACeCar (word)
-CHAR_T                word[MAX_WORD_LEN];
-#endif /* __STDC__ */
+static ThotBool     ACeCar (char word[MAX_WORD_LEN])
 {
 
    ThotBool            result;
@@ -1230,7 +1095,7 @@ CHAR_T                word[MAX_WORD_LEN];
    int                 longueur;
 
    result = FALSE;
-   longueur = ustrlen (word);
+   longueur = strlen (word);
    if (longueur > 0)
      {
 	for (i = 0; i < longueur && (result == FALSE); i++)
@@ -1244,12 +1109,7 @@ CHAR_T                word[MAX_WORD_LEN];
    IncludeANumber                                                       
    retourne TRUE si le mot contient au moins un chiffre arabe.     
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static ThotBool     IncludeANumber (CHAR_T word[MAX_WORD_LEN])
-#else  /* __STDC__ */
-static ThotBool     IncludeANumber (word)
-CHAR_T                word[MAX_WORD_LEN];
-#endif /* __STDC__ */
+static ThotBool     IncludeANumber (char word[MAX_WORD_LEN])
 {
 
    ThotBool            result;
@@ -1257,11 +1117,11 @@ CHAR_T                word[MAX_WORD_LEN];
    int                 longueur;
 
    result = FALSE;
-   longueur = ustrlen (word);
+   longueur = strlen (word);
    if (longueur > 0)
      {
 	for (i = 0; i < longueur && (result == FALSE); i++)
-	   if (word[i] >= TEXT('0') && word[i] <= TEXT('9'))
+	   if (word[i] >= '0' && word[i] <= '9')
 	      result = TRUE;
      }
    return result;
@@ -1271,12 +1131,7 @@ CHAR_T                word[MAX_WORD_LEN];
    IsANumber retourne TRUE si le mot est forme' uniquement de    
    chiffres decimaux arabes.                                       
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static ThotBool     IsANumber (CHAR_T word[MAX_WORD_LEN])
-#else  /* __STDC__ */
-static ThotBool     IsANumber (word)
-CHAR_T                word[MAX_WORD_LEN];
-#endif /* __STDC__ */
+static ThotBool     IsANumber (char word[MAX_WORD_LEN])
 {
 
    ThotBool            result;
@@ -1284,13 +1139,13 @@ CHAR_T                word[MAX_WORD_LEN];
    int                 longueur;
 
    result = FALSE;
-   longueur = ustrlen (word);
+   longueur = strlen (word);
    if (longueur > 0)
      {
 
 	result = TRUE;
 	for (i = 0; i < longueur && result; i++)
-	   if (word[i] < TEXT('0') || word[i] > TEXT('9'))
+	   if (word[i] < '0' || word[i] > '9')
 	      result = FALSE;
      }
    return result;
@@ -1300,36 +1155,15 @@ CHAR_T                word[MAX_WORD_LEN];
    InRoman retourne TRUE si le mot est forme' uniquement de       
    chiffres romains.                                               
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static ThotBool     InRoman (CHAR_T word[MAX_WORD_LEN])
-#else  /* __STDC__ */
-static ThotBool     InRoman (word)
-CHAR_T                word[MAX_WORD_LEN];
-#endif /* __STDC__ */
+static ThotBool     InRoman (char word[MAX_WORD_LEN])
 {
-   /* description des chiffres romains (majuscule) */
-   static CHAR_T         NRomain[] = {
-#         if defined(_I18N_) || defined(__JIS__)
-          L'M', L'C', L'D', L'L', L'X', L'V', L'I'
-#         else /* defined(_I18N_) || defined(__JIS__) */
-          'M', 'C', 'D', 'L', 'X', 'V', 'I'
-#         endif /* defined(_I18N_) || defined(__JIS__) */    
-   };
-   static CHAR_T         NRomainIsole[] = {
-#         if defined(_I18N_) || defined(__JIS__)
-          L'C', L'L', L'V'
-#         else /* defined(_I18N_) || defined(__JIS__) */
-          'C', 'L', 'V'
-#         endif /* defined(_I18N_) || defined(__JIS__) */    
-   };
-
    ThotBool            result;
    int                 i, j, nbcar;
    int                 longueur, lg1;
-   CHAR_T                cecar;
+   char                cecar;
 
    result = FALSE;
-   longueur = ustrlen (word);
+   longueur = strlen (word);
    if (longueur > 0)
      {
 	result = TRUE;
@@ -1364,7 +1198,7 @@ CHAR_T                word[MAX_WORD_LEN];
 	  }
 
 	/* ne pas considerer "M" comme un romain */
- if (ustrlen (word) == 1 && word[0] == TEXT('M'))
+ if (strlen (word) == 1 && word[0] == 'M')
  result = FALSE;
 	/* verifier aussi l'ordre des I V X L C D M */
 	/* A FAIRE */
@@ -1379,12 +1213,7 @@ CHAR_T                word[MAX_WORD_LEN];
    chiffre arabe, car. special)                                       
    retourne FALSE sinon : le mot sera alors verifie par le correcteur 
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static ThotBool     IgnoreWord (CHAR_T word[MAX_WORD_LEN])
-#else  /* __STDC__ */
-static ThotBool     IgnoreWord (word)
-CHAR_T                word[MAX_WORD_LEN];
-#endif /* __STDC__ */
+static ThotBool     IgnoreWord (char word[MAX_WORD_LEN])
 {
 
    ThotBool            result = FALSE;
@@ -1417,72 +1246,65 @@ CHAR_T                word[MAX_WORD_LEN];
    selectionne dans la vue courante du document.                
    Le mot errone' est mis dans ChkrErrWord.                           
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                NextSpellingError (CHAR_T word[MAX_WORD_LEN], PtrDict docDict)
-#else  /* __STDC__ */
-void                NextSpellingError (word, docDict)
-CHAR_T                word[MAX_WORD_LEN];
-PtrDict             docDict;
-
-#endif /* __STDC__ */
+void NextSpellingError (char word[MAX_WORD_LEN], PtrDict docDict)
 {
-   Language            language;
-   ThotBool            ok, novalid;
-   int                 i;
+  Language            language;
+  ThotBool            ok, novalid;
+  int                 i;
 
-   i = 0;
-   do
-     {
-	/* Recherche un mot a corriger */
-	novalid = TRUE;
-        ok = TRUE;
-	while (ok && novalid)
-	  {
-	     if (ChkrRange->SStartToEnd)
-		ok = SearchNextWord (&ChkrElement, &ChkrIndChar, word, ChkrRange);
-	     else
-		ok = SearchPreviousWord (&ChkrElement, &ChkrIndChar, word, ChkrRange);
-	     /* Is it a valid selection ? */
-	     if (ok && ChkrElement->ElParent != NULL)
-		novalid = TypeHasException (ExcNoSpellCheck, ChkrElement->ElParent->ElTypeNumber, ChkrElement->ElParent->ElStructSchema);
-	  }
-
-	if (ok)
-	  {
-	     /* verifie si c'est un nombre ou s'il doit etre ignore' */
-	     if (IsANumber (word) || IgnoreWord (word))
-		i = -1;
-	     else
-	       {
-		  /* Charge si necessaire les dictionnaires de la langue */
-		  language = ChkrElement->ElLanguage;
-		  if (language != ChkrLanguage)
-		    {
-		       ChkrLanguage = language;
-		       TtaLoadLanguageDictionaries (ChkrLanguage);
-		    }
-		  i = CheckWord (word, ChkrLanguage, docDict);
-		  /* 1   = mot trouve dans l'un des dict */
-		  /* 0   = mot inconnu ou vide */
-		  /* -1  = pas de dict pour verifier un mot de cette language */
-		  if (i != 1)
-		     /* est-ce un chiffre romain correct */
-		     i = (InRoman (word) == TRUE) ? 1 : i;
-	       }
-	  }
-     }
-   /* saute les mots qui sont dans une langue SANS dictionnaire */
-   while (ok && (i > 0 || i == -1));
-
-   i = ustrlen (word);
-   if (i > 0)
-     {
-	/* on a trouve un mot */
-	/* selectionner le mot a corriger */
-	if (ChkrRange->SStartToEnd)
-	   SelectString (ChkrRange->SDocument, ChkrElement, ChkrIndChar - i + 1, ChkrIndChar);
-	else
-	   SelectString (ChkrRange->SDocument, ChkrElement, ChkrIndChar + 1, ChkrIndChar + i);
-     }
-   ustrcpy (ChkrErrWord, word);
+  i = 0;
+  do
+    {
+      /* Recherche un mot a corriger */
+      novalid = TRUE;
+      ok = TRUE;
+      while (ok && novalid)
+	{
+	  if (ChkrRange->SStartToEnd)
+	    ok = SearchNextWord (&ChkrElement, &i, &ChkrIndChar, word, ChkrRange);
+	  else
+	    ok = SearchPreviousWord (&ChkrElement, &ChkrIndChar, &i, word, ChkrRange);
+	  /* Is it a valid selection ? */
+	  if (ok && ChkrElement->ElParent != NULL)
+	    novalid = TypeHasException (ExcNoSpellCheck, ChkrElement->ElParent->ElTypeNumber, ChkrElement->ElParent->ElStructSchema);
+	}
+      
+      if (ok)
+	{
+	  /* verifie si c'est un nombre ou s'il doit etre ignore' */
+	  if (IsANumber (word) || IgnoreWord (word))
+	    i = -1;
+	  else
+	    {
+	      /* Charge si necessaire les dictionnaires de la langue */
+	      language = ChkrElement->ElLanguage;
+	      if (language != ChkrLanguage)
+		{
+		  ChkrLanguage = language;
+		  TtaLoadLanguageDictionaries (ChkrLanguage);
+		}
+	      i = CheckWord (word, ChkrLanguage, docDict);
+	      /* 1   = mot trouve dans l'un des dict */
+	      /* 0   = mot inconnu ou vide */
+	      /* -1  = pas de dict pour verifier un mot de cette language */
+	      if (i != 1)
+		/* est-ce un chiffre romain correct */
+		i = (InRoman (word) == TRUE) ? 1 : i;
+	    }
+	}
+    }
+  /* saute les mots qui sont dans une langue SANS dictionnaire */
+  while (ok && (i > 0 || i == -1));
+  
+  i = strlen (word);
+  if (i > 0)
+    {
+      /* on a trouve un mot */
+      /* selectionner le mot a corriger */
+      if (ChkrRange->SStartToEnd)
+	SelectString (ChkrRange->SDocument, ChkrElement, ChkrIndChar - i + 1, ChkrIndChar);
+      else
+	SelectString (ChkrRange->SDocument, ChkrElement, ChkrIndChar + 1, ChkrIndChar + i);
+    }
+  strcpy (ChkrErrWord, word);
 }
