@@ -1,6 +1,6 @@
 /*
  *
- *  (c) COPYRIGHT INRIA 1998.
+ *  (c) COPYRIGHT INRIA 1998-2001
  *  Please read the full copyright statement in file COPYRIGHT.
  *
  */
@@ -54,13 +54,7 @@
 /*----------------------------------------------------------------------
    HistError
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static void HistError (int errorCode)
-#else  /* __STDC__ */
-static void HistError (errorCode)
-int errorCode;
-
-#endif /* __STDC__ */
 {
 #ifdef THOT_DEBUG
    fprintf (stderr, "**** Undo error %d ****\n", errorCode);
@@ -71,14 +65,7 @@ int errorCode;
    UpdateHistoryLength
    Add diff to variable pDoc->DocNbEditsInHistory
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static void UpdateHistoryLength (int diff, PtrDocument pDoc)
-#else  /* __STDC__ */
-static void UpdateHistoryLength (diff, pDoc)
-     int diff;
-     PtrDocument pDoc;
-
-#endif /* __STDC__ */
 {
    if (pDoc->DocNbEditsInHistory == 0 && diff > 0)
      /* enable Undo command */
@@ -93,14 +80,7 @@ static void UpdateHistoryLength (diff, pDoc)
    UpdateRedoLength
    Add diff to variable pDoc->DocNbUndone
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static void UpdateRedoLength (int diff, PtrDocument pDoc)
-#else  /* __STDC__ */
-static void UpdateRedoLength (diff, pDoc)
-     int diff;
-     PtrDocument pDoc;
-
-#endif /* __STDC__ */
 {
    if (pDoc->DocNbUndone == 0 && diff > 0)
      /* enable Redo command */
@@ -116,14 +96,7 @@ static void UpdateRedoLength (diff, pDoc)
    Remove the last editing operation from the undo or redo queue
    (depending on parameter undo) and return it.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static PtrEditOperation UnchainLatestOp (PtrDocument pDoc, ThotBool undo)
-#else  /* __STDC__ */
-static PtrEditOperation UnchainLatestOp (pDoc, undo)
-PtrDocument pDoc;
-ThotBool undo;
-
-#endif /* __STDC__ */
 {
    PtrEditOperation	*editOp, last;
 
@@ -133,7 +106,8 @@ ThotBool undo;
       editOp = &(pDoc->DocLastUndone);
    last = *editOp;
    *editOp = (*editOp)->EoPreviousOp;
-   (*editOp)->EoNextOp = NULL;
+   if (*editOp)
+     (*editOp)->EoNextOp = NULL;
    last->EoPreviousOp = NULL;
    return last;
 }
@@ -142,15 +116,7 @@ ThotBool undo;
    CancelAnEdit
    Remove and delete an editing operation from the history
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static void CancelAnEdit (PtrEditOperation editOp, PtrDocument pDoc, ThotBool undo)
-#else  /* __STDC__ */
-static void CancelAnEdit (editOp, pDoc, undo)
-PtrEditOperation editOp;
-PtrDocument pDoc;
-ThotBool undo;
-
-#endif /* __STDC__ */
 {
    PtrElement		pEl;
    PtrAttribute         pAttr;
@@ -215,10 +181,12 @@ ThotBool undo;
 
    if (editOp->EoType == EtDelimiter)
       /* update the number of editing sequences remaining in the queue */
+     {
       if (undo)
          UpdateHistoryLength (-1, pDoc);
       else
          UpdateRedoLength (-1, pDoc);
+     }
 
    /* free the editing operation descriptor */
    TtaFreeMemory (editOp);
@@ -229,13 +197,7 @@ ThotBool undo;
    ClearRedoQueue
    Clear the Redo queue of document pDoc
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static void ClearRedoQueue (PtrDocument pDoc)
-#else  /* __STDC__ */
-static void ClearRedoQueue (pDoc)
-PtrDocument pDoc;
-
-#endif /* __STDC__ */
 {
    PtrEditOperation editOp, previousEditOp;
 
@@ -258,13 +220,7 @@ PtrDocument pDoc;
    ClearHistory
    Clear the editing history of document pDoc
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void ClearHistory (PtrDocument pDoc)
-#else  /* __STDC__ */
-void ClearHistory (pDoc)
-PtrDocument pDoc;
-
-#endif /* __STDC__ */
 {
    PtrEditOperation editOp, previousEditOp;
 
@@ -294,14 +250,7 @@ PtrDocument pDoc;
    If the selection saved in Op refers to elements that have been copied
    from subtree pTree, change the saved selection to the corresponding copies.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static void ChangePointersOlderEdits (PtrEditOperation Op, PtrElement pTree)
-#else  /* __STDC__ */
-static void ChangePointersOlderEdits (Op, pTree)
-PtrEditOperation Op;
-PtrElement pTree;
-
-#endif /* __STDC__ */
 {
   PtrEditOperation	editOp, prevOp;
 
@@ -371,17 +320,8 @@ PtrElement pTree;
    removeWhenUndoing: element pEl to must be deleted when the operation will
 	 be undone.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void AddEditOpInHistory (PtrElement pEl, PtrDocument pDoc, ThotBool save,
 			 ThotBool removeWhenUndoing)
-#else  /* __STDC__ */
-void AddEditOpInHistory (pEl, pDoc, save, removeWhenUndoing)
-PtrElement pEl;
-PtrDocument pDoc;
-ThotBool save;
-ThotBool removeWhenUndoing;
-
-#endif /* __STDC__ */
 {
    PtrEditOperation	editOp;
    PtrElement		pCopy;
@@ -419,8 +359,8 @@ ThotBool removeWhenUndoing;
         operation descriptor */
      {
        /* do the copy */
-       pCopy = CopyTree (pEl, pDoc, pEl->ElAssocNum, pEl->ElStructSchema,
-		         pDoc, pEl->ElParent, FALSE, FALSE);
+       pCopy = CopyTree (pEl, pDoc, pEl->ElStructSchema, pDoc, pEl->ElParent,
+			 FALSE, FALSE, TRUE);
        /* store the copy in the editing operation descriptor */
        editOp->EoSavedElement = pCopy;
        /* if older editing operations in the history refer to elements that
@@ -434,15 +374,7 @@ ThotBool removeWhenUndoing;
    If Op and older editing operations in the history refer to attribute
    pAttr, change these reference to the corresponding copy pCopyAttr.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static void ChangeAttrPointersOlderEdits (PtrEditOperation Op, PtrAttribute pAttr, PtrAttribute pCopyAttr)
-#else  /* __STDC__ */
-static void ChangeAttrPointersOlderEdits (Op, pAttr, pCopyAttr)
-PtrEditOperation Op;
-PtrAttribute pAttr;
-PtrAttribute pCopyAttr;
-
-#endif /* __STDC__ */
 {
   PtrEditOperation	editOp;
 
@@ -472,17 +404,8 @@ PtrAttribute pCopyAttr;
    removeWhenUndoing: attribute pAttr to must be deleted when the operation
 	 will be undone.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void AddAttrEditOpInHistory (PtrAttribute pAttr, PtrElement pEl, PtrDocument pDoc, ThotBool save, ThotBool removeWhenUndoing)
-#else  /* __STDC__ */
-void AddAttrEditOpInHistory (pAttr, pEl, pDoc, save, removeWhenUndoing)
-PtrAttribute pAttr;
-PtrElement pEl;
-PtrDocument pDoc;
-ThotBool save;
-ThotBool removeWhenUndoing;
-
-#endif /* __STDC__ */
+void AddAttrEditOpInHistory (PtrAttribute pAttr, PtrElement pEl, PtrDocument pDoc,
+			     ThotBool save, ThotBool removeWhenUndoing)
 {
    PtrEditOperation	editOp = NULL;
    PtrAttribute		pCopy, pOldAttr;
@@ -553,17 +476,7 @@ ThotBool removeWhenUndoing;
    of document, only if it's an attribute operation for element oldEl.
    In that case, make it related to element newEl and attribute newAttr.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void ChangeLastRegisteredAttr (PtrElement oldEl, PtrElement newEl, PtrAttribute oldAttr, PtrAttribute newAttr, PtrDocument pDoc)
-#else  /* __STDC__ */
-void ChangeLastRegisteredAttr (oldEl, newEl, oldAttr, newAttr, pDoc)
-PtrElement oldEl;
-PtrElement newEl;
-PtrAttribute oldAttr;
-PtrAttribute newAttr;
-PtrDocument pDoc;
-
-#endif /* __STDC__ */
 {
    ThotBool	done;
 
@@ -609,13 +522,7 @@ PtrDocument pDoc;
    Replace the latest operation registered in the editing history of document:
    an attribute value modification becomes an attribute value deletion.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void ReplaceLastRegisteredAttr (PtrDocument pDoc)
-#else  /* __STDC__ */
-void ReplaceLastRegisteredAttr (pDoc)
-PtrDocument pDoc;
-
-#endif /* __STDC__ */
 {
    if (pDoc->DocLastEdit)
      if (pDoc->DocLastEdit->EoType == EtAttribute)
@@ -628,13 +535,7 @@ PtrDocument pDoc;
    CancelLastEditFromHistory
    Cancel the most recent editing operation registered in the editing history.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void CancelLastEditFromHistory (PtrDocument pDoc)
-#else  /* __STDC__ */
-void CancelLastEditFromHistory (pDoc)
-PtrDocument pDoc;
-
-#endif /* __STDC__ */
 {
    if (!pDoc->DocLastEdit)
      /* history empty. Error */
@@ -663,13 +564,7 @@ PtrDocument pDoc;
 
    Cancel the oldest sequence in the Undo (if undo==TRUE) or Redo queue.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static void CancelOldestSequence (PtrDocument pDoc, ThotBool undo)
-#else  /* __STDC__ */
-static void CancelOldestSequence (pDoc, undo)
-PtrDocument pDoc;
-ThotBool undo;
-#endif /* __STDC__ */
 {
    PtrEditOperation    editOp, nextOp;
 
@@ -699,16 +594,8 @@ ThotBool undo;
    firstSel, lastSel, firstSelChar, lastSelChar: indicate the selection
 	 that must be set when the operation will be undone.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void OpenHistorySequence (PtrDocument pDoc, PtrElement firstSel, PtrElement lastSel, int firstSelChar, int lastSelChar)
-#else  /* __STDC__ */
-void OpenHistorySequence (pDoc, firstSel, lastSel, firstSelChar, lastSelChar)
-PtrDocument pDoc;
-PtrElement firstSel;
-PtrElement lastSel;
-int firstSelChar;
-int lastSelChar;
-#endif /* __STDC__ */
+void OpenHistorySequence (PtrDocument pDoc, PtrElement firstSel,
+			  PtrElement lastSel, int firstSelChar, int lastSelChar)
 {
   PtrEditOperation	editOp;
 
@@ -745,13 +632,7 @@ int lastSelChar;
    Close a sequence of editing operations in the history.
    return FALSE if the Sequence is empty.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 ThotBool CloseHistorySequence (PtrDocument pDoc)
-#else  /* __STDC__ */
-ThotBool CloseHistorySequence (pDoc)
-PtrDocument pDoc;
-
-#endif /* __STDC__ */
 {
   ThotBool	result;
 
@@ -761,7 +642,7 @@ PtrDocument pDoc;
      HistError (9);
   else
      {
-     if (pDoc->DocLastEdit->EoType == EtDelimiter)
+     if (pDoc->DocLastEdit && pDoc->DocLastEdit->EoType == EtDelimiter)
         /* empty sequence, remove it */
         CancelAnEdit (pDoc->DocLastEdit, pDoc, TRUE);
      else
@@ -781,26 +662,20 @@ PtrDocument pDoc;
    Cancel the last sequence of editing operations registered in the
    editing history of document.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                CancelLastSequenceFromHistory (PtrDocument pDoc)
-#else  /* __STDC__ */
-void                CancelLastSequenceFromHistory (pDoc)
-PtrDocument         pDoc;
-
-#endif /* __STDC__ */
 {
    ThotBool	stop;
 
-   if (!pDoc->DocLastEdit)
-      /* history is empty */
-      return;
    stop = FALSE;
    while (!stop)
-      {
+   {
+      if (!pDoc->DocLastEdit)
+      /* history is empty */
+        return;
       if (pDoc->DocLastEdit->EoType == EtDelimiter)
-	 stop = TRUE;
+	    stop = TRUE;
       CancelAnEdit (pDoc->DocLastEdit, pDoc, TRUE);
-      }
+   }
 }
 
 /*----------------------------------------------------------------------
@@ -811,15 +686,7 @@ PtrDocument         pDoc;
    If reverse, the editing operation descriptor will decribe the reverse
    editing operation when returning.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static void	UndoOperation (ThotBool undo, Document doc, ThotBool reverse)
-#else  /* __STDC__ */
-static void	UndoOperation (undo, doc, reverse)
-ThotBool undo;
-Document doc;
-ThotBool reverse;
-
-#endif /* __STDC__ */
 {
    PtrEditOperation	editOp;
    PtrElement		pEl, pSibling,
@@ -836,6 +703,8 @@ ThotBool reverse;
    newPreviousSibling = NULL;
    newCreatedElement = NULL;
    newSavedElement = NULL;
+   SavedAttribute = NULL;
+   CreatedAttribute = NULL;
    pDoc = LoadedDocument [doc - 1];
    if (undo)
       editOp = pDoc->DocLastEdit;
@@ -1015,6 +884,8 @@ ThotBool reverse;
             pSibling = pSibling->ElPrevious;
             }
          notifyEl.position = nSiblings;
+	 /* tell the application that this element is deleted by the Undo
+	    command */
 	 notifyEl.info = 1;
          /* remove the element */
 	 if (!reverse)
@@ -1063,13 +934,7 @@ ThotBool reverse;
    Move the latest undone edit of document pDoc from the Undo queue to
    the Redo queue.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static void MoveEditToRedoQueue (PtrDocument pDoc)
-#else  /* __STDC__ */
-static void MoveEditToRedoQueue (pDoc)
-PtrDocument pDoc;
-
-#endif /* __STDC__ */
 {
    PtrEditOperation	editOp;
 
@@ -1088,13 +953,7 @@ PtrDocument pDoc;
    Move the latest redone edit of document pDoc from the Redo queue to
    the Undo queue.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static void MoveEditToUndoQueue (PtrDocument pDoc)
-#else  /* __STDC__ */
-static void MoveEditToUndoQueue (pDoc)
-PtrDocument pDoc;
-
-#endif /* __STDC__ */
 {
    PtrEditOperation	editOp;
 
@@ -1112,13 +971,7 @@ PtrDocument pDoc;
    OpenRedoSequence
    Open a sequence of editing operations in the Redo queue.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static void OpenRedoSequence (Document doc)
-
-#else  /* __STDC__ */
-static void OpenRedoSequence (doc)
-Document doc;
-#endif /* __STDC__ */
 {
   PtrDocument		pDoc;
   PtrEditOperation	editOp;
@@ -1155,13 +1008,7 @@ Document doc;
    of document doc and forget about this sequence: it won't be redone by
    the next Redo command issued by the user.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                UndoNoRedo (Document doc)
-#else  /* __STDC__ */
-void                UndoNoRedo (doc)
-Document            doc;
-
-#endif /* __STDC__ */
 {
    PtrDocument          pDoc;
    ThotBool		doit;
@@ -1193,16 +1040,10 @@ Document            doc;
    Undo the latest sequence of editing operations recorded in the history
    of document doc and register it in the Redo queue.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                TtcUndo (Document doc, View view)
-#else  /* __STDC__ */
-void                TtcUndo (doc, view)
-Document            doc;
-View                view;
-
-#endif /* __STDC__ */
 {
    PtrDocument          pDoc;
+   DisplayMode          dispMode;
    ThotBool		doit;
 
    pDoc = LoadedDocument [doc - 1];
@@ -1214,7 +1055,9 @@ View                view;
    OpenRedoSequence (doc);
 
    TtaUnselect (doc);
-   TtaSetDisplayMode (doc, DeferredDisplay);
+   dispMode = TtaGetDisplayMode (doc);
+   if (dispMode == DisplayImmediately)
+     TtaSetDisplayMode (doc, DeferredDisplay);
    /* disable structure checking */
    TtaSetStructureChecking (FALSE, doc);
 
@@ -1234,7 +1077,8 @@ View                view;
          Remove it from the editing history and put it in the Redo queue */
          MoveEditToRedoQueue (pDoc);
       }
-   TtaSetDisplayMode (doc, DisplayImmediately);
+   if (dispMode == DisplayImmediately)
+     TtaSetDisplayMode (doc, DisplayImmediately);
 }
 
 /*----------------------------------------------------------------------
@@ -1242,17 +1086,11 @@ View                view;
    Redo the latest sequence of editing operations undone by the TtcUndo
    and register it in the editing history.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 void                TtcRedo (Document doc, View view)
-#else  /* __STDC__ */
-void                TtcRedo (doc, view)
-Document            doc;
-View                view;
-
-#endif /* __STDC__ */
 {
    PtrDocument          pDoc;
    Element		firstSel, lastSel;
+   DisplayMode          dispMode;
    int			firstSelChar, lastSelChar, i;
    ThotBool		doit;
 
@@ -1267,7 +1105,9 @@ View                view;
    TtaUnselect (doc);
    OpenHistorySequence (pDoc, (PtrElement)firstSel, (PtrElement)lastSel,
 			firstSelChar, lastSelChar);
-   TtaSetDisplayMode (doc, DeferredDisplay);
+   dispMode = TtaGetDisplayMode (doc);
+   if (dispMode == DisplayImmediately)
+     TtaSetDisplayMode (doc, DeferredDisplay);
    /* disable structure checking */
    TtaSetStructureChecking (FALSE, doc);
 
@@ -1289,5 +1129,7 @@ View                view;
       }
    /* close sequence in Undo queue */
    pDoc->DocEditSequence = FALSE;
-   TtaSetDisplayMode (doc, DisplayImmediately);
+   if (dispMode == DisplayImmediately)
+     TtaSetDisplayMode (doc, DisplayImmediately);
 }
+
