@@ -1,19 +1,10 @@
 /*
  *
- *  (c) COPYRIGHT MIT and INRIA, 1996.
+ *  (c) COPYRIGHT MIT and INRIA, 1996-2001.
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
 
-/*
- * Warning:
- * This module is part of the Thot library, which was originally
- * developed in French. That's why some comments are still in
- * French, but their translation is in progress and the full module
- * will be available in English in the next release.
- * 
- */
- 
 #ifndef _DOCUMENT_H_
 #define _DOCUMENT_H_
 
@@ -32,8 +23,28 @@ typedef int        *SSchema;
 #define		CONFIG_EXCLUSION		4
 
 #ifndef __CEXTRACT__
-#ifdef __STDC__
 
+/*----------------------------------------------------------------------
+   TtaInitDocument
+
+   Creates the internal representation of a new document according to a given
+   structure schema. No file is created immediately, but the backup files
+   (.BAK and .SAV) and the document file (.PIV see TtaNewDocument) will be created
+   in the first directory of the document path (see TtaSetDocumentPath).
+
+   Parameters:
+   structureSchema: name of the structure schema that defines the type of
+   document to be created.
+   documentName: name of the document to be created (maximum length 19
+   characters). The directory name is not part of this parameter
+   (see TtaSetDocumentPath).
+   document: the requested document or 0.
+
+   Return value:
+   the document that has been created or 0 if the document has not
+   been created.
+  ----------------------------------------------------------------------*/
+extern Document     TtaInitDocument (CHAR_T* structureSchema, CHAR_T* documentName, Document document);
 
 /*----------------------------------------------------------------------
    TtaNewDocument
@@ -54,7 +65,7 @@ typedef int        *SSchema;
    the document that has been created or 0 if the document has not
    been created.
   ----------------------------------------------------------------------*/
-extern Document     TtaNewDocument (STRING structureSchema, STRING documentName);
+extern Document     TtaNewDocument (CHAR_T* structureSchema, CHAR_T* documentName);
 
 /*----------------------------------------------------------------------
    TtaOpenDocument
@@ -199,7 +210,7 @@ extern ThotBool     TtaCheckPath (char* path );
    directory: the new directory name.
 
   ----------------------------------------------------------------------*/
-extern ThotBool     TtaIsInDocumentPath (char* aDirectory);
+extern ThotBool     TtaIsInDocumentPath (CHAR_T* aDirectory);
 
 /*----------------------------------------------------------------------
    TtaAppendDocumentPath
@@ -211,7 +222,7 @@ extern ThotBool     TtaIsInDocumentPath (char* aDirectory);
    directory: the new directory name.
 
   ----------------------------------------------------------------------*/
-extern void         TtaAppendDocumentPath (STRING aDirectory);
+extern void         TtaAppendDocumentPath (CHAR_T* aDirectory);
 
 /*----------------------------------------------------------------------
    TtaSetSchemaPath
@@ -234,6 +245,7 @@ extern void         TtaSetSchemaPath (STRING path);
    the function simply returns the structure schema of that nature.
 
    Parameters:
+   document: the document of interest
    schema: the structure schema to which the nature is added.
    natureName: name of the nature to be added in the structure schema.
    presentationName: name of the presentation schema to be associated with
@@ -246,7 +258,7 @@ extern void         TtaSetSchemaPath (STRING path);
    has not been loaded.
 
   ----------------------------------------------------------------------*/
-extern SSchema      TtaNewNature (SSchema schema, STRING natureName, STRING presentationName);
+extern SSchema      TtaNewNature (Document document, SSchema schema, CHAR_T* natureName, CHAR_T* presentationName);
 
 /*----------------------------------------------------------------------
    TtaNewSchemaExtension
@@ -265,7 +277,7 @@ extern SSchema      TtaNewNature (SSchema schema, STRING natureName, STRING pres
    the extension schema, NULL if the extension schema has not been loaded.
 
   ----------------------------------------------------------------------*/
-extern SSchema      TtaNewSchemaExtension (Document document, STRING extensionName, STRING presentationName);
+extern SSchema      TtaNewSchemaExtension (Document document, CHAR_T* extensionName, CHAR_T* presentationName);
 
 /*----------------------------------------------------------------------
    TtaGetSchemaExtension
@@ -313,7 +325,7 @@ extern void         TtaRemoveSchemaExtension (Document document, SSchema extensi
    with the document.
 
   ----------------------------------------------------------------------*/
-extern void         TtaSetPSchema (Document document, STRING presentationName);
+extern void         TtaSetPSchema (Document document, CHAR_T* presentationName);
 
 /*----------------------------------------------------------------------
    TtaSetDocumentDirectory
@@ -325,7 +337,7 @@ extern void         TtaSetPSchema (Document document, STRING presentationName);
    directory: new document directory.
 
   ----------------------------------------------------------------------*/
-extern void         TtaSetDocumentDirectory (Document document, STRING directory);
+extern void         TtaSetDocumentDirectory (Document document, CHAR_T* directory);
 
 /*----------------------------------------------------------------------
    TtaRemoveSchemaExtension
@@ -411,6 +423,20 @@ extern void         TtaSetDocumentModified (Document document);
   ----------------------------------------------------------------------*/
 extern void         TtaSetDocumentUnmodified (Document document);
 
+/*----------------------------------------------------------------------
+   TtaSetDocumentUnupdated
+
+   Notifies the tool kit that a document must be considered as not updated
+   by the application or by the user. That will allow the application to
+   detect if any change will be made on the document
+   (see TtaIsDocumentUpdated).
+
+   Parameter:
+   document: the document.
+
+  ----------------------------------------------------------------------*/
+extern void         TtaSetDocumentUnupdated (Document document);
+
 /*----------------------------------------------------------------------
    TtaGetDocumentName
 
@@ -423,7 +449,7 @@ extern void         TtaSetDocumentUnmodified (Document document);
    name of that document.
 
   ----------------------------------------------------------------------*/
-extern STRING       TtaGetDocumentName (Document document);
+extern CHAR_T*       TtaGetDocumentName (Document document);
 
 /*----------------------------------------------------------------------
    TtaGetDocumentFromName
@@ -481,7 +507,7 @@ extern SSchema      TtaGetDocumentSSchema (Document document);
    name of that structure schema.
 
   ----------------------------------------------------------------------*/
-extern STRING        TtaGetSSchemaName (SSchema schema);
+extern CHAR_T*        TtaGetSSchemaName (SSchema schema);
 
 /*----------------------------------------------------------------------
    TtaGetPSchemaName
@@ -496,7 +522,7 @@ extern STRING        TtaGetSSchemaName (SSchema schema);
    name of the associated presentation schema.
 
   ----------------------------------------------------------------------*/
-extern STRING       TtaGetPSchemaName (SSchema schema);
+extern CHAR_T*       TtaGetPSchemaName (SSchema schema);
 
 /*----------------------------------------------------------------------
    TtaGetSSchema
@@ -504,7 +530,7 @@ extern STRING       TtaGetPSchemaName (SSchema schema);
    Returns a structure schema whose name is known and that is used in a
    given document.
 
-   Parameter:
+   Parameters:
    name: the name of the structure schema of interest.
    document: the document that uses this structure schema.
 
@@ -513,7 +539,24 @@ extern STRING       TtaGetPSchemaName (SSchema schema);
    schema is not loaded or not used by the document.
 
   ----------------------------------------------------------------------*/
-extern SSchema      TtaGetSSchema (STRING name, Document document);
+extern SSchema      TtaGetSSchema (CHAR_T* name, Document document);
+
+/*----------------------------------------------------------------------
+   TtaGetSSchemaByUri
+
+   Returns a structure schema whose URI is known and that is used in a
+   given document.
+
+   Parameters:
+   uriName: the URI of the structure schema of interest.
+   document: the document that uses this structure schema.
+
+   Return value:
+   the structure schema having this URI, or NULL if this structure
+   schema is not loaded or not used by the document.
+
+  ----------------------------------------------------------------------*/
+SSchema             TtaGetSSchemaByUri (CHAR_T* uriName, Document document);
 
 /*----------------------------------------------------------------------
    TtaSameSSchemas
@@ -548,7 +591,7 @@ extern int          TtaSameSSchemas (SSchema schema1, SSchema schema2);
    presentationName: Name of the document presentation schema.
 
   ----------------------------------------------------------------------*/
-extern void         TtaGiveSchemasOfDocument (STRING documentName, /*OUT*/ STRING structureName, /*OUT*/ STRING presentationName);
+extern void         TtaGiveSchemasOfDocument (STRING documentName, /*OUT*/ char* structureName, /*OUT*/ char* presentationName);
 
 /*----------------------------------------------------------------------
    TtaNextSchemaExtension
@@ -602,6 +645,24 @@ extern void         TtaNextNature (Document document, /*INOUT*/ SSchema * nature
   ----------------------------------------------------------------------*/
 extern int          TtaIsDocumentModified (Document document);
 
+/*----------------------------------------------------------------------
+   TtaIsDocumentUpdated
+
+   Indicates whether a document has been modified by the user or not
+   since the last TtaSetDocumentUnupdated or TtaSetDocumentUnmodified.
+   Modifications made by the application program are not considered,
+   except when explicitely notified by TtaDocumentModified.
+
+   Parameter:
+   document: the document.
+
+   Return value:
+   1 if the document has been modified by the user since it has been saved,
+   loaded or created, 0 if it has not been modified.
+
+  ----------------------------------------------------------------------*/
+extern int          TtaIsDocumentUpdated (Document document);
+
 /*----------------------------------------------------------------------
    TtaGetDocumentAccessMode
 
@@ -699,7 +760,7 @@ extern Document     TtaGetDocumentOfSavedElements ();
    structure (documents, natures et extensions) qui ont    
    des fichiers de langue dans les directories de schemas. 
   ----------------------------------------------------------------------*/
-extern void TtaConfigReadConfigFiles ( char* aSchemaPath );
+extern void TtaConfigReadConfigFiles ( CHAR_T* aSchemaPath );
 
 /*----------------------------------------------------------------------
    TtaConfigSSchemaExternalName retourne dans nameUser le nom     
@@ -708,59 +769,20 @@ extern void TtaConfigReadConfigFiles ( char* aSchemaPath );
    Typ indique s'il s'agit d'un schema de document (1), de         
    nature (2) ou d'extension (3).                                  
   ----------------------------------------------------------------------*/
-extern void TtaConfigSSchemaExternalName (/*OUT*/ char* nameUser, char* nameSchema, int Typ );
+extern void TtaConfigSSchemaExternalName (/*OUT*/ CHAR_T* nameUser, CHAR_T* nameSchema, int Typ );
 
-#else  /* __STDC__ */
+/*----------------------------------------------------------------------
+  TtaGetDocumentCharset gets the document charset
+  Returns UNDEFINED_CHARSET when the document uses the default charset.
+ ----------------------------------------------------------------------*/
+extern CHARSET TtaGetDocumentCharset (Document document);
 
-extern Document     TtaNewDocument ( /* char *structureSchema, char *documentName */ );
-extern Document     TtaOpenDocument ( /* char *documentName, int accessMode */ );
-extern void         TtaSaveDocument ( /* Document document, char *documentName */ );
-extern ThotBool     TtaExportDocument ( /* Document document, char *fileName, char* TSchemaName */ );
-extern ThotBool     TtaExportDocumentWithNewLineNumbers ( /* Document document, char *fileName, char* TSchemaName */ );
-extern void         TtaCloseDocument ( /* Document document */ );
-extern void         TtaRemoveDocument ( /* Document document */ );
-extern void         TtaSetDocumentPath ( /* char *path */ );
-extern ThotBool     TtaCheckPath (/* char *path */);
-extern ThotBool     TtaIsInDocumentPath ( /*char *aDirectory */ );
-extern void         TtaAppendDocumentPath ( /*char *aDirectory */ );
-extern void         TtaSetSchemaPath ( /* char *path */ );
-extern SSchema      TtaNewNature ( /* SSchema schema, char *natureName, char *presentationName */ );
-extern SSchema      TtaNewSchemaExtension ( /* Document document, char *extensionName, char *presentationName */ );
-extern SSchema      TtaGetSchemaExtension ( /*Document document, char *NomExtension */ );
-extern void         TtaRemoveSchemaExtension ( /* Document document, SSchema extension, int *removedElements, int *removedAttributes */ );
-extern void         TtaSetPSchema ( /* Document document, char *presentationName */ );
-extern void         TtaSetDocumentDirectory ( /* Document document, char *directory */ );
-extern void         TtaSetDocumentName ( /* Document document, char *documentName */ );
-extern void         TtaSetDocumentAccessMode ( /* Document document, int accessMode */ );
-extern void         TtaSetDocumentBackUpInterval ( /* Document document, int interval */ );
-extern void         TtaSetNotificationMode ( /* Document document, int notificationMode */ );
-extern void         TtaSetDocumentModified ( /* Document document */ );
-extern void         TtaSetDocumentUnmodified ( /* Document document */ );
-extern STRING       TtaGetDocumentName ( /* Document document */ );
-extern Document     TtaGetDocumentFromName ( /* char *documentName */ );
-extern void         TtaGetDocumentDirectory ( /* Document document, char *buffer, int bufferLength */ );
-extern SSchema      TtaGetDocumentSSchema ( /* Document document */ );
-extern STRING       TtaGetSSchemaName ( /* SSchema schema */ );
-extern STRING       TtaGetPSchemaName ( /* SSchema schema */ );
-extern SSchema      TtaGetSSchema ( /* char *name, Document document */ );
-extern int          TtaSameSSchemas ( /* SSchema schema1, SSchema schema2 */ );
-extern void         TtaGiveSchemasOfDocument ( /* char *documentName, char *structureName, char *presentationName */ );
-extern void         TtaNextSchemaExtension ( /* Document document, SSchema *extension */ );
-extern void         TtaNextNature ( /* Document document, SSchema *nature */ );
-extern int          TtaIsDocumentModified ( /* Document document */ );
-extern int          TtaGetDocumentAccessMode ( /* Document document */ );
-extern int          TtaGetDocumentBackUpInterval ( /* Document document */ );
-extern int          TtaGetNotificationMode ( /* Document document */ );
-extern void         TtaGetDocumentPath ( /* char *buffer, int bufferLength */ );
-extern void         TtaGetSchemaPath ( /* char *buffer, int bufferLength */ );
-extern Document     TtaGetDocumentOfSavedElements ();
+/*----------------------------------------------------------------------
+  TtaSetDocumentCharset sets the document charset
+  ----------------------------------------------------------------------*/
+extern void  TtaSetDocumentCharset (Document document,
+				    CHARSET charSet);
 
-extern void TtaConfigReadConfigFiles (/* char *aSchemaPath */);
-extern void TtaConfigSSchemaExternalName (/* char *nameUser,
-                                             char *nameSchema,
-                                             int Typ */);
-
-#endif /* __STDC__ */
 #endif /* __CEXTRACT__ */
 
 #endif
