@@ -1,19 +1,10 @@
 /*
  *
- *  (c) COPYRIGHT MIT and INRIA, 1996.
+ *  (c) COPYRIGHT MIT and INRIA, 1996-2001.
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
 
-/*
- * Warning:
- * This module is part of the Thot library, which was originally
- * developed in French. That's why some comments are still in
- * French, but their translation is in progress and the full module
- * will be available in English in the next release.
- * 
- */
- 
 #ifndef _PRESENTATION_H_
 #define _PRESENTATION_H_
 #include "view.h"
@@ -21,6 +12,7 @@
 typedef int        *PRule;
 
 /* Types of presentation rule */
+/* These values must follow the order of PRuleType defined in typeprs.h */
 
 #define PRVisibility 0
 #define PRFunction 1
@@ -30,40 +22,61 @@ typedef int        *PRule;
 #define PRWidth 5
 #define PRVertPos 6
 #define PRHorizPos 7
-#define PRSize 8
-#define PRStyle 9
-#define PRFont 10
-#define PRUnderline 11
-#define PRThickness 12
-#define PRIndent 13
-#define PRLineSpacing 14
-#define PRDepth 15
-#define PRAdjust 16
-#define PRJustify 17
-#define PRLineStyle 18
-#define PRLineWeight 19
-#define PRFillPattern 20
-#define PRBackground 21
-#define PRForeground 22
-#define PRHyphenate 23
-/* 24 and 25 reserved */
-#define PRNoBreak1 26
-#define PRNoBreak2 27
-/* 28 reserved */
-#define PRNotInLine 29
-#define PRShowBox 30
-#define PRBackgroundPicture 31
-#define PRPictureMode 32
-#define PRTMargin 33
-#define PRLMargin 34
-#define PRBMargin 35
-#define PRRMargin 36
-#define PRCreateEnclosing 37
-#define PRHorizOverflow 38
-#define PRVertOverflow 39
-#define PRLine 40
-#define PRNone 41
-#define PRWeight 42
+#define PRMarginTop 8
+#define PRMarginRight 9
+#define PRMarginBottom 10
+#define PRMarginLeft 11
+#define PRPaddingTop 12
+#define PRPaddingRight 13
+#define PRPaddingBottom 14
+#define PRPaddingLeft 15
+#define PRBorderTopWidth 16
+#define PRBorderRightWidth 17
+#define PRBorderBottomWidth 18
+#define PRBorderLeftWidth 19
+#define PRBorderTopColor 20
+#define PRBorderRightColor 21
+#define PRBorderBottomColor 22
+#define PRBorderLeftColor 23
+#define PRBorderTopStyle 24
+#define PRBorderRightStyle 25
+#define PRBorderBottomStyle 26
+#define PRBorderLeftStyle 27
+#define PRSize 28
+#define PRStyle 29
+#define PRWeight 30
+#define PRFont 31
+#define PRUnderline 32
+#define PRThickness 33
+#define PRIndent 34
+#define PRLineSpacing 35
+#define PRDepth 36
+#define PRAdjust 37
+#define PRLineStyle 38
+#define PRLineWeight 39
+#define PRFillPattern 40
+#define PRBackground 41
+#define PRForeground 42
+#define PRHyphenate 43
+#define PRVertOverflow 44
+#define PRHorizOverflow 45
+/* PtPageBreak, PtLineBreak, PtGather */
+#define PRXRadius 49
+#define PRYRadius 50
+#define PRNoBreak1 51
+#define PRNoBreak2 52
+/* PtPictInfo */
+#define PRLine 54
+#define PRCreateEnclosing 55
+#define PRShowBox 56
+#define PRBackgroundPicture 57
+#define PRPictureMode 58
+#define PRNotInLine 59
+#define PRNone 60
+#define PRPageBefore 61
+#define PRPageAfter 62
+#define PRPageInside 63
+#define LAST_PRES_RULE_TYPE 63
 
 /* values for rule PRStyle */
 #define StyleRoman 1
@@ -94,10 +107,7 @@ typedef int        *PRule;
 #define AdjustRight 2
 #define Centered 3
 #define LeftWithDots 4
-
-/* values for rule PRJustify */
-#define Justified 1
-#define NotJustified 2
+#define Justify 5
 
 /* values for rule PRLineStyle */
 #define SolidLine 1
@@ -110,7 +120,6 @@ typedef int        *PRule;
 #define NoHyphenation 2
 
 #ifndef __CEXTRACT__
-#ifdef __STDC__
 
 
 /*----------------------------------------------------------------------
@@ -128,7 +137,7 @@ extern void TtaSetFontZoom (int zoom);
    Parameter:
    presentationType: type of the presentation rule to be created. Available
    values are PRSize, PRStyle, PRWeight, PRFont, PRUnderline, PRThickness,
-   PRIndent, PRLineSpacing, PRDepth, PRAdjust, PRJustify, PRLineStyle,
+   PRIndent, PRLineSpacing, PRDepth, PRAdjust, PRLineStyle,
    PRLineWeight, PRFillPattern, PRBackground, PRForeground, PRHyphenate,
    PRWidth, PRHeight, PRVertPos, PRHorizPos.
    view: the view (this view must be open).
@@ -149,7 +158,7 @@ extern PRule        TtaNewPRule (int presentationType, View view, Document docum
    Parameter:
    presentationType: type of the presentation rule to be created. Available
    values are PRSize, PRStyle, PRWeight, PRFont, PRUnderline, PRThickness,
-   PRIndent, PRLineSpacing, PRDepth, PRAdjust, PRJustify, PRLineStyle,
+   PRIndent, PRLineSpacing, PRDepth, PRAdjust, PRLineStyle,
    PRLineWeight, PRFillPattern, PRBackground, PRForeground, PRHyphenate,
    PRShowBox, PRNotInLine.
    viewName: the name of the view (this view does not need to be open).
@@ -170,7 +179,7 @@ extern PRule        TtaNewPRuleForView (int presentationType, int view, Document
    Parameter:
    presentationType: type of the presentation rule to be created. Available
    values are PRSize, PRStyle, PRWeight, PRFont, PRUnderline, PRThickness,
-   PRIndent, PRLineSpacing, PRDepth, PRAdjust, PRJustify, PRLineStyle,
+   PRIndent, PRLineSpacing, PRDepth, PRAdjust, PRLineStyle,
    PRLineWeight, PRFillPattern, PRBackground, PRForeground, PRHyphenate,
    PRShowBox, PRNotInLine.
    viewName: the name of the view (this view does not need to be open).
@@ -211,6 +220,19 @@ extern PRule        TtaCopyPRule (PRule pRule);
   ----------------------------------------------------------------------*/
 extern void         TtaAttachPRule (Element element, PRule pRule, Document document);
 
+/*----------------------------------------------------------------------
+   TtaIsCSSPRule
+
+   Check whether a presentation rule is associated with a CSS rule
+
+   Parameters:
+   pRule: the presentation rule to be tested.
+
+   Return value:
+   TRUE if pRule is a CSS rule
+  ----------------------------------------------------------------------*/
+extern ThotBool    TtaIsCSSPRule (PRule pRule);
+
 /*----------------------------------------------------------------------
    TtaRemovePRule
 
@@ -237,28 +259,69 @@ extern void         TtaRemovePRule (Element element, PRule pRule, Document docum
    document: the document to which the element belongs.
 
    Valid values according to rule type:
-   PRSize: an integer between 6 and 72 (body size in points).
+   PRDepth: an integer (z-index of the element).
+   PRVisibility: an integer >= 0 (visibility level).
+   PRFillPattern: rank of the pattern in file thot.pattern.
+   PRBackground: rank of the background color in file thot.color.
+   PRForeground: rank of the foreground color in file thot.color.
+   PRBorderTopColor, PRBorderRightColor, PRBorderBottomColor,PRBorderLeftColor:
+      if value >= 0: rank of the color in file thot.color.
+      if value < 0 : -2 means transparent and -1 means same color as foreground
+   PRFont: FontTimes, FontHelvetica, FontCourier.
    PRStyle: StyleRoman, StyleItalics, StyleOblique.
    PRWeight: WeightNormal, WeightBold.
-   PRFont: FontTimes, FontHelvetica, FontCourier.
    PRUnderline: NoUnderline, Underline, Overline, CrossOut.
    PRThickness: ThinUnderline, ThickUnderline.
+   PRLineStyle, PRBorderTopStyle, PRBorderRightStyle, PRBorderBottomStyle,
+      PRBorderLeftStyle: SolidLine, DashedLine, DottedLine.
+   PRNoBreak1, PRNoBreak2: a positive integer (distance in points).
    PRIndent: a positive, null or negative integer (indentation in points).
+   PRSize: an integer between 6 and 72 (body size in points).
    PRLineSpacing: a positive integer (line spacing in points).
-   PRDepth: a positive integer (depth of the element).
-   PRAdjust: AdjustLeft, AdjustRight, Centered, LeftWithDots.
-   PRJustify: Justified, NotJustified.
+   PRLineWeight: a positive or null integer (stroke width for graphics in
+      points).
+   PRMarginTop, PRMarginLeft, PRMarginBottom, PRMarginRight: a positive, null
+      or negative integer (margin in points).
+   PRPaddingTop, PRPaddingRight, PRPaddingBottom, PRPaddingLeft: an integer
+      > 0 (padding in points).
+   PRBorderTopWidth, PRBorderRightWidth, PRBorderBottomWidth, PRBorderLeftWidth:
+      an integer > 0 (border width in points).
    PRHyphenate: Hyphenation, NoHyphenation.
-   PRLineStyle: SolidLine, DashedLine, DottedLine.
-   PRLineWeight: a positive or null integer (stroke width for graphics).
-   PRFillPattern: rank of the pattern in the file thot.pattern.
-   PRBackground: rank of the background color in the file thot.color.
-   PRForeground: rank of the foreground color in the file thot.color.
-   PRWidth, PRHeight, PRVertPos, PRHorizPos: a positive or null integer.
+   PRAdjust: AdjustLeft, AdjustRight, Centered, LeftWithDots, Justify.
 
   ----------------------------------------------------------------------*/
 extern void         TtaSetPRuleValue (Element element, PRule pRule, int value, Document document);
 
+/*----------------------------------------------------------------------
+   TtaSetPRuleValueWithUnit
+
+   Changes the value and the length unit of a presentation rule.
+   The presentation rule must be attached to an element that is part of
+   a document.
+
+   Parameters:
+   element: the element to which the presentation rule is attached.
+   pRule: the presentation rule to be changed.
+   value: the value to be set.
+   unit: the length unit in which the value is expressed.
+   document: the document to which the element belongs.
+
+   Valid values according to rule type:
+   PRNoBreak1, PRNoBreak2: a positive integer (distance).
+   PRIndent: a positive, null or negative integer (indentation).
+   PRSize: an integer between 6 and 72 (body size).
+   PRLineSpacing: a positive integer (line spacing).
+   PRLineWeight: a positive or null integer (stroke width for graphics).
+   PRMarginTop, PRMarginLeft, PRMarginBottom, PRMarginRight: a positive, null
+      or negative integer (margin).
+   PRPaddingTop, PRPaddingRight, PRPaddingBottom, PRPaddingLeft: an integer
+      > 0 (padding).
+   PRBorderTopWidth, PRBorderRightWidth, PRBorderBottomWidth, PRBorderLeftWidth:
+      an integer > 0 (border width).
+
+  ----------------------------------------------------------------------*/
+extern void         TtaSetPRuleValueWithUnit (Element element, PRule pRule, int value, TypeUnit unit, Document document);
+
 /*----------------------------------------------------------------------
    TtaSetPRuleView
 
@@ -305,6 +368,17 @@ extern void         TtaChangeBoxSize (Element element, Document document, View v
   ----------------------------------------------------------------------*/
 extern void         TtaChangeBoxPosition (Element element, Document document, View view, int X, int Y, TypeUnit unit);
 
+/*----------------------------------------------------------------------
+   TtaGetDepth
+   Returns the depth of the box corresponding to an element in a given view.
+
+   Parameters:
+   element: the element of interest.
+   document: the document of interest.
+   view: the view.
+  ----------------------------------------------------------------------*/
+extern int          TtaGetDepth (Element element, Document document, View view);
+
 /*----------------------------------------------------------------------
    TtaGiveBoxSize
 
@@ -388,7 +462,7 @@ extern void        TtaGiveWindowSize (Document document, View view, TypeUnit uni
 /*----------------------------------------------------------------------
  *   TtaGiveRGB returns the RGB of the color.
  ----------------------------------------------------------------------*/
-extern void         TtaGiveRGB ( char* colname, /*OUT*/ unsigned short *red, /*OUT*/ unsigned short *green, /*OUT*/ unsigned short *blue );
+extern CHAR_T      *TtaGiveRGB ( CHAR_T* colname, /*OUT*/ unsigned short *red, /*OUT*/ unsigned short *green, /*OUT*/ unsigned short *blue );
 
 /*----------------------------------------------------------------------
    TtaGiveThotRGB returns the Red Green and Blue values corresponding
@@ -426,7 +500,7 @@ extern void         TtaNextPRule (Element element, /*INOUT*/ PRule * pRule);
    element: the element of interest.
    presentationType: type of the desired presentation rule. Available
    values are PRSize, PtStyle, PtWeight, PRFont, PRUnderline, PRThickness,
-   PRIndent, PRLineSpacing, PRDepth, PRAdjust, PRJustify, PRLineStyle,
+   PRIndent, PRLineSpacing, PRDepth, PRAdjust, PRLineStyle,
    PRLineWeight, PRFillPattern, PRBackground, PRForeground, PRHyphenate,
    PRShowBox, PRNotInLine.
  
@@ -448,7 +522,7 @@ extern PRule        TtaGetPRule (Element element, int presentationType);
    Return value:
    type of that presentation rule. Available values are RSize, PtStyle,
    RFont, RUnderline, RThickness, PRIndent, RLineSpacing, RDepth, RAdjust,
-   RJustify, RLineStyle, RLineWeight, RFillPattern, RBackground,
+   RLineStyle, RLineWeight, RFillPattern, RBackground,
    RForeground, RHyphenate, PRShowBox, PRNotInLine.
 
   ----------------------------------------------------------------------*/
@@ -463,24 +537,34 @@ extern int          TtaGetPRuleType (PRule pRule);
    pRule: the presentation rule of interest.
 
    Return values according to rule type:
-   PRSize: an integer between 6 and 72 (body size in points).
+   PRVisibility: an integer >= 0 (visibility level).
+   PRDepth: an integer (z-index of the element).
+   PRFillPattern: rank of the pattern in file thot.pattern.
+   PRBackground: rank of the background color in file thot.color.
+   PRForeground: rank of the foreground color in file thot.color.
+   PRBorderTopColor, PRBorderRightColor, PRBorderBottomColor,PRBorderLeftColor:
+      if value >= 0: rank of the color in file thot.color.
+      if value < 0 : -2 means transparent and -1 means same color as foreground
+   PRFont: FontTimes, FontHelvetica, FontCourier.
    PRStyle: StyleRoman, StyleItalics, StyleOblique.
    PRWeight: WeightNormal, WeightBold.
-   PRFont: FontTimes, FontHelvetica, FontCourier.
-   RPUnderline: NoUnderline, Underline, Overline, CrossOut.
+   PRUnderline: NoUnderline, Underline, Overline, CrossOut.
    PRThickness: ThinUnderline, ThickUnderline.
+   PRLineStyle, PRBorderTopStyle, PRBorderRightStyle, PRBorderBottomStyle,
+      PRBorderLeftStyle: SolidLine, DashedLine, DottedLine.
+   PRNoBreak1, PRNoBreak2: a positive integer (distance in points).
    PRIndent: a positive, null or negative integer (indentation in points).
+   PRSize: an integer between 6 and 72 (body size in points).
    PRLineSpacing: a positive integer (line spacing in points).
-   PRDepth: a positive integer (depth of the element).
-   PRAdjust: AdjustLeft, AdjustRight, Centered, LeftWithDots.
-   PRJustify: Justified, NotJustified.
-   PRHyphenate: Hyphenation, NoHyphenation.
-   PRLineStyle: SolidLine, DashedLine, DottedLine.
    PRLineWeight: a positive or null integer (stroke width for graphics).
-   PRFillPattern: rank of the pattern in the file thot.pattern.
-   PRBackground: rank of the background color in the file thot.color.
-   PRForeground: rank of the foreground color in the file thot.color.
-   PRWidth, PRHeight, PRVertPos, PRHorizPos: a positive or null integer.
+   PRMarginTop, PRMarginLeft, PRMarginBottom, PRMarginRight: a positive, null
+      or negative integer (margin in points).
+   PRPaddingTop, PRPaddingRight, PRPaddingBottom, PRPaddingLeft: an integer
+      > 0 (padding in points).
+   PRBorderTopWidth, PRBorderRightWidth, PRBorderBottomWidth, PRBorderLeftWidth:
+      an integer > 0 (border width in points).
+   PRHyphenate: Hyphenation, NoHyphenation.
+   PRAdjust: AdjustLeft, AdjustRight, Centered, LeftWithDots, Justify.
 
   ----------------------------------------------------------------------*/
 extern int          TtaGetPRuleValue (PRule pRule);
@@ -531,34 +615,6 @@ extern int          TtaGetPRuleView (PRule pRule);
   ----------------------------------------------------------------------*/
 extern int          TtaSamePRules (PRule pRule1, PRule pRule2);
 
-#else  /* __STDC__ */
-
-extern void         TtaSetFontZoom (/* int zoom */);
-extern PRule        TtaNewPRule ( /* int presentationType, View view, Document document */ );
-extern PRule        TtaNewPRuleForView (/* int presentationType, int view, Document document */);
-extern PRule        TtaNewPRuleForNamedView ( /* int presentationType, STRING viewName, Document document */ );
-extern PRule        TtaCopyPRule ( /* PRule pRule */ );
-extern void         TtaAttachPRule ( /* Element element, PRule pRule, Document document */ );
-extern void         TtaRemovePRule ( /* Element element, PRule pRule, Document document */ );
-extern void         TtaSetPRuleValue ( /* Element element, PRule pRule, int value, Document document */ );
-extern void         TtaSetPRuleView ( /* PRule pRule, int view */ );
-extern void         TtaChangeBoxSize ( /* Element element, View view, Document document, int deltaX, int deltaY, TypeUnit unit */ );
-extern void         TtaChangeBoxPosition ( /* Element element, Document document, View view, int X, int Y, TypeUnit unit */ );
-extern void         TtaGiveBoxSize ( /* Element element, Document document, View view, TypeUnit unit, int *width, int *height */ );
-extern void         TtaGiveBoxPosition ( /* Element element, Document document, View view, TypeUnit unit, int *xCoord, int *yCoord */ );
-extern void         TtaGiveBoxAbsPosition ( /* Element element, Document document, View view, TypeUnit unit, int *xCoord, int *yCoord */ );
-extern void         TtaGiveWindowSize ( /* Document document, View view, TypeUnit unit, int *width, int *height */ );
-extern void         TtaGiveRGB ( /*STRING colname, unsigned short *red, unsigned short *green, unsigned short *blue*/ );
-extern void         TtaGiveThotRGB (/*int num, unsigned short *red, unsigned short *green, unsigned short *blue*/);
-extern void         TtaNextPRule ( /* Element element, PRule *pRule */ );
-extern PRule        TtaGetPRule ( /* Element element, int presentationType */ );
-extern int          TtaGetPRuleType ( /* PRule pRule */ );
-extern int          TtaGetPRuleValue ( /* PRule pRule */ );
-extern int          TtaGetPRuleUnit ( /* PRule pRule */);
-extern int          TtaGetPRuleView ( /* PRule pRule */ );
-extern int          TtaSamePRules ( /* PRule pRule1, PRule pRule2 */ );
-
-#endif /* __STDC__ */
 #endif /* __CEXTRACT__ */
 
 #endif
