@@ -1,6 +1,6 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996.
+ *  (c) COPYRIGHT INRIA, 1996-2001.
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
@@ -13,6 +13,9 @@
 /* element */
 typedef int        *Element;
 
+/* attribute */
+typedef int        *Attribute;
+
 #include "document.h"
 
 /* element type */
@@ -23,6 +26,13 @@ typedef struct _ElementType
   }
 ElementType;
 
+/* attribute type */
+typedef struct _AttributeType
+  {
+     SSchema             AttrSSchema;
+     int                 AttrTypeNum;
+  }
+AttributeType;
 
 /* search domain */
 typedef enum _SearchDomain
@@ -51,12 +61,14 @@ typedef enum _Construct
      ConstructBasicType,
      ConstructNature,
      ConstructPair,
+     ConstructDocument,
+     ConstructAny,
+     ConstructEmpty,
      ConstructError
   }
 Construct;
 
 #ifndef __CEXTRACT__
-#ifdef __STDC__
 
 /* ----------------------------------------------------------------------
    ChangeElementType
@@ -102,7 +114,22 @@ extern Element      TtaNewElement (Document document, ElementType elementType);
    the root element of the created tree.
 
    ---------------------------------------------------------------------- */
-extern Element      TtaNewTree (Document document, ElementType elementType, STRING label);
+extern Element      TtaNewTree (Document document, ElementType elementType, char* label);
+
+/* ----------------------------------------------------------------------
+   TtaNewTranscludedElement
+
+   Creates a new element that is a dynamic copy of another element.
+
+   Parameters:
+   document: the document for which the element is created.
+   orig:     the element that is copied.
+
+   Return value:
+   the created element.
+
+   ---------------------------------------------------------------------- */
+extern Element      TtaNewTranscludedElement (Document document, Element orig);
 
 /* ----------------------------------------------------------------------
    TtaCopyTree
@@ -389,17 +416,28 @@ extern void         TtaSetCheckingMode (ThotBool strict);
 /* ----------------------------------------------------------------------
    TtaGetMainRoot
 
-   Returns the root element of the main abstract tree representing a document.
+   Returns the document element of the abstract tree representing a document.
 
    Parameter:
    document: the document.
 
    Return value:
-   the root element of the main abstract tree.
+   the document element of the abstract tree.
 
    ---------------------------------------------------------------------- */
 extern Element      TtaGetMainRoot (Document document);
 
+/* ----------------------------------------------------------------------
+   TtaGetRootElement
+
+   Returns the root element of the abstract tree representing a document.
+   Parameter:
+   document: the document.
+   Return value:
+   the root element of the abstract tree.
+   ---------------------------------------------------------------------- */
+extern Element      TtaGetRootElement (Document document);
+
 /* ----------------------------------------------------------------------
    TtaNextAssociatedRoot
 
@@ -597,7 +635,7 @@ extern ElementType  TtaGetElementType (Element element);
 /* ----------------------------------------------------------------------
    TtaIsExtensionElement
 
-   Returns true is the element is from an extension schema
+   Returns true if the element is from an extension schema
 
    Parameter:
    element: the element.
@@ -608,6 +646,19 @@ extern ElementType  TtaGetElementType (Element element);
    ---------------------------------------------------------------------- */
 extern ThotBool     TtaIsExtensionElement (Element element);
 
+/* ----------------------------------------------------------------------
+   TtaIsTranscludedElement
+
+   Returns true if the element is a transcluded element
+
+   Parameter:
+   element: the element.
+
+   Return value:
+   true or false.
+   ---------------------------------------------------------------------- */
+extern ThotBool     TtaIsTranscludedElement (Element element);
+
 /* ----------------------------------------------------------------------
    TtaGetElementTypeName
 
@@ -1198,81 +1249,55 @@ extern void         TtaListAbstractTree (Element root, FILE * fileDescriptor);
    ---------------------------------------------------------------------- */
 extern void         TtaAskFirstCreation ();
 
-#else  /* __STDC__ */
+/* ----------------------------------------------------------------------
+   TtaHasHiddenException
 
-extern void         ChangeElementType ( /* Element element, int typeNum */ );
-extern Element      TtaNewElement ( /* Document document, ElementType elementType */ );
-extern Element      TtaNewTree ( /* Document document, ElementType elementType, char *label */ );
-extern Element      TtaCopyTree ( /* Element sourceElement, Document sourceDocument, Document destinationDocument, Element parent */ );
-extern Element      TtaCreateDescent ( /* Document document, Element element, ElementType elementType */ );
-extern Element      TtaCreateDescentWithContent ( /* Document document, Element element, ElementType elementType */ );
-extern void         TtaDeleteTree ( /* Element element, Document document */ );
-extern void         TtaAttachNewTree ( /* Element tree, Document document */ );
-extern void         TtaExportTree ( /* Element element, Document document, char *fileName, char *TSchemaName */ );
-extern void         TtaInsertSibling ( /* Element newElement, Element sibling, ThotBool before, Document document */ );
-extern void         TtaInsertFirstChild ( /* Element *newElement, Element parent, Document document */ );
-extern void         TtaCreateElement ( /* ElementType elementType, Document document */ );
-extern void         TtaInsertElement ( /* ElementType elementType, Document document */ );
-extern void         TtaRemoveTree ( /* Element element, Document document */ );
-extern void         TtaSetElementLineNumber ( /* Element element, int nb */ );
-extern void         TtaSetAccessRight ( /* Element element, AccessRight right, Document document */ );
-extern void         TtaHolophrastElement ( /* Element element, ThotBool holophrast, Document document */ );
-extern void         TtaSetMandatoryInsertion ( /* ThotBool on, Document document */ );
-extern void         TtaSetStructureChecking ( /* ThotBool on, Document document */ );
-extern int          TtaGetStructureChecking ( /* Document document */ );
-extern void         TtaSetCheckingMode ( /* ThotBool strict */ );
-extern Element      TtaGetMainRoot ( /* Document document */ );
-extern void         TtaNextAssociatedRoot ( /* Document document, Element *root */ );
-extern Element      TtaGetFirstChild ( /* Element parent */ );
-extern Element      TtaGetLastChild ( /* Element parent */ );
-extern Element      TtaGetFirstLeaf ( /* Element parent */ );
-extern Element      TtaGetLastLeaf ( /* Element parent */ );
-extern void         TtaPreviousSibling ( /* Element *element */ );
-extern void         TtaNextSibling ( /* Element *element */ );
-extern Element      TtaGetSuccessor ( /* Element element */ );
-extern Element      TtaGetPredecessor ( /* Element element */ );
-extern Element      TtaGetParent ( /* Element element */ );
-extern Element      TtaGetCommonAncestor ( /* Element element1, Element element2 */ );
-extern Element      TtaGetTypedAncestor ( /* Element element, ElementType ancestorType */ );
-extern ElementType  TtaGetElementType ( /* Element element */ );
-extern ThotBool     TtaIsExtensionElement ( /* Element element */ );
-extern STRING       TtaGetElementTypeName ( /* ElementType elementType */ );
-extern void         TtaGiveTypeFromName ( /* ElementType *elementType, char *name */ );
-extern int          TtaSameTypes ( /* ElementType type1, ElementType type2 */ );
-extern STRING       TtaGetElementLabel ( /* Element element */ );
-extern int          TtaGetElementLineNumber ( /* Element element */ );
-extern int          TtaGetElementVolume ( /* Element element */ );
-extern int          TtaIsConstant ( /* ElementType elementType */ );
-extern int          TtaIsLeaf ( /* ElementType elementType */ );
-extern Construct    TtaGetConstructOfType ( /* ElementType elementType */ );
-extern int	    TtaGetCardinalOfType( /* ElementType elementType */ );
-extern void         TtaGiveConstructorsOfType( /* ElementType **typesArrey, int *size, ElementType elementType */ );
-extern int          TtaGetRankInAggregate ( /* componentType, aggregateType */ );
-extern ThotBool     TtaIsOptionalInAggregate( /* int rank, ElementType elementType */ );
-extern Construct    TtaGetConstruct ( /* Element element */ );
-extern AccessRight  TtaGetAccessRight ( /* Element element */ );
-extern int          TtaIsHolophrasted ( /* Element element */ );
-extern int          TtaIsReadOnly ( /* Element element */ );
-extern int          TtaIsHidden ( /* Element element */ );
-extern int          TtaIsInAnInclusion ( /* Element element */ );
-extern int          TtaIsAncestor ( /* Element element, Element ancestor */ );
-extern int          TtaIsBefore ( /* Element element1, Element element2 */ );
-extern int          TtaIsFirstPairedElement ( /* Element element */ );
-extern ThotBool     TtaCanInsertSibling ( /* ElementType elementType, Element sibling, ThotBool before, Document document */ );
-extern ThotBool     TtaCanInsertFirstChild (ElementType elementType, Element parent, Document document);
-extern Document     TtaGetDocument ( /* Element element */ );
-extern void         TtaNextCopiedElement ( /* Element *element */ );
-extern Document     TtaGetCopiedDocument ( /* void */ );
-extern Element      TtaSearchTypedElement ( /* ElementType searchedType, SearchDomain scope, Element element */ );
-extern Element      TtaSearchTypedElementInTree ( /* ElementType searchedType, SearchDomain scope, Element parent, Element element */ );
-extern Element      TtaSearchElementByLabel ( /* char *searchedLabel, Element element */ );
-extern Element      TtaSearchEmptyElement ( /* SearchDomain scope, Element element */ );
-extern Element      TtaSearchOtherPairedElement ( /* Element element */ );
-extern Element      TtaSearchNoPageBreak ( /* Element element, ThotBool forward */ );
-extern void         TtaListAbstractTree ( /* Element root, FILE *fileDescriptor */ );
-extern void         TtaAskFirstCreation ();
+   Parameters:
+   elType : the element type we want to test.
+   Returns TRUE if the elType is defined by the document schema's
+   DTD. For example, elements with the hidden and exception
+   attributes are not included in the DTD.
+
+   ---------------------------------------------------------------------- */
+extern ThotBool     TtaHasHiddenException (ElementType elType);
+
+/* ----------------------------------------------------------------------
+   TtaHasInvisibleException
+
+   Parameters:
+   attrType : the attribute type we want to test.
+   Returns TRUE if the attrType is defined by the document schema's
+   DTD. For example, elements with the hidden and exception
+   attributes are not included in the DTD.
+
+   ---------------------------------------------------------------------- */
+/* extern ThotBool     TtaHasInvisibleException (AttributeType attrType); */
+
+/*----------------------------------------------------------------------
+  TtaAppendXMLAttribute
+  ----------------------------------------------------------------------*/
+extern void TtaAppendXMLAttribute (char *XMLName, AttributeType *attrType);
+
+/*----------------------------------------------------------------------
+  TtaGetXMLAttributeType
+  ----------------------------------------------------------------------*/
+extern void TtaGetXMLAttributeType (char *XMLName, AttributeType *attrType);
+
+/*----------------------------------------------------------------------
+  TtaAppendXMLElement
+  ----------------------------------------------------------------------*/
+extern void TtaAppendXMLElement (char *XMLName, ElementType *elType, char **mappedName);
+
+/*----------------------------------------------------------------------
+  TtaGetXMLElementType
+  ----------------------------------------------------------------------*/
+extern void TtaGetXMLElementType (char *XMLElementName, ElementType *elType, char **mappedName);
+
+/*----------------------------------------------------------------------
+  TtaChangeGenericSSchemaName
+  ----------------------------------------------------------------------*/
+extern void TtaChangeGenericSchemaNames (char *sSchemauri, char *sSchemaName, Document doc);
 
-#endif /* __STDC__ */
 #endif /* __CEXTRACT__ */
 
 #endif
