@@ -1,19 +1,10 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996.
+ *  (c) COPYRIGHT INRIA, 1996-2001.
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
 
-/*
- * Warning:
- * This module is part of the Thot library, which was originally
- * developed in French. That's why some comments are still in
- * French, but their translation is in progress and the full module
- * will be available in English in the next release.
- * 
- */
- 
 #ifndef _TYPEBASE_H_
 #define _TYPEBASE_H_
 /* do not declare before */
@@ -31,19 +22,22 @@ typedef enum
      UnXHeight,
      UnPoint,
      UnPixel,
-     UnPercent
+     UnPercent,
+     UnAuto
   }
 TypeUnit;
-
+#define MAX_DOCUMENTS 20  /* max. number of simultaneous open documents */
 #ifdef MAXINT
 #undef MAXINT
 #endif
 #define THOT_MAXINT ((1<<((sizeof(int) * 8) - 2)) - 1)
 
-#if 0
-#define MAXINT  2147483647
-#endif
-
 #define ord(c) (int)((unsigned char)(c))
 
 #endif
+
+
+
+
+
+
