@@ -1,10 +1,9 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996.
+ *  (c) COPYRIGHT INRIA, 1996-2001
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
- 
 
 /*
  * Type declarations for the formatter
@@ -20,7 +19,7 @@
 #include "typecorr.h"
 #include "typetra.h"
 
-typedef UCHAR_T RuleSet[32];
+typedef unsigned char RuleSet[32];
 
 /* List of pointers used */
 typedef struct _Box *PtrBox;
@@ -132,6 +131,14 @@ typedef struct _TabRelations
   int              TaRTPercents[MAX_RELAT_DIM];
 } TabRelations;
 
+typedef struct _TabSpan *PtrTabSpan;
+typedef struct _TabSpan
+{
+  PtrTabSpan       TaSpanNext;	/* Next block */
+  PtrAbstractBox   TaSpanCell[MAX_RELAT_DIM];
+  int              TaSpanNumber[MAX_RELAT_DIM];
+} TabSpan;
+
 /* Structure to store table updates */
 typedef struct _TabUpdate *PtrTabUpdate;
 typedef struct _TabUpdate
@@ -144,16 +151,32 @@ typedef struct _TabUpdate
 
 typedef struct _Box
 {
-  PtrAbstractBox  BxAbstractBox;/* Pointer on the associated abstract box */
-  PtrBox          BxPrevious;	        /* Previous displayable box */
-  PtrBox          BxNext;	        /* Next displayable box */
-  PtrBox          BxNextBackground;	/* Next background box to display */
+  PtrAbstractBox  BxAbstractBox;/* Pointer to the associated abstract box */
+  PtrBox          BxPrevious;	/* Previous displayable box */
+  PtrBox          BxNext;	/* Next displayable box */
   int	          BxNChars;	/* Total number of characters in the box */
   int             BxIndChar;	/* 0 or position of the split box */
   int             BxXOrg;	/* X origin from the root */
   int             BxYOrg;	/* Y origin from the root */
-  int             BxHeight;	        /* Current height */
-  int             BxWidth;	        /* Width including spaces */
+  int             BxHeight;	        /* Box height including margins */
+  int             BxWidth;	        /* Box width including margins */
+
+  int             BxH;	        	/* Inner height */
+  int             BxW;	        	/* Inner Width including spaces */
+  int             BxTMargin;	        /* Top Margin */
+  int             BxLMargin;	        /* Left Margin */
+  int             BxBMargin;	        /* Bottom Margin */
+  int             BxRMargin;	        /* Right Margin */
+  int             BxTBorder;	        /* Top Border */
+  int             BxLBorder;	        /* Left Border */
+  int             BxBBorder;	        /* Bottom Border */
+  int             BxRBorder;	        /* Right Border */
+
+  int             BxTPadding;	        /* Top Padding */
+  int             BxLPadding;	        /* Left Padding */
+  int             BxBPadding;	        /* Bottom Padding */
+  int             BxRPadding;	        /* Right Padding */
+
   int             BxHorizRef;	        /* Current base */
   int             BxVertRef;	        /* Current vertical reference */
   int             BxEndOfBloc;	        /* Fill length:
@@ -183,7 +206,9 @@ typedef struct _Box
   ThotBool	  BxNew;	        /* Newly displayed box */
   ThotBool	  BxContentHeight;	/* Real height is the content height */
   ThotBool	  BxContentWidth;	/* Real width is the content width */
-  ThotBool        BxShadow;		/* Characters are showed as a set of '*' */
+  ThotBool        BxShadow;		/* Characters are showed as '*' */
+  ThotBool        BxFill;	        /* The box has borders or background */
+  ThotBool        BxDisplay;	        /* The box has borders or background */
   int		  BxRuleHeigth;         /* Content height or minimum */
   int		  BxRuleWidth;	        /* Content width or minimum */
   PtrTextBuffer   BxBuffer;	        /* Pointer on the buffer list */
@@ -198,12 +223,16 @@ typedef struct _Box
       int	 _BxSpaceWidth_;/* >0 of the box is justified */
       int	 _BxFirstChar_;	/* First character in buffer */
     } s0;
-    struct /* BoPicture */
+    struct /* BoPicture - used for pictures, polylines and paths */
     {
-      int	 *_BxPictInfo_;  /* Image pointer in memory
+      union
+        {
+        int	 *_BxPictInfo_;  /* Image pointer in memory
 				    List of control points for a spline
 				    + twisting ratio of the control
 			            points */
+	PtrPathSeg _BxFirstPathSeg_; /* pointer to the first path segment */
+        } u;
       float 	 _BxXRatio_;
       float 	 _BxYRation_;
     } s1;
@@ -213,8 +242,8 @@ typedef struct _Box
       PtrLine 	 _BxLastLine_;	/* Last line */
       int        _BxMaxWidth_;  /* Width without line wrapping */
       int        _BxMinWidth_;  /* Mininmum width */
-      short      _BxCycles_;    /* count reformatting cycles */
-      short      _BxPacking_;   /* Packing */
+      int        _BxCycles_;    /* count reformatting cycles */
+      int        _BxPacking_;   /* Packing */
     } s2;
     struct /* BoTable BoColumn BoRow */
     {
@@ -222,9 +251,15 @@ typedef struct _Box
       PtrTabRelations	_BxRows_;	/* list of rows within a table */
       int        	_BxMaxWidth_;   /* Width without line wrapping */
       int        	_BxMinWidth_;   /* Mininmum width */
-      short             _BxCycles_;     /* count reformatting cycles */
-      short             _BxPacking_;     /* Packing */
+      int               _BxCycles_;     /* count reformatting cycles */
+      int               _BxPacking_;     /* Packing */
+      PtrTabSpan        _BxSpans_;	/* list of spanned cells */
     } s3;
+    struct /* BoComplete for Graphics = 'C' */
+    {
+      int        	_BxRx_;         /* Horizontal radius */
+      int        	_BxRy_;         /* Vertical radius */
+    } s4;
   } u;
 } Box;
 
@@ -233,7 +268,8 @@ typedef struct _Box
 #define BxNPixels u.s0._BxNPixels_
 #define BxSpaceWidth u.s0._BxSpaceWidth_
 #define BxFirstChar u.s0._BxFirstChar_
-#define BxPictInfo u.s1._BxPictInfo_
+#define BxPictInfo u.s1.u._BxPictInfo_
+#define BxFirstPathSeg u.s1.u._BxFirstPathSeg_
 #define BxXRatio u.s1._BxXRatio_
 #define BxYRatio u.s1._BxYRation_
 #define BxFirstLine u.s2._BxFirstLine_
@@ -245,6 +281,9 @@ typedef struct _Box
 #define BxColumns u.s3._BxColumns_
 #define BxTable u.s3._BxColumns_
 #define BxRows u.s3._BxRows_
+#define BxSpans u.s3._BxSpans_
+#define BxRx u.s4._BxRx_
+#define BxRy u.s4._BxRy_
 
 typedef struct C_points_
 {
@@ -324,7 +363,7 @@ typedef struct _AbstractBox
   PtrAbstractBox  AbPreviousRepeated; /* Linking towards the previous
 					 repeated abstract box */
   PtrPSchema      AbPSchema;	/* Presentation schema of the abstract box */
-  int		  AbDocView;	/* Document view number */
+  int             AbDocView;	/* Document view number */
   PtrCopyDescr	  AbCopyDescr;	/* Descriptor of the copied element if the
 				   abstract box is produced by a Copy rule */
   PtrAttribute    AbCreatorAttr;/* Pointer on the attribute that created the
@@ -332,62 +371,101 @@ typedef struct _AbstractBox
 				    presentation abstract box */
   PtrDelayedPRule AbDelayedPRule;       /* Used by the editor */
   int             AbVolume;	/* Equivalent characters number */
+  int	          AbTypeNum;	/* Type number/presentation box */
+  int	          AbNum;	/* Abstract box number for debug */
   AbPosition      AbVertRef;	/* Vertical reference mark position */
   AbPosition      AbHorizRef;	/* Horizontal reference mark position */
   AbPosition      AbVertPos;	/* Vertical position in the box */
   AbPosition      AbHorizPos;	/* Horizontal position in the box */
   AbDimension     AbHeight;	/* Box height */
   AbDimension     AbWidth;	/* Box width */
-  int		  AbUnderline;	/* Underlining type */
-  int		  AbThickness;	/* Underlining thickness */
+  int             AbUnderline;	/* Underlining type */
+  int             AbThickness;	/* Underlining thickness */
   int             AbIndent;	/* Indentation for line breaking */
-  TypeUnit        AbIndentUnit; /* Indentation unit */
   int             AbDepth;	/* Abstract box display plane */
-  int	          AbTypeNum;	/* Type number/presentation box */
-  int	          AbNum;	/* Abstract box number for debug */
   int	          AbVisibility; /* Abstract box visibility degree */
-  CHAR_T          AbFont;	/* Characteristics of the font used */
-  int		  AbFontStyle;	/* Font style: roman, italic, oblique */
-  int		  AbFontWeight;	/* Font weight: normal, bold */
-  int		  AbSize;	/* Character logical/real size */
-  TypeUnit        AbSizeUnit;   /* Unit for the size */
-  CHAR_T	  AbLineStyle;  /* Line style */
+  int             AbFontStyle;	/* Font style: roman, italic, oblique */
+  int             AbFontWeight;	/* Font weight: normal, bold */
+  int             AbSize;	/* Character logical/real size */
   int             AbLineWeight; /* Line thickness */
-  TypeUnit	  AbLineWeightUnit; 	/* Unit of thickness */
-  int		  AbFillPattern;/* Fill pattern */	
-  int		  AbBackground; /* Background color */
-  int		  AbForeground; /* Drawing color */
-  int             AbLineSpacing;        /* Interlining */
-  TypeUnit        AbLineSpacingUnit;    /* Interlining unit */
-  BAlignment      AbAdjust;	/* BAlignment of lines in the abstract box */
-  ThotBool        AbJustify;	/* Lines are justified */
-  ThotBool        AbAcceptLineBreak;    /* Can be split in lines */
-  ThotBool	  AbAcceptPageBreak;    /* Can be split by page breaks */
-  ThotBool	  AbHyphenate;	/* Contents can be hyphenated */
-  ThotBool        AbOnPageBreak;	/* The box crosses the page limit */
-  ThotBool        AbAfterPageBreak;	/* Abstract box beyond the page limit*/
-  ThotBool	  AbNotInLine;	/* The abstract box is not part of the line */
-  ThotBool        AbHorizEnclosing;	/* True: horizontally enclosed box */
-  ThotBool        AbVertEnclosing;	/* True: vertically enclosed box */
-  ThotBool        AbCanBeModified;	/* Modification is allowed */
-  ThotBool        AbSelected;		/* The abstract box is selected */
-  ThotBool        AbPresentationBox;	/* A presentation box */
-  ThotBool	  AbRepeatedPresBox;	/* A repeated presentation box */
-  ThotBool        AbSensitive;	/* True: the abstract box is active */
-  ThotBool	  AbReadOnly;	/* Abstract box is read only */
+  int             AbLineSpacing;/* Interlining */
+  int             AbFillPattern;/* Fill pattern */	
+  int             AbBackground; /* Background color */
+  int             AbForeground; /* Drawing color */
+
+  int             AbTopBColor;     /* Border Top color */
+  int             AbRightBColor;   /* Border Right color */
+  int             AbBottomBColor;  /* Border Bottom color */
+  int             AbLeftBColor;    /* Border Left color */
+  int             AbTopStyle;      /* Border Top style */
+  int             AbRightStyle;    /* Border Right style */
+  int             AbBottomStyle;   /* Border Bottom style */
+  int             AbLeftStyle;     /* Border Left style */
+
+  int             AbTopMargin;     /* Top Margin */
+  int             AbRightMargin;   /* Right Margin */
+  int             AbBottomMargin;  /* Bottom Margin */
+  int             AbLeftMargin;    /* Left Margin */
+  int             AbTopPadding;    /* Top Padding */
+  int             AbRightPadding;  /* Right Padding */
+  int             AbBottomPadding; /* Bottom Padding */
+  int             AbLeftPadding;   /* Left Padding */
+  int             AbTopBorder;     /* Top Border */
+  int             AbRightBorder;   /* Right Border */
+  int             AbBottomBorder;  /* Bottom Border */
+  int             AbLeftBorder;    /* Left Border */
+
+  char            AbFont;	      /* Characteristics of the font used */
+  char            AbLineStyle;        /* Line style */
+  BAlignment      AbAdjust;	      /* Alignment of lines in the box */
+  TypeUnit        AbSizeUnit;         /* Unit for the size */
+  TypeUnit        AbIndentUnit;       /* Indentation unit */
+  TypeUnit        AbLineWeightUnit;   /* Unit of thickness */
+  TypeUnit        AbLineSpacingUnit;  /* Interlining unit */
+
+  TypeUnit        AbTopMarginUnit;    /* Top Margin Unit */
+  TypeUnit        AbRightMarginUnit;  /* Right Margin Unit */
+  TypeUnit        AbBottomMarginUnit; /* Bottom Margin Unit */
+  TypeUnit        AbLeftMarginUnit;   /* Left Margin Unit */
+  TypeUnit        AbTopPaddingUnit;   /* Top Padding Unit */
+  TypeUnit        AbRightPaddingUnit; /* Right Padding Unit */
+  TypeUnit        AbBottomPaddingUnit;/* Bottom Padding Unit */
+  TypeUnit        AbLeftPaddingUnit;  /* Left Padding Unit */
+  TypeUnit        AbTopBorderUnit;    /* Top Border Unit */
+  TypeUnit        AbRightBorderUnit;  /* Right Border Unit */
+  TypeUnit        AbBottomBorderUnit; /* Bottom Border Unit */
+  TypeUnit        AbLeftBorderUnit;   /* Left Border Unit */
+
+  ThotBool        AbBuildAll;         /* All descendant abstract boxes must
+					 always be built */
+  ThotBool        AbAcceptLineBreak;  /* Can be split in lines */
+  ThotBool        AbAcceptPageBreak;  /* Can be split by page breaks */
+  ThotBool        AbHyphenate;	      /* Contents can be hyphenated */
+  ThotBool        AbOnPageBreak;      /* The box crosses the page limit */
+  ThotBool        AbAfterPageBreak;   /* Abstract box beyond the page limit*/
+  ThotBool        AbNotInLine;	 /* The abstract box is not part of the line */
+  ThotBool        AbHorizEnclosing;   /* True: horizontally enclosed box */
+  ThotBool        AbVertEnclosing;    /* True: vertically enclosed box */
+  ThotBool        AbCanBeModified;    /* Modification is allowed */
+  ThotBool        AbSelected;	      /* The abstract box is selected */
+  ThotBool        AbPresentationBox;  /* A presentation box */
+  ThotBool        AbRepeatedPresBox;  /* A repeated presentation box */
+  ThotBool        AbSensitive;	      /* True: the abstract box is active */
+  ThotBool        AbReadOnly;	      /* Abstract box is read only */
   /* Indications of modification for the abstract box */
-  ThotBool        AbNew;	/* Newly created abstract box */
-  ThotBool        AbDead;       /* Abstract box to be destroyed */
-  ThotBool        AbWidthChange;	/* Change the horizontal dimension */
-  ThotBool        AbHeightChange;	/* Change the vertical dimension */
-  ThotBool        AbHorizPosChange;	/* Change the horizontal position */
-  ThotBool        AbVertPosChange;	/* Change the vertical axis */
-  ThotBool        AbHorizRefChange;	/* Change the horizontal axis */
-  ThotBool        AbVertRefChange;	/* Change the vertical positioning */
-  ThotBool        AbSizeChange;	        /* Change the character size */
-  ThotBool        AbAspectChange;       /* Change the graphical aspect: plane,
-					   color, pattern, line style */
-  ThotBool        AbChange;	/* Change of another type */
+  ThotBool        AbNew;	      /* Newly created abstract box */
+  ThotBool        AbDead;             /* Abstract box to be destroyed */
+  ThotBool        AbWidthChange;      /* Change the horizontal dimension */
+  ThotBool        AbHeightChange;     /* Change the vertical dimension */
+  ThotBool        AbHorizPosChange;   /* Change the horizontal position */
+  ThotBool        AbVertPosChange;    /* Change the vertical axis */
+  ThotBool        AbHorizRefChange;   /* Change the horizontal axis */
+  ThotBool        AbVertRefChange;    /* Change the vertical positioning */
+  ThotBool        AbSizeChange;	      /* Change the character size */
+  ThotBool        AbAspectChange;     /* Change the graphical aspect: plane,
+				         color, pattern, line style */
+  ThotBool        AbMBPChange;	      /* Change margins, borders, paddings */
+  ThotBool        AbChange;	      /* Change of another type */
   LeafType        AbLeafType;
   union
   {
@@ -402,14 +480,18 @@ typedef struct _AbstractBox
     } s0;
     struct /* AbLeafType = LtText */
     {
-      PtrTextBuffer  _AbText_;      /* On first text buffer */
-      Language  _AbLanguage_;  /* Language used */
+      PtrTextBuffer _AbText_;     /* On first text buffer */
+      Language      _AbLanguage_; /* Language used */
     } s1;
     struct /* AbLeafType = LtGraphics or LtSymbol */
     {
-      CHAR_T     _AbShape_;         /* Drawing code */
-      CHAR_T     _AbGraphAlphabet_; /* Alphabet used*/
-      CHAR_T     _AbRealShape_;     /* Effective drawing code */
+      char     _AbShape_;         /* Drawing code */
+      char     _AbGraphAlphabet_; /* Alphabet used*/
+      char     _AbRealShape_;     /* Effective drawing code */
+      int      _AbRx_;            /* Horizontal radius */
+      int      _AbRy_;            /* Vertical radius */     
+      TypeUnit _AbRxUnit_;        /* Unit for the horizontal radius */
+      TypeUnit _AbRyUnit_;        /* Unit for the vertical radius */
     } s2;
     struct /* AbLeafType = LtPicture */
     {
@@ -418,8 +500,12 @@ typedef struct _AbstractBox
     struct /* AbLeafType = LtPolyline  */
     {
       PtrTextBuffer _AbPolyLineBuffer_; /* First buffer */
-      CHAR_T        _AbPolyLineShape_;  /* Drawing type */
+      char          _AbPolyLineShape_;  /* Drawing type */
     } s4;
+    struct /* AbLeafType = LtPath  */
+    {
+      PtrPathSeg    _AbFirstPathSeg_;   /* First path segment */
+    } s5;
   } u;
 } AbstractBox;
 
@@ -433,9 +519,14 @@ typedef struct _AbstractBox
 #define AbShape u.s2._AbShape_
 #define AbGraphAlphabet u.s2._AbGraphAlphabet_
 #define AbRealShape u.s2._AbRealShape_
+#define AbRx u.s2._AbRx_
+#define AbRy u.s2._AbRy_
+#define AbRxUnit u.s2._AbRxUnit_
+#define AbRyUnit u.s2._AbRyUnit_
 #define AbPictInfo u.s3._AbPictInfo_
 #define AbPolyLineBuffer u.s4._AbPolyLineBuffer_
 #define AbPolyLineShape u.s4._AbPolyLineShape_
+#define AbFirstPathSeg u.s5._AbFirstPathSeg_
 
 typedef struct _ViewFrame
 {
@@ -460,11 +551,9 @@ typedef struct _ViewFrame
 typedef struct _VueDeDoc
 {
   int             VdView;
-  int             VdAssocNum;
   Name            VdViewName;
   PtrSSchema      VdSSchema;
   ThotBool        VdOpen;
-  ThotBool        VdAssoc;
   ThotBool	  VdExist;
   ThotBool        VdNature;
   ThotBool        VdPaginated;
@@ -490,6 +579,6 @@ typedef SearchContext *PtrSearchContext;
 /* Declaration for dialogue */
 
 /* List of the pointers used */
-typedef CHAR_T    FontName[30];
+typedef char    FontName[30];
 
 #endif
