@@ -13,10 +13,11 @@ THOT_EXPORT ViewFrame 	ViewFrameTable[MAX_FRAME];
 THOT_EXPORT Propagation	Propagate;/* Fix limits of the updates propagation */
 THOT_EXPORT ThotBool 	ReadyToDisplay;
 THOT_EXPORT ThotBool 	FrameUpdating;	/* The frame is currently updated */
-THOT_EXPORT ThotBool 	TextInserting;		/* Text is currently inserted */
+THOT_EXPORT ThotBool 	TextInserting;	/* Text is currently inserted */
 THOT_EXPORT ThotBool	BoxCreating;	/* Boxes are currently created */
 THOT_EXPORT PtrBox 	PackBoxRoot;	/* Root box to repack */
 THOT_EXPORT PtrDimRelations DifferedPackBlocks;/* Differed packing */
+THOT_EXPORT ThotBool    AnyWidthUpdate;
 
 
 /* paragraphe to be reformatted after insertion */
@@ -31,4 +32,3 @@ THOT_EXPORT int          LastInsertThotWindow;
 /* attribute for which a presentation abstract box has been modified */
 THOT_EXPORT PtrAttribute LastInsertAttr;
 THOT_EXPORT PtrElement   LastInsertAttrElem;
-THOT_EXPORT ThotBool     FromKeyboard;
