@@ -7,7 +7,7 @@
 
 THOT_EXPORT ThotGC          GCpicture;	 /* for bitmap */
 THOT_EXPORT ThotGC          GCimage;	 /* for pixmap */
-THOT_EXPORT char*           FileExtension[];
+THOT_EXPORT char           *FileExtension[];
 THOT_EXPORT int             HandlersCounter;
 THOT_EXPORT int             InlineHandlers;
 #ifndef _WINDOWS
@@ -25,10 +25,8 @@ THOT_EXPORT int             currentExtraHandler;
 THOT_EXPORT ThotGC          GCpicture;
 THOT_EXPORT Pixmap          EpsfPictureLogo;
 
-/* bg colors used by Windows */#ifdef _WINDOWS
-THOT_EXPORT int             bgRed;
-THOT_EXPORT int             bgGreen;
-THOT_EXPORT int             bgBlue;
+/* bg colors used by Windows */
+#ifdef _WINDOWS
 THOT_EXPORT ThotBool        bgAlpha;
 THOT_EXPORT HBITMAP         alphamap;
 #endif /* _WINDOWS */
