@@ -1,18 +1,9 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996.
+ *  (c) COPYRIGHT INRIA, 1996-2001.
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
-
-/*
- * Warning:
- * This module is part of the Thot library, which was originally
- * developed in French. That's why some comments are still in
- * French, but their translation is in progress and the full module
- * will be available in English in the next release.
- * 
- */
  
 /*
  * Change specific presentation
@@ -58,6 +49,7 @@
 #include "font_f.h"
 #include "memory_f.h"
 #include "presrules_f.h"
+#include "schemas_f.h"
 #include "structcreation_f.h"
 #include "structmodif_f.h"
 #include "structselect_f.h"
@@ -66,31 +58,13 @@
 #include "undo_f.h"
 #include "unstructchange_f.h"
 
-#ifdef __STDC__
-static void         ApplyInherit (PRuleType ruleType, PtrAbstractBox pAb, PtrDocument pDoc);
-
-#else  /* __STDC__ */
-static void         ApplyInherit ();
-
-#endif /* __STDC__ */
-
-
 /*----------------------------------------------------------------------
   ApplyRuleSubTree
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         ApplyRuleSubTree (PtrElement pE, PRuleType ruleType, PtrDocument pDoc, PtrPRule * pPRule, int view)
-#else  /* __STDC__ */
-static void         ApplyRuleSubTree (pE, ruleType, pDoc, pPRule, view)
-PtrElement          pE;
-PRuleType           ruleType;
-PtrDocument         pDoc;
-PtrPRule           *pPRule;
-int                 view;
-
-#endif /* __STDC__ */
+static void   ApplyRuleSubTree (PtrElement pE, PRuleType ruleType,
+				PtrDocument pDoc, PtrPRule * pPRule,
+				int view, ThotBool display)
 {
-   ThotBool            stop;
    PtrAbstractBox      pAbb, pAbbF;
    PtrPSchema          pSPR;
    PtrAttribute        pAttr;
@@ -98,44 +72,42 @@ int                 view;
    if (pE->ElTerminal)
       pE = NULL;
    else
-      pE = pE->ElFirstChild;	/* on passe au premier fils */
-   while (pE != NULL)
+      /* on passe au premier fils */
+      pE = pE->ElFirstChild;
+   /* traite tous les fils */
+   while (pE)
      {
-	pAbb = pE->ElAbstractBox[view - 1];	/* 1er pave de l'element dans la view */
-	if (pAbb != NULL)
+	/* 1er pave de l'element dans la view */
+	pAbb = pE->ElAbstractBox[view - 1];
+	if (pAbb)
 	   if (pAbb->AbDead)
 	      pAbb = NULL;	/* on ne traite pas les paves morts */
 	if (pAbb == NULL)
 	   /* cet element n'a pas de pave, mais ses descendants en */
 	   /* ont peut etre... */
-	   ApplyRuleSubTree (pE, ruleType, pDoc, pPRule, view);
+	   ApplyRuleSubTree (pE, ruleType, pDoc, pPRule, view, display);
 	else
 	  {
-	     /* il y a un element descendant dont les paves peuvent heriter de pAb. 
-	        On parcourt ses paves dans la view */
-	     stop = FALSE;
-	     while (!stop)
+	     /* il y a un element descendant dont les paves peuvent heriter
+		de pAb. On parcourt ses paves dans la vue */
+	     do
 	       {
-		  *pPRule = SearchRulepAb (pDoc, pAbb, &pSPR, ruleType, FnAny, TRUE, &pAttr);
-		  if (*pPRule != NULL)
+		  *pPRule = SearchRulepAb (pDoc, pAbb, &pSPR, ruleType, FnAny,
+					   TRUE, &pAttr);
+		  if (*pPRule)
 		    {
-		       if ((*pPRule)->PrPresMode == PresInherit && ((*pPRule)->PrInheritMode == InheritParent ||
+		       if ((*pPRule)->PrPresMode == PresInherit &&
+			   ((*pPRule)->PrInheritMode == InheritParent ||
 			    (*pPRule)->PrInheritMode == InheritGrandFather))
 			  /* la regle de ce pave herite de l'ascendant, */
 			  /* on applique la regle */
 			  if (ApplyRule (*pPRule, pSPR, pAbb, pDoc, pAttr))
 			    {
-			       if (ruleType == PtSize)
-				  pAbb->AbSizeChange = TRUE;
-			       else if (ruleType == PtDepth || ruleType == PtLineStyle ||
-					ruleType == PtLineWeight || ruleType == PtFillPattern ||
-					ruleType == PtBackground || ruleType == PtForeground)
-				  pAbb->AbAspectChange = TRUE;
-			       else
-				  pAbb->AbChange = TRUE;
-			       RedispAbsBox (pAbb, pDoc);
+			       SetChange (pAbb, ruleType);
+			       if (display)
+				 RedispAbsBox (pAbb, pDoc);
 			       if (!pAbb->AbPresentationBox)
-				  ApplyInherit (ruleType, pAbb, pDoc);
+				 ApplyInherit (ruleType, pAbb, pDoc, display);
 			    }
 		    }
 		  if (!pAbb->AbPresentationBox)
@@ -143,29 +115,22 @@ int                 view;
 		     /* les paves crees par l'element au niveau inferieur */
 		    {
 		       pAbbF = pAbb->AbFirstEnclosed;
-		       while (pAbbF != NULL)
+		       while (pAbbF)
 			 {
 			    if (pAbbF->AbElement == pE)
 			      {
-				 *pPRule = SearchRulepAb (pDoc, pAbbF, &pSPR, ruleType, FnAny, TRUE, &pAttr);
-				 if (*pPRule != NULL)
+				 *pPRule = SearchRulepAb (pDoc, pAbbF, &pSPR,
+						ruleType, FnAny, TRUE, &pAttr);
+				 if (*pPRule)
 				   {
 				      if ((*pPRule)->PrPresMode == PresInherit
 					  && (*pPRule)->PrInheritMode == InheritParent)
-					 if (ApplyRule (*pPRule, pSPR, pAbbF, pDoc, pAttr))
+					 if (ApplyRule (*pPRule, pSPR, pAbbF,
+							pDoc, pAttr))
 					   {
-					      if (ruleType == PtSize)
-						 pAbbF->AbSizeChange = TRUE;
-					      else if (ruleType == PtDepth ||
-						  ruleType == PtLineStyle ||
-						 ruleType == PtLineWeight ||
-						 ruleType == PtFillPattern ||
-						 ruleType == PtBackground ||
-						   ruleType == PtForeground)
-						 pAbb->AbAspectChange = TRUE;
-					      else
-						 pAbbF->AbChange = TRUE;
-					      RedispAbsBox (pAbbF, pDoc);
+					     SetChange (pAbbF, ruleType);
+					     if (display)
+					       RedispAbsBox (pAbbF, pDoc);
 					   }
 				   }
 			      }
@@ -173,42 +138,27 @@ int                 view;
 			 }
 		    }
 		  pAbb = pAbb->AbNext;	/* passe au pave suivant */
-		  if (pAbb == NULL)
-		     stop = TRUE;	/* pas de pave suivant, on arrete */
-		  else
-		     /* on arrete si le pave suivant n'appartient pas a */
-		     /* l'element */
-		     stop = pAbb->AbElement != pE;
 	       }
+	       /* on arrete s'il n'y a pas de pave suivant ou si le pave
+		  suivant n'appartient pas a l'element */
+	     while (pAbb && pAbb->AbElement == pE);
 	  }
 	pE = pE->ElNext;	/* on traite l'element suivant */
      }
 }
 
-
 /*----------------------------------------------------------------------
-   	ApplyInherit on vient d'appliquer la regle de presentation de type	
+  ApplyInherit  On vient d'appliquer la regle de presentation de type	
    		ruleType au pave pAb. Verifie si les paves environnants	
    		heritent de cette regle et si oui leur applique		
-   		l'heritage.						
+   		l'heritage et on les r'eaffiche si display est TRUE
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         ApplyInherit (PRuleType ruleType, PtrAbstractBox pAb, PtrDocument pDoc)
-
-#else  /* __STDC__ */
-static void         ApplyInherit (ruleType, pAb, pDoc)
-PRuleType           ruleType;
-PtrAbstractBox      pAb;
-PtrDocument         pDoc;
-
-#endif /* __STDC__ */
-
+void         ApplyInherit (PRuleType ruleType, PtrAbstractBox pAb, PtrDocument pDoc, ThotBool display)
 {
    PtrElement          pEl;
    int                 view;
    PtrAbstractBox      pAbbCur;
    PtrPRule            pPRule;
-   ThotBool            stop;
    PtrPSchema          pSchP;
    PtrAttribute        pAttrib;
 
@@ -216,47 +166,38 @@ PtrDocument         pDoc;
    view = pAb->AbDocView;
    if (pEl->ElNext != NULL)
      {
-	/* l'element a un suivant. Celui-ci herite-t-il de son precedent ? */
+	/* l'element a un frere suivant. Celui-ci herite-t-il de son
+	   precedent ? */
 	pAbbCur = NULL;
 	while (pEl->ElNext != NULL && pAbbCur == NULL)
 	  {
 	     pEl = pEl->ElNext;
-	     pAbbCur = pEl->ElAbstractBox[view - 1];	/* saute les paves de presentation */
-	     stop = FALSE;
-	     do
-		if (pAbbCur == NULL)
-		   stop = TRUE;
-		else if (!pAbbCur->AbPresentationBox)
-		   stop = TRUE;
-		else
-		   pAbbCur = pAbbCur->AbNext;
-	     while (!stop);
-	     if (pAbbCur != NULL)
+	     pAbbCur = pEl->ElAbstractBox[view - 1];
+	     /* saute les paves de presentation */
+	     while (pAbbCur && pAbbCur->AbPresentationBox)
+	        pAbbCur = pAbbCur->AbNext;
+	     if (pAbbCur)
 		if (pAbbCur->AbDead)
 		   pAbbCur = NULL;
 	  }
-	if (pAbbCur != NULL)
+	if (pAbbCur)
 	  {
-	     /* il y a un element suivant dont le pave pAbbCur pourrait heriter de pAb */
-	     pPRule = SearchRulepAb (pDoc, pAbbCur, &pSchP, ruleType, FnAny, TRUE, &pAttrib);
-	     if (pPRule != NULL)
+	     /* il y a un element suivant dont le pave pAbbCur pourrait
+		heriter de pAb. Cherche sa regle de presentation */
+	     pPRule = SearchRulepAb (pDoc, pAbbCur, &pSchP, ruleType, FnAny,
+				     TRUE, &pAttrib);
+	     if (pPRule)
 	       {
 		  if (pPRule->PrPresMode == PresInherit &&
 		      pPRule->PrInheritMode == InheritPrevious)
-		     /* la regle de cet element herite du precedent, on applique */
-		     /* la regle */
+		     /* la regle de cet element herite du precedent,
+			on applique la regle */
 		     if (ApplyRule (pPRule, pSchP, pAbbCur, pDoc, pAttrib))
 		       {
-			  if (ruleType == PtSize)
-			     pAbbCur->AbSizeChange = TRUE;
-			  else if (ruleType == PtDepth || ruleType == PtLineStyle ||
-				   ruleType == PtLineWeight || ruleType == PtFillPattern ||
-				   ruleType == PtBackground || ruleType == PtForeground)
-			     pAbbCur->AbAspectChange = TRUE;
-			  else
-			     pAbbCur->AbChange = TRUE;
-			  ApplyInherit (ruleType, pAbbCur, pDoc);
-			  RedispAbsBox (pAbbCur, pDoc);
+			  SetChange (pAbbCur, ruleType);
+			  ApplyInherit (ruleType, pAbbCur, pDoc, display);
+			  if (display)
+			    RedispAbsBox (pAbbCur, pDoc);
 		       }
 	       }
 	  }
@@ -265,34 +206,29 @@ PtrDocument         pDoc;
    if (!pEl->ElTerminal && pEl->ElFirstChild != NULL)
       /* l'element a des descendants. Ceux-ci heritent-t-il de leur */
       /* ascendant ? */
-      ApplyRuleSubTree (pEl, ruleType, pDoc, &pPRule, view);
-   if (pEl->ElParent != NULL)
+      ApplyRuleSubTree (pEl, ruleType, pDoc, &pPRule, view, display);
+   if (pEl->ElParent)
      {
 	/* l'element a un ascendant. Celui-ci herite-t-il de son premier */
 	/* descendant ? */
 	pAbbCur = NULL;
-	while (pEl->ElParent != NULL && pAbbCur == NULL)
+	while (pEl->ElParent && !pAbbCur)
 	  {
 	     pEl = pEl->ElParent;
-	     pAbbCur = pEl->ElAbstractBox[view - 1];	/* saute les paves de presentation */
-	     stop = FALSE;
-	     do
-		if (pAbbCur == NULL)
-		   stop = TRUE;
-		else if (!pAbbCur->AbPresentationBox)
-		   stop = TRUE;
-		else
-		   pAbbCur = pAbbCur->AbNext;
-	     while (!(stop));
-	     if (pAbbCur != NULL)
+	     /* saute les paves de presentation */
+	     pAbbCur = pEl->ElAbstractBox[view - 1];
+	     while (pAbbCur && pAbbCur->AbPresentationBox)
+	        pAbbCur = pAbbCur->AbNext;
+	     if (pAbbCur)
 		if (pAbbCur->AbDead)
 		   pAbbCur = NULL;
 	  }
-	if (pAbbCur != NULL)
+	if (pAbbCur)
 	  {
-	     /* il y a un element ascendant dont le pave pAbbCur pourrait heriter */
-	     /* de pAb */
-	     pPRule = SearchRulepAb (pDoc, pAbbCur, &pSchP, ruleType, FnAny, TRUE, &pAttrib);
+	     /* il y a un element ascendant dont le pave pAbbCur pourrait
+		heriter de pAb */
+	     pPRule = SearchRulepAb (pDoc, pAbbCur, &pSchP, ruleType, FnAny,
+				     TRUE, &pAttrib);
 	     if (pPRule != NULL)
 		if (pPRule->PrPresMode == PresInherit &&
 		    pPRule->PrInheritMode == InheritChild)
@@ -300,16 +236,10 @@ PtrDocument         pDoc;
 		   /* applique la regle */
 		   if (ApplyRule (pPRule, pSchP, pAbbCur, pDoc, pAttrib))
 		     {
-			if (ruleType == PtSize)
-			   pAbbCur->AbSizeChange = TRUE;
-			else if (ruleType == PtDepth || ruleType == PtLineStyle ||
-				 ruleType == PtLineWeight || ruleType == PtFillPattern ||
-			ruleType == PtBackground || ruleType == PtForeground)
-			   pAbbCur->AbAspectChange = TRUE;
-			else
-			   pAbbCur->AbChange = TRUE;
-			ApplyInherit (ruleType, pAbbCur, pDoc);
-			RedispAbsBox (pAbbCur, pDoc);
+		       SetChange (pAbbCur, ruleType);
+		       ApplyInherit (ruleType, pAbbCur, pDoc, display);
+		       if (display)
+			 RedispAbsBox (pAbbCur, pDoc);
 		     }
 	  }
      }
@@ -323,26 +253,23 @@ PtrDocument         pDoc;
 	pAbbCur = pAb->AbPrevious;
 	while (pAbbCur != NULL)
 	   if (!pAbbCur->AbPresentationBox || pAbbCur->AbElement != pEl)
-	      /* ce n'est pas un pave de presentation de l'element, on arrete */
+	      /* ce n'est pas un pave de presentation de l'element, on arrete*/
 	      pAbbCur = NULL;
 	   else
 	     {
-		pPRule = SearchRulepAb (pDoc, pAbbCur, &pSchP, ruleType, FnAny, TRUE, &pAttrib);
+		pPRule = SearchRulepAb (pDoc, pAbbCur, &pSchP, ruleType, FnAny,
+					TRUE, &pAttrib);
 		if (pPRule != NULL)
-		   if (pPRule->PrPresMode == PresInherit && pPRule->PrInheritMode == InheritCreator)
-		      /* la regle de ce pave herite de son createur, on l'applique */
+		   if (pPRule->PrPresMode == PresInherit &&
+		       pPRule->PrInheritMode == InheritCreator)
+		      /* la regle de ce pave herite de son createur,
+			 on l'applique */
 		      if (ApplyRule (pPRule, pSchP, pAbbCur, pDoc, pAttrib))
 			{
-			   if (ruleType == PtSize)
-			      pAbbCur->AbSizeChange = TRUE;
-			   else if (ruleType == PtDepth || ruleType == PtLineStyle ||
-				    ruleType == PtLineWeight || ruleType == PtFillPattern ||
-				    ruleType == PtBackground || ruleType == PtForeground)
-			      pAbbCur->AbAspectChange = TRUE;
-			   else
-			      pAbbCur->AbChange = TRUE;
-			   ApplyInherit (ruleType, pAbbCur, pDoc);
-			   RedispAbsBox (pAbbCur, pDoc);
+			  SetChange (pAbbCur, ruleType);
+			  ApplyInherit (ruleType, pAbbCur, pDoc, display);
+			  if (display)
+			    RedispAbsBox (pAbbCur, pDoc);
 			}
 		/* examine le pave precedent */
 		pAbbCur = pAbbCur->AbPrevious;
@@ -351,71 +278,59 @@ PtrDocument         pDoc;
 	pAbbCur = pAb->AbNext;
 	while (pAbbCur != NULL)
 	   if (!pAbbCur->AbPresentationBox || pAbbCur->AbElement != pEl)
-	      /* ce n'est pas un pave de presentation de l'element, on arrete */
+	      /* ce n'est pas un pave de presentation de l'element, on arrete*/
 	      pAbbCur = NULL;
 	   else
 	     {
-		pPRule = SearchRulepAb (pDoc, pAbbCur, &pSchP, ruleType, FnAny, TRUE, &pAttrib);
+		pPRule = SearchRulepAb (pDoc, pAbbCur, &pSchP, ruleType, FnAny,
+					TRUE, &pAttrib);
 		if (pPRule != NULL)
-		   if (pPRule->PrPresMode == PresInherit && pPRule->PrInheritMode == InheritCreator)
-		      /* la regle de ce pave herite de son createur, on l'applique */
+		   if (pPRule->PrPresMode == PresInherit &&
+		       pPRule->PrInheritMode == InheritCreator)
+		      /* la regle de ce pave herite de son createur,
+			 on l'applique */
 		      if (ApplyRule (pPRule, pSchP, pAbbCur, pDoc, pAttrib))
 			{
-			   if (ruleType == PtSize)
-			      pAbbCur->AbSizeChange = TRUE;
-			   else if (ruleType == PtDepth || ruleType == PtLineStyle ||
-				    ruleType == PtLineWeight || ruleType == PtFillPattern ||
-				    ruleType == PtBackground || ruleType == PtForeground)
-			      pAbbCur->AbAspectChange = TRUE;
-			   else
-			      pAbbCur->AbChange = TRUE;
-			   ApplyInherit (ruleType, pAbbCur, pDoc);
-			   RedispAbsBox (pAbbCur, pDoc);
+			  SetChange (pAbbCur, ruleType);
+			  ApplyInherit (ruleType, pAbbCur, pDoc, display);
+			  if (display)
+			    RedispAbsBox (pAbbCur, pDoc);
 			}
 		/* examine le pave suivant */
 		pAbbCur = pAbbCur->AbNext;
 	     }
-	/* on regarde les paves crees au niveau inferieur (par Create et CreateLast) */
+	/* on regarde les paves crees au niveau inferieur (par CreateFirst et
+	   CreateLast) */
 	pAbbCur = pAb->AbFirstEnclosed;
-	while (pAbbCur != NULL)
+	while (pAbbCur)
 	  {
-	     if (pAbbCur->AbPresentationBox && pAbbCur->AbElement == pEl)
-		/* c'est un pave de presentation de l'element, on le traite */
-	       {
-		  pPRule = SearchRulepAb (pDoc, pAbbCur, &pSchP, ruleType, FnAny, TRUE, &pAttrib);
-		  if (pPRule != NULL)
-		     if (pPRule->PrPresMode == PresInherit && pPRule->PrInheritMode == InheritCreator)
-			/* la regle de ce pave herite de son createur, on l'applique */
-			if (ApplyRule (pPRule, pSchP, pAbbCur, pDoc, pAttrib))
-			  {
-			     if (ruleType == PtSize)
-				pAbbCur->AbSizeChange = TRUE;
-			     else if (ruleType == PtDepth || ruleType == PtLineStyle ||
-				      ruleType == PtLineWeight || ruleType == PtFillPattern ||
-				      ruleType == PtBackground || ruleType == PtForeground)
-				pAbbCur->AbAspectChange = TRUE;
-			     else
-				pAbbCur->AbChange = TRUE;
-			     ApplyInherit (ruleType, pAbbCur, pDoc);
-			     RedispAbsBox (pAbbCur, pDoc);
-			  }
-	       }
-	     /* examine le pave suivant */
-	     pAbbCur = pAbbCur->AbNext;
+	    if (pAbbCur->AbPresentationBox && pAbbCur->AbElement == pEl)
+	      /* c'est un pave de presentation de l'element, on le traite */
+	      {
+		pPRule = SearchRulepAb (pDoc, pAbbCur, &pSchP, ruleType, FnAny,
+					TRUE, &pAttrib);
+		if (pPRule)
+		  if (pPRule->PrPresMode == PresInherit &&
+		      pPRule->PrInheritMode == InheritCreator)
+		    /* la regle de ce pave herite de son createur,
+		       on l'applique */
+		    if (ApplyRule (pPRule, pSchP, pAbbCur, pDoc, pAttrib))
+		      {
+			SetChange (pAbbCur, ruleType);
+			ApplyInherit (ruleType, pAbbCur, pDoc, display);
+			if (display)
+			  RedispAbsBox (pAbbCur, pDoc);
+		      }
+	      }
+	    /* examine le pave suivant */
+	    pAbbCur = pAbbCur->AbNext;
 	  }
      }
 }
 
-
 /*----------------------------------------------------------------------
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 int          NumTypePRuleAPI (PtrPRule pRule)
-#else  /* __STDC__ */
-int          NumTypePRuleAPI (pRule)
-PRuleType    pRule;
-
-#endif /* __STDC__ */
 {
    switch (pRule->PrType)
 	 {
@@ -440,6 +355,72 @@ PRuleType    pRule;
 	    case PtHorizPos:
 	       return PRHorizPos;
 	       break;
+            case PtMarginTop:
+               return PRMarginTop;
+               break;
+            case PtMarginRight:
+               return PRMarginRight;
+               break;
+            case PtMarginBottom:
+               return PRMarginBottom;
+               break;
+            case PtMarginLeft:
+               return PRMarginLeft;
+               break;
+            case PtPaddingTop:
+               return PRPaddingTop;
+               break;
+            case PtPaddingRight:
+               return PRPaddingRight;
+               break;
+            case PtPaddingBottom:
+               return PRPaddingBottom;
+               break;
+            case PtPaddingLeft:
+               return PRPaddingLeft;
+               break;
+            case PtBorderTopWidth:
+               return PRBorderTopWidth;
+               break;
+            case PtBorderRightWidth:
+               return PRBorderRightWidth;
+               break;
+            case PtBorderBottomWidth:
+               return PRBorderBottomWidth;
+               break;
+            case PtBorderLeftWidth:
+               return PRBorderLeftWidth;
+               break;
+            case PtXRadius:
+               return PRXRadius;
+               break;
+            case PtYRadius:
+               return PRYRadius;
+               break;
+            case PtBorderTopColor:
+               return PRBorderTopColor;
+               break;
+            case PtBorderRightColor:
+               return PRBorderRightColor;
+               break;
+            case PtBorderBottomColor:
+               return PRBorderBottomColor;
+               break;
+            case PtBorderLeftColor:
+               return PRBorderLeftColor;
+               break;
+            case PtBorderTopStyle:
+               return PRBorderTopStyle;
+               break;
+            case PtBorderRightStyle:
+               return PRBorderRightStyle;
+               break;
+            case PtBorderBottomStyle:
+               return PRBorderBottomStyle;
+               break;
+	    case PtBorderLeftStyle:
+               return PRBorderLeftStyle;
+               break;
 	    case PtSize:
 	       return PRSize;
 	       break;
@@ -470,9 +451,6 @@ PRuleType    pRule;
 	    case PtAdjust:
 	       return PRAdjust;
 	       break;
-	    case PtJustify:
-	       return PRJustify;
-	       break;
 	    case PtLineStyle:
 	       return PRLineStyle;
 	       break;
@@ -515,14 +493,7 @@ PRuleType    pRule;
 /*----------------------------------------------------------------------
    	RuleSetIn teste l'appartenance d'un element a` un ensemble.	
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-int                 RuleSetIn (register int num, RuleSet RuleS1)
-#else  /* __STDC__ */
-int                 RuleSetIn (num, RuleS1)
-register int        num;
-RuleSet             RuleS1;
-
-#endif /* __STDC__ */
+int RuleSetIn (register int num, RuleSet RuleS1)
 {
    if (num >= 0 && num < SETSIZE * 8)
       return RuleS1[num >> 3] & (1 << (num & 7));
@@ -534,14 +505,7 @@ RuleSet             RuleS1;
 /*----------------------------------------------------------------------
    	RuleSetPut ajoute un element a` un ensemble.			
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                RuleSetPut (RuleSet RuleS1, int num)
-#else  /* __STDC__ */
-void                RuleSetPut (RuleS1, num)
-RuleSet             RuleS1;
-int                 num;
-
-#endif /* __STDC__ */
+void RuleSetPut (RuleSet RuleS1, int num)
 {
    if (num >= 0 && num < SETSIZE * 8)
       RuleS1[num >> 3] |= (1 << (num & 7));
@@ -551,15 +515,9 @@ int                 num;
 /*----------------------------------------------------------------------
    	RuleSetClr met a` 0 l'ensemble RuleS1.				
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                RuleSetClr (RuleSet RuleS1)
-#else  /* __STDC__ */
-void                RuleSetClr (RuleS1)
-RuleSet             RuleS1;
-
-#endif /* __STDC__ */
+void RuleSetClr (RuleSet RuleS1)
 {
-   USTRING s1;
+   unsigned char *s1;
    int     num;
 
    s1 = RuleS1;
@@ -572,14 +530,7 @@ RuleSet             RuleS1;
    		pEl1 et pEl2 possedent des regles de presentation	
    		specifique.						
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool            BothHaveNoSpecRules (PtrElement pEl1, PtrElement pEl2)
-#else  /* __STDC__ */
-ThotBool            BothHaveNoSpecRules (pEl1, pEl2)
-PtrElement          pEl1;
-PtrElement          pEl2;
-
-#endif /* __STDC__ */
+ThotBool BothHaveNoSpecRules (PtrElement pEl1, PtrElement pEl2)
 {
    ThotBool            equal;
 
@@ -595,14 +546,7 @@ PtrElement          pEl2;
    		qui appartient a la view view				
    		et qui n'est pas un pave de presentation.		
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-PtrAbstractBox      AbsBoxOfEl (PtrElement pEl, int view)
-#else  /* __STDC__ */
-PtrAbstractBox      AbsBoxOfEl (pEl, view)
-PtrElement          pEl;
-int                 view;
-
-#endif /* __STDC__ */
+PtrAbstractBox AbsBoxOfEl (PtrElement pEl, int view)
 {
    PtrAbstractBox      pAb;
    ThotBool            stop;
@@ -629,15 +573,7 @@ int                 view;
   ApplyNewRule applique au pave courant la regle de		
   presentation specifique qui vient d'etre creee.		
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                ApplyNewRule (PtrDocument pDoc, PtrPRule pPRule, PtrElement pEl)
-#else  /* __STDC__ */
-void                ApplyNewRule (pDoc, pPRule, pEl)
-PtrDocument         pDoc;
-PtrPRule            pPRule;
-PtrElement          pEl;
-
-#endif /* __STDC__ */
+void    ApplyNewRule (PtrDocument pDoc, PtrPRule pPRule, PtrElement pEl)
 {
   PtrAbstractBox      pAb;
   int                 view;
@@ -667,44 +603,18 @@ PtrElement          pEl;
 		/* applique la regle de presentation specifique a ce pave' */
 		  if (ApplyRule (pPRule, NULL, pAb, pDoc, NULL))
 		    {
-		      switch (pPRule->PrType)
+		      if (pPRule->PrType == PtFunction)
 			{
-			case PtHeight:
-			  pAb->AbHeightChange = TRUE;
-			  break;
-			case PtWidth:
-			  pAb->AbWidthChange = TRUE;
-			  break;
-			case PtVertPos:
-			  pAb->AbVertPosChange = TRUE;
-			  break;
-			case PtHorizPos:
-			  pAb->AbHorizPosChange = TRUE;
-			  break;
-			case PtSize:
-			  pAb->AbSizeChange = TRUE;
-			  break;
-			case PtDepth:
-			case PtLineStyle:
-			case PtLineWeight:
-			case PtFillPattern:
-			case PtBackground:
-			case PtForeground:
-			  pAb->AbAspectChange = TRUE;
-			  break;
-			case PtFunction:
 			  if (pPRule->PrPresFunction == FnPictureMode
 			      || pPRule->PrPresFunction == FnBackgroundPicture
 			      || pPRule->PrPresFunction == FnShowBox)
 			    pAb->AbAspectChange = TRUE;
 			  else
 			    pAb->AbChange = TRUE;
-			  break;
-			default:
-			  pAb->AbChange = TRUE;
-			  break;
 			}
-		      ApplyInherit (pPRule->PrType, pAb, pDoc);
+		      else
+			SetChange (pAb, pPRule->PrType);
+		      ApplyInherit (pPRule->PrType, pAb, pDoc, TRUE);
 		      /* indique le pave a faire reafficher */
 		      RedispAbsBox (pAb, pDoc);
 		    }
@@ -716,16 +626,7 @@ PtrElement          pEl;
   RemoveSpecifPres supprime toutes les regles de presentation specifiques
   associees a l'element pEl.				
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         RemoveSpecifPres (PtrElement pEl, PtrDocument pDoc, RuleSet rules, int viewToApply)
-#else  /* __STDC__ */
-static void         RemoveSpecifPres (pEl, pDoc, rules, viewToApply)
-PtrElement          pEl;
-PtrDocument         pDoc;
-RuleSet             rules;
-int                 viewToApply;
-
-#endif /* __STDC__ */
+static void RemoveSpecifPres (PtrElement pEl, PtrDocument pDoc, RuleSet rules, int viewToApply)
 {
    PtrPRule            pPRule, pR, pRS;
    NotifyPresentation  notifyPres;
@@ -805,71 +706,30 @@ int                 viewToApply;
   ApplyPRuleAndRedisplay: apply a presentation rule, update the view
   and apply the inheritance of the rule.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         ApplyPRuleAndRedisplay (PtrAbstractBox pAb, PtrDocument pDoc, PtrAttribute pAttr, PtrPRule pRP, PtrPSchema pSPR)
-#else  /* __STDC__ */
-static void         ApplyPRuleAndRedisplay (pAb, pDoc, pAttr, pRP, pSPR)
-PtrAbstractBox      pAb;
-PtrDocument         pDoc;
-PtrAttribute        pAttr;
-PtrPRule            pRP;
-PtrPSchema          pSPR;
-
-#endif /* __STDC__ */
+static void ApplyPRuleAndRedisplay (PtrAbstractBox pAb, PtrDocument pDoc,
+				    PtrAttribute pAttr, PtrPRule pRP,
+				    PtrPSchema pSPR)
 {
   if (pRP == NULL)
      return;
 
   ApplyRule (pRP, pSPR, pAb, pDoc, pAttr);
   /* marque que le pave a change' et doit etre reaffiche' */
-  switch (pRP->PrType)
+  if (pRP->PrType == PtFunction)
     {
-    case PtVertRef:
-      pAb->AbVertRefChange = TRUE;
-      break;
-    case PtHorizRef:
-      pAb->AbHorizRefChange = TRUE;
-      break;
-    case PtHeight:
-      pAb->AbHeightChange = TRUE;
-      break;
-    case PtWidth:
-      pAb->AbWidthChange = TRUE;
-      break;
-    case PtVertPos:
-      pAb->AbVertPosChange = TRUE;
-      break;
-    case PtHorizPos:
-      pAb->AbHorizPosChange = TRUE;
-      break;
-    case PtSize:
-      pAb->AbSizeChange = TRUE;
-      break;
-    case PtDepth:
-    case PtLineStyle:
-    case PtLineWeight:
-    case PtFillPattern:
-    case PtBackground:
-    case PtForeground:
-      pAb->AbAspectChange = TRUE;
-      break;
-    case PtFunction:
       if (pRP->PrPresFunction == FnPictureMode
 	  || pRP->PrPresFunction == FnBackgroundPicture
 	  || pRP->PrPresFunction == FnShowBox)
 	pAb->AbAspectChange = TRUE;
       else
 	pAb->AbChange = TRUE;
-      break;
-    default:
-      pAb->AbChange = TRUE;
-      break;
     }
-  
+  else
+    SetChange (pAb, pRP->PrType);
   RedispAbsBox (pAb, pDoc);
   /* applique la regle de meme type aux paves environnants */
   /* s'ils heritent de ce parametre de presentation */
-  ApplyInherit (pRP->PrType, pAb, pDoc);
+  ApplyInherit (pRP->PrType, pAb, pDoc, TRUE);
 }
 
 /*----------------------------------------------------------------------
@@ -877,17 +737,9 @@ PtrPSchema          pSPR;
   pDoc la regle de presentation standard de type ruleType	
   pour la view viewSch.						
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                ApplyStandardRule (PtrElement pEl, PtrDocument pDoc, PRuleType ruleType, FunctionType funcType, int viewSch)
-#else  /* __STDC__ */
-void                ApplyStandardRule (pEl, pDoc, ruleType, funcType, viewSch)
-PtrElement          pEl;
-PtrDocument         pDoc;
-PRuleType           ruleType;
-FunctionType        funcType;
-int                 viewSch;
-
-#endif /* __STDC__ */
+void  ApplyStandardRule (PtrElement pEl, PtrDocument pDoc,
+			 PRuleType ruleType, FunctionType funcType,
+			 int viewSch)
 {
   PtrPRule            pRP;
   PtrAbstractBox      pAb;
@@ -937,13 +789,7 @@ int                 viewSch;
 /*----------------------------------------------------------------------
   NextAbstractBox: search the next abstract box.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 static PtrAbstractBox     NextAbstractBox (PtrAbstractBox pAb)
-#else  /* __STDC__ */
-static PtrAbstractBox     NextAbstractBox (pAb)
-PtrAbstractBox     pAb;
-#endif /* __STDC__ */
-
 {
   PtrAbstractBox      pNextAb;
 
@@ -972,15 +818,8 @@ PtrAbstractBox     pAb;
   The pPres function presentation rule has been removed for the element
   having abstract box pAb.  Undo that presentation rule for that abstract box.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void       RemoveFunctionPRule (PtrPRule pPres, PtrAbstractBox pAb, PtrDocument pDoc)
-#else  /* __STDC__ */
-static void       RemoveFunctionPRule (pPres, pAb, pDoc)
-PtrPRule pPres;
-PtrAbstractBox pAb;
-PtrDocument pDoc;
-#endif /* __STDC__ */
-
+static void RemoveFunctionPRule (PtrPRule pPres, PtrAbstractBox pAb,
+				 PtrDocument pDoc)
 {
    if (pPres->PrPresFunction == FnBackgroundPicture &&
        pAb->AbPictBackground != NULL)
@@ -1006,20 +845,12 @@ PtrDocument pDoc;
   Redisplay boxes of element pEl that are concerned by removing the
   presentation function pRule
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void            ApplyASpecificStyleRule (PtrPRule pRule, PtrElement pEl, PtrDocument pDoc, ThotBool remove)
-#else  /* __STDC__ */
-void            ApplyASpecificStyleRule (pRule, pEl, pDoc, remove)
-PtrPRule	pRule;
-PtrElement	pEl;
-PtrDocument	pDoc;
-ThotBool        remove;
-
-#endif /* __STDC__ */
-
+void  ApplyASpecificStyleRule (PtrPRule pRule, PtrElement pEl,
+			       PtrDocument pDoc, ThotBool remove)
 {
   PtrAbstractBox  pAb, pParent;
   PtrPRule	  pCurrentRule, pRP;
+  PtrElement      pPage;
   PtrPSchema	  pSPR;
   PtrAttribute	  pAttr;
   PRuleType	  ruleType;
@@ -1027,10 +858,9 @@ ThotBool        remove;
   int             view;
   ThotBool	  done, enclosed;
 
-  TtaClearViewSelections ();
   enclosed = FALSE;
   /* do nothing if the document no longer exists */
-  if (pDoc != NULL)
+  if (pDoc)
     /* examine all abstract boxes of element */
     for (view = 0; view < MAX_VIEW_DOC; view++)
     {
@@ -1050,23 +880,39 @@ ThotBool        remove;
 	    if (pCurrentRule->PrViewNum == 1 ||
 		pCurrentRule->PrViewNum == viewSch)
 	       {
-	       /* checks if the abstract box is concerned by the rule */
-	       pRP = SearchRulepAb (pDoc, pAb, &pSPR, ruleType,
-				   pCurrentRule->PrPresFunction, TRUE, &pAttr);
-	       if (pRP == pCurrentRule || remove)
-		  {
-		  done = TRUE;
-	          if (remove && ruleType == PtFunction &&
-		     pAb->AbLeafType == LtCompound)
-	             /* remove a PtFunction rule */
-		     RemoveFunctionPRule (pCurrentRule, pAb, pDoc);
-		  else if (pRP != NULL)
-		     ApplyPRuleAndRedisplay (pAb, pDoc, pAttr, pRP, pSPR);
-		  }
+		 if (ruleType == PtFunction &&
+		     pCurrentRule->PrPresFunction == FnPage)
+		   {
+		     /* generate or remove a page break */
+		     if (remove)
+		       {
+			 pPage = pEl->ElPrevious;
+			 if (pPage && pPage->ElTypeNumber == PageBreak + 1)
+			   DeleteElement (&pPage, pDoc);
+		       }
+		     else
+		       pPage = CreateSibling (pDoc, pEl, TRUE, TRUE, PageBreak + 1, pEl->ElStructSchema, FALSE);
+		     done = TRUE;
+		   }
+		 else
+		   {
+		     /* checks if the abstract box is concerned by the rule */
+		     pRP = SearchRulepAb (pDoc, pAb, &pSPR, ruleType,
+					  pCurrentRule->PrPresFunction, TRUE, &pAttr);
+		     if (pRP == pCurrentRule || remove)
+		       {
+			 done = TRUE;
+			 if (remove && ruleType == PtFunction &&
+			     pAb->AbLeafType == LtCompound)
+			   /* remove a PtFunction rule */
+			   RemoveFunctionPRule (pCurrentRule, pAb, pDoc);
+			 else if (pRP != NULL)
+			   ApplyPRuleAndRedisplay (pAb, pDoc, pAttr, pRP, pSPR);
+		       }
+		   }
 	       }
-	    /* pCurrentRule = pCurrentRule->PrNextPRule; */
 	    }
-
+	  
 	  if (done)
 	    {
 	      /* update abstract image and redisplay */
@@ -1122,19 +968,9 @@ ThotBool        remove;
   For each displayed abstract box and each new presention rule
   check if it is concerned by this new pRule.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void               ApplyAGenericStyleRule (Document doc, PtrSSchema pSS, int elType, int attrType, int presBox, PtrPRule pRule, ThotBool remove)
-#else  /* __STDC__ */
-void               ApplyAGenericStyleRule (doc, pSS, elType, attrType, presBox, pRule, remove)
-Document           doc;
-PtrSSchema         pSS;
-int                elType;
-int                attrType;
-int                presBox;
-PtrPRule           pRule;
-ThotBool           remove;
-#endif /* __STDC__ */
-
+void  ApplyAGenericStyleRule (Document doc, PtrSSchema pSS, int elType,
+			      int attrType, int presBox, PtrPRule pRule,
+			      ThotBool remove)
 {
   PtrPRule        pCurrentRule, pRP;
   PtrPSchema      pSPR;
@@ -1152,8 +988,6 @@ ThotBool           remove;
   pDoc = LoadedDocument[doc - 1];
   selectionOK = GetCurrentSelection (&pSelDoc, &pFirstSel, &pLastSel,
 				     &firstChar, &lastChar);
-  /* eteint la selection courante */
-  TtaClearViewSelections ();
   /* do nothing if the document no longer exists */
   if (pDoc != NULL)
     /* examine all abstract boxes of elements */
@@ -1165,11 +999,12 @@ ThotBool           remove;
       viewSch = pDoc->DocView[view].DvPSchemaView;
       while (pAb != NULL)
 	{
+	  /* there is probably a problem with visibility rules: pAb doesn't exists */
 	  found = FALSE;
 	  if (elType > 0)
 	    /* presentation rules are associated with an element type */
 	    found = (pAb->AbElement->ElTypeNumber == elType &&
-	             pAb->AbElement->ElStructSchema->SsCode == pSS->SsCode);
+	             !ustrcmp (pAb->AbElement->ElStructSchema->SsName, pSS->SsName));
 	  else if (attrType > 0)
 	    {
 	      /* presentation rules are associated with an attribute type */
@@ -1177,7 +1012,7 @@ ThotBool           remove;
 	      while (!found && pAttr != NULL)
 		{
 		  found = (pAttr->AeAttrNum == attrType &&
-			   pAttr->AeAttrSSchema->SsCode == pSS->SsCode);
+			   !ustrcmp (pAttr->AeAttrSSchema->SsName, pSS->SsName));
 		  if (!found)
 		     pAttr = pAttr->AeNext;
 		}
@@ -1185,7 +1020,7 @@ ThotBool           remove;
 	  else if (presBox > 0)
 	    /* presentation rules are associated with a presentation box */
 	    found = (pAb->AbPresentationBox && pAb->AbTypeNum == presBox &&
-		     pAb->AbPSchema == pSS->SsPSchema);
+		     pAb->AbPSchema == PresentationSchema (pSS, pDoc));
 	  if (found)
 	    {
 	      /* process each presentation rule */
@@ -1217,7 +1052,6 @@ ThotBool           remove;
 			    ApplyPRuleAndRedisplay (pAb, pDoc, pAttr, pRP, pSPR);
 			}
 		    }
-		  /*pCurrentRule = pCurrentRule->PrNextPRule;*/
 		}
 	      /* redisplay the element if needed */
 	      if (found)
@@ -1237,7 +1071,7 @@ ThotBool           remove;
     }
   /* tente de fusionner les elements voisins et reaffiche les paves */
   /* modifie's et la selection */
-  if (pSelDoc != NULL && pSelDoc == pDoc)
+  if (pDoc && pSelDoc == pDoc)
     SelectRange (pSelDoc, pFirstSel, pLastSel, firstChar, lastChar);
 }
 
@@ -1246,16 +1080,7 @@ ThotBool           remove;
   contenues dans 'RulesS' attachees aux elements du	
   sous-arbre de racine pElRoot				
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                RemoveSpecPresTree (PtrElement pElRoot, PtrDocument pDoc, RuleSet RulesS, int viewToApply)
-#else  /* __STDC__ */
-void                RemoveSpecPresTree (pElRoot, pDoc, RulesS, viewToApply)
-PtrElement          pElRoot;
-PtrDocument         pDoc;
-RuleSet             RulesS;
-int                 viewToApply;
-
-#endif /* __STDC__ */
+void  RemoveSpecPresTree (PtrElement pElRoot, PtrDocument pDoc, RuleSet RulesS, int viewToApply)
 {
    PtrElement          pEl, pNext;
 
@@ -1276,25 +1101,39 @@ int                 viewToApply;
    RemoveSpecifPres (pElRoot, pDoc, RulesS, viewToApply);
 }
 
+/*----------------------------------------------------------------------
+   TtaIsCSSPRule
+
+   Check whether a presentation rule is associated with a CSS rule
+   Parameters:
+   pRule: the presentation rule to be tested.
+   Return value:
+   TRUE if pRule is a CSS rule
+  ----------------------------------------------------------------------*/
+ThotBool            TtaIsCSSPRule (PRule pRule)
+{
+   ThotBool         ret;
+
+   ret = FALSE;
+   UserErrorCode = 0;
+   if (pRule == NULL)
+     TtaError (ERR_invalid_parameter);
+   else
+     /* parameter pRule is correct */
+     ret = (((PtrPRule) pRule)->PrLevel != 0);
+   return ret;
+}
+
 /*----------------------------------------------------------------------
    TtaRemovePRule
 
    Removes a presentation rule from an element and release that rule.
-
    Parameters:
    element: the element with which the presentation rule is associated.
    pRule: the presentation rule to be removed.
    document: the document to which the element belongs.
-
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                TtaRemovePRule (Element element, PRule pRule, Document document)
-#else  /* __STDC__ */
-void                TtaRemovePRule (element, pRule, document)
-Element             element;
-PRule               pRule;
-Document            document;
-#endif /* __STDC__ */
+void    TtaRemovePRule (Element element, PRule pRule, Document document)
 {
    PtrPRule            pPres, pPreviousPres;
 
@@ -1344,28 +1183,15 @@ Document            document;
    Returns the first presentation rule associated with a given
    element (if pRule is NULL) or the presentation rule that
    follows a given rule of a given element.
-
    Parameters:
    element: the element of interest.
    pRule: a presentation rule of that element, or NULL
    if the first rule is asked.
-
    Return parameter:
    pRule: the next presentation rule, or NULL if
    pRule is the last rule of the element.
-
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
 void                TtaNextPRule (Element element, PRule * pRule)
-
-#else  /* __STDC__ */
-void                TtaNextPRule (element, pRule)
-Element             element;
-PRule              *pRule;
-
-#endif /* __STDC__ */
-
 {
    PtrPRule            nextPRule;
 
