@@ -1,19 +1,10 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996.
+ *  (c) COPYRIGHT INRIA, 1996-2001
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
 
-/*
- * Warning:
- * This module is part of the Thot library, which was originally
- * developed in French. That's why some comments are still in
- * French, but their translation is in progress and the full module
- * will be available in English in the next release.
- * 
- */
- 
 /*
  * Manipulation des variables de presentation pour
  * les images abstraites des documents.
@@ -37,7 +28,6 @@
 #include "content_f.h"
 #include "presvariables_f.h"
 
-
 /*----------------------------------------------------------------------
    MakeAliasTypeCount cree un alias temporaire qui va servir a faire 
    une recherche multiple sur les elements du compteur     
@@ -45,18 +35,8 @@
    du compteur.  On cree l'alias  MAX_RULES_SSCHEMA + 1 pour les 
    elements add du compteur.                               
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-static int          MakeAliasTypeCount (Counter * pCounter, CounterOp op, PtrSSchema pSchStr)
-
-#else  /* __STDC__ */
-static int          MakeAliasTypeCount (pCounter, op, pSchStr)
-Counter            *pCounter;
-CounterOp           op;
-PtrSSchema          pSchStr;
-
-#endif /* __STDC__ */
-
+static int MakeAliasTypeCount (Counter *pCounter, CounterOp op,
+			       PtrSSchema pSchStr)
 {
    SRule              *NewAlias;
    int                 i;
@@ -69,12 +49,9 @@ PtrSSchema          pSchStr;
       return pCounter->CnItem[0].CiElemType;
 
    /* initialise l'alias temporaire */
-   ustrcpy (NewAlias->SrName, TEXT("Counter alias"));
+   ustrcpy (NewAlias->SrName, "Counter alias");
    NewAlias->SrNDefAttrs = 0;
    NewAlias->SrNLocalAttrs = 0;
-   NewAlias->SrAssocElem = FALSE;
-   NewAlias->SrAssocElem = FALSE;
-   NewAlias->SrParamElem = FALSE;
    NewAlias->SrUnitElem = FALSE;
    NewAlias->SrRecursive = FALSE;
    NewAlias->SrExportedElem = FALSE;
@@ -102,24 +79,12 @@ PtrSSchema          pSchStr;
       return MAX_RULES_SSCHEMA + 2;
 }
 
-
 /*----------------------------------------------------------------------
    GetCounterValEl renvoie la valeur numerique de set ou d'increment 
    associee a l'element pEl.                               
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-static int          GetCounterValEl (Counter * pCounter, PtrElement pEl, CounterOp op, PtrSSchema pSchStr)
-
-#else  /* __STDC__ */
-static int          GetCounterValEl (pCounter, pEl, op, pSchStr)
-Counter            *pCounter;
-PtrElement          pEl;
-CounterOp           op;
-PtrSSchema          pSchStr;
-
-#endif /* __STDC__ */
-
+static int GetCounterValEl (Counter * pCounter, PtrElement pEl, CounterOp op,
+			    PtrSSchema pSchStr)
 {
    int                 i;
 
@@ -134,22 +99,11 @@ PtrSSchema          pSchStr;
    return 0;			/* par defaut... */
 }
 
-
 /*----------------------------------------------------------------------
    InitCounterByAttribute                                          
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static ThotBool     InitCounterByAttribute (int *valinit, Counter * pCo, PtrElement pElNum, PtrSSchema pSS)
-
-#else  /* __STDC__ */
-static ThotBool     InitCounterByAttribute (valinit, pCo, pElNum, pSS)
-int                *valinit;
-Counter            *pCo;
-PtrElement          pElNum;
-PtrSSchema          pSS;
-
-#endif /* __STDC__ */
-
+static ThotBool InitCounterByAttribute (int *valinit, Counter * pCo,
+					PtrElement pElNum, PtrSSchema pSS)
 {
    ThotBool            result, stop;
    PtrElement          pEl;
@@ -172,7 +126,7 @@ PtrSSchema          pSS;
 		if (pAttr == NULL)
 		   stop = TRUE;	/* dernier attribut */
 		else if (pAttr->AeAttrNum == pCo->CnItem[0].CiInitAttr &&
-			 pAttr->AeAttrSSchema->SsCode == pSS->SsCode)
+			 !ustrcmp (pAttr->AeAttrSSchema->SsName, pSS->SsName))
 		   stop = TRUE;	/* c'est l'attribut cherche' */
 		else
 		   pAttr = pAttr->AeNext;	/* au suivant */
@@ -191,23 +145,13 @@ PtrSSchema          pSS;
    return result;
 }
 
-
 /*----------------------------------------------------------------------
   CondAttrOK
   return TRUE if the attribute condition in counter item pCountItem is
   satisfied for element pEl.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static ThotBool     CondAttrOK (CntrItem * pCountItem, PtrElement pEl, PtrSSchema pSS)
-
-#else  /* __STDC__ */
-static ThotBool     CondAttrOK (pCountItem, pEl, pSS)
-CntrItem            *pCountItem;
-PtrElement          pEl;
-PtrSSchema          pSS;
-
-#endif /* __STDC__ */
-
+static ThotBool CondAttrOK (CntrItem * pCountItem, PtrElement pEl,
+			    PtrSSchema pSS)
 {
    ThotBool            result, stop;
    PtrAttribute        pAttr;
@@ -223,7 +167,7 @@ PtrSSchema          pSS;
 	if (pAttr == NULL)
 	   stop = TRUE;	/* dernier attribut */
 	else if (pAttr->AeAttrNum == pCountItem->CiCondAttr &&
-		 pAttr->AeAttrSSchema->SsCode == pSS->SsCode)
+		 !ustrcmp (pAttr->AeAttrSSchema->SsName, pSS->SsName))
 	   stop = TRUE;	/* c'est l'attribut cherche' */
 	else
 	   pAttr = pAttr->AeNext;	/* au suivant */
@@ -235,25 +179,14 @@ PtrSSchema          pSS;
    return result;
 }
 
-
 /*----------------------------------------------------------------------
   GetCounterItem
   return the rank of the item of counter pCounter which applies an operation
   cntrOp to element pEl.
   return -1 if not found.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static int      GetCounterItem (Counter * pCounter, CounterOp cntrOp, PtrSSchema pSS, PtrElement pEl)
-
-#else  /* __STDC__ */
-static int      GetCounterItem (pCounter, cntrOp, pSS, pEl)
-Counter            *pCounter;
-CounterOp	    cntrOp;
-PtrSSchema          pSS;
-PtrElement          pEl;
-
-#endif /* __STDC__ */
-
+static int GetCounterItem (Counter * pCounter, CounterOp cntrOp,
+			   PtrSSchema pSS, PtrElement pEl)
 {
    int		i;
 
@@ -265,7 +198,6 @@ PtrElement          pEl;
    return (-1);
 }
 
-
 /*----------------------------------------------------------------------
    CounterValMinMax
    retourne la valeur minimale ou maximale (selon que Maximum est faux ou vrai)
@@ -273,21 +205,8 @@ PtrElement          pEl;
    qui s'applique au schema de structure pSS) pour l'element pElNum.
    view indique la vue concernee (uniquement pour les compteurs de page).
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-int                 CounterValMinMax (int counterNum, PtrSSchema pSS, PtrPSchema pSchP, PtrElement pElNum, int view, ThotBool Maximum)
-
-#else  /* __STDC__ */
-int                 CounterValMinMax (counterNum, pSS, pSchP, pElNum, view, Maximum)
-int                 counterNum;
-PtrSSchema          pSS;
-PtrPSchema          pSchP;
-PtrElement          pElNum;
-int                 view;
-ThotBool            Maximum;
-
-#endif /* __STDC__ */
-
+int CounterValMinMax (int counterNum, PtrSSchema pSS, PtrPSchema pSchP,
+		      PtrElement pElNum, int view, ThotBool Maximum)
 {
    int                 value, valueinitattr, i;
    int                 TypeIncr, TypeSet, TypeRank;
@@ -326,49 +245,50 @@ ThotBool            Maximum;
 
 	     if (Maximum)
 	       {
-		  /* mais on veut la valeur maximale; alors, on continue */
-		  pEl = pElNum;
-		  pEl2 = pEl;
-		  while (pEl2->ElParent != NULL)
-		     pEl2 = pEl2->ElParent;
-		  pSSpr = pEl2->ElStructSchema;
-		  /* view a laquelle appartient la marque de page cherchee */
-		  if (pCo1->CnItem[0].CiViewNum > 0)
-		     view = pCo1->CnItem[0].CiViewNum;
-		  if (pCo1->CnItem[0].CiViewNum == 0 && pElNum->ElAssocNum > 0)
-		     view = pElNum->ElViewPSchema;
-		  /* cherche la marque de page qui precede l'element */
-		  stop = FALSE;
-		  do
-		    {
-		       pEl = BackSearchTypedElem (pEl, TypeRank, NULL);
-		       if (pEl == NULL)
-			  /* pas de marque de page precedente */
-			  stop = TRUE;
-		       else
-			 {
-			    if (pElNum->ElStructSchema->SsCode != pSSpr->SsCode)
-			       /* Saut de page d'une view squelette */
-			       /* on ne que compte les pages etrangeres au schema */
-			       /* principal */
-			       pstop = pEl->ElStructSchema->SsCode !=
-				  pSSpr->SsCode;
-			    else
-			       pstop = pEl->ElStructSchema->SsCode ==
-				  pSSpr->SsCode;
+		 /* mais on veut la valeur maximale; alors, on continue */
+		 pEl = pElNum;
+		 pEl2 = pEl;
+		 while (pEl2->ElParent != NULL)
+		   pEl2 = pEl2->ElParent;
+		 pSSpr = pEl2->ElStructSchema;
+		 /* view a laquelle appartient la marque de page cherchee */
+		 if (pCo1->CnItem[0].CiViewNum > 0)
+		   view = pCo1->CnItem[0].CiViewNum;
+		 /* cherche la marque de page qui precede l'element */
+		 stop = FALSE;
+		 do
+		   {
+		     pEl = BackSearchTypedElem (pEl, TypeRank, NULL);
+		     if (pEl == NULL)
+		       /* pas de marque de page precedente */
+		       stop = TRUE;
+		     else
+		       {
+			 if (ustrcmp (pElNum->ElStructSchema->SsName, pSSpr->SsName))
+			   /* Saut de page d'une view squelette */
+			   /* on ne que compte les pages etrangeres au schema */
+			   /* principal */
+			   pstop = ustrcmp (pEl->ElStructSchema->SsName,
+					    pSSpr->SsName);
+			 else
+			   pstop = !ustrcmp (pEl->ElStructSchema->SsName,
+					     pSSpr->SsName);
 
-			    /* on ignore les pages qui ne concernent pas la view */
-			    if ((pEl->ElViewPSchema == view) && (pstop))
-			       stop = TRUE;
-			 }
-		    }
-		  while (!stop);
+			 /* on ignore les pages qui ne concernent pas la view */
+			 if ((pEl->ElViewPSchema == view) && (pstop))
+			   stop = TRUE;
+		       }
+		   }
+		 while (!stop);
 
-		  if (pEl == NULL)	/* pas de marque de page precedente */
+		 if (pEl == NULL)
+		   {
+		     /* pas de marque de page precedente */
 		     if (initattr)
-			value = valueinitattr;
+		       value = valueinitattr;
 		     else
 			value = 0;
+		   }
 		  else
 		     /* on prend pour valeur le numero de la marque de page */
 		     /* precedente */
@@ -499,8 +419,9 @@ ThotBool            Maximum;
 		  {
 		     pEl = FwdSearchElem2Types (pEl, TypeIncr, pElNum->ElTypeNumber, pSchIncr,
 						pElNum->ElStructSchema);
-		     if (pEl != NULL)
-			if (EquivalentType (pEl, TypeIncr, pSchIncr))
+		     if (pEl != NULL &&
+			 EquivalentType (pEl, TypeIncr, pSchIncr))
+		       {
 			   /* on a trouve' un element du type qui incremente */
 			if (!CondAttr)
 			   value += GetCounterValEl (pCo1, pEl, CntrAdd, pSS);
@@ -512,6 +433,7 @@ ThotBool            Maximum;
 			      if (CondAttrOK (&pCo1->CnItem[i], pEl, pSS))
 			         value += GetCounterValEl (pCo1, pEl, CntrAdd, pSS);
 			   }
+		       }
 		  }
 		while (pEl != NULL && !EquivalentType (pEl, TypeSet, pSS));
 	  }
@@ -522,7 +444,6 @@ ThotBool            Maximum;
    return value;
 }
 
-
 /*----------------------------------------------------------------------
    CounterVal retourne la valeur du compteur de numero counterNum (defini
    dans le schema de presentation  pointe' par pSchP, qui  
@@ -531,17 +452,8 @@ ThotBool            Maximum;
    view indique la view concernee (uniquement pour les       
    compteurs de page).                                     
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-int                 CounterVal (int counterNum, PtrSSchema pSS, PtrPSchema pSchP, PtrElement pElNum, int view)
-#else  /* __STDC__ */
-int                 CounterVal (counterNum, pSS, pSchP, pElNum, view)
-int                 counterNum;
-PtrSSchema          pSS;
-PtrPSchema          pSchP;
-PtrElement          pElNum;
-int                 view;
-#endif /* __STDC__ */
-
+int CounterVal (int counterNum, PtrSSchema pSS, PtrPSchema pSchP,
+		PtrElement pElNum, int view)
 {
    int                 i, value, valueinitattr, level, Nincr, incrVal;
    int                 TypeIncr, TypeSet, TypeRank, TypeRLevel;
@@ -576,7 +488,8 @@ int                 view;
 	while (pEl != NULL)
 	  {
 	     if (pEl->ElTypeNumber == TypeRLevel &&
-		 pEl->ElStructSchema->SsCode == pElNum->ElStructSchema->SsCode)
+		 !ustrcmp (pEl->ElStructSchema->SsName,
+			   pElNum->ElStructSchema->SsName))
 		/* cet element englobant a le type qui incremente le compteur*/
 		/* if there is a condition about an attribute attached to the
 		   element, check that condition */
@@ -604,8 +517,6 @@ int                 view;
 	     if (pCo1->CnItem[0].CiViewNum > 0)
 		/* vue a laquelle appartient la marque de page cherchee */
 		view = pCo1->CnItem[0].CiViewNum;
-	     if (pCo1->CnItem[0].CiViewNum == 0 && pElNum->ElAssocNum > 0)
-		view = pElNum->ElViewPSchema;
 	     /* cherche la marque de page qui precede l'element */
 	     stop = FALSE;
 	     do
@@ -616,12 +527,14 @@ int                 view;
 		     stop = TRUE;
 		  else
 		    {
-		       if (pElNum->ElStructSchema->SsCode != pSSpr->SsCode)
+		       if (ustrcmp (pElNum->ElStructSchema->SsName, pSSpr->SsName))
 			  /* Saut de page d'une view squelette */
 			  /*on ne que compte les pages etrangeres au schema principal */
-			  pstop = pEl->ElStructSchema->SsCode != pSSpr->SsCode;
+			  pstop = ustrcmp (pEl->ElStructSchema->SsName,
+					   pSSpr->SsName);
 		       else
-			  pstop = pEl->ElStructSchema->SsCode == pSSpr->SsCode;
+			  pstop = !ustrcmp (pEl->ElStructSchema->SsName,
+					    pSSpr->SsName);
 
 		       /* on ignore les pages qui ne concernent pas la view */
 		       /* on ignore les pages qui ne concernent pas la view */
@@ -675,8 +588,8 @@ int                 view;
 		  while (level > 0 && pEl != NULL)
 		    {
 		       if (pEl->ElTypeNumber == TypeRank &&
-			   pEl->ElStructSchema->SsCode ==
-			   pElNum->ElStructSchema->SsCode)
+			   !ustrcmp (pEl->ElStructSchema->SsName,
+				     pElNum->ElStructSchema->SsName))
 			  /* cet element englobant a le type qui incremente le
 			     compteur */
 			    {
@@ -706,27 +619,27 @@ int                 view;
 		  pAttr = NULL;
 		  pElReinit = NULL;
 		  if (pCo1->CnItem[0].CiReinitAttr != 0)
-		     /* le compteur est reinitialise' par un attribut */
-		     /* cherche si l'element ou un de ses freres precedents */
-		     /* porte cet attribut */
+		    /* le compteur est reinitialise' par un attribut */
+		    /* cherche si l'element ou un de ses freres precedents */
+		    /* porte cet attribut */
 		    {
-		       pElReinit = pEl;
-		       while (pElReinit != NULL && pAttr == NULL)
-			 {
-			    pAttr = pElReinit->ElFirstAttr;
-			    stop = FALSE;	/* parcourt les attributs de l'element */
-			    do
-			       if (pAttr == NULL)
-				  stop = TRUE;	/* dernier attribut */
-			       else if (pAttr->AeAttrNum == pCo1->CnItem[0].CiReinitAttr &&
-				pAttr->AeAttrSSchema->SsCode == pSS->SsCode)
-				  stop = TRUE;	/* c'est l'attribut cherche' */
-			       else
-				  pAttr = pAttr->AeNext;	/* au suivant */
-			    while (!stop);
+		      pElReinit = pEl;
+		      while (pElReinit != NULL && pAttr == NULL)
+			{
+			  pAttr = pElReinit->ElFirstAttr;
+			  stop = FALSE;	/* parcourt les attributs de l'element */
+			  do
 			    if (pAttr == NULL)
-			       pElReinit = pElReinit->ElPrevious;
-			 }
+			      stop = TRUE;	/* dernier attribut */
+			    else if (pAttr->AeAttrNum == pCo1->CnItem[0].CiReinitAttr &&
+				     !ustrcmp (pAttr->AeAttrSSchema->SsName, pSS->SsName))
+			      stop = TRUE;	/* c'est l'attribut cherche' */
+			    else
+			      pAttr = pAttr->AeNext;	/* au suivant */
+			  while (!stop);
+			  if (pAttr == NULL)
+			    pElReinit = pElReinit->ElPrevious;
+			}
 		    }
 		  /* on compte les elements qui precedent l'element a numeroter */
 		  /* en s'arretant sur l'element qui reinitialise le compteur */
@@ -805,19 +718,21 @@ int                 view;
 		  pEl = FwdSearchElem2Types (pEl, TypeIncr,
 					     pElNum->ElTypeNumber, pSchIncr,
 					     pElNum->ElStructSchema);
-		  if (pEl != NULL)
-		     if (EquivalentType (pEl, TypeIncr, pSchIncr))
-			/* on a trouve' un element du type qui incremente */
-			if (!CondAttr)
-			   value += GetCounterValEl (pCo1, pEl, CntrAdd, pSS);
-			else
-			   /* check conditions on attributes */
-			   {
-			   i = GetCounterItem (pCo1, CntrAdd, pSS, pEl);
-			   if (i >= 0)
-			      if (CondAttrOK (&pCo1->CnItem[i], pEl, pSS))
-				 value += GetCounterValEl (pCo1, pEl, CntrAdd, pSS);
-			   }
+		  if (pEl != NULL &&
+		      EquivalentType (pEl, TypeIncr, pSchIncr))
+		    {
+		      /* on a trouve' un element du type qui incremente */
+		      if (!CondAttr)
+			value += GetCounterValEl (pCo1, pEl, CntrAdd, pSS);
+		      else
+			/* check conditions on attributes */
+			{
+			  i = GetCounterItem (pCo1, CntrAdd, pSS, pEl);
+			  if (i >= 0)
+			    if (CondAttrOK (&pCo1->CnItem[i], pEl, pSS))
+			      value += GetCounterValEl (pCo1, pEl, CntrAdd, pSS);
+			}
+		    }
 	       }
 	     while (pEl != NULL && pEl != pElNum);
 	  }
@@ -866,6 +781,7 @@ int                 view;
 		  pEl = BackSearchElem2Types (pEl, TypeSet, TypeIncr, pSchSet,
 					      pSchIncr);
 		  if (pEl != NULL)
+		    {
 		     if (EquivalentType (pEl, TypeIncr, pSchIncr))
 			/* on a trouve' un element du type qui incremente */
 			{
@@ -910,6 +826,7 @@ int                 view;
 				 }
 			   }
 			}
+		    }
 	       }
 	     while (pEl != NULL);
 	  value += Nincr * incrVal;
@@ -927,13 +844,7 @@ int                 view;
    pave de presentation dont le contenu peut etre modifie' 
    par l'utilisateur.                                      
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool            PresAbsBoxUserEditable (PtrAbstractBox pAb)
-#else  /* __STDC__ */
-ThotBool            PresAbsBoxUserEditable (pAb)
-PtrAbstractBox      pAb;
-
-#endif /* __STDC__ */
+ThotBool PresAbsBoxUserEditable (PtrAbstractBox pAb)
 {
    ThotBool            result;
    PresentationBox    *pBo;
@@ -946,11 +857,7 @@ PtrAbstractBox      pAb;
 	{
 	   /* cherche la boite de presentation correspondant au pave' */
 	   pBo = &pAb->AbPSchema->PsPresentBox[pAb->AbTypeNum - 1];
-	   if (pBo->PbContent == ContElement)
-	      /* une boite qui regroupe des elements associes */
-	      /* son contenu est modifiable */
-	      result = TRUE;
-	   else if (pBo->PbContent == ContVariable)
+	   if (pBo->PbContent == ContVariable)
 	      /* une boite dont le contenu est une variable de presentation */
 	     {
 		pPr = &pAb->AbPSchema->PsVariable[pBo->PbContVariable - 1];
@@ -969,32 +876,17 @@ PtrAbstractBox      pAb;
    return result;
 }
 
-
 /*----------------------------------------------------------------------
-   NewVariable met dans le pave pAb le texte correspondant a la  
-   variable de numero varNum definie dans le schema de       
-   presentation pSchP (et qui correspond au schema de      
-   structure pSS). pDoc pointe sur le descripteur du       
-   document pour lequel on travaille. Si le pave avait     
-   deja un contenu et que ce contenu ne change pas la      
-   fonction retourne 'faux'. S'il y a un isNew contenu,  
-   elle retourne 'vrai'.                                   
+   NewVariable met dans le pave pAb le texte correspondant a la
+   variable de numero varNum definie dans le schema de presentation pSchP
+   (et qui correspond au schema de structure pSS).
+   Si pAttr n'est pas nul, c'est pour cet attribut qu'on calcule la variable.
+   pDoc pointe sur le descripteur du document pour lequel on travaille.
+   Si le pave avait deja un contenu et que ce contenu ne change pas la      
+   fonction retourne 'faux'. S'il y a un nouveau contenu, elle retourne 'vrai'.
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-ThotBool            NewVariable (int varNum, PtrSSchema pSS, PtrPSchema pSchP,
-				 PtrAbstractBox pAb, PtrDocument pDoc)
-
-#else  /* __STDC__ */
-ThotBool            NewVariable (varNum, pSS, pSchP, pAb, pDoc)
-int                 varNum;
-PtrSSchema          pSS;
-PtrPSchema          pSchP;
-PtrAbstractBox      pAb;
-PtrDocument         pDoc;
-
-#endif /* __STDC__ */
-
+ThotBool NewVariable (int varNum, PtrSSchema pSS, PtrPSchema pSchP,
+		      PtrAbstractBox pAb, PtrAttribute pAttr, PtrDocument pDoc)
 {
    int                 f, l;
    int                 i;
@@ -1002,7 +894,7 @@ PtrDocument         pDoc;
    long               *pt;
    struct tm          *ptm;
    PtrTextBuffer       isOld, isNew;
-   PtrAttribute        pAttr;
+   PtrAttribute        pA;
    ThotBool            found;
    ThotBool            equal;
    PresVariable       *pPr1;
@@ -1011,7 +903,7 @@ PtrDocument         pDoc;
    TtAttribute        *pAttr1;
    PtrElement          pEl;
    Counter            *pCo1;
-   CHAR_T              number[20];
+   char                number[20];
    PtrTextBuffer       pBTN, pBTA, pBTAPrec;
 
    /* sauve temporairement le contenu de ce pave de presentation */
@@ -1020,7 +912,7 @@ PtrDocument         pDoc;
    /* de la variable */
    GetConstantBuffer (pAb);
    pAb->AbVolume = 0;
-   pAttr = NULL;
+   pA = NULL;
    /* remplit le buffer avec le contenu defini par la variable */
    pPr1 = &pSchP->PsVariable[varNum - 1];
    for (f = 1; f <= pPr1->PvNItems; f++)
@@ -1028,198 +920,221 @@ PtrDocument         pDoc;
      {
 	pVa1 = &pPr1->PvItem[f - 1];
 	switch (pVa1->ViType)
+	  {
+	    /* traitement specifique selon le type de l'element de variable */
+	  case VarText:
+	    /* constante textuelle */
+	    pPres1 = &pSchP->PsConstant[pVa1->ViConstant - 1];
+	    CopyStringToText (pPres1->PdString, pAb->AbText, &l);
+	    pAb->AbVolume += l;
+	    pAb->AbLanguage = TtaGetLanguageIdFromAlphabet (pPres1->PdAlphabet);
+	    break;
+	    
+	  case VarAttrValue:
+	    /* valeur d'un attribut */
+	    found = FALSE;
+	    if (pVa1->ViAttr == 0)
+	      /* Content: AttributeValue */
 	      {
-		    /* traitement specifique selon le type de l'element de variable */
-		 case VarText:
-		    /* constante textuelle */
-		    pPres1 = &pSchP->PsConstant[pVa1->ViConstant - 1];
-		    CopyStringToText (pPres1->PdString, pAb->AbText, &l);
-		    pAb->AbVolume += l;
-		    pAb->AbLanguage = TtaGetLanguageIdFromAlphabet (pPres1->PdAlphabet);
-		    break;
-
-		 case VarAttrValue:
-		    /* valeur d'un attribut */
-		    /* cherche si l'element auquel se rapporte le pave (ou l'un de */
-		    /* ses ascendants) possede cet attribut */
-		    pEl = pAb->AbElement;
-		    found = FALSE;
-		    while (!found && pEl != NULL)
-		      {
-			 pAttr = pEl->ElFirstAttr;	/* premier attribut */
-			 while (!found && pAttr != NULL)
-			    if (pAttr->AeAttrNum == pVa1->ViAttr &&
-				pAttr->AeAttrSSchema->SsCode == pSS->SsCode)
-			       found = TRUE;
-			    else
-			       pAttr = pAttr->AeNext;
-			 if (!found)
-			    /* passe a l'element ascendant */
-			    pEl = pEl->ElParent;
-		      }
-		    if (found)
-		       /* l'element possede l'attribut */
-		      {
-			 switch (pAttr->AeAttrType)
-			       {
-				  case AtNumAttr:
-				     /* traduit l'entier en ASCII selon le style voulu */
-				     GetCounterValue (pAttr->AeAttrValue, pVa1->ViStyle, number, &l);
-				     CopyStringToText (number, pAb->AbText, &l);
-				     pAb->AbVolume += l;
-				     pAb->AbCreatorAttr = pAttr;
-				     break;
-				  case AtTextAttr:
-				     if (pAttr->AeAttrText != NULL)
-				       {
-					  CopyTextToText (pAttr->AeAttrText,
-							  pAb->AbText, &l);
-					  pAb->AbVolume += l;
-				       }
-				     pAb->AbCreatorAttr = pAttr;
-				     break;
-				  case AtReferenceAttr:
-				     CopyStringToText (REF_EXT2, pAb->AbText, &l);
-				     pAb->AbVolume += l;
-				     break;
-				  case AtEnumAttr:
-				     pAttr1 = &pSS->SsAttribute[pVa1->ViAttr - 1];
-				     CopyStringToText (pAttr1->AttrEnumValue[pAttr->AeAttrValue - 1],
-						       pAb->AbText, &l);
-				     pAb->AbVolume += l;
-				     pAb->AbCreatorAttr = pAttr;
-				     break;
-			       }
-			 /* end case AttrType */
-		      }
-		    break;
-		 case VarCounter:
-		    /* valeur d'un compteur */
-		    pCo1 = &pSchP->PsCounter[pVa1->ViCounter - 1];
-		    if (pVa1->ViCounterVal == CntMaxVal)
-		       /* on cherche la valeur maximale du compteur */
-		       i = CounterValMinMax (pVa1->ViCounter, pSS, pSchP, pAb->AbElement,
-					     pDoc->DocView[pAb->AbDocView - 1].DvPSchemaView, TRUE);
-		    else if (pVa1->ViCounterVal == CntMinVal)
-		       /* on cherche la valeur minimale du compteur */
-		       i = CounterValMinMax (pVa1->ViCounter, pSS, pSchP,
-					     pAb->AbElement,
-			    pDoc->DocView[pAb->AbDocView - 1].DvPSchemaView,
-					     FALSE);
-		    else
-		       /* valeur courante du compteur */
-		       i = CounterVal (pVa1->ViCounter, pSS, pSchP, pAb->AbElement,
-			   pDoc->DocView[pAb->AbDocView - 1].DvPSchemaView);
-		    /* le cas particulier des compteurs en bas de page (ou il */
-		    /* fallait decrementer la valeur) est supprime dans V4 car  */
-		    /* le bas de page est associe a la page courante et non la */
-		    /* page suivante comme avant */
-		    if (pCo1->CnPageFooter)
-		       /* c'est un compteur qui s'affiche en bas de page */
-		       if (pAb->AbElement->ElTerminal
-			   && pAb->AbElement->ElLeafType == LtPageColBreak)
-			  /* on calcule sa valeur pour une marque de page, on */
-			  /* reduit la valeur du compteur */
-			  if (pCo1->CnItem[0].CiCntrOp == CntrRank)
-			     i--;
-			  else
-			     i -= pCo1->CnItem[1].CiParamValue;
-		    /* traduit l'entier en ASCII */
-		    GetCounterValue (i, pVa1->ViStyle, number, &l);
-		    CopyStringToText (number, pAb->AbText, &l);
-		    pAb->AbVolume += l;
-		    break;
-		 case VarDate:
-		    /* date en anglais */
-		    pt = &tod;
-		    *pt = time (NULL);
-		    ptm = localtime (pt);
-
-		    GetCounterValue (ptm->tm_year, CntArabic, number, &l);
-		    CopyStringToText (number, pAb->AbText, &l);
-		    pAb->AbVolume += l;
-		    CopyStringToText (TEXT("/"), pAb->AbText, &l);
-		    pAb->AbVolume += l;
-		    GetCounterValue (ptm->tm_mon + 1, CntArabic, number, &l);
-		    CopyStringToText (number, pAb->AbText, &l);
-		    pAb->AbVolume += l;
-		    CopyStringToText (TEXT("/"), pAb->AbText, &l);
-		    pAb->AbVolume += l;
-		    GetCounterValue (ptm->tm_mday, CntArabic, number, &l);
-		    CopyStringToText (number, pAb->AbText, &l);
-		    pAb->AbVolume += l;
-		    break;
-		 case VarFDate:
-		    /* date en francais */
-		    pt = &tod;
-		    *pt = time (NULL);
-		    ptm = localtime (pt);
-		    GetCounterValue (ptm->tm_mday, CntArabic, number, &l);
-		    CopyStringToText (number, pAb->AbText, &l);
-		    pAb->AbVolume += l;
-		    CopyStringToText (TEXT("/"), pAb->AbText, &l);
-		    pAb->AbVolume += l;
-		    GetCounterValue (ptm->tm_mon + 1, CntArabic, number, &l);
-		    CopyStringToText (number, pAb->AbText, &l);
-		    pAb->AbVolume += l;
-		    CopyStringToText (TEXT("/"), pAb->AbText, &l);
-		    pAb->AbVolume += l;
-		    GetCounterValue (ptm->tm_year, CntArabic, number, &l);
-		    CopyStringToText (number, pAb->AbText, &l);
-		    pAb->AbVolume += l;
-		    break;
-		 case VarDocName:
-		    /* Name du document */
-		    CopyStringToText (pDoc->DocDName, pAb->AbText, &l);
-		    pAb->AbVolume += l;
-		    break;
-		 case VarDirName:
-		    /* Name du document */
-		    CopyStringToText (pDoc->DocDirectory, pAb->AbText, &l);
-		    pAb->AbVolume += l;
-		    break;
-		 case VarElemName:
-		    /* Name de l'element */
-		    pEl = pAb->AbElement;
-		    CopyStringToText (pEl->ElStructSchema->SsRule[pEl->ElTypeNumber - 1].
-				      SrName, pAb->AbText, &l);
-		    pAb->AbVolume += l;
-		    break;
-		 case VarAttrName:
-		    /* Name de l'attribut */
-		    /* non implemente' */
-		    break;
-		 case VarPageNumber:
-		    /* numero de la marque de page precedente dans la */
-		    /* view ViView */
-		    /* cherche en arriere la premiere marque de page de cette view */
-		    pEl = pAb->AbElement;
-		    found = FALSE;
-		    do
-		      {
-			 pEl = BackSearchTypedElem (pEl, PageBreak + 1, NULL);
-			 if (pEl != NULL)
-			    /* on ignore les pages qui ne concernent pas la view */
-			    if (pEl->ElViewPSchema == pVa1->ViView)
-			       found = TRUE;
-		      }
-		    while ((!found) && (pEl != NULL));
-		    if (pEl == NULL)
-		       i = 1;	/* pas trouve', on considere que c'est la page 1 */
-		    else
-		       i = pEl->ElPageNumber;	/* numero de la page trouvee */
-		    /* traduit le numero de page en ASCII selon le style voulu */
-		    GetCounterValue (i, pVa1->ViStyle, number, &l);
-		    CopyStringToText (number, pAb->AbText, &l);
-		    pAb->AbVolume += l;
-		    break;
-		 default:
-		    break;
+		if (pAttr)
+		  {
+		    pA = pAttr;
+		    found = TRUE;
+		  }
 	      }
+	    else
+	      {
+		/* cherche si l'element auquel se rapporte le pave (ou l'un */
+		/* de ses ascendants) possede cet attribut */
+		pEl = pAb->AbElement;
+		while (!found && pEl != NULL)
+		  {
+		    pA = pEl->ElFirstAttr;	/* premier attribut */
+		    while (!found && pA != NULL)
+		      if (pA->AeAttrNum == pVa1->ViAttr &&
+			  !ustrcmp (pA->AeAttrSSchema->SsName, pSS->SsName))
+			found = TRUE;
+		      else
+			pA = pA->AeNext;
+		    if (!found)
+		      /* passe a l'element ascendant */
+		      pEl = pEl->ElParent;
+		  }
+	      }
+	    if (found)
+	      /* l'element possede l'attribut */
+	      {
+		switch (pA->AeAttrType)
+		  {
+		  case AtNumAttr:
+		    /* traduit l'entier en ASCII selon le style voulu */
+		    GetCounterValue (pA->AeAttrValue, pVa1->ViStyle, number, &l);
+		    CopyStringToText (number, pAb->AbText, &l);
+		    pAb->AbVolume += l;
+		    pAb->AbCreatorAttr = pA;
+		    break;
+		  case AtTextAttr:
+		    if (pA->AeAttrText != NULL)
+		      {
+			CopyTextToText (pA->AeAttrText,
+					pAb->AbText, &l);
+			pAb->AbVolume += l;
+		      }
+		    pAb->AbCreatorAttr = pA;
+		    break;
+		  case AtReferenceAttr:
+		    CopyStringToText ("REF", pAb->AbText, &l);
+		    pAb->AbVolume += l;
+		    break;
+		  case AtEnumAttr:
+		    pAttr1 = &pSS->SsAttribute[pA->AeAttrNum - 1];
+		    CopyStringToText (pAttr1->AttrEnumValue[pA->AeAttrValue-1],
+				      pAb->AbText, &l);
+		    pAb->AbVolume += l;
+		    pAb->AbCreatorAttr = pA;
+		    break;
+		  }
+		/* end case AttrType */
+	      }
+	    break;
+
+	  case VarCounter:
+	    /* valeur d'un compteur */
+	    pCo1 = &pSchP->PsCounter[pVa1->ViCounter - 1];
+	    if (pVa1->ViCounterVal == CntMaxVal)
+	      /* on cherche la valeur maximale du compteur */
+	      i = CounterValMinMax (pVa1->ViCounter, pSS, pSchP, pAb->AbElement,
+				    pDoc->DocView[pAb->AbDocView - 1].DvPSchemaView, TRUE);
+	    else if (pVa1->ViCounterVal == CntMinVal)
+	      /* on cherche la valeur minimale du compteur */
+	      i = CounterValMinMax (pVa1->ViCounter, pSS, pSchP,
+				    pAb->AbElement,
+				    pDoc->DocView[pAb->AbDocView - 1].DvPSchemaView,
+				    FALSE);
+	    else
+	      /* valeur courante du compteur */
+	      i = CounterVal (pVa1->ViCounter, pSS, pSchP, pAb->AbElement,
+			      pDoc->DocView[pAb->AbDocView - 1].DvPSchemaView);
+	    /* le cas particulier des compteurs en bas de page (ou il */
+	    /* fallait decrementer la valeur) est supprime dans V4 car  */
+	    /* le bas de page est associe a la page courante et non la */
+	    /* page suivante comme avant */
+	    if (pCo1->CnPageFooter)
+	      /* c'est un compteur qui s'affiche en bas de page */
+	      if (pAb->AbElement->ElTerminal
+		  && pAb->AbElement->ElLeafType == LtPageColBreak)
+		{
+		/* on calcule sa valeur pour une marque de page, on */
+		/* reduit la valeur du compteur */
+		if (pCo1->CnItem[0].CiCntrOp == CntrRank)
+		  i--;
+		else
+		  i -= pCo1->CnItem[1].CiParamValue;
+		}
+	    /* traduit l'entier en ASCII */
+	    GetCounterValue (i, pVa1->ViStyle, number, &l);
+	    CopyStringToText (number, pAb->AbText, &l);
+	    pAb->AbVolume += l;
+	    break;
+
+	  case VarDate:
+	    /* date en anglais */
+	    pt = &tod;
+	    *pt = time (NULL);
+	    ptm = localtime (pt);
+	    GetCounterValue (ptm->tm_year, CntArabic, number, &l);
+	    CopyStringToText (number, pAb->AbText, &l);
+	    pAb->AbVolume += l;
+	    CopyStringToText ("/", pAb->AbText, &l);
+	    pAb->AbVolume += l;
+	    GetCounterValue (ptm->tm_mon + 1, CntArabic, number, &l);
+	    CopyStringToText (number, pAb->AbText, &l);
+	    pAb->AbVolume += l;
+	    CopyStringToText ("/", pAb->AbText, &l);
+	    pAb->AbVolume += l;
+	    GetCounterValue (ptm->tm_mday, CntArabic, number, &l);
+	    CopyStringToText (number, pAb->AbText, &l);
+	    pAb->AbVolume += l;
+	    break;
+
+	  case VarFDate:
+	    /* date en francais */
+	    pt = &tod;
+	    *pt = time (NULL);
+	    ptm = localtime (pt);
+	    GetCounterValue (ptm->tm_mday, CntArabic, number, &l);
+	    CopyStringToText (number, pAb->AbText, &l);
+	    pAb->AbVolume += l;
+	    CopyStringToText ("/", pAb->AbText, &l);
+	    pAb->AbVolume += l;
+	    GetCounterValue (ptm->tm_mon + 1, CntArabic, number, &l);
+	    CopyStringToText (number, pAb->AbText, &l);
+	    pAb->AbVolume += l;
+	    CopyStringToText ("/", pAb->AbText, &l);
+	    pAb->AbVolume += l;
+	    GetCounterValue (ptm->tm_year, CntArabic, number, &l);
+	    CopyStringToText (number, pAb->AbText, &l);
+	    pAb->AbVolume += l;
+	    break;
+
+	  case VarDocName:
+	    /* Name du document */
+	    CopyStringToText (pDoc->DocDName, pAb->AbText, &l);
+	    pAb->AbVolume += l;
+	    break;
+
+	  case VarDirName:
+	    /* Name du document */
+	    CopyStringToText (pDoc->DocDirectory, pAb->AbText, &l);
+	    pAb->AbVolume += l;
+	    break;
+
+	  case VarElemName:
+	    /* Name de l'element */
+	    pEl = pAb->AbElement;
+	    CopyStringToText (pEl->ElStructSchema->SsRule[pEl->ElTypeNumber - 1].
+			      SrName, pAb->AbText, &l);
+	    pAb->AbVolume += l;
+	    break;
+
+	  case VarAttrName:
+	    /* Nom de l'attribut */
+	    CopyStringToText (pAttr->AeAttrSSchema->SsAttribute[pAttr->AeAttrNum - 1].AttrName, pAb->AbText, &l);
+	    pAb->AbVolume += l;
+	    break;
+
+	  case VarPageNumber:
+	    /* numero de la marque de page precedente dans la */
+	    /* view ViView */
+	    /* cherche en arriere la premiere marque de page de cette view */
+	    pEl = pAb->AbElement;
+	    found = FALSE;
+	    do
+	      {
+		pEl = BackSearchTypedElem (pEl, PageBreak + 1, NULL);
+		if (pEl != NULL &&
+		    /* on ignore les pages qui ne concernent pas la view */
+		    pEl->ElViewPSchema == pVa1->ViView)
+		  found = TRUE;
+	      }
+	    while ((!found) && (pEl != NULL));
+	    if (pEl == NULL)
+	      i = 1;	/* pas trouve', on considere que c'est la page 1 */
+	    else
+	      i = pEl->ElPageNumber;	/* numero de la page trouvee */
+	    /* traduit le numero de page en ASCII selon le style voulu */
+	    GetCounterValue (i, pVa1->ViStyle, number, &l);
+	    CopyStringToText (number, pAb->AbText, &l);
+	    pAb->AbVolume += l;
+	    break;
+
+	  default:
+	    break;
+	  }
 	/* termine la mise a jour du pave */
      }
    if (PresAbsBoxUserEditable (pAb))
-      /* le contenu de ce pave de presentation est donc modifiable */
+     /* le contenu de ce pave de presentation est donc modifiable */
       pAb->AbCanBeModified = TRUE;
    pAb->AbLeafType = LtText;
    if (isOld == NULL)
