@@ -1,6 +1,6 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996.
+ *  (c) COPYRIGHT INRIA, 1996-2001.
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
@@ -29,6 +29,7 @@
 #include "select_tv.h"
 #include "edit_tv.h"
 #include "appdialogue_tv.h"
+#include "frame_tv.h"
 
 #include "applicationapi_f.h"
 #include "attributes_f.h"
@@ -43,12 +44,12 @@
 #include "docs_f.h"
 #include "displayview_f.h"
 #include "documentapi_f.h"
-#include "draw_f.h"
 #include "exceptions_f.h"
 #include "frame_f.h"
 #include "memory_f.h"
 #include "presvariables_f.h"
 #include "references_f.h"
+#include "schemas_f.h"
 #include "structcreation_f.h"
 #include "structmodif_f.h"
 #include "structselect_f.h"
@@ -61,14 +62,7 @@
    Retourne Vrai si les deux elements pointes par pEl1 et pEl2     
    possedent les memes attributs avec les memes valeurs            
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-ThotBool            SameAttributes (PtrElement pEl1, PtrElement pEl2)
-#else  /* __STDC__ */
-ThotBool            SameAttributes (pEl1, pEl2)
-PtrElement          pEl1;
-PtrElement          pEl2;
-
-#endif /* __STDC__ */
+ThotBool SameAttributes (PtrElement pEl1, PtrElement pEl2)
 {
    PtrAttribute        pAttr1, pAttr2;
    int                 nAttr1, nAttr2;
@@ -146,16 +140,7 @@ PtrElement          pEl2;
    l'element pEl.							
    UNIQUEMENT pour une reference *INTERNE*                         
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-static void         SetAttrReference (PtrAttribute pAttr, PtrElement pEl)
-
-#else  /* __STDC__ */
-static void         SetAttrReference (pAttr, pEl)
-PtrElement          pEl;
-PtrAttribute        pAttr;
-
-#endif /* __STDC__ */
-
+static void SetAttrReference (PtrAttribute pAttr, PtrElement pEl)
 {
    PtrReference        pPR1;
 
@@ -186,19 +171,8 @@ PtrAttribute        pAttr;
    Ce lien peut ensuite etre etabli par la procedure SetReference, 
    en particulier pour un lien externe.                            
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-PtrAttribute        AttachAttrByExceptNum (int ExceptNum, PtrElement pEl, PtrElement pReferredEl, PtrDocument pDoc)
-
-#else  /* __STDC__ */
-PtrAttribute        AttachAttrByExceptNum (ExceptNum, pEl, pReferredEl, pDoc)
-int                 ExceptNum;
-PtrElement          pEl;
-PtrElement          pReferredEl;
-PtrDocument         pDoc;
-
-#endif /* __STDC__ */
-
+PtrAttribute AttachAttrByExceptNum (int ExceptNum, PtrElement pEl,
+				    PtrElement pReferredEl, PtrDocument pDoc)
 {
    PtrAttribute        pAttr;
    PtrReference        pRef;
@@ -236,7 +210,7 @@ PtrDocument         pDoc;
       if (pAttr->AeAttrNum == attrNum &&
       /* attrNum = 1: Langue, quel que soit le schema de structure */
 	  (attrNum == 1 ||
-	   pAttr->AeAttrSSchema->SsCode == pSS->SsCode))
+	   !strcmp (pAttr->AeAttrSSchema->SsName, pSS->SsName)))
 	 found = TRUE;
       else
 	 pAttr = pAttr->AeNext;
@@ -310,62 +284,41 @@ PtrDocument         pDoc;
 /*----------------------------------------------------------------------
    On reaffiche un pave modifie                                    
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-static void         RedisplayAbsBox (PtrAbstractBox pAbsBox, int boxNum, PtrPSchema pPSchema, int view, PtrElement pEl, PtrDocument pDoc, PtrAttribute pAttr)
-
-#else  /* __STDC__ */
-static void         RedisplayAbsBox (pAbsBox, boxNum, pPSchema, view, pEl, pDoc, pAttr)
-PtrAbstractBox      pAbsBox;
-int                 boxNum;
-PtrPSchema          pPSchema;
-int                 view;
-PtrElement          pEl;
-PtrDocument         pDoc;
-PtrAttribute        pAttr;
-
-#endif /* __STDC__ */
-
+static void RedisplayAbsBox (PtrAbstractBox pAbsBox, int boxNum,
+			     PtrPSchema pPSchema, int frame, PtrElement pEl,
+			     PtrDocument pDoc, PtrAttribute pAttr)
 {
-   int                 frame, height;
-   PtrAbstractBox      pAbChild;
+  int                 height;
+  PtrAbstractBox      pAbChild;
 
-   if (pAbsBox->AbPresentationBox)
-     {
-	/* c'est un pave de presentation */
-	if (pAbsBox->AbTypeNum == boxNum && pAbsBox->AbPSchema == pPSchema)
-	   /* c'est bien un pave du type cherche' */
-	   /* recalcule la valeur de la variable de presentation */
-	    if (NewVariable (pPSchema->PsPresentBox[boxNum - 1].PbContVariable,
-			     pAttr->AeAttrSSchema, pPSchema, pAbsBox, pDoc))
-	      {
-
-		/* la variable de presentation a change' de valeur */
-		pAbsBox->AbChange = TRUE;
-		if (AssocView (pEl))
-		  frame = (pDoc)->DocAssocFrame[(pEl)->ElAssocNum - 1];
-		else
-		  frame = (pDoc)->DocViewFrame[view - 1];
-		height = PageHeight;
-		ChangeConcreteImage (frame, &height, pAbsBox);
-		/* on ne reaffiche pas si on est en train de calculer les pages */
-		if (PageHeight == 0)
-		  DisplayFrame (frame);
-	      }
-     }
-   else
-      /* ce n'est pas un pave' de pre'sentation */
-      /* cherche parmi les fils les paves de presentation */
-      /* de l'element et de ses descendants */
-     {
-	pAbChild = pAbsBox->AbFirstEnclosed;
-	while (pAbChild != NULL)
+  if (pAbsBox->AbPresentationBox)
+    {
+      /* c'est un pave de presentation */
+      if (pAbsBox->AbTypeNum == boxNum && pAbsBox->AbPSchema == pPSchema)
+	/* c'est bien un pave du type cherche' */
+	/* recalcule la valeur de la variable de presentation */
+	if (NewVariable (pPSchema->PsPresentBox[boxNum - 1].PbContVariable,
+			 pAttr->AeAttrSSchema, pPSchema, pAbsBox, pAttr, pDoc))
 	  {
-	     RedisplayAbsBox (pAbChild, boxNum, pPSchema, view, pEl, pDoc, pAttr);
-	     /* next child abstract box */
-	     pAbChild = pAbChild->AbNext;
+	    /* la variable de presentation a change' de valeur */
+	    pAbsBox->AbChange = TRUE;
+	    height = PageHeight;
+	    ChangeConcreteImage (frame, &height, pAbsBox);
 	  }
-     }
+    }
+  else
+    /* ce n'est pas un pave' de pre'sentation */
+    /* cherche parmi les fils les paves de presentation */
+    /* de l'element et de ses descendants */
+    {
+      pAbChild = pAbsBox->AbFirstEnclosed;
+      while (pAbChild != NULL)
+	{
+	  RedisplayAbsBox (pAbChild, boxNum, pPSchema, frame, pEl, pDoc, pAttr);
+	  /* next child abstract box */
+	  pAbChild = pAbChild->AbNext;
+	}
+    }
 }
 
 /*----------------------------------------------------------------------
@@ -374,29 +327,19 @@ PtrAttribute        pAttr;
    Reafficher toutes les boites de presentation qui utilisent      
    la valeur de cet attribut.					
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-void                RedisplayAttribute (PtrAttribute pAttr, PtrElement pEl, PtrDocument pDoc)
-
-#else  /* __STDC__ */
-void                RedisplayAttribute (pAttr, pEl, pDoc)
-PtrAttribute        pAttr;
-PtrElement          pEl;
-PtrDocument         pDoc;
-
-#endif /* __STDC__ */
-
+void RedisplayAttribute (PtrAttribute pAttr, PtrElement pEl, PtrDocument pDoc)
 {
    PtrPSchema          pPSchema;
-   int                 varNum, item, presBox, view;
    ThotBool            found;
    PtrAbstractBox      pAbsBox;
    PresVariable       *pPresVar;
+   int                 varNum, item, presBox;
+   int                 frame, view, doc = 0;
 
    /* l'attribut dont la valeur a ete modifie' apparait-il dans une */
    /* variable de presentation ? */
    /* schema de presentation de l'attribut */
-   pPSchema = pAttr->AeAttrSSchema->SsPSchema;
+   pPSchema = PresentationSchema (pAttr->AeAttrSSchema, pDoc);
 
    if (pPSchema != NULL)
       /* parcourt les variables de presentation du schema */
@@ -424,15 +367,27 @@ PtrDocument         pDoc;
 		      for (view = 0; view < MAX_VIEW_DOC; view++)
 			{
 			   pAbsBox = pEl->ElAbstractBox[view];
-			   while (pAbsBox != NULL)	/* parcourt les paves de l'element */
-			      if (pAbsBox->AbElement != pEl)
-				 pAbsBox = NULL;	/* on a traite' tous les paves de l'element */
-			      else
-				 /* c'est un pave' de l'element */
-				{
-				   RedisplayAbsBox (pAbsBox, presBox + 1, pPSchema, view + 1, pEl, pDoc, pAttr);
-				   pAbsBox = pAbsBox->AbNext;
-				}
+			   frame = pDoc->DocViewFrame[view];
+			   if (frame > 0)
+			     {
+			       if (doc == 0)
+				 doc = FrameTable[frame].FrDoc;
+			       /* parcourt les paves de l'element */
+			       while (pAbsBox != NULL)
+				 if (pAbsBox->AbElement != pEl)
+				   /* on a traite' tous les paves de l'element */
+				   pAbsBox = NULL;
+				 else
+				   /* c'est un pave' de l'element */
+				   {
+				     RedisplayAbsBox (pAbsBox, presBox + 1, pPSchema, frame, pEl, pDoc, pAttr);
+				     pAbsBox = pAbsBox->AbNext;
+				   }
+			       /* on ne reaffiche pas si on est en train de calculer les pages */
+			       if (PageHeight == 0 &&
+				   documentDisplayMode[doc - 1] == DisplayImmediately)
+				 DisplayFrame (frame);
+			     }
 			}
 	     }
 	}
@@ -443,21 +398,9 @@ PtrDocument         pDoc;
    regles de presentation correspondant a l'attribut decrit dans   
    le bloc pointe' par pAttr.                                      
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-void                ApplyAttrPRulesToElem (PtrElement pEl, PtrDocument pDoc,
-		      PtrAttribute pAttr, PtrElement pElAttr, ThotBool inherit)
-
-#else  /* __STDC__ */
-void                ApplyAttrPRulesToElem (pEl, pDoc, pAttr, pElAttr, inherit)
-PtrElement          pEl;
-PtrDocument         pDoc;
-PtrAttribute        pAttr;
-PtrElement          pElAttr;
-ThotBool            inherit;
-
-#endif /* __STDC__ */
-
+void ApplyAttrPRulesToElem (PtrElement pEl, PtrDocument pDoc,
+			    PtrAttribute pAttr, PtrElement pElAttr,
+			    ThotBool inherit)
 {
    PtrAttribute        pOldAttr;
    ThotBool            doIt;
@@ -482,7 +425,7 @@ ThotBool            inherit;
 		doIt = TRUE;
 	     /* si pour cet element, cet attribut a une valeur imposee par */
 	     /* le schema de structure, on ne fait rien d'autre */
-	     else if (!pOldAttr->AeDefAttr)
+	     else if (pOldAttr->AeDefAttr == 0)
 		doIt = TRUE;
 	     /* s'il s'agit d'une suppression de l'attribut, on ne fait rien */
 	     if (doIt)
@@ -525,23 +468,12 @@ ThotBool            inherit;
    On arrete la recursion quand on rencontre un fils portant       
    lui-meme un attribut de meme type que pAttr			
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-void                ApplyAttrPRulesToSubtree (PtrElement pEl, PtrDocument pDoc,
-				       PtrAttribute pAttr, PtrElement pElAttr)
-
-#else  /* __STDC__ */
-void                ApplyAttrPRulesToSubtree (pEl, pDoc, pAttr, pElAttr)
-PtrElement          pEl;
-PtrDocument         pDoc;
-PtrAttribute        pAttr;
-PtrElement          pElAttr;
-
-#endif /* __STDC__ */
-
+void ApplyAttrPRulesToSubtree (PtrElement pEl, PtrDocument pDoc,
+			       PtrAttribute pAttr, PtrElement pElAttr)
 {
    PtrElement          pChild;
    PtrAttribute        pOldAttr;
+   PtrPSchema          pPS;
    InheritAttrTable   *inheritedAttr;
 
    pOldAttr = GetAttributeOfElement (pEl, pAttr);
@@ -556,17 +488,16 @@ PtrElement          pElAttr;
 
 	/* on traite l'element lui-meme */
 	/* on cherche d'abord si pEl herite de pAttr */
-	if (pEl->ElStructSchema->SsPSchema != NULL)
-	   if (pEl->ElStructSchema->SsPSchema->PsNInheritedAttrs[pEl->ElTypeNumber - 1])
+	pPS = PresentationSchema (pEl->ElStructSchema, pDoc);
+	if (pPS != NULL)
+	   if (pPS->PsNInheritedAttrs[pEl->ElTypeNumber - 1])
 	     {
 		/* pEl peut heriter d'un attribut */
-		if ((inheritedAttr = pEl->ElStructSchema->SsPSchema->
-		     PsInheritedAttr[pEl->ElTypeNumber - 1]) == NULL)
+		if ((inheritedAttr = pPS->PsInheritedAttr[pEl->ElTypeNumber - 1]) == NULL)
 		  {
 		     /* la table d'heritage n'existe pas. On la cree */
-		     CreateInheritedAttrTable (pEl);
-		     inheritedAttr = pEl->ElStructSchema->SsPSchema->
-			PsInheritedAttr[pEl->ElTypeNumber - 1];
+		     CreateInheritedAttrTable (pEl, pDoc);
+		     inheritedAttr = pPS->PsInheritedAttr[pEl->ElTypeNumber - 1];
 		  }
 		if ((*inheritedAttr)[pAttr->AeAttrNum - 1])
 		  {
@@ -583,23 +514,13 @@ PtrElement          pElAttr;
    regles de presentation des attributs dont les valeurs se	
    	comparent a pAttr.						
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-void                ApplyAttrPRules (PtrElement pEl, PtrDocument pDoc, PtrAttribute pAttr)
-
-#else  /* __STDC__ */
-void                ApplyAttrPRules (pEl, pDoc, pAttr)
-PtrElement          pEl;
-PtrDocument         pDoc;
-PtrAttribute        pAttr;
-
-#endif /* __STDC__ */
-
+void ApplyAttrPRules (PtrElement pEl, PtrDocument pDoc, PtrAttribute pAttr)
 {
    PtrElement          pChild;
    ComparAttrTable    *attrValComp;
    int                 i;
    PtrAttribute        pCompAttr;
+   PtrPSchema          pPS;
 
    if (GetAttributeOfElement (pEl, pAttr) == NULL)
      {
@@ -613,15 +534,14 @@ PtrAttribute        pAttr;
 
    /* on traite l'element lui-meme */
    /* cherche si pEl possede un attribut se comparant a pAttr */
-   if (pEl->ElStructSchema->SsPSchema != NULL)
+   pPS = PresentationSchema (pEl->ElStructSchema, pDoc);
+   if (pPS != NULL)
      {
-	if ((attrValComp = pEl->ElStructSchema->SsPSchema->
-	     PsComparAttr[pAttr->AeAttrNum - 1]) == NULL)
+	if ((attrValComp = pPS->PsComparAttr[pAttr->AeAttrNum - 1]) == NULL)
 	  {
 	     /* la table de comparaison n'existe pas. On la creee */
-	     CreateComparAttrTable (pAttr);
-	     attrValComp = pEl->ElStructSchema->SsPSchema->
-		PsComparAttr[pAttr->AeAttrNum - 1];
+	     CreateComparAttrTable (pAttr, pDoc);
+	     attrValComp = pPS->PsComparAttr[pAttr->AeAttrNum - 1];
 	  }
 	if (attrValComp != NULL)
 	   for (i = pEl->ElStructSchema->SsNAttributes; i > 0; i--)
@@ -639,17 +559,7 @@ PtrAttribute        pAttr;
 /*----------------------------------------------------------------------
    Chaine les elements liberes par les fusions de texte.           
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-void                KeepFreeElements (PtrElement pEl, PtrElement * pFirstFree)
-
-#else  /* __STDC__ */
-void                KeepFreeElements (pEl, pFirstFree)
-PtrElement          pEl;
-PtrElement         *pFirstFree;
-
-#endif /* __STDC__ */
-
+void KeepFreeElements (PtrElement pEl, PtrElement *pFirstFree)
 {
    pEl->ElNext = *pFirstFree;
    *pFirstFree = pEl;
@@ -663,19 +573,8 @@ PtrElement         *pFirstFree;
    Le parametre force est vrai quand on veut forcer le changement  
    de langue.                                                      
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-void                ChangeLanguage (PtrDocument pDoc, PtrElement pEl, Language lang, ThotBool force)
-
-#else  /* __STDC__ */
-void                ChangeLanguage (pDoc, pEl, lang, force)
-PtrDocument         pDoc;
-PtrElement          pEl;
-Language            lang;
-ThotBool            force;
-
-#endif /* __STDC__ */
-
+void ChangeLanguage (PtrDocument pDoc, PtrElement pEl, Language lang,
+		     ThotBool force)
 {
    int                 view;
    PtrElement          pChild;
@@ -698,10 +597,15 @@ ThotBool            force;
 	  }
      }
    else
-      /* l'element est une feuille */
-   if (pEl->ElLeafType == LtText && pEl->ElLanguage != lang)
-      /* c'est du texte dans une autre langue */
-    	 /* change la langue de l'element */
+      /* this element is a leaf */
+      if (pEl->ElLeafType == LtText && pEl->ElLanguage != lang)
+       /* That's a text leaf in a different language */
+       /* Make the change only if the leaf is empty or if its language uses
+	  the same alphabet as the new language, i.e. don't change the
+	  character set of some existing text. */
+    	 /* change the language of the element */
+       if (pEl->ElTextLength == 0 ||
+	   TtaGetAlphabet (pEl->ElLanguage) == TtaGetAlphabet (lang))
 	{
 	  oldElLang = pEl->ElLanguage;
 	   pEl->ElLanguage = lang;
@@ -713,25 +617,23 @@ ThotBool            force;
 		{
 		   pAbsBox = pEl->ElAbstractBox[view];
 		   /* saute les paves de presentation de l'element */
-		   while (pAbsBox->AbPresentationBox && pAbsBox->AbElement == pEl)
+		   while (pAbsBox->AbPresentationBox &&
+			  pAbsBox->AbElement == pEl)
 		      pAbsBox = pAbsBox->AbNext;
 		   if (!pAbsBox->AbDead)
 		      /* traite le pave' principal de l'element */
 		      /* change la langue du pave */
 		     {
 			pAbsBox->AbLanguage = lang;
-			if (force || TtaGetAlphabet (oldElLang) != TtaGetAlphabet (lang))
+			if (force ||
+			    TtaGetAlphabet (oldElLang) != TtaGetAlphabet(lang))
 			  /* cette langue s'ecrit dans un alphabet different */
 			  /* ou la langue est forcee */
 			  {
 			    pAbsBox->AbChange = TRUE;
 			    /* conserve le pointeur sur le pave a reafficher */
-			    if (AssocView (pEl))
-			      pDoc->DocAssocModifiedAb[pEl->ElAssocNum - 1] =
-				Enclosing (pAbsBox, pDoc->DocAssocModifiedAb[pEl->ElAssocNum - 1]);
-			    else
-			      pDoc->DocViewModifiedAb[view] =
-				Enclosing (pAbsBox, pDoc->DocViewModifiedAb[view]);
+			    pDoc->DocViewModifiedAb[view] =
+			      Enclosing (pAbsBox, pDoc->DocViewModifiedAb[view]);
 			  }
 		     }
 		}
@@ -744,18 +646,7 @@ ThotBool            force;
    contient un attribut qui initialise un (des) compteur(s).	
    	Si oui, met a jour les valeurs de ce(s) compteur(s).		
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-void                UpdateCountersByAttr (PtrElement pEl, PtrAttribute pAttr, PtrDocument pDoc)
-
-#else  /* __STDC__ */
-void                UpdateCountersByAttr (pEl, pAttr, pDoc)
-PtrElement          pEl;
-PtrAttribute        pAttr;
-PtrDocument         pDoc;
-
-#endif /* __STDC__ */
-
+void UpdateCountersByAttr (PtrElement pEl, PtrAttribute pAttr, PtrDocument pDoc)
 {
    int                 counter;
    PtrPSchema          pPS;
@@ -766,7 +657,7 @@ PtrDocument         pDoc;
    /* initiale d'un compteur */
    {
       /* schema de presentation qui s'applique a l'attribut */
-      pPS = pAttr->AeAttrSSchema->SsPSchema;
+      pPS = PresentationSchema (pAttr->AeAttrSSchema, pDoc);
       if (pPS != NULL)
 	 for (counter = 0; counter < pPS->PsNCounters; counter++)
 	   {
@@ -779,12 +670,12 @@ PtrDocument         pDoc;
 		   if (pCnt->CnItem[0].CiCntrOp == CntrRank && pCnt->CnItem[0].
 		       CiElemType == PageBreak + 1)
 		      /* c'est un compteur de la forme CntrRank of Page(view) */
-		      ComputePageNum (pEl, pCnt->CnItem[0].CiViewNum);
+		      ComputePageNum (pEl, pDoc, pCnt->CnItem[0].CiViewNum);
 		   else
 		      /* c'est un compteur de la forme Set...Add n on Page(view) */
 		      if (pCnt->CnItem[0].CiCntrOp == CntrSet
 			  && pCnt->CnItem[1].CiElemType == PageBreak + 1)
-		      ComputePageNum (pEl, pCnt->CnItem[1].CiViewNum);
+		      ComputePageNum (pEl, pDoc, pCnt->CnItem[1].CiViewNum);
 		   /* fait reafficher toutes les boites de presentation dependant */
 		   /* de la valeur de ce compteur */
 		   UpdateBoxesCounter (pEl, pDoc, counter + 1, pPS, pEl->ElStructSchema);
@@ -802,24 +693,9 @@ PtrDocument         pDoc;
    comparaison et ne pas en chercher d'autre dans les ascendants	
    de pEl.                                                         
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-void                RemoveAttrPresentation (PtrElement pEl, PtrDocument pDoc,
-		                     PtrAttribute pAttr, PtrElement pElAttr,
-				     ThotBool inherit, PtrAttribute pCompAttr)
-
-#else  /* __STDC__ */
-void                RemoveAttrPresentation (pEl, pDoc, pAttr, pElAttr, inherit,
-					    pCompAttr)
-PtrElement          pEl;
-PtrDocument         pDoc;
-PtrAttribute        pAttr;
-PtrElement          pElAttr;
-ThotBool            inherit;
-PtrAttribute        pCompAttr;
-
-#endif /* __STDC__ */
-
+void RemoveAttrPresentation (PtrElement pEl, PtrDocument pDoc,
+			     PtrAttribute pAttr, PtrElement pElAttr,
+			     ThotBool inherit, PtrAttribute pCompAttr)
 {
    /* on ne traite pas les marques page */
    if (!pEl->ElTerminal || pEl->ElLeafType != LtPageColBreak)
@@ -840,51 +716,39 @@ PtrAttribute        pCompAttr;
    	presentation heritees de l'attribut pAttr.			
    Si pEl porte lui-meme un attribut de type pAttr, on arrete.	
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-void                RemoveInheritedAttrPresent (PtrElement pEl, PtrDocument pDoc, PtrAttribute pAttr, PtrElement pElAttr)
-
-#else  /* __STDC__ */
-void                RemoveInheritedAttrPresent (pEl, pDoc, pAttr, pElAttr)
-PtrElement          pEl;
-PtrDocument         pDoc;
-PtrAttribute        pAttr;
-PtrElement          pElAttr;
-
-#endif /* __STDC__ */
-
+void RemoveInheritedAttrPresent (PtrElement pEl, PtrDocument pDoc,
+				 PtrAttribute pAttr, PtrElement pElAttr)
 {
-   PtrElement          pChild;
-   InheritAttrTable   *inheritedAttr;
+  PtrElement          pChild;
+  PtrPSchema          pPS;
+  InheritAttrTable   *inheritedAttr;
 
-   if (GetAttributeOfElement (pEl, pAttr) == NULL)
-     {
-	/* pEl does not have an attribute of that type */
-	/* process the subtree */
-	if (!pEl->ElTerminal)
-	   for (pChild = pEl->ElFirstChild; pChild != NULL; pChild = pChild->ElNext)
-	      if (pChild->ElStructSchema == pEl->ElStructSchema)
-		 /* same structure schema */
-		 RemoveInheritedAttrPresent (pChild, pDoc, pAttr, pElAttr);
+  if (GetAttributeOfElement (pEl, pAttr) == NULL)
+    {
+      /* pEl does not have an attribute of that type */
+      /* process the subtree */
+      if (!pEl->ElTerminal)
+	for (pChild = pEl->ElFirstChild; pChild != NULL; pChild = pChild->ElNext)
+	  if (pChild->ElStructSchema == pEl->ElStructSchema)
+	    /* same structure schema */
+	    RemoveInheritedAttrPresent (pChild, pDoc, pAttr, pElAttr);
 
-	/* process element pEl itself */
-	if (pEl->ElStructSchema->SsPSchema != NULL)
-	   if (pEl->ElStructSchema->SsPSchema->PsNInheritedAttrs[pEl->ElTypeNumber - 1])
-	     {
-		/* pEl can inherit some presentation rules from attributes */
-		if ((inheritedAttr = pEl->ElStructSchema->SsPSchema->
-		     PsInheritedAttr[pEl->ElTypeNumber - 1]) == NULL)
-		  {
-		     /* la table d'heritage n'existe pas. On la cree */
-		     CreateInheritedAttrTable (pEl);
-		     inheritedAttr = pEl->ElStructSchema->SsPSchema->
-			PsInheritedAttr[pEl->ElTypeNumber - 1];
-		  }
-		if ((*inheritedAttr)[pAttr->AeAttrNum - 1])
-		   RemoveAttrPresentation (pEl, pDoc, pAttr, pElAttr,
-					   TRUE, NULL);
-	     }
-     }
+      /* process element pEl itself */
+      pPS = PresentationSchema (pEl->ElStructSchema, pDoc);
+      if (pPS != NULL)
+	if (pPS->PsNInheritedAttrs[pEl->ElTypeNumber - 1])
+	  {
+	    /* pEl can inherit some presentation rules from attributes */
+	    if ((inheritedAttr = pPS->PsInheritedAttr[pEl->ElTypeNumber - 1]) == NULL)
+	      {
+		/* la table d'heritage n'existe pas. On la cree */
+		CreateInheritedAttrTable (pEl, pDoc);
+		inheritedAttr = pPS->PsInheritedAttr[pEl->ElTypeNumber - 1];
+	      }
+	    if ((*inheritedAttr)[pAttr->AeAttrNum - 1])
+	      RemoveAttrPresentation (pEl, pDoc, pAttr, pElAttr, TRUE, NULL);
+	  }
+    }
 }
 
 
@@ -895,20 +759,10 @@ PtrElement          pElAttr;
    On arrete la recursion quand on rencontre un fils portant       
    lui-meme un attribut de meme type que pAttr			
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-void                RemoveComparAttrPresent (PtrElement pEl, PtrDocument pDoc, PtrAttribute pAttr)
-
-#else  /* __STDC__ */
-void                RemoveComparAttrPresent (pEl, pDoc, pAttr)
-PtrElement          pEl;
-PtrDocument         pDoc;
-PtrAttribute        pAttr;
-
-#endif /* __STDC__ */
-
+void RemoveComparAttrPresent (PtrElement pEl, PtrDocument pDoc, PtrAttribute pAttr)
 {
    PtrElement          pChild;
+   PtrPSchema            pPS;
    ComparAttrTable    *attrValComp;
    int                 i;
    PtrAttribute        pCompAttr;
@@ -925,15 +779,14 @@ PtrAttribute        pAttr;
 
    /* on traite l'element lui-meme */
    /* cherche si pEl possede un attribut se comparant a pAttr */
-   if (pEl->ElStructSchema->SsPSchema != NULL)
+   pPS = PresentationSchema (pEl->ElStructSchema, pDoc);
+   if (pPS != NULL)
      {
-	if ((attrValComp = pEl->ElStructSchema->SsPSchema->
-	     PsComparAttr[pAttr->AeAttrNum - 1]) == NULL)
+	if ((attrValComp = pPS->PsComparAttr[pAttr->AeAttrNum - 1]) == NULL)
 	  {
 	     /* la table de comparaison n'existe pas. On la creee */
-	     CreateComparAttrTable (pAttr);
-	     attrValComp = pEl->ElStructSchema->SsPSchema->
-		PsComparAttr[pAttr->AeAttrNum - 1];
+	     CreateComparAttrTable (pAttr, pDoc);
+	     attrValComp = pPS->PsComparAttr[pAttr->AeAttrNum - 1];
 	  }
 	if (attrValComp != NULL)
 	   for (i = pEl->ElStructSchema->SsNAttributes; i > 0; i--)
@@ -951,14 +804,8 @@ PtrAttribute        pAttr;
 /*----------------------------------------------------------------------
    Ajoute un attribut pNewAttr a l'element pEl avant l'attribut pAttrNext
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-PtrAttribute        AddAttrToElem (PtrElement pEl, PtrAttribute pNewAttr, PtrAttribute pAttrNext)
-#else  /* __STDC__ */
-PtrAttribute        AddAttrToElem (pEl, pNewAttr, pAttrNext)
-PtrElement          pEl;
-PtrAttribute        pNewAttr;
-PtrAttribute        pAttrNext;
-#endif /* __STDC__ */
+PtrAttribute AddAttrToElem (PtrElement pEl, PtrAttribute pNewAttr,
+			    PtrAttribute pAttrNext)
 {
   PtrAttribute        pAttr, pA;
   PtrReference        pRef;
@@ -967,21 +814,23 @@ PtrAttribute        pAttrNext;
   GetAttribute (&pAttr);
   /* on chaine cet attribut apres le dernier attribut de  l'element */
   if (pEl)
-    if (pEl->ElFirstAttr == NULL || pEl->ElFirstAttr == pAttrNext)
-      {
-      /* c'est le 1er attribut de l'element */
-      pAttrNext = pEl->ElFirstAttr;
-      pEl->ElFirstAttr = pAttr;
-      }
-    else
-      {
-      /* cherche l'attribut qui doit etre le suivant */
-      pA = pEl->ElFirstAttr;
-      while (pA->AeNext != pAttrNext)
-	pA = pA->AeNext;
-      /* chaine le nouvel attribut */
-      pA->AeNext = pAttr;
-      }
+    {
+      if (pEl->ElFirstAttr == NULL || pEl->ElFirstAttr == pAttrNext)
+	{
+	  /* c'est le 1er attribut de l'element */
+	  pAttrNext = pEl->ElFirstAttr;
+	  pEl->ElFirstAttr = pAttr;
+	}
+      else
+	{
+	  /* cherche l'attribut qui doit etre le suivant */
+	  pA = pEl->ElFirstAttr;
+	  while (pA->AeNext != pAttrNext)
+	    pA = pA->AeNext;
+	  /* chaine le nouvel attribut */
+	  pA->AeNext = pAttr;
+	}
+    }
   pAttr->AeNext = pAttrNext;
   pAttr->AeAttrSSchema = pNewAttr->AeAttrSSchema;
   pAttr->AeAttrNum = pNewAttr->AeAttrNum;
@@ -1034,19 +883,12 @@ PtrAttribute        pAttrNext;
    Egalement utilise' pour supprimer un attribut et desappliquer les
    regles de presentation correspondantes.
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                AttachAttrWithValue (PtrElement pEl, PtrDocument pDoc, PtrAttribute pNewAttr)
-#else  /* __STDC__ */
-void                AttachAttrWithValue (pEl, pDoc, pNewAttr)
-PtrElement          pEl;
-PtrdocumentA        pDoc;
-PtrAttribute        pNewAttr;
-
-#endif /* __STDC__ */
+void AttachAttrWithValue (PtrElement pEl, PtrDocument pDoc, PtrAttribute pNewAttr)
 {
    PtrAttribute        pAttr, pAttrAsc, pAttrNext;
    PtrElement          pChild, pElAttr;
-   ThotBool            suppress, compare, inherit, mandatory, create;
+   PtrPSchema          pPS;
+   ThotBool            suppress, compare, inherit, mandatory, create, allowed;
    NotifyAttribute     notifyAttr;
 
    if (pNewAttr == NULL || pNewAttr->AeAttrNum == 0)
@@ -1059,7 +901,8 @@ PtrAttribute        pNewAttr;
    create = (pAttr == NULL);
 
    /* peut-on appliquer l'attribut a l'element ? */
-   if (create && !CanAssociateAttr (pEl, pAttr, pNewAttr, &mandatory))
+   allowed = CanAssociateAttr (pEl, pAttr, pNewAttr, &mandatory);
+   if (!allowed && create)
       return;
 
    /* est-ce une suppression d'attribut */
@@ -1102,20 +945,18 @@ PtrAttribute        pNewAttr;
 	      if (pNewAttr->AeAttrNum == 1)
 		 mandatory = TRUE;
 	if (mandatory)
-	   /* suppression d'un attribut obligatoire. Interdit */
-	  {
-	     TtaDisplaySimpleMessage (INFO, LIB, TMSG_LIB_ATTR_REQUIRED_NOT_DELETED);
-	     return;
-	  }
+	  /* suppression d'un attribut obligatoire. Interdit */
+	  return;
      }
 
    /* faut-il traiter des heritages et comparaisons d'attributs */
    inherit = FALSE;
    compare = FALSE;
-   if (pNewAttr->AeAttrSSchema->SsPSchema != NULL)
+   pPS = PresentationSchema (pNewAttr->AeAttrSSchema, pDoc);
+   if (pPS != NULL)
      {
-       inherit = (pNewAttr->AeAttrSSchema->SsPSchema->PsNHeirElems[pNewAttr->AeAttrNum - 1] != 0);
-       compare = (pNewAttr->AeAttrSSchema->SsPSchema->PsNComparAttrs[pNewAttr->AeAttrNum - 1] != 0);
+       inherit = (pPS->PsNHeirElems[pNewAttr->AeAttrNum - 1] != 0);
+       compare = (pPS->PsNComparAttrs[pNewAttr->AeAttrNum - 1] != 0);
      }
    if (inherit || compare)
       /* cherche le premier attribut de meme type sur un ascendant de pEl */
@@ -1205,17 +1046,11 @@ PtrAttribute        pNewAttr;
 	    /* indique que le document a ete modifie' */
 	    /* un changement d'attribut vaut dix caracteres saisis */
 	    SetDocumentModified (pDoc, TRUE, 10);
-	    /* traitement special a l'ajout d'un attribut a un element d'un
-	       objet Draw */
-	    DrawAddAttr (&pAttr, pEl);
 	  }
 
 	else
 	   /* suppression */
 	  {
-	     /* traitement special a la suppression d'un attribut a un element
-	        d'un objet Draw */
-	     DrawSupprAttr (pNewAttr, pEl);
 	     /* valide les modifications */
 	     AbstractImageUpdated (pDoc);
 	     /* la suppression est maintenant prise en compte dans les
@@ -1278,36 +1113,31 @@ PtrAttribute        pNewAttr;
    ExceptNum et porte' par l'element pEl.				
    	On retourne NULL si l'element n'a pas cet attribut.		
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
 PtrAttribute        GetAttrByExceptNum (PtrElement pEl, int ExceptNum)
-#else  /* __STDC__ */
-PtrAttribute        GetAttrByExceptNum (pEl, ExceptNum)
-PtrElement          pEl;
-int                 ExceptNum;
-#endif /* __STDC__ */
 {
-   PtrSSchema          pSS;
-   PtrAttribute        pAttr;
-   ThotBool            found;
-   int                 attrNum;
+  PtrSSchema          pSS;
+  PtrAttribute        pAttr;
+  ThotBool            found;
+  int                 attrNum;
 
-   pSS = pEl->ElStructSchema;
-   /* on recupere le numero d'attribut associe a l'exception */
-   attrNum = GetAttrWithException (ExceptNum, pEl->ElStructSchema);
-   if (attrNum != 0)
-     {
-	/* on cherche un attribut sur l'element */
-	pAttr = pEl->ElFirstAttr;
-	found = FALSE;
-	while (pAttr != NULL && !found)
-	   if (pAttr->AeAttrSSchema->SsCode == pSS->SsCode && pAttr->AeAttrNum == attrNum)
-	      found = TRUE;
-	   else
-	      pAttr = pAttr->AeNext;
-	return pAttr;
-     }
-   else
-      return NULL;
+  pSS = pEl->ElStructSchema;
+  /* on recupere le numero d'attribut associe a l'exception */
+  attrNum = GetAttrWithException (ExceptNum, pEl->ElStructSchema);
+  if (attrNum != 0)
+    {
+      /* on cherche un attribut sur l'element */
+      pAttr = pEl->ElFirstAttr;
+      found = FALSE;
+      while (pAttr != NULL && !found)
+	if (!strcmp (pAttr->AeAttrSSchema->SsName, pSS->SsName) &&
+	    pAttr->AeAttrNum == attrNum)
+	  found = TRUE;
+	else
+	  pAttr = pAttr->AeNext;
+      return pAttr;
+    }
+  else
+    return NULL;
 }
 
 /* ----------------------------------------------------------------------
@@ -1327,16 +1157,8 @@ int                 ExceptNum;
    Return value:
    the attribute found, or NULL if the element  does not have this
    type of attribute.
-
    ---------------------------------------------------------------------- */
-#ifdef __STDC__
-Attribute           TtaGetAttribute (Element element, AttributeType attributeType)
-#else  /* __STDC__ */
-Attribute           TtaGetAttribute (element, attributeType)
-Element             element;
-AttributeType       attributeType;
-
-#endif /* __STDC__ */
+Attribute TtaGetAttribute (Element element, AttributeType attributeType)
 {
    PtrAttribute        pAttr;
    PtrAttribute        attribute;
@@ -1360,25 +1182,27 @@ AttributeType       attributeType;
 	   TtaError (ERR_invalid_attribute_type);
 	else
 	  {
-	     attribute = NULL;
-	     pAttr = ((PtrElement) element)->ElFirstAttr;
-	     found = FALSE;
-	     while (pAttr != NULL && !found)
-	       {
-		  if (pAttr->AeAttrNum == attributeType.AttrTypeNum)
-		     /* Same attribute number */
-		     if (attributeType.AttrSSchema == NULL)
-			/* The structure schema does not interest us */
-			found = TRUE;
-		     else if (pAttr->AeAttrSSchema->SsCode ==
-			 ((PtrSSchema) (attributeType.AttrSSchema))->SsCode)
-			/* Same schema of structure */
-			found = TRUE;
-		  if (found)
-		     attribute = pAttr;
-		  else
-		     pAttr = pAttr->AeNext;
-	       }
+	    attribute = NULL;
+	    pAttr = ((PtrElement) element)->ElFirstAttr;
+	    found = FALSE;
+	    while (pAttr != NULL && !found)
+	      {
+		if (pAttr->AeAttrNum == attributeType.AttrTypeNum)
+		  {
+		    /* Same attribute number */
+		    if (attributeType.AttrSSchema == NULL)
+		      /* The structure schema does not interest us */
+		      found = TRUE;
+		    else if (!strcmp (pAttr->AeAttrSSchema->SsName,
+				      ((PtrSSchema) (attributeType.AttrSSchema))->SsName))
+		      /* Same schema of structure */
+		      found = TRUE;
+		  }
+		if (found)
+		  attribute = pAttr;
+		else
+		  pAttr = pAttr->AeNext;
+	      }
 	  }
      }
    return ((Attribute) attribute);
@@ -1386,22 +1210,14 @@ AttributeType       attributeType;
 
  /* ----------------------------------------------------------------------
    TtaGetTextAttributeLength
-
    Returns the length of a given attribute of type text.
 
    Parameter:
    attribute: the attribute of interest.
-
    Return values:
    length of the character string contained in the attribute.
-
    ---------------------------------------------------------------------- */
-#ifdef __STDC__
-int                 TtaGetTextAttributeLength (Attribute attribute)
-#else  /* __STDC__ */
-int                 TtaGetTextAttributeLength (attribute)
-Attribute           attribute;
-#endif /* __STDC__ */
+int TtaGetTextAttributeLength (Attribute attribute)
 {
    int                 length;
    PtrTextBuffer       pBT;
@@ -1426,28 +1242,17 @@ Attribute           attribute;
 
 /* ----------------------------------------------------------------------
    TtaGiveTextAttributeValue
-
    Returns the value of a given attribute of type text.
 
    Parameters:
    attribute: the attribute of interest.
    buffer: address of the buffer that will contain the value of the attribute.
    length: size of the buffer (in bytes).
-
    Return values:
    buffer: character string representing the value of the attribute.
    length: actual length of the character string.
-
    ---------------------------------------------------------------------- */
-#ifdef __STDC__
-void                TtaGiveTextAttributeValue (Attribute attribute, STRING buffer, int *length)
-#else  /* __STDC__ */
-void                TtaGiveTextAttributeValue (attribute, buffer, length)
-Attribute           attribute;
-STRING              buffer;
-int                *length;
-#endif /* __STDC__ */
-
+void TtaGiveTextAttributeValue (Attribute attribute, char *buffer, int *length)
 {
   UserErrorCode = 0;
   *buffer = EOS;
