@@ -1,6 +1,6 @@
 /*
  *
- *  (c) COPYRIGHT INRIA, 1996.
+ *  (c) COPYRIGHT INRIA, 1996-2001
  *  Please first read the full copyright statement in file COPYRIGHT.
  *
  */
@@ -33,7 +33,7 @@
 #include "memory_f.h"
 #include "readpivot_f.h"
 #include "references_f.h"
-#include "schemastr_f.h"
+#include "schemas_f.h"
 #include "search_f.h"
 #include "structmodif_f.h"
 #include "structschema_f.h"
@@ -47,26 +47,14 @@
 
    Changes (or sets) the target of a reference element. The reference element
    must be part of an abstract tree.
-
    Parameters:
    element: the reference element to be set.
    document: the document containing the reference element.
    target : the target element (NULL for resetting the reference).
    targetDocument: the document containing the target element.
-
   ----------------------------------------------------------------------*/
-#ifdef __STDC__
-void                TtaSetReference (Element element, Document document, Element target, Document targetDocument)
-
-#else  /* __STDC__ */
-void                TtaSetReference (element, document, target, targetDocument)
-Element             element;
-Document            document;
-Element             target;
-Document            targetDocument;
-
-#endif /* __STDC__ */
-
+void TtaSetReference (Element element, Document document, Element target,
+		      Document targetDocument)
 {
    PtrDocument         pRefDoc;
    PtrReference       *pRef;
@@ -79,9 +67,7 @@ Document            targetDocument;
    ok = FALSE;
    UserErrorCode = 0;
    if (element == NULL)
-     {
        TtaError (ERR_invalid_parameter);
-     }
    else if (((PtrElement) element)->ElIsCopy)
      {
        ok = TRUE;
@@ -96,21 +82,15 @@ Document            targetDocument;
        pRef = &((PtrElement) element)->ElReference;
      } 
    else
-     {
 	TtaError (ERR_invalid_element_type);
-     }
     
    if (ok)
      {
 	/* checks the parameter document */
 	if (document < 1 || document > MAX_DOCUMENTS)
-	  {
 	     TtaError (ERR_invalid_document_parameter);
-	  }
 	else if (LoadedDocument[document - 1] == NULL)
-	  {
 	     TtaError (ERR_invalid_document_parameter);
-	  }
 	else
 	   /* parameter document is ok */
 	  {
@@ -122,16 +102,11 @@ Document            targetDocument;
 		     DeleteReference (*pRef);
 		  ok = TRUE;
 	       }
-	     else
-		/* checks the parameter targetDocument */
-	     if (targetDocument < 1 || targetDocument > MAX_DOCUMENTS)
-	       {
+	     /* checks the parameter targetDocument */
+	     else if (targetDocument < 1 || targetDocument > MAX_DOCUMENTS)
 		  TtaError (ERR_invalid_document_parameter);
-	       }
 	     else if (LoadedDocument[targetDocument - 1] == NULL)
-	       {
 		  TtaError (ERR_invalid_document_parameter);
-	       }
 	     else
 		/* parameter targetDocument is correct */
 	       {
@@ -160,9 +135,7 @@ Document            targetDocument;
 		  /* the number of characters typed by the user */
 		  LoadedDocument[document - 1]->DocNTypedChars = saveNbCar;
 		  if (!ok)
-		    {
 		       TtaError (ERR_cannot_set_link);
-		    }
 	       }
 #ifndef NODISPLAY
 	     if (ok)
@@ -177,28 +150,14 @@ Document            targetDocument;
    TtaNewInclusion
 
    Creates an inclusion of a given element.
-
    Parameters:
    document: the document for which the inclusion is created.
    target: the element to be included.
    targetDocument: the document containing the element to be included.
-
    Return value:
    the created inclusion.
-
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-Element             TtaNewInclusion (Document document, Element target, Document targetDocument)
-
-#else  /* __STDC__ */
-Element             TtaNewInclusion (document, target, targetDocument)
-Document            document;
-Element             target;
-Document            targetDocument;
-
-#endif /* __STDC__ */
-
+Element TtaNewInclusion (Document document, Element target, Document targetDocument)
 {
    PtrElement          inclusion;
    PtrDocument         pRefDoc;
@@ -208,35 +167,23 @@ Document            targetDocument;
    inclusion = NULL;
    /* checks the parameter document */
    if (document < 1 || document > MAX_DOCUMENTS)
-     {
 	TtaError (ERR_invalid_document_parameter);
-     }
    else if (LoadedDocument[document - 1] == NULL)
-     {
 	TtaError (ERR_invalid_document_parameter);
-     }
-   else
       /* parameter document is ok */
-   if (target == NULL)
-     {
+   else if (target == NULL)
 	TtaError (ERR_invalid_parameter);
-     }
-   else
-      /* checks the parameter targetDocument */
-   if (targetDocument < 1 || targetDocument > MAX_DOCUMENTS)
-     {
+   /* checks the parameter targetDocument */
+   else if (targetDocument < 1 || targetDocument > MAX_DOCUMENTS)
 	TtaError (ERR_invalid_document_parameter);
-     }
    else if (LoadedDocument[targetDocument - 1] == NULL)
-     {
 	TtaError (ERR_invalid_document_parameter);
-     }
    else
       /* parameter targetDocument is ok */
      {
 	inclusion = NewSubtree (((PtrElement) target)->ElTypeNumber,
 				((PtrElement) target)->ElStructSchema,
-				LoadedDocument[document - 1], 0, FALSE,
+				LoadedDocument[document - 1], FALSE,
 				TRUE, TRUE, TRUE);
 	GetReference (&inclusion->ElSource);
 	inclusion->ElSource->RdElement = inclusion;
@@ -255,9 +202,7 @@ Document            targetDocument;
 			LoadedDocument[document - 1], pRefDoc, TRUE, FALSE))
 	   CopyIncludedElem (inclusion, LoadedDocument[document - 1]);
 	else
-	  {
 	     TtaError (ERR_cannot_set_link);
-	  }
 	/* an API function is not supposed to change */
 	/* the number of characters typed by the user */
 	LoadedDocument[document - 1]->DocNTypedChars = saveNbCar;
@@ -271,40 +216,22 @@ Document            targetDocument;
 
    Copies a reference element into another reference element.
    Both reference elements must be in an abstract tree.
-
    Parameters:
    element: the reference element to be set.
    source : the element to be copied.
-
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-void                TtaCopyReference (Element element, Element source, Document document)
-
-#else  /* __STDC__ */
-void                TtaCopyReference (element, source, document)
-Element             element;
-Element             source;
-Document            document;
-#endif /* __STDC__ */
-
+void TtaCopyReference (Element element, Element source, Document document)
 {
 
    UserErrorCode = 0;
    if (element == NULL || source == NULL)
-     {
-	TtaError (ERR_invalid_parameter);
-     }
-   else if (!((PtrElement) element)->ElTerminal ||
+ 	TtaError (ERR_invalid_parameter);
+    else if (!((PtrElement) element)->ElTerminal ||
 	    ((PtrElement) element)->ElLeafType != LtReference)
-     {
-	TtaError (ERR_invalid_element_type);
-     }
-   else if (!((PtrElement) source)->ElTerminal ||
+ 	TtaError (ERR_invalid_element_type);
+    else if (!((PtrElement) source)->ElTerminal ||
 	    ((PtrElement) source)->ElLeafType != LtReference)
-     {
 	TtaError (ERR_invalid_element_type);
-     }
    else
      {
 	CancelReference ((PtrElement) element, LoadedDocument[document -1]);
@@ -323,29 +250,16 @@ Document            document;
    TtaSetAttributeReference
 
    Changes the value of an attribute of type reference
-
    Parameters:
    attribute: the attribute to be changed.
    element: the element with which the attribute is associated.
    document: the document containing the attribute.
    target: the target element (NULL for resetting the reference).
    targetDocument: the document containing the target element.
-
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-void                TtaSetAttributeReference (Attribute attribute, Element element, Document document, Element target, Document targetDocument)
-
-#else  /* __STDC__ */
-void                TtaSetAttributeReference (attribute, element, document, target, targetDocument)
-Attribute           attribute;
-Element             element;
-Document            document;
-Element             target;
-Document            targetDocument;
-
-#endif /* __STDC__ */
-
+void TtaSetAttributeReference (Attribute attribute, Element element,
+			       Document document, Element target,
+			       Document targetDocument)
 {
    PtrDocument         pDoc, pRefDoc;
    PtrReference        ref;
@@ -355,24 +269,16 @@ Document            targetDocument;
 
    UserErrorCode = 0;
    if (attribute == NULL || element == NULL)
-     {
 	TtaError (ERR_invalid_parameter);
-     }
    else if (((PtrAttribute) attribute)->AeAttrType != AtReferenceAttr)
-     {
 	TtaError (ERR_invalid_attribute_type);
-     }
    else
      {
-	/* checks the parameter document */
+       /* checks the parameter document */
 	if (document < 1 || document > MAX_DOCUMENTS)
-	  {
 	     TtaError (ERR_invalid_document_parameter);
-	  }
 	else if (LoadedDocument[document - 1] == NULL)
-	  {
 	     TtaError (ERR_invalid_document_parameter);
-	  }
 	else
 	   /* parameter document is ok */
 	  {
@@ -402,13 +308,9 @@ Document            targetDocument;
 		  /* checks the parameter targetDocument */
 		  ok = FALSE;
 		  if (targetDocument < 1 || targetDocument > MAX_DOCUMENTS)
-		    {
 		       TtaError (ERR_invalid_document_parameter);
-		    }
 		  else if (LoadedDocument[targetDocument - 1] == NULL)
-		    {
 		       TtaError (ERR_invalid_document_parameter);
-		    }
 		  else
 		     /* parameter targetDocument is ok */
 		    {
@@ -463,25 +365,13 @@ Document            targetDocument;
 
    Copies the reference attribute source into the reference attribute attribute.
    Both attributes must be attached to an element in an abstract tree.
-
    Parameters:
    attribute: the reference attribute to be set.
    element: the element to which attribute is attached.
    source : the source attribute.
-
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-void                TtaCopyAttributeReference (Attribute attribute, Element element, Attribute source)
-
-#else  /* __STDC__ */
-void                TtaCopyAttributeReference (attribute, element, source)
-Attribute           attribute;
-Element             element;
-Attribute           source;
-
-#endif /* __STDC__ */
-
+void TtaCopyAttributeReference (Attribute attribute, Element element,
+				Attribute source)
 {
    PtrElement          pEl;
 
@@ -510,22 +400,11 @@ Attribute           source;
    TtaCopyIncludedElem
 
    Up to date the value of inclusion element with the value of its source.
-
    Parameters:
    element: the element to be up to dated.
    document: the document that contains the element.
-
    ---------------------------------------------------------------------- */
-
-#ifdef __STDC__
 void		TtaCopyIncludedElem (Element element, Document document)
-#else  /* __STDC__ */
-void		TtaCopyIncludedElem (element, document)
-Element		element;
-Document	document;
-
-#endif /* __STDC__ */
-
 {
    UserErrorCode = 0;
 
@@ -559,7 +438,6 @@ Document	document;
    another document, are up to date too. In this case, the others documents
    are opened temporarely. If removeExclusions is TRUE, the exclusions
    are removed from the documents opened temporarely.
-
    Parameters:
    document: the document in question.
    loadExternalDoc: TRUE if it is necessary to up to date the inclusions
@@ -567,17 +445,8 @@ Document	document;
    removeExclusions : TRUE if exclusions of external documents have to be
    removed when these ones are temporarely opened.
    ---------------------------------------------------------------------- */
-
-#ifdef __STDC__
-void                TtaUpdateInclusionElements (Document document, ThotBool loadExternalDoc, ThotBool removeExclusions)
-#else  /* __STDC__ */
-void                TtaUpdateInclusionElements (document, loadExternalDoc, removeExclusions)
-Document	document;
-ThotBool		loadExternalDoc;	
-ThotBool		removeExclusions;	
-
-#endif /* __STDC__ */
-
+void TtaUpdateInclusionElements (Document document, ThotBool loadExternalDoc,
+				 ThotBool removeExclusions)
 {
    PtrDocument           pDoc;
 
@@ -605,10 +474,8 @@ ThotBool		removeExclusions;
    TtaGiveReferredElement
 
    Returns the element referred by a given reference element.
-
    Parameter:
    element: the reference element.
-
    Return parameters:
    target: the referred element, or NULL if that element is not
    accessible (empty reference or referred document not open).
@@ -619,21 +486,9 @@ ThotBool		removeExclusions;
    0 if the document containing the referred element is not loaded or
    if the referred element is in the same document as the reference
    element.
-
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-void                TtaGiveReferredElement (Element element, Element * target, STRING targetDocumentName, Document * targetDocument)
-
-#else  /* __STDC__ */
-void                TtaGiveReferredElement (element, target, targetDocumentName, targetDocument)
-Element             element;
-Element            *target;
-STRING              targetDocumentName;
-Document           *targetDocument;
-
-#endif /* __STDC__ */
-
+void TtaGiveReferredElement (Element element, Element *target,
+			     char *targetDocumentName, Document *targetDocument)
 {
    DocumentIdentifier  iDocExt;
    PtrDocument         pDocExt;
@@ -659,7 +514,7 @@ Document           *targetDocument;
 						&iDocExt, &pDocExt);
 	if (!DocIdentIsNull (iDocExt))
 	  {
-	     ustrncpy (targetDocumentName, iDocExt, MAX_DOC_IDENT_LEN);
+	     strncpy (targetDocumentName, iDocExt, MAX_DOC_IDENT_LEN);
 	     targetDocumentName[MAX_DOC_IDENT_LEN - 1] = EOS;
 	  }
 	if (pDocExt != NULL)
@@ -672,38 +527,22 @@ Document           *targetDocument;
    TtaIsElementTypeReference
 
    Indicates whether an element type is a reference.
-
    Parameter:
    elementType: type to be tested.
-
    Return value:
    1 = the type is a reference, 0 = the type is not a reference.
-
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
 int                 TtaIsElementTypeReference (ElementType elementType)
-
-#else  /* __STDC__ */
-int                 TtaIsElementTypeReference (elementType)
-ElementType         elementType;
-
-#endif /* __STDC__ */
-
 {
    int                 result;
 
    UserErrorCode = 0;
    result = 0;
    if (elementType.ElSSchema == NULL)
-     {
 	TtaError (ERR_invalid_parameter);
-     }
    else if (elementType.ElTypeNum > ((PtrSSchema) (elementType.ElSSchema))->SsNRules ||
 	    elementType.ElTypeNum < 1)
-     {
 	TtaError (ERR_invalid_element_type);
-     }
    else
      {
 	if (((PtrSSchema) (elementType.ElSSchema))->SsRule[elementType.ElTypeNum - 1].SrConstruct == CsReference)
@@ -716,26 +555,13 @@ ElementType         elementType;
    TtaSameReferences
 
    Compares two reference elements.
-
    Parameters:
    element1: first reference element.
    element2: second reference element.
-
    Return value:
    0 if both references are different, 1 if they are identical.
-
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-int                 TtaSameReferences (Element element1, Element element2)
-
-#else  /* __STDC__ */
-int                 TtaSameReferences (element1, element2)
-Element             element1;
-Element             element2;
-
-#endif /* __STDC__ */
-
+int TtaSameReferences (Element element1, Element element2)
 {
    int                 result;
    PtrReferredDescr    pRef1, pRef2;
@@ -771,13 +597,13 @@ Element             element2;
 		   /* Internal references */
 		  {
 		     if (pRef1->ReReferredElem != NULL && pRef2->ReReferredElem != NULL)
-			if (ustrcmp (pRef1->ReReferredElem->ElLabel, pRef2->ReReferredElem->ElLabel) == 0)
+			if (strcmp (pRef1->ReReferredElem->ElLabel, pRef2->ReReferredElem->ElLabel) == 0)
 			   result = 1;
 		  }
 		else
 		   /* external references */
-		if (ustrcmp (pRef1->ReReferredLabel, pRef2->ReReferredLabel) == 0)
-		   if (ustrcmp (pRef1->ReExtDocument, pRef2->ReExtDocument) == 0)
+		if (strcmp (pRef1->ReReferredLabel, pRef2->ReReferredLabel) == 0)
+		   if (strcmp (pRef1->ReExtDocument, pRef2->ReExtDocument) == 0)
 		      result = 1;
 	     }
      }
@@ -788,10 +614,8 @@ Element             element2;
    TtaGiveReferenceAttributeValue
 
    Returns the value of a given attribute of type reference
-
    Parameter:
    attribute: the attribute of interest.
-
    Return parameters:
    target: the element referred by the attribute, or NULL
    if that element is not accessible (empty reference or referred
@@ -802,21 +626,10 @@ Element             element2;
    targetDocument: the document containing the referred element;
    0 if the document containing the referred element is not loaded or
    if the referred element is in the same document as the attribute.
-
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-void                TtaGiveReferenceAttributeValue (Attribute attribute, Element * target, STRING targetDocumentName, Document * targetDocument)
-
-#else  /* __STDC__ */
-void                TtaGiveReferenceAttributeValue (attribute, target, targetDocumentName, targetDocument)
-Attribute           attribute;
-Element            *target;
-STRING              targetDocumentName;
-Document           *targetDocument;
-
-#endif /* __STDC__ */
-
+void TtaGiveReferenceAttributeValue (Attribute attribute, Element *target,
+				     char *targetDocumentName,
+				     Document *targetDocument)
 {
    DocumentIdentifier  iDocExt;
    PtrDocument         pDocExt;
@@ -836,7 +649,7 @@ Document           *targetDocument;
 						&iDocExt, &pDocExt);
 	if (!DocIdentIsNull (iDocExt))
 	  {
-	     ustrncpy (targetDocumentName, iDocExt, MAX_DOC_IDENT_LEN);
+	     strncpy (targetDocumentName, iDocExt, MAX_DOC_IDENT_LEN);
 	     targetDocumentName[MAX_DOC_IDENT_LEN - 1] = EOS;
 	  }
 	if (pDocExt != NULL)
@@ -848,34 +661,20 @@ Document           *targetDocument;
    TtaIsElementReferred
 
    Tells whether a given element is the target of a reference or not.
-
    Parameter:
    element: the element.
-
    Return value:
    1 if the element is referred by another element or an
    attribute, 0 if not.
-
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-int                 TtaIsElementReferred (Element element)
-
-#else  /* __STDC__ */
-int                 TtaIsElementReferred (element)
-Element             element;
-
-#endif /* __STDC__ */
-
+int TtaIsElementReferred (Element element)
 {
    int                 result;
 
    UserErrorCode = 0;
    result = 0;
    if (element == NULL)
-     {
 	TtaError (ERR_invalid_parameter);
-     }
    else
      {
 	if (((PtrElement) element)->ElReferredDescr != NULL)
@@ -892,26 +691,13 @@ Element             element;
    TtaSameReferenceAttributes
 
    Compares two reference attributes.
-
    Parameters:
    attribute1: first reference attribute.
    attribute2: second reference attribute.
-
    Return value:
    0 if both references are different, 1 if they are identical.
-
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-int                 TtaSameReferenceAttributes (Attribute attribute1, Attribute attribute2)
-
-#else  /* __STDC__ */
-int                 TtaSameReferenceAttributes (attribute1, attribute2)
-Attribute           attribute1;
-Attribute           attribute2;
-
-#endif /* __STDC__ */
-
+int TtaSameReferenceAttributes (Attribute attribute1, Attribute attribute2)
 {
    int                 result;
    PtrReferredDescr    pRef1, pRef2;
@@ -919,14 +705,10 @@ Attribute           attribute2;
    UserErrorCode = 0;
    result = 0;
    if (attribute1 == NULL || attribute2 == NULL)
-     {
 	TtaError (ERR_invalid_parameter);
-     }
    else if (((PtrAttribute) attribute1)->AeAttrType != AtReferenceAttr ||
 	    ((PtrAttribute) attribute2)->AeAttrType != AtReferenceAttr)
-     {
 	TtaError (ERR_invalid_attribute_type);
-     }
    else
      {
 	if (((PtrAttribute) attribute1)->AeAttrReference != NULL &&
@@ -940,13 +722,13 @@ Attribute           attribute2;
 		   /* Internal references */
 		  {
 		     if (pRef1->ReReferredElem != NULL && pRef2->ReReferredElem != NULL)
-			if (ustrcmp (pRef1->ReReferredElem->ElLabel, pRef1->ReReferredElem->ElLabel) == 0)
+			if (strcmp (pRef1->ReReferredElem->ElLabel, pRef1->ReReferredElem->ElLabel) == 0)
 			   result = 1;
 		  }
 		else
 		   /* External references */
-		if (ustrcmp (pRef1->ReReferredLabel, pRef2->ReReferredLabel) == 0)
-		   if (ustrcmp (pRef1->ReExtDocument, pRef2->ReExtDocument) == 0)
+		if (strcmp (pRef1->ReReferredLabel, pRef2->ReReferredLabel) == 0)
+		   if (strcmp (pRef1->ReExtDocument, pRef2->ReExtDocument) == 0)
 		      result = 1;
 	     }
      }
@@ -958,7 +740,6 @@ Attribute           attribute2;
 
    Searches a reference that has a given element as a target and that
    belongs to a document currently loaded.
-
    Parameters:
    target: the target element.
    targetDocument: the document to which the target element belongs.
@@ -970,7 +751,6 @@ Attribute           attribute2;
    function was an element.
    referenceDocument: document to which the previous reference found belongs;
    Zero if the first reference is searched.
-
    Return parameters:
    referenceAttribute: the reference attribute found. NULL if the reference
    found is an element or if no reference is found.
@@ -980,22 +760,10 @@ Attribute           attribute2;
    and referenceElement are NULL, then no reference has been found.
    referenceDocument: the document to which the reference found belongs.
    Zero if no reference has been found.
-
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-void                TtaNextLoadedReference (Element target, Document targetDocument, Element * referenceElement, Attribute * referenceAttribute, Document * referenceDocument)
-
-#else  /* __STDC__ */
-void                TtaNextLoadedReference (target, targetDocument, referenceElement, referenceAttribute, referenceDocument)
-Element             target;
-Document            targetDocument;
-Element            *referenceElement;
-Attribute          *referenceAttribute;
-Document           *referenceDocument;
-
-#endif /* __STDC__ */
-
+void TtaNextLoadedReference (Element target, Document targetDocument,
+			     Element *referenceElement,
+			     Attribute *referenceAttribute, Document *referenceDocument)
 {
   PtrReference        pRef;
   PtrExternalDoc      pDE;
@@ -1020,6 +788,7 @@ Document           *referenceDocument;
 	  {
 	    *referenceDocument = 0;
 	    if (((PtrElement) target)->ElReferredDescr != NULL)
+	      {
 	      /*  The element has a referenced element descriptor */
 	      if (((PtrElement) target)->ElReferredDescr->ReFirstReference != NULL)
 		/* The element has an internal reference */
@@ -1038,6 +807,7 @@ Document           *referenceDocument;
 		    /* There is an external reference into a loaded document */
 		    *referenceDocument = IdentDocument (pDocRef);
 		}
+	      }
 	  }
 	else
 	  /* Other references were searched for this element o */
@@ -1139,30 +909,17 @@ Document           *referenceDocument;
 
    Returns the name of a document that is not currently loaded and that contains
    references to a given target element.
-
    Parameters:
    target: the target element.
    targetDocument: the document to which the target element belongs.
-   referringDocumentName: name of the previous document found. PcEmpty string
+   referringDocumentName: name of the previous document found. Empty string
    if the first referring document is searched.
-
    Return parameter:
-   referringDocumentName: name of the document found. PcEmpty string if no
+   referringDocumentName: name of the document found. Empty string if no
    referring document has been found.
-
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-void                TtaNextUnloadedReferringDocument (Element target, Document targetDocument, STRING referringDocumentName)
-
-#else  /* __STDC__ */
-void                TtaNextUnloadedReferringDocument (target, targetDocument, referringDocumentName)
-Element             target;
-Document            targetDocument;
-STRING              referringDocumentName;
-
-#endif /* __STDC__ */
-
+void TtaNextUnloadedReferringDocument (Element target, Document targetDocument,
+				       char *referringDocumentName)
 {
    PtrExternalDoc      pDE;
    ThotBool            found;
@@ -1195,7 +952,7 @@ STRING              referringDocumentName;
 	     found = FALSE;
 	     while (pDE != NULL && !found)
 	       {
-		  if (ustrcmp (pDE->EdDocIdent, referringDocumentName) == 0)
+		  if (strcmp (pDE->EdDocIdent, referringDocumentName) == 0)
 		     found = TRUE;
 		  /* Go to the next document */
 		  pDE = pDE->EdNext;
@@ -1217,7 +974,7 @@ STRING              referringDocumentName;
 	if (pDE == NULL)
 	   referringDocumentName[0] = EOS;
 	else
-	   ustrcpy (referringDocumentName, pDE->EdDocIdent);
+	   strcpy (referringDocumentName, pDE->EdDocIdent);
      }
 }
 
@@ -1228,28 +985,15 @@ STRING              referringDocumentName;
    Searches the next reference element.
    Searching can be done in a subtree or starting from a given element towards
    the beginning or the end of the abstract tree.
-
    Parameters:
    scope: SearchForward, SearchBackward or SearchInTree.
    element: the element that is the root of the subtree
    (if scope = SearchInTree) or the starting element
    (if scope = SearchForward or SearchBackward).
-
    Return value:
    the element found, or NULL if not found.
-
   ----------------------------------------------------------------------*/
-
-#ifdef __STDC__
-Element             TtaSearchReferenceElement (SearchDomain scope, Element element)
-
-#else  /* __STDC__ */
-Element             TtaSearchReferenceElement (scope, element)
-SearchDomain        scope;
-Element             element;
-
-#endif /* __STDC__ */
-
+Element TtaSearchReferenceElement (SearchDomain scope, Element element)
 {
    PtrElement          pEl;
    PtrElement          elementFound;
